package com.mywickr.gui;

import android.app.AlertDialog.Builder;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Filter;
import android.widget.ListView;
import android.widget.RadioGroup;
import android.widget.RadioGroup.OnCheckedChangeListener;
import android.widget.TextView;
import com.actionbarsherlock.app.ActionBar;
import com.commonsware.cwac.merge.MergeAdapter;
import com.mywickr.gui.details.ConvoDetailActivity;
import com.mywickr.gui.listadapters.WickrContactBookAdapter;
import com.mywickr.gui.listadapters.WickrContactBookFilterAdapter;
import com.mywickr.gui.listadapters.WickrSearchItemAdapter;
import com.mywickr.gui.listadapters.WickrUserAdapter;
import com.mywickr.gui.listadapters.WickrUserFilterAdapter;
import com.mywickr.helpers.WCInviteMethods;
import com.mywickr.wickr.WickrAPICode;
import com.mywickr.wickr.WickrContactValidator;
import com.mywickr.wickr.WickrConvo;
import com.mywickr.wickr.WickrSearchItem;
import com.mywickr.wickr.WickrUser;
import com.mywickr.wickr.WickrUserValidator;
import com.mywickr.wickr.WickrUserValidatorInterface;
import com.mywickr.wickr.WickrUtil;
import com.mywickr.wickr.contacts.Contact;
import com.mywickr.wickr.contacts.ContactFetcher;
import it.sephiroth.android.library.widget.AdapterView.OnItemLongClickListener;
import it.sephiroth.android.library.widget.HListView;
import java.security.InvalidParameterException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

public class WickrNewConvoActivity extends WickrSherlockListActivity
  implements WickrUserValidatorInterface
{
  private HashMap<WickrSearchItem, WickrUserValidator> activeSearches;
  private WickrContactBookAdapter contactAdapter = null;
  private ContactFetcher contactFetcher = null;
  private WickrContactBookFilterAdapter contactFilterAdapter = null;
  private MergeAdapter contactSearchFilterAdapter = null;
  private ListView contactSearchResultsListView = null;
  private String currentVgroupTag = null;
  private View customSearchTextView;
  private String existingVgroupId;
  private EditText groupNameField = null;
  private WickrUserFilterMode mode;
  private RadioGroup modeSelectionGroup = null;
  private EditText searchField = null;
  private TextView selectedContactsHint;
  private WickrSearchItemAdapter selectedItemsAdapter = null;
  private HListView selectedItemsHorizontalScrollView = null;
  private ArrayList<WickrUser> selectedUsers;
  private Button startButton = null;
  private WickrUserAdapter userAdapter = null;
  private WickrUserFilterAdapter userFilterAdapter = null;

  private void disableStartButton()
  {
    this.startButton.setBackgroundResource(2131034137);
    this.startButton.setAlpha(0.8F);
    this.startButton.setTextColor(-12303292);
    this.startButton.setText("Verifying, Please Wait");
    this.startButton.setEnabled(false);
  }

  private void enableStartButton()
  {
    this.startButton.setAlpha(1.0F);
    this.startButton.setTextColor(-1);
    this.startButton.setBackgroundResource(2130837790);
    this.startButton.setText("Start Conversation");
    this.startButton.setEnabled(true);
  }

  private WickrContactBookAdapter getContactBookAdapter()
  {
    if (this.contactAdapter == null)
      this.contactAdapter = new WickrContactBookAdapter(this.contactFetcher.getContacts(), this);
    return this.contactAdapter;
  }

  private WickrContactBookFilterAdapter getContactBookFilterAdapter()
  {
    if (this.contactFilterAdapter == null)
      this.contactFilterAdapter = new WickrContactBookFilterAdapter(this.contactFetcher.getContacts(), this);
    return this.contactFilterAdapter;
  }

  private WickrUserAdapter getUserAdapter()
  {
    if (this.userAdapter == null)
      this.userAdapter = new WickrUserAdapter(WickrUser.getUserCacheList(), this);
    return this.userAdapter;
  }

  private WickrUserFilterAdapter getUserFilterAdapter()
  {
    if (this.userFilterAdapter == null)
      this.userFilterAdapter = new WickrUserFilterAdapter(WickrUser.getUserCacheList(), this);
    return this.userFilterAdapter;
  }

  private WickrUser getUserFromALias(WickrSearchItem paramWickrSearchItem)
  {
    Iterator localIterator = this.selectedUsers.iterator();
    WickrUser localWickrUser;
    do
    {
      if (!localIterator.hasNext())
        return null;
      localWickrUser = (WickrUser)localIterator.next();
    }
    while (!localWickrUser.getUserAlias().equals(paramWickrSearchItem.getsearchQueryString()));
    return localWickrUser;
  }

  private void setMode(WickrUserFilterMode paramWickrUserFilterMode)
  {
    this.mode = paramWickrUserFilterMode;
    if (this.mode == WickrUserFilterMode.WICKR_FILTER_MODE_USERS)
    {
      getListView().setFastScrollAlwaysVisible(false);
      getListView().setFastScrollEnabled(false);
      setListAdapter(getUserAdapter());
    }
    while (this.mode != WickrUserFilterMode.WICKR_FILTER_MODE_CONTACTS)
      return;
    getListView().setFastScrollAlwaysVisible(true);
    getListView().setFastScrollEnabled(true);
    setListAdapter(getContactBookAdapter());
  }

  private void setUpActionBar()
  {
    getSupportActionBar().setDisplayHomeAsUpEnabled(true);
  }

  private void startConvo()
  {
    try
    {
      String str = WickrConvo.getVGroupIDWithUsers((WickrUser[])this.selectedUsers.toArray(new WickrUser[this.selectedUsers.size()]));
      WickrConvo localWickrConvo = WickrConvo.getConvoWithvGroupID(str);
      if (localWickrConvo == null)
        localWickrConvo = new WickrConvo(str, this.currentVgroupTag, (WickrUser[])this.selectedUsers.toArray(new WickrUser[this.selectedUsers.size()]));
      if (this.selectedUsers.size() > 1)
        localWickrConvo.setVGroupTag(this.groupNameField.getText().toString());
      Intent localIntent = new Intent(this, ConvoDetailActivity.class);
      localIntent.putExtra("con_det_id", localWickrConvo.getID());
      this.navigatingInApp = true;
      finish();
      startActivity(localIntent);
      return;
    }
    catch (InvalidParameterException localInvalidParameterException)
    {
      localInvalidParameterException.printStackTrace();
      WickrUtil.showDialog(this, localInvalidParameterException.getMessage());
      return;
    }
    catch (Exception localException)
    {
      localException.printStackTrace();
      WickrUtil.showDialog(this, "There was an unknown error while creating your conversation. Please try again. If this error persists, please contact Wickr Support");
    }
  }

  public void addUserToConversation(WickrUser paramWickrUser, WickrSearchItem paramWickrSearchItem)
  {
    if (this.selectedUsers.indexOf(paramWickrUser) < 0)
    {
      this.selectedUsers.add(paramWickrUser);
      if (this.activeSearches.isEmpty())
        enableStartButton();
    }
    while (true)
    {
      adjustGroupFieldVisibility();
      return;
      disableStartButton();
      continue;
      this.selectedItemsAdapter.remove(paramWickrSearchItem);
      WickrUtil.showDialog(this, "You have already added " + paramWickrUser.getPrimaryName() + " to the conversation.");
    }
  }

  protected boolean addUserToSelectedItems(WickrSearchItem paramWickrSearchItem)
  {
    if (this.selectedItemsAdapter.getCount() < 9)
    {
      this.selectedItemsAdapter.add(paramWickrSearchItem);
      return true;
    }
    WickrUtil.showDialog(this, "Currently Wickr only allows for groups up to 9 people");
    return false;
  }

  public void adjustGroupFieldVisibility()
  {
    if (this.selectedUsers.size() > 1)
    {
      this.groupNameField.setVisibility(0);
      return;
    }
    this.groupNameField.setText(null);
    this.groupNameField.setVisibility(8);
  }

  protected void onCreate(Bundle paramBundle)
  {
    super.onCreate(paramBundle);
    if (this.hasError)
      return;
    setUpActionBar();
    setContentView(2130903064);
    this.selectedContactsHint = ((TextView)findViewById(2131296349));
    this.startButton = ((Button)findViewById(2131296352));
    this.startButton.setOnClickListener(new View.OnClickListener()
    {
      public void onClick(View paramAnonymousView)
      {
        WickrNewConvoActivity.this.startConvo();
      }
    });
    this.activeSearches = new HashMap();
    this.selectedUsers = new ArrayList();
    this.modeSelectionGroup = ((RadioGroup)findViewById(2131296353));
    this.modeSelectionGroup.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener()
    {
      public void onCheckedChanged(RadioGroup paramAnonymousRadioGroup, int paramAnonymousInt)
      {
        if (paramAnonymousInt == 2131296354)
        {
          WickrNewConvoActivity.this.setMode(WickrNewConvoActivity.WickrUserFilterMode.WICKR_FILTER_MODE_USERS);
          return;
        }
        WickrNewConvoActivity.this.setMode(WickrNewConvoActivity.WickrUserFilterMode.WICKR_FILTER_MODE_CONTACTS);
      }
    });
    this.contactFetcher = new ContactFetcher(this);
    this.groupNameField = ((EditText)findViewById(2131296351));
    this.selectedItemsHorizontalScrollView = ((HListView)findViewById(2131296350));
    this.selectedItemsAdapter = new WickrSearchItemAdapter(this, new ArrayList());
    this.selectedItemsHorizontalScrollView.setAdapter(this.selectedItemsAdapter);
    this.selectedItemsHorizontalScrollView.setOnItemLongClickListener(new AdapterView.OnItemLongClickListener()
    {
      public boolean onItemLongClick(it.sephiroth.android.library.widget.AdapterView<?> paramAnonymousAdapterView, View paramAnonymousView, int paramAnonymousInt, long paramAnonymousLong)
      {
        final WickrSearchItem localWickrSearchItem = (WickrSearchItem)WickrNewConvoActivity.this.selectedItemsAdapter.getItem(paramAnonymousInt);
        AlertDialog.Builder localBuilder = new AlertDialog.Builder(WickrNewConvoActivity.this);
        localBuilder.setTitle("Remove User?");
        localBuilder.setMessage("Are you sure you want to remove " + localWickrSearchItem.getName() + " from the conversation?");
        localBuilder.setCancelable(true);
        localBuilder.setPositiveButton("Remove", new DialogInterface.OnClickListener()
        {
          public void onClick(DialogInterface paramAnonymous2DialogInterface, int paramAnonymous2Int)
          {
            WickrNewConvoActivity.this.removeUserFromConversation(localWickrSearchItem);
            paramAnonymous2DialogInterface.dismiss();
          }
        });
        localBuilder.setNegativeButton("Cancel", new DialogInterface.OnClickListener()
        {
          public void onClick(DialogInterface paramAnonymous2DialogInterface, int paramAnonymous2Int)
          {
            paramAnonymous2DialogInterface.dismiss();
          }
        });
        localBuilder.show();
        return false;
      }
    });
    setMode(WickrUserFilterMode.WICKR_FILTER_MODE_USERS);
    this.customSearchTextView = getLayoutInflater().inflate(2130903094, null);
    ((TextView)this.customSearchTextView.findViewById(2131296447)).setText("Search for WickrID:");
    this.customSearchTextView.setOnClickListener(new View.OnClickListener()
    {
      public void onClick(View paramAnonymousView)
      {
        WickrNewConvoActivity.this.searchForUser(WickrNewConvoActivity.this.searchField.getText().toString());
        WickrNewConvoActivity.this.searchField.setText(null);
      }
    });
    this.contactSearchFilterAdapter = new MergeAdapter();
    this.contactSearchFilterAdapter.addAdapter(getUserFilterAdapter());
    this.contactSearchFilterAdapter.addAdapter(getContactBookFilterAdapter());
    this.contactSearchFilterAdapter.addView(this.customSearchTextView);
    this.contactSearchResultsListView = ((ListView)findViewById(2131296356));
    this.contactSearchResultsListView.setAdapter(this.contactSearchFilterAdapter);
    this.contactSearchResultsListView.setOnItemClickListener(new AdapterView.OnItemClickListener()
    {
      public void onItemClick(android.widget.AdapterView<?> paramAnonymousAdapterView, View paramAnonymousView, int paramAnonymousInt, long paramAnonymousLong)
      {
        switch (WickrNewConvoActivity.this.contactSearchFilterAdapter.getSectionForPosition(paramAnonymousInt))
        {
        default:
        case 0:
        case 1:
        }
        while (true)
        {
          WickrNewConvoActivity.this.searchField.setText(null);
          return;
          WickrUser localWickrUser = (WickrUser)WickrNewConvoActivity.this.contactSearchFilterAdapter.getItem(paramAnonymousInt);
          WickrNewConvoActivity.this.searchForUser(localWickrUser);
          continue;
          Contact localContact = (Contact)WickrNewConvoActivity.this.contactSearchFilterAdapter.getItem(paramAnonymousInt);
          WickrNewConvoActivity.this.searchForContact(localContact);
        }
      }
    });
    ArrayList localArrayList2;
    Iterator localIterator;
    if (getIntent().getExtras() != null)
    {
      ArrayList localArrayList1 = getIntent().getExtras().getStringArrayList("existing_users");
      this.existingVgroupId = getIntent().getExtras().getString("convo_vgroup_id");
      localArrayList2 = new ArrayList();
      localIterator = localArrayList1.iterator();
    }
    while (true)
    {
      if (!localIterator.hasNext())
      {
        adjustGroupFieldVisibility();
        this.searchField = ((EditText)findViewById(2131296347));
        this.searchField.addTextChangedListener(new TextWatcher()
        {
          public void afterTextChanged(Editable paramAnonymousEditable)
          {
            if (paramAnonymousEditable.toString().length() <= 0)
            {
              WickrNewConvoActivity.this.contactSearchResultsListView.setVisibility(8);
              return;
            }
            WickrNewConvoActivity.this.contactSearchResultsListView.setVisibility(0);
          }

          public void beforeTextChanged(CharSequence paramAnonymousCharSequence, int paramAnonymousInt1, int paramAnonymousInt2, int paramAnonymousInt3)
          {
          }

          public void onTextChanged(CharSequence paramAnonymousCharSequence, int paramAnonymousInt1, int paramAnonymousInt2, int paramAnonymousInt3)
          {
            WickrNewConvoActivity.this.userFilterAdapter.getFilter().filter(paramAnonymousCharSequence);
            WickrNewConvoActivity.this.contactFilterAdapter.getFilter().filter(paramAnonymousCharSequence);
            ((TextView)WickrNewConvoActivity.this.customSearchTextView.findViewById(16908308)).setText(paramAnonymousCharSequence);
          }
        });
        return;
      }
      WickrUser localWickrUser = WickrUser.getUserWithID((String)localIterator.next());
      localArrayList2.add(localWickrUser);
      searchForUser(localWickrUser);
    }
  }

  protected void onDestroy()
  {
    Iterator localIterator;
    if (this.activeSearches != null)
      localIterator = this.activeSearches.values().iterator();
    while (true)
    {
      if (!localIterator.hasNext())
      {
        super.onDestroy();
        return;
      }
      WickrUserValidator localWickrUserValidator = (WickrUserValidator)localIterator.next();
      if (localWickrUserValidator != null)
        localWickrUserValidator.cancel();
    }
  }

  protected void onListItemClick(ListView paramListView, View paramView, int paramInt, long paramLong)
  {
    if (this.mode == WickrUserFilterMode.WICKR_FILTER_MODE_USERS)
      searchForUser((WickrUser)this.userAdapter.getItem(paramInt));
    while (true)
    {
      super.onListItemClick(paramListView, paramView, paramInt, paramLong);
      return;
      if (this.mode == WickrUserFilterMode.WICKR_FILTER_MODE_CONTACTS)
        searchForContact((Contact)this.contactAdapter.getItem(paramInt));
    }
  }

  public void removeUserFromConversation(WickrSearchItem paramWickrSearchItem)
  {
    if (paramWickrSearchItem.getRepresentedUser() == null);
    for (WickrUser localWickrUser = getUserFromALias(paramWickrSearchItem); ; localWickrUser = paramWickrSearchItem.getRepresentedUser())
    {
      this.selectedUsers.remove(localWickrUser);
      this.selectedItemsAdapter.remove(paramWickrSearchItem);
      if (this.activeSearches.get(paramWickrSearchItem) != null)
        ((WickrUserValidator)this.activeSearches.get(paramWickrSearchItem)).cancel();
      if (this.selectedItemsAdapter.getCount() == 0)
      {
        this.startButton.setVisibility(8);
        this.selectedContactsHint.setVisibility(0);
      }
      adjustGroupFieldVisibility();
      return;
    }
  }

  protected void searchForContact(Contact paramContact)
  {
    if (!this.selectedItemsAdapter.isDuplicate(paramContact))
    {
      WickrSearchItem localWickrSearchItem = new WickrSearchItem(paramContact);
      if (addUserToSelectedItems(localWickrSearchItem))
      {
        this.selectedContactsHint.setVisibility(8);
        this.startButton.setVisibility(0);
        disableStartButton();
        WickrContactValidator localWickrContactValidator = new WickrContactValidator(this, localWickrSearchItem);
        this.activeSearches.put(localWickrSearchItem, localWickrContactValidator);
        localWickrContactValidator.start();
      }
      return;
    }
    WickrUtil.showDialog(this, "You have already selected " + paramContact.displayName);
  }

  protected void searchForUser(WickrUser paramWickrUser)
  {
    if (!this.selectedItemsAdapter.isDuplicate(paramWickrUser))
    {
      WickrSearchItem localWickrSearchItem = new WickrSearchItem(paramWickrUser);
      if (addUserToSelectedItems(localWickrSearchItem))
      {
        this.selectedContactsHint.setVisibility(8);
        this.startButton.setVisibility(0);
        disableStartButton();
        WickrUserValidator localWickrUserValidator = new WickrUserValidator(this, localWickrSearchItem);
        this.activeSearches.put(localWickrSearchItem, localWickrUserValidator);
        localWickrUserValidator.start();
      }
      return;
    }
    WickrUtil.showDialog(this, "You have already selected " + paramWickrUser.getPrimaryName());
  }

  protected void searchForUser(String paramString)
  {
    if (!this.selectedItemsAdapter.isDuplicate(paramString))
    {
      WickrSearchItem localWickrSearchItem = new WickrSearchItem(paramString);
      if (addUserToSelectedItems(localWickrSearchItem))
      {
        this.selectedContactsHint.setVisibility(8);
        this.startButton.setVisibility(0);
        disableStartButton();
        WickrUserValidator localWickrUserValidator = new WickrUserValidator(this, paramString, localWickrSearchItem);
        this.activeSearches.put(localWickrSearchItem, localWickrUserValidator);
        localWickrUserValidator.start();
      }
      return;
    }
    WickrUtil.showDialog(this, "You have already added " + paramString + " to the conversation");
  }

  public void userValidatorFailedWithError(WickrAPICode paramWickrAPICode, String paramString, WickrUserValidator paramWickrUserValidator)
  {
    WickrSearchItem localWickrSearchItem = paramWickrUserValidator.getSearchItem();
    this.activeSearches.remove(localWickrSearchItem);
    if (paramWickrUserValidator.getSearchItem().getRepresentedContact() != null)
      new WCInviteMethods().showDialog(paramString, localWickrSearchItem, this);
    while (true)
    {
      this.selectedItemsAdapter.remove(localWickrSearchItem);
      if (this.selectedItemsAdapter.getCount() > 0)
        break;
      this.startButton.setVisibility(8);
      return;
      WickrUtil.showDialog(this, paramString);
    }
    if (this.activeSearches.isEmpty())
    {
      enableStartButton();
      return;
    }
    disableStartButton();
  }

  public void userValidatorHasNetworkIssue()
  {
    this.startButton.setText("Verifying (Check Connection)");
  }

  public void userValidatorSuccess(Object paramObject, WickrUserValidator paramWickrUserValidator)
  {
    WickrSearchItem localWickrSearchItem = paramWickrUserValidator.getSearchItem();
    this.activeSearches.remove(localWickrSearchItem);
    if (paramObject.getClass().equals(WickrUser.class))
      addUserToConversation((WickrUser)paramObject, localWickrSearchItem);
    while (!paramObject.getClass().equals([Lcom.mywickr.wickr.WickrUser.class))
      return;
    addUserToConversation(((WickrUser[])paramObject)[0], localWickrSearchItem);
  }

  public static enum WickrUserFilterMode
  {
    static
    {
      WICKR_FILTER_MODE_CONTACTS = new WickrUserFilterMode("WICKR_FILTER_MODE_CONTACTS", 1);
      WickrUserFilterMode[] arrayOfWickrUserFilterMode = new WickrUserFilterMode[2];
      arrayOfWickrUserFilterMode[0] = WICKR_FILTER_MODE_USERS;
      arrayOfWickrUserFilterMode[1] = WICKR_FILTER_MODE_CONTACTS;
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.gui.WickrNewConvoActivity
 * JD-Core Version:    0.6.2
 */