package com.mywickr.gui.fragments;

import android.app.ProgressDialog;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.view.Window;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.ProgressBar;
import android.widget.SeekBar;
import android.widget.SeekBar.OnSeekBarChangeListener;
import android.widget.TextView;
import com.mywickr.interfaces.WickrShredderInterface;
import com.mywickr.services.ShredderService;
import com.mywickr.wickr.WickrSession;
import com.mywickr.wickr.WickrUtil;
import org.jraf.android.backport.switchwidget.Switch;

public class WickrShredderFragment extends WickrSherlockFragment
  implements WickrShredderInterface
{
  private SeekBar afSpeedBar;
  private Switch afStatusSwitch;
  private boolean autoShreddingEnabeled = false;
  private ProgressDialog completingDialog = null;
  private int currentProgress;
  private TextView percentComplete = null;
  private ProgressBar progress = null;
  private ShredderService shredderService = null;
  private Button startButton = null;
  private boolean superShredRunning = false;
  private boolean wantsOut = false;

  public void onActivityCreated(Bundle paramBundle)
  {
    super.onActivityCreated(paramBundle);
    if (this.activityHasError)
      return;
    getActivity().getWindow().addFlags(128);
    this.autoShreddingEnabeled = WickrSession.getActiveSession().isAutoShredderEnabeled();
    this.afSpeedBar = ((SeekBar)getView().findViewById(2131296406));
    this.afStatusSwitch = ((Switch)getView().findViewById(2131296404));
    this.afStatusSwitch.setChecked(WickrSession.getActiveSession().isAutoShredderEnabeled());
    this.afStatusSwitch.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener()
    {
      public void onCheckedChanged(CompoundButton paramAnonymousCompoundButton, boolean paramAnonymousBoolean)
      {
        WickrSession.getActiveSession().setAutoShredderEnabeled(paramAnonymousBoolean);
      }
    });
    this.currentProgress = WickrSession.getActiveSession().getAutoShredderSpeed();
    this.afSpeedBar.setMax(6);
    this.afSpeedBar.setProgress(this.currentProgress);
    this.afSpeedBar.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener()
    {
      public void onProgressChanged(SeekBar paramAnonymousSeekBar, int paramAnonymousInt, boolean paramAnonymousBoolean)
      {
      }

      public void onStartTrackingTouch(SeekBar paramAnonymousSeekBar)
      {
      }

      public void onStopTrackingTouch(SeekBar paramAnonymousSeekBar)
      {
        WickrSession.getActiveSession().setAutoShredderSpeed(paramAnonymousSeekBar.getProgress());
      }
    });
    this.startButton = ((Button)getActivity().findViewById(2131296352));
    this.startButton.setOnClickListener(new View.OnClickListener()
    {
      public void onClick(View paramAnonymousView)
      {
        if (!WickrShredderFragment.this.superShredRunning)
        {
          WickrShredderFragment.this.shredderService = WickrSession.getActiveSession().getShredderService();
          WickrShredderFragment.this.shredderService.setShredderGUI(WickrShredderFragment.this);
          WickrShredderFragment.this.shredderService.doSuperShred();
          return;
        }
        WickrShredderFragment.this.shredderService.cancelSuperShred();
        WickrShredderFragment.this.shredderHasProgress(-1.0F);
      }
    });
    this.progress = ((ProgressBar)getActivity().findViewById(2131296408));
    this.progress.setProgress(0);
    this.progress.setVisibility(8);
    this.percentComplete = ((TextView)getActivity().findViewById(2131296407));
    this.percentComplete.setVisibility(8);
  }

  public boolean onBackPressed()
  {
    if (this.superShredRunning)
    {
      this.shredderService.cancelSuperShred();
      this.wantsOut = true;
      shredderHasProgress(-1.0F);
      return true;
    }
    return false;
  }

  public View onCreateView(LayoutInflater paramLayoutInflater, ViewGroup paramViewGroup, Bundle paramBundle)
  {
    return paramLayoutInflater.inflate(2130903085, paramViewGroup, false);
  }

  public void onDestroy()
  {
    if (this.activityHasError)
    {
      super.onDestroy();
      return;
    }
    getActivity().getWindow().clearFlags(128);
    if (this.activityHasError)
    {
      super.onDestroy();
      return;
    }
    if (!this.autoShreddingEnabeled)
      WickrSession.getActiveSession().setAutoShredderEnabeled(false);
    super.onDestroy();
  }

  public void onPause()
  {
    if (this.activityHasError)
      return;
    if (this.superShredRunning)
    {
      shredderHasProgress(-1.0F);
      this.shredderService.cancelSuperShred();
    }
    super.onPause();
  }

  public void onResume()
  {
    if (this.activityHasError)
      return;
    if ((!this.autoShreddingEnabeled) && (!this.activityHasError))
      WickrSession.getActiveSession().setAutoShredderEnabeled(true);
    super.onResume();
  }

  public void shredderHasEnded(boolean paramBoolean)
  {
    this.percentComplete.setVisibility(8);
    this.progress.setVisibility(8);
    this.progress.setProgress(0);
    this.startButton.setText("Start");
    this.superShredRunning = false;
    this.percentComplete.setText("0.0%");
    if (!paramBoolean)
      WickrUtil.showDialog(getActivity(), "File shredding has completed successfully");
    if ((!this.autoShreddingEnabeled) && (WickrSession.getActiveSession().getShredderService() != null))
      WickrSession.getActiveSession().setAutoShredderEnabeled(false);
    if (this.completingDialog != null)
    {
      if (this.completingDialog.isShowing())
        this.completingDialog.dismiss();
      this.completingDialog = null;
    }
    if (this.wantsOut)
      onBackPressed();
  }

  public void shredderHasProgress(float paramFloat)
  {
    if ((paramFloat >= 99.0D) || (paramFloat == -1.0F))
      if (this.completingDialog == null)
      {
        this.completingDialog = new ProgressDialog(getActivity());
        this.completingDialog.setTitle("File Shredder");
        if (paramFloat != -1.0F)
          break label123;
        this.completingDialog.setMessage("File shredding is canceling. Please be patient");
      }
    while (true)
    {
      if (!this.completingDialog.isShowing())
        this.completingDialog.show();
      if (paramFloat > 0.0F)
      {
        TextView localTextView = this.percentComplete;
        Object[] arrayOfObject = new Object[1];
        arrayOfObject[0] = Float.valueOf(paramFloat);
        localTextView.setText(String.format("%2.1f%%", arrayOfObject));
        this.progress.setProgress((int)paramFloat);
      }
      return;
      label123: this.completingDialog.setMessage("File shredding is almost complete. Please be patient");
    }
  }

  public void shredderHasStarted()
  {
    this.superShredRunning = true;
    this.percentComplete.setVisibility(0);
    this.progress.setVisibility(0);
    this.startButton.setText("Cancel");
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.gui.fragments.WickrShredderFragment
 * JD-Core Version:    0.6.2
 */