package com.mywickr.services;

import android.app.IntentService;
import android.content.Intent;
import android.os.Looper;
import com.loopj.android.http.BinaryHttpResponseHandler;
import com.mywickr.wickr.WickrAPICode;
import com.mywickr.wickr.WickrAccount;
import com.mywickr.wickr.WickrAsyncHttp;
import com.mywickr.wickr.WickrDBAdapter;
import com.mywickr.wickr.WickrRegistrationCtx;
import com.mywickr.wickr.WickrRegistrationReceipt;
import com.mywickr.wickr.WickrUtil;
import org.apache.http.Header;

public class RegistrationService extends IntentService
{
  public static final int NET_ERROR_CODE = -533;
  public static final String PARAM_DEVID = "devid";
  public static final String PARAM_IGNORE_SUSPEND = "ignoreSuspend";
  public static final String PARAM_PASS = "password";
  public static final String PARAM_RESULT = "result";
  public static final String PARAM_SYNC = "isSync";
  public static final String PARAM_TAG = "type";
  public static final String PARAM_USERID = "userid";
  private Intent currIntent = null;
  private WickrAsyncHttp httpClient;
  private WickrRegistrationReceipt receipt = null;
  private WickrRegistrationCtx regCTX = null;

  public RegistrationService()
  {
    super("RegistrationService");
  }

  private void cleanup()
  {
    this.regCTX = null;
    this.receipt = null;
    this.currIntent = null;
  }

  protected void onFailure(Intent paramIntent, WickrAPICode paramWickrAPICode)
  {
    Intent localIntent = new Intent();
    localIntent.setAction("com.mywickr.wickr.REGISTRATION_FAILED");
    localIntent.addCategory("android.intent.category.DEFAULT");
    localIntent.putExtra("result", paramWickrAPICode.getValue());
    sendBroadcast(localIntent);
  }

  protected void onHandleIntent(Intent paramIntent)
  {
    String str1;
    String str2;
    String str4;
    final boolean bool2;
    if (this.currIntent == null)
    {
      this.currIntent = paramIntent;
      str1 = paramIntent.getStringExtra("userid");
      str2 = paramIntent.getStringExtra("password");
      String str3 = paramIntent.getStringExtra("devid");
      str4 = paramIntent.getStringExtra("type");
      boolean bool1 = paramIntent.getBooleanExtra("isSync", false);
      bool2 = paramIntent.getBooleanExtra("ignoreSuspend", false);
      this.regCTX = new WickrRegistrationCtx(str3, bool1);
      this.regCTX.setAppContext(getApplicationContext());
      if (this.regCTX.isErrorState())
      {
        onFailure(paramIntent, new WickrAPICode(9));
        cleanup();
      }
    }
    else
    {
      return;
    }
    this.regCTX.setUsername(str1);
    this.regCTX.setPassword(str2);
    this.regCTX.setDevTag(str4);
    this.regCTX.setDevType("Android");
    this.regCTX.checkForErrors();
    if (this.regCTX.isErrorState())
    {
      onFailure(paramIntent, new WickrAPICode(9));
      cleanup();
      return;
    }
    String str5 = this.regCTX.preRegistrationCheckString();
    if (this.regCTX.isErrorState())
    {
      onFailure(paramIntent, new WickrAPICode(9));
      cleanup();
      return;
    }
    this.httpClient = new WickrAsyncHttp(this, false);
    this.httpClient.setHasRetry(false);
    BinaryHttpResponseHandler local1 = new BinaryHttpResponseHandler(WickrUtil.allowedContentTypes)
    {
      public void onFailure(int paramAnonymousInt, Header[] paramAnonymousArrayOfHeader, byte[] paramAnonymousArrayOfByte, Throwable paramAnonymousThrowable)
      {
        RegistrationService.this.onNetworkIssue(RegistrationService.this.currIntent);
        RegistrationService.this.cleanup();
      }

      public void onSuccess(int paramAnonymousInt, Header[] paramAnonymousArrayOfHeader, byte[] paramAnonymousArrayOfByte)
      {
        WickrAPICode localWickrAPICode = RegistrationService.this.regCTX.processRegistrationCheckResult(paramAnonymousArrayOfByte);
        if ((localWickrAPICode.isError()) && (!bool2))
        {
          RegistrationService.this.onFailure(RegistrationService.this.currIntent, localWickrAPICode);
          RegistrationService.this.cleanup();
          return;
        }
        new RegistrationService.WickrRegistrationThread(RegistrationService.this, null).start();
      }
    };
    this.httpClient.addStringParameters(new String[] { "json_secure", str5 });
    this.httpClient.post("https://secex.info/service/105/src/registerUserCheck.php", local1);
  }

  protected void onNetworkIssue(Intent paramIntent)
  {
    Intent localIntent = new Intent();
    localIntent.setAction("com.mywickr.wickr.REGISTRATION_FAILED");
    localIntent.addCategory("android.intent.category.DEFAULT");
    localIntent.putExtra("result", -533);
    sendBroadcast(localIntent);
  }

  protected void onSuccess(Intent paramIntent)
  {
    Intent localIntent = new Intent();
    localIntent.setAction("com.mywickr.wickr.REGISTRATION_DONE");
    localIntent.addCategory("android.intent.category.DEFAULT");
    sendBroadcast(localIntent);
  }

  private class WickrRegistrationThread extends Thread
  {
    private WickrRegistrationThread()
    {
    }

    public void run()
    {
      Looper.prepare();
      RegistrationService.this.receipt = RegistrationService.this.regCTX.getRegistrationInfo();
      if ((RegistrationService.this.receipt == null) || (RegistrationService.this.regCTX.isErrorState()))
      {
        RegistrationService.this.onFailure(RegistrationService.this.currIntent, new WickrAPICode(9));
        RegistrationService.this.cleanup();
        return;
      }
      BinaryHttpResponseHandler local1 = new BinaryHttpResponseHandler(WickrUtil.allowedContentTypes)
      {
        public void onFailure(int paramAnonymousInt, Header[] paramAnonymousArrayOfHeader, byte[] paramAnonymousArrayOfByte, Throwable paramAnonymousThrowable)
        {
          RegistrationService.this.onNetworkIssue(RegistrationService.this.currIntent);
          RegistrationService.this.cleanup();
        }

        public void onSuccess(int paramAnonymousInt, Header[] paramAnonymousArrayOfHeader, byte[] paramAnonymousArrayOfByte)
        {
          WickrAPICode localWickrAPICode = RegistrationService.this.regCTX.processRegistrationResult(paramAnonymousArrayOfByte);
          if (localWickrAPICode.isError())
          {
            RegistrationService.this.onFailure(RegistrationService.this.currIntent, localWickrAPICode);
            RegistrationService.this.cleanup();
            return;
          }
          String str = WickrUtil.getDBKeyFromPassword(RegistrationService.this.currIntent.getStringExtra("password"), WickrUtil.getDeviceIdentifier(RegistrationService.this.getApplicationContext()));
          if (str == null)
          {
            RegistrationService.this.onFailure(RegistrationService.this.currIntent, new WickrAPICode(9));
            return;
          }
          WickrDBAdapter.initializeDB(RegistrationService.this.getApplicationContext(), str);
          RegistrationService.this.receipt.getAccount().save();
          RegistrationService.this.onSuccess(RegistrationService.this.currIntent);
          RegistrationService.this.cleanup();
        }
      };
      WickrAsyncHttp localWickrAsyncHttp = RegistrationService.this.httpClient;
      String[] arrayOfString = new String[2];
      arrayOfString[0] = "json_secure";
      arrayOfString[1] = RegistrationService.this.receipt.getJson();
      localWickrAsyncHttp.addStringParameters(arrayOfString);
      RegistrationService.this.httpClient.post("https://secex.info/service/105/src/registerUser.php", local1);
      Looper.loop();
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.services.RegistrationService
 * JD-Core Version:    0.6.2
 */