package it.sephiroth.android.library.widget;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.Resources.Theme;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.TransitionDrawable;
import android.os.Build.VERSION;
import android.os.Bundle;
import android.os.Handler;
import android.os.Parcel;
import android.os.Parcelable;
import android.os.Parcelable.Creator;
import android.support.v4.util.LongSparseArray;
import android.support.v4.util.SparseArrayCompat;
import android.support.v4.view.AccessibilityDelegateCompat;
import android.support.v4.view.accessibility.AccessibilityNodeInfoCompat;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseBooleanArray;
import android.util.TypedValue;
import android.view.ActionMode;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.View.BaseSavedState;
import android.view.ViewConfiguration;
import android.view.ViewDebug.ExportedProperty;
import android.view.ViewGroup.LayoutParams;
import android.view.ViewParent;
import android.view.ViewTreeObserver;
import android.view.ViewTreeObserver.OnGlobalLayoutListener;
import android.view.ViewTreeObserver.OnTouchModeChangeListener;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityManager;
import android.view.accessibility.AccessibilityNodeInfo;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputConnection;
import android.widget.Checkable;
import android.widget.ListAdapter;
import it.sephiroth.android.library.util.ViewHelperFactory;
import it.sephiroth.android.library.util.ViewHelperFactory.ViewHelper;
import it.sephiroth.android.library.util.v11.MultiChoiceModeListener;
import it.sephiroth.android.library.util.v11.MultiChoiceModeWrapper;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

@TargetApi(11)
public abstract class AbsHListView extends AdapterView<ListAdapter>
  implements ViewTreeObserver.OnGlobalLayoutListener, ViewTreeObserver.OnTouchModeChangeListener
{
  private static final int CHECK_POSITION_SEARCH_DISTANCE = 20;
  private static final int INVALID_POINTER = -1;
  public static final int LAYOUT_FORCE_LEFT = 1;
  public static final int LAYOUT_FORCE_RIGHT = 3;
  public static final int LAYOUT_MOVE_SELECTION = 6;
  public static final int LAYOUT_NORMAL = 0;
  public static final int LAYOUT_SET_SELECTION = 2;
  public static final int LAYOUT_SPECIFIC = 4;
  public static final int LAYOUT_SYNC = 5;
  protected static final int OVERSCROLL_LIMIT_DIVISOR = 3;
  public static final int[] STATESET_NOTHING = new int[1];
  private static final String TAG = "AbsListView";
  public static final int TOUCH_MODE_DONE_WAITING = 2;
  public static final int TOUCH_MODE_DOWN = 0;
  public static final int TOUCH_MODE_FLING = 4;
  private static final int TOUCH_MODE_OFF = 1;
  private static final int TOUCH_MODE_ON = 0;
  public static final int TOUCH_MODE_OVERFLING = 6;
  public static final int TOUCH_MODE_OVERSCROLL = 5;
  public static final int TOUCH_MODE_REST = -1;
  public static final int TOUCH_MODE_SCROLL = 3;
  public static final int TOUCH_MODE_TAP = 1;
  private static final int TOUCH_MODE_UNKNOWN = -1;
  public static final int TRANSCRIPT_MODE_ALWAYS_SCROLL = 2;
  public static final int TRANSCRIPT_MODE_DISABLED = 0;
  public static final int TRANSCRIPT_MODE_NORMAL = 1;
  static final Interpolator sLinearInterpolator = new LinearInterpolator();
  private ListItemAccessibilityDelegate mAccessibilityDelegate;
  private int mActivePointerId = -1;
  protected ListAdapter mAdapter;
  boolean mAdapterHasStableIds;
  private int mCacheColorHint;
  protected boolean mCachingActive;
  protected boolean mCachingStarted;
  protected SparseBooleanArray mCheckStates;
  LongSparseArray<Integer> mCheckedIdStates;
  int mCheckedItemCount;
  public Object mChoiceActionMode;
  protected int mChoiceMode = 0;
  private Runnable mClearScrollingCache;
  private ContextMenu.ContextMenuInfo mContextMenuInfo = null;
  protected AdapterDataSetObserver mDataSetObserver;
  private int mDirection = 0;
  boolean mDrawSelectorOnTop = false;
  private EdgeEffect mEdgeGlowBottom;
  private EdgeEffect mEdgeGlowTop;
  boolean mFastScrollEnabled;
  private int mFirstPositionDistanceGuess;
  private FlingRunnable mFlingRunnable;
  private boolean mForceTranscriptScroll;
  private int mGlowPaddingBottom;
  private int mGlowPaddingTop;
  protected int mHeightMeasureSpec = 0;
  private float mHorizontalScrollFactor;
  protected boolean mIsAttached;
  private boolean mIsChildViewEnabled;
  protected final boolean[] mIsScrap = new boolean[1];
  private int mLastAccessibilityScrollEventFromIndex;
  private int mLastAccessibilityScrollEventToIndex;
  private int mLastHandledItemCount;
  private int mLastPositionDistanceGuess;
  private int mLastScrollState = 0;
  private int mLastTouchMode = -1;
  int mLastX;
  protected int mLayoutMode = 0;
  protected Rect mListPadding = new Rect();
  private int mMaximumVelocity;
  private int mMinimumVelocity;
  int mMotionCorrection;
  protected int mMotionPosition;
  int mMotionViewNewLeft;
  int mMotionViewOriginalLeft;
  int mMotionX;
  int mMotionY;
  Object mMultiChoiceModeCallback;
  private OnScrollListener mOnScrollListener;
  int mOverflingDistance;
  int mOverscrollDistance;
  protected int mOverscrollMax;
  private CheckForKeyLongPress mPendingCheckForKeyLongPress;
  private CheckForLongPress mPendingCheckForLongPress;
  private Runnable mPendingCheckForTap;
  private SavedState mPendingSync;
  private PerformClick mPerformClick;
  protected Runnable mPositionScrollAfterLayout;
  protected PositionScroller mPositionScroller;
  protected final RecycleBin mRecycler = new RecycleBin();
  protected int mResurrectToPosition = -1;
  View mScrollLeft;
  View mScrollRight;
  boolean mScrollingCacheEnabled;
  protected int mSelectedLeft = 0;
  int mSelectionBottomPadding = 0;
  int mSelectionLeftPadding = 0;
  int mSelectionRightPadding = 0;
  int mSelectionTopPadding = 0;
  Drawable mSelector;
  int mSelectorPosition = -1;
  protected Rect mSelectorRect = new Rect();
  private boolean mSmoothScrollbarEnabled = true;
  protected boolean mStackFromRight;
  private Rect mTouchFrame;
  protected int mTouchMode = -1;
  private Runnable mTouchModeReset;
  private int mTouchSlop;
  private int mTranscriptMode;
  private float mVelocityScale = 1.0F;
  private VelocityTracker mVelocityTracker;
  ViewHelperFactory.ViewHelper mViewHelper;

  public AbsHListView(Context paramContext)
  {
    super(paramContext);
    initAbsListView();
  }

  public AbsHListView(Context paramContext, AttributeSet paramAttributeSet)
  {
    this(paramContext, paramAttributeSet, paramContext.getResources().getIdentifier("sephiroth_absHListViewStyle", "attr", paramContext.getPackageName()));
  }

  public AbsHListView(Context paramContext, AttributeSet paramAttributeSet, int paramInt)
  {
    super(paramContext, paramAttributeSet, paramInt);
    initAbsListView();
    int[] arrayOfInt = (int[])getFieldFromStyleable(paramContext, "AbsHListView");
    TypedArray localTypedArray = null;
    if (arrayOfInt != null)
      localTypedArray = paramContext.obtainStyledAttributes(paramAttributeSet, arrayOfInt, paramInt, 0);
    boolean bool1 = true;
    boolean bool2 = true;
    int i = 0;
    int j = 0;
    boolean bool3 = false;
    Drawable localDrawable = null;
    boolean bool4 = false;
    int k = 0;
    if (localTypedArray != null)
    {
      localDrawable = localTypedArray.getDrawable(0);
      bool3 = localTypedArray.getBoolean(1, false);
      bool4 = localTypedArray.getBoolean(6, false);
      bool1 = localTypedArray.getBoolean(2, true);
      k = localTypedArray.getInt(7, 0);
      j = localTypedArray.getColor(3, 0);
      bool2 = localTypedArray.getBoolean(5, true);
      i = localTypedArray.getInt(4, 0);
      localTypedArray.recycle();
    }
    if (localDrawable != null)
      setSelector(localDrawable);
    this.mDrawSelectorOnTop = bool3;
    setStackFromRight(bool4);
    setScrollingCacheEnabled(bool1);
    setTranscriptMode(k);
    setCacheColorHint(j);
    setSmoothScrollbarEnabled(bool2);
    setChoiceMode(i);
  }

  private void clearScrollingCache()
  {
    if (!this.mViewHelper.isHardwareAccelerated())
    {
      if (this.mClearScrollingCache == null)
        this.mClearScrollingCache = new Runnable()
        {
          public void run()
          {
            if (AbsHListView.this.mCachingStarted)
            {
              AbsHListView localAbsHListView = AbsHListView.this;
              AbsHListView.this.mCachingActive = false;
              localAbsHListView.mCachingStarted = false;
              AbsHListView.this.setChildrenDrawnWithCacheEnabled(false);
              if ((0x2 & AbsHListView.this.getPersistentDrawingCache()) == 0)
                AbsHListView.this.setChildrenDrawingCacheEnabled(false);
              if (!AbsHListView.this.isAlwaysDrawnWithCacheEnabled())
                AbsHListView.this.invalidate();
            }
          }
        };
      post(this.mClearScrollingCache);
    }
  }

  private boolean contentFits()
  {
    int i = getChildCount();
    if (i == 0);
    do
    {
      return true;
      if (i != this.mItemCount)
        return false;
    }
    while ((getChildAt(0).getLeft() >= this.mListPadding.left) && (getChildAt(i - 1).getRight() <= getWidth() - this.mListPadding.right));
    return false;
  }

  private void createScrollingCache()
  {
    if ((this.mScrollingCacheEnabled) && (!this.mCachingStarted) && (!this.mViewHelper.isHardwareAccelerated()))
    {
      setChildrenDrawnWithCacheEnabled(true);
      setChildrenDrawingCacheEnabled(true);
      this.mCachingActive = true;
      this.mCachingStarted = true;
    }
  }

  private void drawSelector(Canvas paramCanvas)
  {
    if (!this.mSelectorRect.isEmpty())
    {
      Drawable localDrawable = this.mSelector;
      localDrawable.setBounds(this.mSelectorRect);
      localDrawable.draw(paramCanvas);
    }
  }

  private void finishGlows()
  {
    if (this.mEdgeGlowTop != null)
    {
      this.mEdgeGlowTop.finish();
      this.mEdgeGlowBottom.finish();
    }
  }

  public static int getDistance(Rect paramRect1, Rect paramRect2, int paramInt)
  {
    int i;
    int j;
    int k;
    int m;
    switch (paramInt)
    {
    default:
      throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT, FOCUS_FORWARD, FOCUS_BACKWARD}.");
    case 66:
      i = paramRect1.right;
      j = paramRect1.top + paramRect1.height() / 2;
      k = paramRect2.left;
      m = paramRect2.top + paramRect2.height() / 2;
    case 130:
    case 17:
    case 33:
    case 1:
    case 2:
    }
    while (true)
    {
      int n = k - i;
      int i1 = m - j;
      return i1 * i1 + n * n;
      i = paramRect1.left + paramRect1.width() / 2;
      j = paramRect1.bottom;
      k = paramRect2.left + paramRect2.width() / 2;
      m = paramRect2.top;
      continue;
      i = paramRect1.left;
      j = paramRect1.top + paramRect1.height() / 2;
      k = paramRect2.right;
      m = paramRect2.top + paramRect2.height() / 2;
      continue;
      i = paramRect1.left + paramRect1.width() / 2;
      j = paramRect1.top;
      k = paramRect2.left + paramRect2.width() / 2;
      m = paramRect2.bottom;
      continue;
      i = paramRect1.right + paramRect1.width() / 2;
      j = paramRect1.top + paramRect1.height() / 2;
      k = paramRect2.left + paramRect2.width() / 2;
      m = paramRect2.top + paramRect2.height() / 2;
    }
  }

  public static final <T> T getFieldFromStyleable(Context paramContext, String paramString)
  {
    try
    {
      Field localField = Class.forName(paramContext.getPackageName() + ".R$styleable").getField(paramString);
      Object localObject1 = null;
      if (localField != null)
      {
        Object localObject2 = localField.get(null);
        localObject1 = localObject2;
      }
      return localObject1;
    }
    catch (Throwable localThrowable)
    {
      localThrowable.printStackTrace();
    }
    return null;
  }

  private void initAbsListView()
  {
    setClickable(true);
    setFocusableInTouchMode(true);
    setWillNotDraw(false);
    setAlwaysDrawnWithCacheEnabled(false);
    setScrollingCacheEnabled(true);
    ViewConfiguration localViewConfiguration = ViewConfiguration.get(getContext());
    this.mTouchSlop = localViewConfiguration.getScaledTouchSlop();
    this.mMinimumVelocity = localViewConfiguration.getScaledMinimumFlingVelocity();
    this.mMaximumVelocity = localViewConfiguration.getScaledMaximumFlingVelocity();
    this.mOverscrollDistance = localViewConfiguration.getScaledOverscrollDistance();
    this.mOverflingDistance = localViewConfiguration.getScaledOverflingDistance();
    this.mViewHelper = ViewHelperFactory.create(this);
  }

  private void initOrResetVelocityTracker()
  {
    if (this.mVelocityTracker == null)
    {
      this.mVelocityTracker = VelocityTracker.obtain();
      return;
    }
    this.mVelocityTracker.clear();
  }

  private void initVelocityTrackerIfNotExists()
  {
    if (this.mVelocityTracker == null)
      this.mVelocityTracker = VelocityTracker.obtain();
  }

  private void onSecondaryPointerUp(MotionEvent paramMotionEvent)
  {
    int i = (0xFF00 & paramMotionEvent.getAction()) >> 8;
    if (paramMotionEvent.getPointerId(i) == this.mActivePointerId)
      if (i != 0)
        break label65;
    label65: for (int j = 1; ; j = 0)
    {
      this.mMotionX = ((int)paramMotionEvent.getX(j));
      this.mMotionY = ((int)paramMotionEvent.getY(j));
      this.mMotionCorrection = 0;
      this.mActivePointerId = paramMotionEvent.getPointerId(j);
      return;
    }
  }

  private void positionSelector(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    this.mSelectorRect.set(paramInt1 - this.mSelectionLeftPadding, paramInt2 - this.mSelectionTopPadding, paramInt3 + this.mSelectionRightPadding, paramInt4 + this.mSelectionBottomPadding);
  }

  private void recycleVelocityTracker()
  {
    if (this.mVelocityTracker != null)
    {
      this.mVelocityTracker.recycle();
      this.mVelocityTracker = null;
    }
  }

  static View retrieveFromScrap(ArrayList<View> paramArrayList, int paramInt)
  {
    int i = paramArrayList.size();
    if (i > 0)
      for (int j = 0; ; j++)
      {
        if (j >= i)
          return (View)paramArrayList.remove(i - 1);
        View localView = (View)paramArrayList.get(j);
        if (((LayoutParams)localView.getLayoutParams()).scrappedFromPosition == paramInt)
        {
          paramArrayList.remove(j);
          return localView;
        }
      }
    return null;
  }

  private void scrollIfNeeded(int paramInt)
  {
    int i = paramInt - this.mMotionX;
    int j = i - this.mMotionCorrection;
    int k;
    if (this.mLastX != -2147483648)
    {
      k = paramInt - this.mLastX;
      if (this.mTouchMode != 3)
        break label387;
      if (paramInt != this.mLastX)
      {
        if (Math.abs(i) > this.mTouchSlop)
        {
          localViewParent = getParent();
          if (localViewParent != null)
            localViewParent.requestDisallowInterceptTouchEvent(true);
        }
        if (this.mMotionPosition < 0)
          break label324;
        i7 = this.mMotionPosition - this.mFirstPosition;
        localView2 = getChildAt(i7);
        i8 = 0;
        if (localView2 != null)
          i8 = localView2.getLeft();
        bool = false;
        if (k != 0)
          bool = trackMotionScroll(j, k);
        localView3 = getChildAt(i7);
        if (localView3 != null)
        {
          i9 = localView3.getLeft();
          if (bool)
          {
            i10 = -k - (i9 - i8);
            overScrollBy(i10, 0, getScrollX(), 0, 0, 0, this.mOverscrollDistance, 0, true);
            if ((Math.abs(this.mOverscrollDistance) == Math.abs(getScrollX())) && (this.mVelocityTracker != null))
              this.mVelocityTracker.clear();
            i11 = getOverScrollMode();
            if ((i11 == 0) || ((i11 == 1) && (!contentFits())))
            {
              this.mDirection = 0;
              this.mTouchMode = 5;
              if (i <= 0)
                break label335;
              this.mEdgeGlowTop.onPull(i10 / getWidth());
              if (!this.mEdgeGlowBottom.isFinished())
                this.mEdgeGlowBottom.onRelease();
              invalidate(this.mEdgeGlowTop.getBounds(false));
            }
          }
          this.mMotionX = paramInt;
        }
        this.mLastX = paramInt;
      }
    }
    label324: label335: 
    while ((this.mTouchMode != 5) || (paramInt == this.mLastX))
      while (true)
      {
        ViewParent localViewParent;
        View localView2;
        int i8;
        boolean bool;
        View localView3;
        int i9;
        int i10;
        int i11;
        return;
        k = j;
        break;
        int i7 = getChildCount() / 2;
        continue;
        if (i < 0)
        {
          this.mEdgeGlowBottom.onPull(i10 / getWidth());
          if (!this.mEdgeGlowTop.isFinished())
            this.mEdgeGlowTop.onRelease();
          invalidate(this.mEdgeGlowBottom.getBounds(true));
        }
      }
    label387: int m = getScrollX();
    int n = m - k;
    int i1;
    int i2;
    int i3;
    label477: int i4;
    label576: View localView1;
    if (paramInt > this.mLastX)
    {
      i1 = 1;
      if (this.mDirection == 0)
        this.mDirection = i1;
      i2 = -k;
      if (((n >= 0) || (m < 0)) && ((n <= 0) || (m > 0)))
        break label686;
      i2 = -m;
      i3 = k + i2;
      if (i2 != 0)
      {
        overScrollBy(i2, 0, getScrollX(), 0, 0, 0, this.mOverscrollDistance, 0, true);
        int i6 = getOverScrollMode();
        if ((i6 == 0) || ((i6 == 1) && (!contentFits())))
        {
          if (i <= 0)
            break label692;
          this.mEdgeGlowTop.onPull(i2 / getWidth());
          if (!this.mEdgeGlowBottom.isFinished())
            this.mEdgeGlowBottom.onRelease();
          invalidate(this.mEdgeGlowTop.getBounds(false));
        }
      }
      if (i3 != 0)
      {
        if (getScrollX() != 0)
        {
          this.mViewHelper.setScrollX(0);
          invalidateParentIfNeeded();
        }
        trackMotionScroll(i3, i3);
        this.mTouchMode = 3;
        i4 = findClosestMotionCol(paramInt);
        this.mMotionCorrection = 0;
        localView1 = getChildAt(i4 - this.mFirstPosition);
        if (localView1 == null)
          break label744;
      }
    }
    label686: label692: label744: for (int i5 = localView1.getLeft(); ; i5 = 0)
    {
      this.mMotionViewOriginalLeft = i5;
      this.mMotionX = paramInt;
      this.mMotionPosition = i4;
      this.mLastX = paramInt;
      this.mDirection = i1;
      return;
      i1 = -1;
      break;
      i3 = 0;
      break label477;
      if (i >= 0)
        break label576;
      this.mEdgeGlowBottom.onPull(i2 / getWidth());
      if (!this.mEdgeGlowTop.isFinished())
        this.mEdgeGlowTop.onRelease();
      invalidate(this.mEdgeGlowBottom.getBounds(true));
      break label576;
    }
  }

  private boolean startScrollIfNeeded(int paramInt)
  {
    int i = paramInt - this.mMotionX;
    int j = Math.abs(i);
    int k;
    if (getScrollX() != 0)
      k = 1;
    while ((k != 0) || (j > this.mTouchSlop))
    {
      createScrollingCache();
      if (k != 0)
      {
        this.mTouchMode = 5;
        this.mMotionCorrection = 0;
        Handler localHandler = getHandler();
        if (localHandler != null)
          localHandler.removeCallbacks(this.mPendingCheckForLongPress);
        setPressed(false);
        View localView = getChildAt(this.mMotionPosition - this.mFirstPosition);
        if (localView != null)
          localView.setPressed(false);
        reportScrollStateChange(1);
        ViewParent localViewParent = getParent();
        if (localViewParent != null)
          localViewParent.requestDisallowInterceptTouchEvent(true);
        scrollIfNeeded(paramInt);
        return true;
        k = 0;
      }
      else
      {
        this.mTouchMode = 3;
        if (i > 0);
        for (int m = this.mTouchSlop; ; m = -this.mTouchSlop)
        {
          this.mMotionCorrection = m;
          break;
        }
      }
    }
    return false;
  }

  private void updateOnScreenCheckedViews()
  {
    int i = this.mFirstPosition;
    int j = getChildCount();
    if (Build.VERSION.SDK_INT >= 11);
    int m;
    for (int k = 1; ; k = 0)
    {
      m = 0;
      if (m < j)
        break;
      return;
    }
    View localView = getChildAt(m);
    int n = i + m;
    if ((localView instanceof Checkable))
      ((Checkable)localView).setChecked(this.mCheckStates.get(n));
    while (true)
    {
      m++;
      break;
      if (k != 0)
        localView.setActivated(this.mCheckStates.get(n));
    }
  }

  private void useDefaultSelector()
  {
    setSelector(getResources().getDrawable(17301602));
  }

  public void addTouchables(ArrayList<View> paramArrayList)
  {
    int i = getChildCount();
    int j = this.mFirstPosition;
    ListAdapter localListAdapter = this.mAdapter;
    if (localListAdapter == null);
    while (true)
    {
      return;
      for (int k = 0; k < i; k++)
      {
        View localView = getChildAt(k);
        if (localListAdapter.isEnabled(j + k))
          paramArrayList.add(localView);
        localView.addTouchables(paramArrayList);
      }
    }
  }

  public boolean checkInputConnectionProxy(View paramView)
  {
    return false;
  }

  protected boolean checkLayoutParams(ViewGroup.LayoutParams paramLayoutParams)
  {
    return paramLayoutParams instanceof LayoutParams;
  }

  public void clearChoices()
  {
    if (this.mCheckStates != null)
      this.mCheckStates.clear();
    if (this.mCheckedIdStates != null)
      this.mCheckedIdStates.clear();
    this.mCheckedItemCount = 0;
  }

  protected int computeHorizontalScrollExtent()
  {
    int i = getChildCount();
    if (i > 0)
    {
      if (this.mSmoothScrollbarEnabled)
      {
        int j = i * 100;
        View localView1 = getChildAt(0);
        int k = localView1.getLeft();
        int m = localView1.getWidth();
        if (m > 0)
          j += k * 100 / m;
        View localView2 = getChildAt(i - 1);
        int n = localView2.getRight();
        int i1 = localView2.getWidth();
        if (i1 > 0)
          j -= 100 * (n - getWidth()) / i1;
        return j;
      }
      return 1;
    }
    return 0;
  }

  protected int computeHorizontalScrollOffset()
  {
    int i = this.mFirstPosition;
    int j = getChildCount();
    int k = 0;
    if (i >= 0)
    {
      k = 0;
      if (j > 0)
      {
        if (!this.mSmoothScrollbarEnabled)
          break label100;
        View localView = getChildAt(0);
        int i1 = localView.getLeft();
        int i2 = localView.getWidth();
        k = 0;
        if (i2 > 0)
          k = Math.max(i * 100 - i1 * 100 / i2 + (int)(100.0F * (getScrollX() / getWidth() * this.mItemCount)), 0);
      }
    }
    return k;
    label100: int m = this.mItemCount;
    int n;
    if (i == 0)
      n = 0;
    while (true)
    {
      return (int)(i + j * (n / m));
      if (i + j == m)
        n = m;
      else
        n = i + j / 2;
    }
  }

  protected int computeHorizontalScrollRange()
  {
    if (this.mSmoothScrollbarEnabled)
    {
      int i = Math.max(100 * this.mItemCount, 0);
      if (getScrollX() != 0)
        i += Math.abs((int)(100.0F * (getScrollX() / getWidth() * this.mItemCount)));
      return i;
    }
    return this.mItemCount;
  }

  @TargetApi(16)
  void confirmCheckedPositionsById()
  {
    this.mCheckStates.clear();
    int i = 0;
    int j = 0;
    if (j >= this.mCheckedIdStates.size())
    {
      if ((i != 0) && (this.mChoiceActionMode != null))
        ((ActionMode)this.mChoiceActionMode).invalidate();
      return;
    }
    long l = this.mCheckedIdStates.keyAt(j);
    int k = ((Integer)this.mCheckedIdStates.valueAt(j)).intValue();
    int i1;
    label114: int i2;
    if (l != this.mAdapter.getItemId(k))
    {
      int m = Math.max(0, k - 20);
      int n = Math.min(k + 20, this.mItemCount);
      i1 = m;
      i2 = 0;
      if (i1 >= n)
        label124: if (i2 == 0)
        {
          this.mCheckedIdStates.delete(l);
          j--;
          this.mCheckedItemCount = (-1 + this.mCheckedItemCount);
          i = 1;
          if ((Build.VERSION.SDK_INT > 11) && (this.mChoiceActionMode != null) && (this.mMultiChoiceModeCallback != null))
            ((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback).onItemCheckedStateChanged((ActionMode)this.mChoiceActionMode, k, l, false);
        }
    }
    while (true)
    {
      j++;
      break;
      if (l == this.mAdapter.getItemId(i1))
      {
        i2 = 1;
        this.mCheckStates.put(i1, true);
        this.mCheckedIdStates.setValueAt(j, Integer.valueOf(i1));
        break label124;
      }
      i1++;
      break label114;
      this.mCheckStates.put(k, true);
    }
  }

  ContextMenu.ContextMenuInfo createContextMenuInfo(View paramView, int paramInt, long paramLong)
  {
    return new AdapterView.AdapterContextMenuInfo(paramView, paramInt, paramLong);
  }

  protected void dispatchDraw(Canvas paramCanvas)
  {
    boolean bool = this.mDrawSelectorOnTop;
    if (!bool)
      drawSelector(paramCanvas);
    super.dispatchDraw(paramCanvas);
    if (bool)
      drawSelector(paramCanvas);
  }

  protected void dispatchSetPressed(boolean paramBoolean)
  {
  }

  public void draw(Canvas paramCanvas)
  {
    super.draw(paramCanvas);
    if (this.mEdgeGlowTop != null)
    {
      int i = getScrollX();
      if (!this.mEdgeGlowTop.isFinished())
      {
        int i2 = paramCanvas.save();
        int i3 = this.mListPadding.top + this.mGlowPaddingTop;
        int i4 = this.mListPadding.bottom + this.mGlowPaddingBottom;
        int i5 = getHeight() - i3 - i4;
        getWidth();
        int i6 = Math.min(0, i + this.mFirstPositionDistanceGuess);
        paramCanvas.rotate(-90.0F);
        paramCanvas.translate(i3 + -getHeight(), i6);
        this.mEdgeGlowTop.setSize(i5, i5);
        if (this.mEdgeGlowTop.draw(paramCanvas))
        {
          this.mEdgeGlowTop.setPosition(i6, i3);
          invalidate();
        }
        paramCanvas.restoreToCount(i2);
      }
      if (!this.mEdgeGlowBottom.isFinished())
      {
        int j = paramCanvas.save();
        int k = this.mListPadding.left + this.mGlowPaddingTop;
        int m = this.mListPadding.right + this.mGlowPaddingBottom;
        int n = getHeight() - k - m;
        int i1 = Math.max(getWidth(), i + this.mLastPositionDistanceGuess);
        paramCanvas.rotate(90.0F);
        paramCanvas.translate(-k, -i1);
        this.mEdgeGlowBottom.setSize(n, n);
        if (this.mEdgeGlowBottom.draw(paramCanvas))
          invalidate();
        paramCanvas.restoreToCount(j);
      }
    }
  }

  protected void drawableStateChanged()
  {
    super.drawableStateChanged();
    updateSelectorState();
  }

  protected abstract void fillGap(boolean paramBoolean);

  protected int findClosestMotionCol(int paramInt)
  {
    int i = getChildCount();
    int j;
    if (i == 0)
      j = -1;
    do
    {
      return j;
      j = findMotionCol(paramInt);
    }
    while (j != -1);
    return -1 + (i + this.mFirstPosition);
  }

  protected abstract int findMotionCol(int paramInt);

  protected ViewGroup.LayoutParams generateDefaultLayoutParams()
  {
    return new LayoutParams(-2, -1, 0);
  }

  protected ViewGroup.LayoutParams generateLayoutParams(ViewGroup.LayoutParams paramLayoutParams)
  {
    return new LayoutParams(paramLayoutParams);
  }

  public LayoutParams generateLayoutParams(AttributeSet paramAttributeSet)
  {
    return new LayoutParams(getContext(), paramAttributeSet);
  }

  @ViewDebug.ExportedProperty(category="drawing")
  public int getCacheColorHint()
  {
    return this.mCacheColorHint;
  }

  public int getCheckedItemCount()
  {
    return this.mCheckedItemCount;
  }

  public long[] getCheckedItemIds()
  {
    long[] arrayOfLong;
    if ((this.mChoiceMode == 0) || (this.mCheckedIdStates == null) || (this.mAdapter == null))
      arrayOfLong = new long[0];
    while (true)
    {
      return arrayOfLong;
      LongSparseArray localLongSparseArray = this.mCheckedIdStates;
      int i = localLongSparseArray.size();
      arrayOfLong = new long[i];
      for (int j = 0; j < i; j++)
        arrayOfLong[j] = localLongSparseArray.keyAt(j);
    }
  }

  public int getCheckedItemPosition()
  {
    if ((this.mChoiceMode == 1) && (this.mCheckStates != null) && (this.mCheckStates.size() == 1))
      return this.mCheckStates.keyAt(0);
    return -1;
  }

  public SparseBooleanArray getCheckedItemPositions()
  {
    if (this.mChoiceMode != 0)
      return this.mCheckStates;
    return null;
  }

  public int getChoiceMode()
  {
    return this.mChoiceMode;
  }

  protected ContextMenu.ContextMenuInfo getContextMenuInfo()
  {
    return this.mContextMenuInfo;
  }

  public void getFocusedRect(Rect paramRect)
  {
    View localView = getSelectedView();
    if ((localView != null) && (localView.getParent() == this))
    {
      localView.getFocusedRect(paramRect);
      offsetDescendantRectToMyCoords(localView, paramRect);
      return;
    }
    super.getFocusedRect(paramRect);
  }

  protected int getFooterViewsCount()
  {
    return 0;
  }

  protected int getHeaderViewsCount()
  {
    return 0;
  }

  protected float getHorizontalScrollFactor()
  {
    if (this.mHorizontalScrollFactor == 0.0F)
    {
      int i = getResources().getIdentifier("sephiroth_listPreferredItemWidth", "attr", getContext().getPackageName());
      if (i == 0)
        break label91;
      TypedValue localTypedValue = new TypedValue();
      if (getContext().getTheme().resolveAttribute(i, localTypedValue, true))
        this.mHorizontalScrollFactor = localTypedValue.getDimension(getContext().getResources().getDisplayMetrics());
    }
    else
    {
      return this.mHorizontalScrollFactor;
    }
    throw new IllegalStateException("Expected theme to define sephiroth_listPreferredItemWidth.");
    label91: throw new IllegalStateException("Expected theme to define sephiroth_listPreferredItemWidth.");
  }

  protected int getHorizontalScrollbarHeight()
  {
    return super.getHorizontalScrollbarHeight();
  }

  protected float getLeftFadingEdgeStrength()
  {
    int i = getChildCount();
    float f1 = super.getLeftFadingEdgeStrength();
    if (i == 0);
    int j;
    float f2;
    do
    {
      return f1;
      if (this.mFirstPosition > 0)
        return 1.0F;
      j = getChildAt(0).getLeft();
      f2 = getHorizontalFadingEdgeLength();
    }
    while (j >= getPaddingLeft());
    return -(j - getPaddingLeft()) / f2;
  }

  public int getListPaddingBottom()
  {
    return this.mListPadding.bottom;
  }

  public int getListPaddingLeft()
  {
    return this.mListPadding.left;
  }

  public int getListPaddingRight()
  {
    return this.mListPadding.right;
  }

  public int getListPaddingTop()
  {
    return this.mListPadding.top;
  }

  protected float getRightFadingEdgeStrength()
  {
    int i = getChildCount();
    float f1 = super.getRightFadingEdgeStrength();
    if (i == 0);
    int j;
    int k;
    float f2;
    do
    {
      return f1;
      if (-1 + (i + this.mFirstPosition) < -1 + this.mItemCount)
        return 1.0F;
      j = getChildAt(i - 1).getRight();
      k = getWidth();
      f2 = getHorizontalFadingEdgeLength();
    }
    while (j <= k - getPaddingRight());
    return (j - k + getPaddingRight()) / f2;
  }

  @ViewDebug.ExportedProperty
  public View getSelectedView()
  {
    if ((this.mItemCount > 0) && (this.mSelectedPosition >= 0))
      return getChildAt(this.mSelectedPosition - this.mFirstPosition);
    return null;
  }

  public Drawable getSelector()
  {
    return this.mSelector;
  }

  public int getSolidColor()
  {
    return this.mCacheColorHint;
  }

  public int getTranscriptMode()
  {
    return this.mTranscriptMode;
  }

  protected void handleDataChanged()
  {
    int i = 3;
    int j = this.mItemCount;
    int k = this.mLastHandledItemCount;
    this.mLastHandledItemCount = this.mItemCount;
    if ((Build.VERSION.SDK_INT >= 16) && (this.mChoiceMode != 0) && (this.mAdapter != null) && (this.mAdapter.hasStableIds()))
      confirmCheckedPositionsById();
    this.mRecycler.clearTransientStateViews();
    if (j > 0)
    {
      if (this.mNeedSync)
      {
        this.mNeedSync = false;
        this.mPendingSync = null;
        if (this.mTranscriptMode == 2)
          this.mLayoutMode = i;
      }
      do
      {
        return;
        if (this.mTranscriptMode == 1)
        {
          if (this.mForceTranscriptScroll)
          {
            this.mForceTranscriptScroll = false;
            this.mLayoutMode = i;
            return;
          }
          int i3 = getChildCount();
          int i4 = getWidth() - getPaddingRight();
          View localView = getChildAt(i3 - 1);
          if (localView != null);
          for (int i5 = localView.getBottom(); (i3 + this.mFirstPosition >= k) && (i5 <= i4); i5 = i4)
          {
            this.mLayoutMode = i;
            return;
          }
          awakenScrollBars();
        }
        switch (this.mSyncMode)
        {
        default:
        case 0:
        case 1:
        }
        while (!isInTouchMode())
        {
          int m = getSelectedItemPosition();
          if (m >= j)
            m = j - 1;
          if (m < 0)
            m = 0;
          int n = lookForSelectablePosition(m, true);
          if (n >= 0)
          {
            setNextSelectedPositionInt(n);
            return;
            if (isInTouchMode())
            {
              this.mLayoutMode = 5;
              this.mSyncPosition = Math.min(Math.max(0, this.mSyncPosition), j - 1);
              return;
            }
            int i2 = findSyncPosition();
            if ((i2 >= 0) && (lookForSelectablePosition(i2, true) == i2))
            {
              this.mSyncPosition = i2;
              if (this.mSyncWidth == getWidth());
              for (this.mLayoutMode = 5; ; this.mLayoutMode = 2)
              {
                setNextSelectedPositionInt(i2);
                return;
              }
              this.mLayoutMode = 5;
              this.mSyncPosition = Math.min(Math.max(0, this.mSyncPosition), j - 1);
            }
          }
          else
          {
            int i1 = lookForSelectablePosition(m, false);
            if (i1 < 0)
              break label426;
            setNextSelectedPositionInt(i1);
            return;
          }
        }
      }
      while (this.mResurrectToPosition >= 0);
    }
    label426: if (this.mStackFromRight);
    while (true)
    {
      this.mLayoutMode = i;
      this.mSelectedPosition = -1;
      this.mSelectedColId = -9223372036854775808L;
      this.mNextSelectedPosition = -1;
      this.mNextSelectedColId = -9223372036854775808L;
      this.mNeedSync = false;
      this.mPendingSync = null;
      this.mSelectorPosition = -1;
      checkSelectionChanged();
      return;
      i = 1;
    }
  }

  protected void hideSelector()
  {
    if (this.mSelectedPosition != -1)
    {
      if (this.mLayoutMode != 4)
        this.mResurrectToPosition = this.mSelectedPosition;
      if ((this.mNextSelectedPosition >= 0) && (this.mNextSelectedPosition != this.mSelectedPosition))
        this.mResurrectToPosition = this.mNextSelectedPosition;
      setSelectedPositionInt(-1);
      setNextSelectedPositionInt(-1);
      this.mSelectedLeft = 0;
    }
  }

  @TargetApi(11)
  protected void invalidateParentIfNeeded()
  {
    if ((this.mViewHelper.isHardwareAccelerated()) && ((getParent() instanceof View)))
      ((View)getParent()).invalidate();
  }

  public void invalidateViews()
  {
    this.mDataChanged = true;
    rememberSyncState();
    requestLayout();
    invalidate();
  }

  protected void invokeOnItemScrollListener()
  {
    if (this.mOnScrollListener != null)
      this.mOnScrollListener.onScroll(this, this.mFirstPosition, getChildCount(), this.mItemCount);
    onScrollChanged(0, 0, 0, 0);
  }

  public boolean isItemChecked(int paramInt)
  {
    if ((this.mChoiceMode != 0) && (this.mCheckStates != null))
      return this.mCheckStates.get(paramInt);
    return false;
  }

  @ViewDebug.ExportedProperty
  public boolean isScrollingCacheEnabled()
  {
    return this.mScrollingCacheEnabled;
  }

  @ViewDebug.ExportedProperty
  public boolean isSmoothScrollbarEnabled()
  {
    return this.mSmoothScrollbarEnabled;
  }

  public boolean isStackFromRight()
  {
    return this.mStackFromRight;
  }

  @TargetApi(11)
  public void jumpDrawablesToCurrentState()
  {
    super.jumpDrawablesToCurrentState();
    if (this.mSelector != null)
      this.mSelector.jumpToCurrentState();
  }

  protected void keyPressed()
  {
    if ((!isEnabled()) || (!isClickable()));
    while (true)
    {
      return;
      Drawable localDrawable1 = this.mSelector;
      Rect localRect = this.mSelectorRect;
      if ((localDrawable1 != null) && ((isFocused()) || (touchModeDrawsInPressedState())) && (!localRect.isEmpty()))
      {
        View localView = getChildAt(this.mSelectedPosition - this.mFirstPosition);
        if (localView != null)
        {
          if (!localView.hasFocusable())
            localView.setPressed(true);
        }
        else
        {
          setPressed(true);
          boolean bool = isLongClickable();
          Drawable localDrawable2 = localDrawable1.getCurrent();
          if ((localDrawable2 != null) && ((localDrawable2 instanceof TransitionDrawable)))
          {
            if (!bool)
              break label179;
            ((TransitionDrawable)localDrawable2).startTransition(ViewConfiguration.getLongPressTimeout());
          }
          while ((bool) && (!this.mDataChanged))
          {
            if (this.mPendingCheckForKeyLongPress == null)
              this.mPendingCheckForKeyLongPress = new CheckForKeyLongPress(null);
            this.mPendingCheckForKeyLongPress.rememberWindowAttachCount();
            postDelayed(this.mPendingCheckForKeyLongPress, ViewConfiguration.getLongPressTimeout());
            return;
            label179: ((TransitionDrawable)localDrawable2).resetTransition();
          }
        }
      }
    }
  }

  protected void layoutChildren()
  {
  }

  @SuppressLint({"NewApi"})
  protected View obtainView(int paramInt, boolean[] paramArrayOfBoolean)
  {
    paramArrayOfBoolean[0] = false;
    View localView1 = this.mRecycler.getTransientStateView(paramInt);
    View localView3;
    if (localView1 != null)
    {
      localView3 = localView1;
      return localView3;
    }
    View localView2 = this.mRecycler.getScrapView(paramInt);
    label108: ViewGroup.LayoutParams localLayoutParams;
    LayoutParams localLayoutParams1;
    if (localView2 != null)
    {
      localView3 = this.mAdapter.getView(paramInt, localView2, this);
      if ((Build.VERSION.SDK_INT >= 16) && (localView3.getImportantForAccessibility() == 0))
        localView3.setImportantForAccessibility(1);
      if (localView3 != localView2)
      {
        this.mRecycler.addScrapView(localView2, paramInt);
        if (this.mCacheColorHint != 0)
          localView3.setDrawingCacheBackgroundColor(this.mCacheColorHint);
        if (this.mAdapterHasStableIds)
        {
          localLayoutParams = localView3.getLayoutParams();
          if (localLayoutParams != null)
            break label257;
          localLayoutParams1 = (LayoutParams)generateDefaultLayoutParams();
        }
      }
    }
    while (true)
    {
      localLayoutParams1.itemId = this.mAdapter.getItemId(paramInt);
      localView3.setLayoutParams(localLayoutParams1);
      if ((!this.mAccessibilityManager.isEnabled()) || (this.mAccessibilityDelegate != null))
        break;
      this.mAccessibilityDelegate = new ListItemAccessibilityDelegate();
      return localView3;
      paramArrayOfBoolean[0] = true;
      localView3.onFinishTemporaryDetach();
      break label108;
      localView3 = this.mAdapter.getView(paramInt, null, this);
      if ((Build.VERSION.SDK_INT >= 16) && (localView3.getImportantForAccessibility() == 0))
        localView3.setImportantForAccessibility(1);
      if (this.mCacheColorHint == 0)
        break label108;
      localView3.setDrawingCacheBackgroundColor(this.mCacheColorHint);
      break label108;
      label257: if (!checkLayoutParams(localLayoutParams))
        localLayoutParams1 = (LayoutParams)generateLayoutParams(localLayoutParams);
      else
        localLayoutParams1 = (LayoutParams)localLayoutParams;
    }
  }

  public void offsetChildrenLeftAndRight(int paramInt)
  {
    int i = getChildCount();
    for (int j = 0; ; j++)
    {
      if (j >= i)
        return;
      getChildAt(j).offsetLeftAndRight(paramInt);
    }
  }

  protected void onAttachedToWindow()
  {
    super.onAttachedToWindow();
    getViewTreeObserver().addOnTouchModeChangeListener(this);
    if ((this.mAdapter != null) && (this.mDataSetObserver == null))
    {
      this.mDataSetObserver = new AdapterDataSetObserver();
      this.mAdapter.registerDataSetObserver(this.mDataSetObserver);
      this.mDataChanged = true;
      this.mOldItemCount = this.mItemCount;
      this.mItemCount = this.mAdapter.getCount();
    }
    this.mIsAttached = true;
  }

  protected int[] onCreateDrawableState(int paramInt)
  {
    if (this.mIsChildViewEnabled)
    {
      arrayOfInt = super.onCreateDrawableState(paramInt);
      return arrayOfInt;
    }
    int i = ENABLED_STATE_SET[0];
    int[] arrayOfInt = super.onCreateDrawableState(paramInt + 1);
    int j = -1;
    label83: for (int k = -1 + arrayOfInt.length; ; k--)
    {
      if (k < 0);
      while (j >= 0)
      {
        System.arraycopy(arrayOfInt, j + 1, arrayOfInt, j, -1 + (arrayOfInt.length - j));
        return arrayOfInt;
        if (arrayOfInt[k] != i)
          break label83;
        j = k;
      }
      break;
    }
  }

  public InputConnection onCreateInputConnection(EditorInfo paramEditorInfo)
  {
    return null;
  }

  protected void onDetachedFromWindow()
  {
    super.onDetachedFromWindow();
    this.mRecycler.clear();
    getViewTreeObserver().removeOnTouchModeChangeListener(this);
    if ((this.mAdapter != null) && (this.mDataSetObserver != null))
    {
      this.mAdapter.unregisterDataSetObserver(this.mDataSetObserver);
      this.mDataSetObserver = null;
    }
    if (this.mFlingRunnable != null)
      removeCallbacks(this.mFlingRunnable);
    if (this.mPositionScroller != null)
      this.mPositionScroller.stop();
    if (this.mClearScrollingCache != null)
      removeCallbacks(this.mClearScrollingCache);
    if (this.mPerformClick != null)
      removeCallbacks(this.mPerformClick);
    if (this.mTouchModeReset != null)
    {
      removeCallbacks(this.mTouchModeReset);
      this.mTouchModeReset = null;
    }
    this.mIsAttached = false;
  }

  protected void onFocusChanged(boolean paramBoolean, int paramInt, Rect paramRect)
  {
    super.onFocusChanged(paramBoolean, paramInt, paramRect);
    if ((paramBoolean) && (this.mSelectedPosition < 0) && (!isInTouchMode()))
    {
      if ((!this.mIsAttached) && (this.mAdapter != null))
      {
        this.mDataChanged = true;
        this.mOldItemCount = this.mItemCount;
        this.mItemCount = this.mAdapter.getCount();
      }
      resurrectSelection();
    }
  }

  @TargetApi(12)
  public boolean onGenericMotionEvent(MotionEvent paramMotionEvent)
  {
    if ((0x2 & paramMotionEvent.getSource()) != 0)
      switch (paramMotionEvent.getAction())
      {
      default:
      case 8:
      }
    int i;
    do
    {
      float f;
      do
      {
        do
          return super.onGenericMotionEvent(paramMotionEvent);
        while (this.mTouchMode != -1);
        f = paramMotionEvent.getAxisValue(10);
      }
      while (f == 0.0F);
      i = (int)(f * getHorizontalScrollFactor());
    }
    while (trackMotionScroll(i, i));
    return true;
  }

  public void onInitializeAccessibilityEvent(AccessibilityEvent paramAccessibilityEvent)
  {
    super.onInitializeAccessibilityEvent(paramAccessibilityEvent);
    paramAccessibilityEvent.setClassName(AbsHListView.class.getName());
  }

  @TargetApi(14)
  public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo paramAccessibilityNodeInfo)
  {
    super.onInitializeAccessibilityNodeInfo(paramAccessibilityNodeInfo);
    paramAccessibilityNodeInfo.setClassName(AbsHListView.class.getName());
    if (isEnabled())
    {
      if (getFirstVisiblePosition() > 0)
        paramAccessibilityNodeInfo.addAction(8192);
      if (getLastVisiblePosition() < -1 + getCount())
        paramAccessibilityNodeInfo.addAction(4096);
    }
  }

  public boolean onInterceptTouchEvent(MotionEvent paramMotionEvent)
  {
    int i = paramMotionEvent.getAction();
    if (this.mPositionScroller != null)
      this.mPositionScroller.stop();
    if (!this.mIsAttached);
    int k;
    do
    {
      int m;
      do
      {
        return false;
        switch (i & 0xFF)
        {
        case 4:
        case 5:
        default:
          return false;
        case 0:
          m = this.mTouchMode;
          if ((m == 6) || (m == 5))
          {
            this.mMotionCorrection = 0;
            return true;
          }
          int n = (int)paramMotionEvent.getX();
          int i1 = (int)paramMotionEvent.getY();
          this.mActivePointerId = paramMotionEvent.getPointerId(0);
          int i2 = findMotionCol(n);
          if ((m != 4) && (i2 >= 0))
          {
            this.mMotionViewOriginalLeft = getChildAt(i2 - this.mFirstPosition).getLeft();
            this.mMotionX = n;
            this.mMotionY = i1;
            this.mMotionPosition = i2;
            this.mTouchMode = 0;
            clearScrollingCache();
          }
          this.mLastX = -2147483648;
          initOrResetVelocityTracker();
          this.mVelocityTracker.addMovement(paramMotionEvent);
        case 2:
        case 1:
        case 3:
        case 6:
        }
      }
      while (m != 4);
      return true;
      switch (this.mTouchMode)
      {
      default:
        return false;
      case 0:
      }
      int j = paramMotionEvent.findPointerIndex(this.mActivePointerId);
      if (j == -1)
      {
        j = 0;
        this.mActivePointerId = paramMotionEvent.getPointerId(0);
      }
      k = (int)paramMotionEvent.getX(j);
      initVelocityTrackerIfNotExists();
      this.mVelocityTracker.addMovement(paramMotionEvent);
    }
    while (!startScrollIfNeeded(k));
    return true;
    this.mTouchMode = -1;
    this.mActivePointerId = -1;
    recycleVelocityTracker();
    reportScrollStateChange(0);
    return false;
    onSecondaryPointerUp(paramMotionEvent);
    return false;
  }

  public boolean onKeyDown(int paramInt, KeyEvent paramKeyEvent)
  {
    return false;
  }

  public boolean onKeyUp(int paramInt, KeyEvent paramKeyEvent)
  {
    boolean bool = true;
    switch (paramInt)
    {
    default:
    case 23:
    case 66:
    }
    do
    {
      bool = super.onKeyUp(paramInt, paramKeyEvent);
      do
        return bool;
      while (!isEnabled());
    }
    while ((!isClickable()) || (!isPressed()) || (this.mSelectedPosition < 0) || (this.mAdapter == null) || (this.mSelectedPosition >= this.mAdapter.getCount()));
    View localView = getChildAt(this.mSelectedPosition - this.mFirstPosition);
    if (localView != null)
    {
      performItemClick(localView, this.mSelectedPosition, this.mSelectedColId);
      localView.setPressed(false);
    }
    setPressed(false);
    return bool;
  }

  protected void onLayout(boolean paramBoolean, int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    super.onLayout(paramBoolean, paramInt1, paramInt2, paramInt3, paramInt4);
    this.mInLayout = true;
    int i;
    if (paramBoolean)
      i = getChildCount();
    for (int j = 0; ; j++)
    {
      if (j >= i)
      {
        this.mRecycler.markChildrenDirty();
        layoutChildren();
        this.mInLayout = false;
        this.mOverscrollMax = ((paramInt3 - paramInt1) / 3);
        return;
      }
      getChildAt(j).forceLayout();
    }
  }

  protected void onMeasure(int paramInt1, int paramInt2)
  {
    int i = 1;
    if (this.mSelector == null)
      useDefaultSelector();
    Rect localRect = this.mListPadding;
    localRect.left = (this.mSelectionLeftPadding + getPaddingLeft());
    localRect.top = (this.mSelectionTopPadding + getPaddingTop());
    localRect.right = (this.mSelectionRightPadding + getPaddingRight());
    localRect.bottom = (this.mSelectionBottomPadding + getPaddingBottom());
    int k;
    int m;
    if (this.mTranscriptMode == i)
    {
      int j = getChildCount();
      k = getWidth() - getPaddingRight();
      View localView = getChildAt(j - 1);
      if (localView == null)
        break label149;
      m = localView.getRight();
      if ((j + this.mFirstPosition < this.mLastHandledItemCount) || (m > k))
        break label156;
    }
    while (true)
    {
      this.mForceTranscriptScroll = i;
      return;
      label149: m = k;
      break;
      label156: i = 0;
    }
  }

  protected void onOverScrolled(int paramInt1, int paramInt2, boolean paramBoolean1, boolean paramBoolean2)
  {
    if (getScrollX() != paramInt1)
    {
      onScrollChanged(paramInt1, getScrollY(), getScrollX(), getScrollY());
      this.mViewHelper.setScrollX(paramInt1);
      invalidateParentIfNeeded();
      awakenScrollBars();
    }
  }

  public void onRestoreInstanceState(Parcelable paramParcelable)
  {
    SavedState localSavedState = (SavedState)paramParcelable;
    super.onRestoreInstanceState(localSavedState.getSuperState());
    this.mDataChanged = true;
    this.mSyncWidth = localSavedState.width;
    if (localSavedState.selectedId >= 0L)
    {
      this.mNeedSync = true;
      this.mPendingSync = localSavedState;
      this.mSyncColId = localSavedState.selectedId;
      this.mSyncPosition = localSavedState.position;
      this.mSpecificLeft = localSavedState.viewLeft;
      this.mSyncMode = 0;
    }
    while (true)
    {
      if (localSavedState.checkState != null)
        this.mCheckStates = localSavedState.checkState;
      if (localSavedState.checkIdState != null)
        this.mCheckedIdStates = localSavedState.checkIdState;
      this.mCheckedItemCount = localSavedState.checkedItemCount;
      if ((Build.VERSION.SDK_INT >= 11) && (localSavedState.inActionMode) && (this.mChoiceMode == 3) && (this.mMultiChoiceModeCallback != null))
        this.mChoiceActionMode = startActionMode((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback);
      requestLayout();
      return;
      if (localSavedState.firstId >= 0L)
      {
        setSelectedPositionInt(-1);
        setNextSelectedPositionInt(-1);
        this.mSelectorPosition = -1;
        this.mNeedSync = true;
        this.mPendingSync = localSavedState;
        this.mSyncColId = localSavedState.firstId;
        this.mSyncPosition = localSavedState.position;
        this.mSpecificLeft = localSavedState.viewLeft;
        this.mSyncMode = 1;
      }
    }
  }

  public Parcelable onSaveInstanceState()
  {
    SavedState localSavedState = new SavedState(super.onSaveInstanceState());
    if (this.mPendingSync != null)
    {
      localSavedState.selectedId = this.mPendingSync.selectedId;
      localSavedState.firstId = this.mPendingSync.firstId;
      localSavedState.viewLeft = this.mPendingSync.viewLeft;
      localSavedState.position = this.mPendingSync.position;
      localSavedState.width = this.mPendingSync.width;
      localSavedState.filter = this.mPendingSync.filter;
      localSavedState.inActionMode = this.mPendingSync.inActionMode;
      localSavedState.checkedItemCount = this.mPendingSync.checkedItemCount;
      localSavedState.checkState = this.mPendingSync.checkState;
      localSavedState.checkIdState = this.mPendingSync.checkIdState;
      return localSavedState;
    }
    int i;
    if ((getChildCount() > 0) && (this.mItemCount > 0))
      i = 1;
    while (true)
    {
      long l = getSelectedItemId();
      localSavedState.selectedId = l;
      localSavedState.width = getWidth();
      label194: boolean bool;
      if (l >= 0L)
      {
        localSavedState.viewLeft = this.mSelectedLeft;
        localSavedState.position = getSelectedItemPosition();
        localSavedState.firstId = -1L;
        localSavedState.filter = null;
        if ((Build.VERSION.SDK_INT < 11) || (this.mChoiceMode != 3) || (this.mChoiceActionMode == null))
          break label395;
        bool = true;
        localSavedState.inActionMode = bool;
        if (this.mCheckStates == null);
      }
      try
      {
        localSavedState.checkState = this.mCheckStates.clone();
        if (this.mCheckedIdStates != null)
        {
          localLongSparseArray = new LongSparseArray();
          int j = this.mCheckedIdStates.size();
          k = 0;
          if (k >= j)
            localSavedState.checkIdState = localLongSparseArray;
        }
        else
        {
          localSavedState.checkedItemCount = this.mCheckedItemCount;
          return localSavedState;
          i = 0;
          continue;
          if ((i != 0) && (this.mFirstPosition > 0))
          {
            localSavedState.viewLeft = getChildAt(0).getLeft();
            int m = this.mFirstPosition;
            if (m >= this.mItemCount)
              m = -1 + this.mItemCount;
            localSavedState.position = m;
            localSavedState.firstId = this.mAdapter.getItemId(m);
            break label194;
          }
          localSavedState.viewLeft = 0;
          localSavedState.firstId = -1L;
          localSavedState.position = 0;
          break label194;
          label395: bool = false;
        }
      }
      catch (NoSuchMethodError localNoSuchMethodError)
      {
        while (true)
        {
          LongSparseArray localLongSparseArray;
          int k;
          localNoSuchMethodError.printStackTrace();
          localSavedState.checkState = new SparseBooleanArray();
          continue;
          localLongSparseArray.put(this.mCheckedIdStates.keyAt(k), (Integer)this.mCheckedIdStates.valueAt(k));
          k++;
        }
      }
    }
  }

  protected void onSizeChanged(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    if (getChildCount() > 0)
    {
      this.mDataChanged = true;
      rememberSyncState();
    }
  }

  public boolean onTouchEvent(MotionEvent paramMotionEvent)
  {
    if (!isEnabled())
      return (isClickable()) || (isLongClickable());
    if (this.mPositionScroller != null)
      this.mPositionScroller.stop();
    if (!this.mIsAttached)
      return false;
    int i = paramMotionEvent.getAction();
    initVelocityTrackerIfNotExists();
    this.mVelocityTracker.addMovement(paramMotionEvent);
    switch (i & 0xFF)
    {
    case 4:
    default:
    case 0:
    case 2:
    case 1:
    case 3:
    case 6:
    case 5:
    }
    while (true)
    {
      return true;
      int i16;
      int i17;
      int i18;
      switch (this.mTouchMode)
      {
      default:
        this.mActivePointerId = paramMotionEvent.getPointerId(0);
        i16 = (int)paramMotionEvent.getX();
        i17 = (int)paramMotionEvent.getY();
        i18 = pointToPosition(i16, i17);
        if (!this.mDataChanged)
        {
          if ((this.mTouchMode == 4) || (i18 < 0) || (!((ListAdapter)getAdapter()).isEnabled(i18)))
            break label398;
          this.mTouchMode = 0;
          if (this.mPendingCheckForTap == null)
          {
            CheckForTap localCheckForTap = new CheckForTap();
            this.mPendingCheckForTap = localCheckForTap;
          }
          postDelayed(this.mPendingCheckForTap, ViewConfiguration.getTapTimeout());
        }
        break;
      case 6:
      }
      while (true)
      {
        if (i18 >= 0)
          this.mMotionViewOriginalLeft = getChildAt(i18 - this.mFirstPosition).getLeft();
        this.mMotionX = i16;
        this.mMotionY = i17;
        this.mMotionPosition = i18;
        this.mLastX = -2147483648;
        while ((performButtonActionOnTouchDown(paramMotionEvent)) && (this.mTouchMode == 0))
        {
          removeCallbacks(this.mPendingCheckForTap);
          break;
          this.mFlingRunnable.endFling();
          if (this.mPositionScroller != null)
            this.mPositionScroller.stop();
          this.mTouchMode = 5;
          this.mMotionY = ((int)paramMotionEvent.getY());
          int i15 = (int)paramMotionEvent.getX();
          this.mLastX = i15;
          this.mMotionX = i15;
          this.mMotionCorrection = 0;
          this.mActivePointerId = paramMotionEvent.getPointerId(0);
          this.mDirection = 0;
        }
        label398: if (this.mTouchMode == 4)
        {
          createScrollingCache();
          this.mTouchMode = 3;
          this.mMotionCorrection = 0;
          i18 = findMotionCol(i16);
          this.mFlingRunnable.flywheelTouch();
        }
      }
      int i13 = paramMotionEvent.findPointerIndex(this.mActivePointerId);
      if (i13 == -1)
      {
        i13 = 0;
        this.mActivePointerId = paramMotionEvent.getPointerId(0);
      }
      int i14 = (int)paramMotionEvent.getX(i13);
      if (this.mDataChanged)
        layoutChildren();
      switch (this.mTouchMode)
      {
      case 4:
      default:
        break;
      case 0:
      case 1:
      case 2:
        startScrollIfNeeded(i14);
        break;
      case 3:
      case 5:
        scrollIfNeeded(i14);
        continue;
        switch (this.mTouchMode)
        {
        case 4:
        default:
        case 0:
        case 1:
        case 2:
        case 3:
        case 5:
        }
        while (true)
        {
          setPressed(false);
          if (this.mEdgeGlowTop != null)
          {
            this.mEdgeGlowTop.onRelease();
            this.mEdgeGlowBottom.onRelease();
          }
          invalidate();
          Handler localHandler2 = getHandler();
          if (localHandler2 != null)
            localHandler2.removeCallbacks(this.mPendingCheckForLongPress);
          recycleVelocityTracker();
          this.mActivePointerId = -1;
          break;
          int i11 = this.mMotionPosition;
          final View localView2 = getChildAt(i11 - this.mFirstPosition);
          float f = paramMotionEvent.getX();
          int i12;
          final PerformClick localPerformClick2;
          Object localObject;
          if ((f > this.mListPadding.left) && (f < getWidth() - this.mListPadding.right))
          {
            i12 = 1;
            if ((localView2 == null) || (localView2.hasFocusable()) || (i12 == 0))
              break label1045;
            if (this.mTouchMode != 0)
              localView2.setPressed(false);
            if (this.mPerformClick == null)
            {
              PerformClick localPerformClick1 = new PerformClick(null);
              this.mPerformClick = localPerformClick1;
            }
            localPerformClick2 = this.mPerformClick;
            localPerformClick2.mClickMotionPosition = i11;
            localPerformClick2.rememberWindowAttachCount();
            this.mResurrectToPosition = i11;
            if ((this.mTouchMode != 0) && (this.mTouchMode != 1))
              break label1019;
            Handler localHandler3 = getHandler();
            if (localHandler3 != null)
            {
              if (this.mTouchMode != 0)
                break label998;
              localObject = this.mPendingCheckForTap;
              label833: localHandler3.removeCallbacks((Runnable)localObject);
            }
            this.mLayoutMode = 0;
            if ((this.mDataChanged) || (!this.mAdapter.isEnabled(i11)))
              break label1007;
            this.mTouchMode = 1;
            setSelectedPositionInt(this.mMotionPosition);
            layoutChildren();
            localView2.setPressed(true);
            positionSelector(this.mMotionPosition, localView2);
            setPressed(true);
            if (this.mSelector != null)
            {
              Drawable localDrawable = this.mSelector.getCurrent();
              if ((localDrawable != null) && ((localDrawable instanceof TransitionDrawable)))
                ((TransitionDrawable)localDrawable).resetTransition();
            }
            if (this.mTouchModeReset != null)
              removeCallbacks(this.mTouchModeReset);
            Runnable local1 = new Runnable()
            {
              public void run()
              {
                AbsHListView.this.mTouchMode = -1;
                localView2.setPressed(false);
                AbsHListView.this.setPressed(false);
                if (!AbsHListView.this.mDataChanged)
                  localPerformClick2.run();
              }
            };
            this.mTouchModeReset = local1;
            postDelayed(this.mTouchModeReset, ViewConfiguration.getPressedStateDuration());
          }
          while (true)
          {
            return true;
            i12 = 0;
            break;
            label998: localObject = this.mPendingCheckForLongPress;
            break label833;
            label1007: this.mTouchMode = -1;
            updateSelectorState();
          }
          label1019: if ((!this.mDataChanged) && (this.mAdapter.isEnabled(i11)))
            localPerformClick2.run();
          label1045: this.mTouchMode = -1;
          updateSelectorState();
          continue;
          int i5 = getChildCount();
          if (i5 > 0)
          {
            int i6 = getChildAt(0).getLeft();
            int i7 = getChildAt(i5 - 1).getRight();
            int i8 = this.mListPadding.left;
            int i9 = getWidth() - this.mListPadding.right;
            if ((this.mFirstPosition == 0) && (i6 >= i8) && (i5 + this.mFirstPosition < this.mItemCount) && (i7 <= getWidth() - i9))
            {
              this.mTouchMode = -1;
              reportScrollStateChange(0);
            }
            else
            {
              VelocityTracker localVelocityTracker2 = this.mVelocityTracker;
              localVelocityTracker2.computeCurrentVelocity(1000, this.mMaximumVelocity);
              int i10 = (int)(localVelocityTracker2.getXVelocity(this.mActivePointerId) * this.mVelocityScale);
              if ((Math.abs(i10) > this.mMinimumVelocity) && ((this.mFirstPosition != 0) || (i6 != i8 - this.mOverscrollDistance)) && ((i5 + this.mFirstPosition != this.mItemCount) || (i7 != i9 + this.mOverscrollDistance)))
              {
                if (this.mFlingRunnable == null)
                {
                  FlingRunnable localFlingRunnable3 = new FlingRunnable();
                  this.mFlingRunnable = localFlingRunnable3;
                }
                reportScrollStateChange(2);
                this.mFlingRunnable.start(-i10);
              }
              else
              {
                this.mTouchMode = -1;
                reportScrollStateChange(0);
                if (this.mFlingRunnable != null)
                  this.mFlingRunnable.endFling();
                if (this.mPositionScroller != null)
                  this.mPositionScroller.stop();
              }
            }
          }
          else
          {
            this.mTouchMode = -1;
            reportScrollStateChange(0);
            continue;
            if (this.mFlingRunnable == null)
            {
              FlingRunnable localFlingRunnable2 = new FlingRunnable();
              this.mFlingRunnable = localFlingRunnable2;
            }
            VelocityTracker localVelocityTracker1 = this.mVelocityTracker;
            localVelocityTracker1.computeCurrentVelocity(1000, this.mMaximumVelocity);
            int i4 = (int)localVelocityTracker1.getXVelocity(this.mActivePointerId);
            reportScrollStateChange(2);
            if (Math.abs(i4) > this.mMinimumVelocity)
              this.mFlingRunnable.startOverfling(-i4);
            else
              this.mFlingRunnable.startSpringback();
          }
        }
        switch (this.mTouchMode)
        {
        default:
          this.mTouchMode = -1;
          setPressed(false);
          View localView1 = getChildAt(this.mMotionPosition - this.mFirstPosition);
          if (localView1 != null)
            localView1.setPressed(false);
          clearScrollingCache();
          Handler localHandler1 = getHandler();
          if (localHandler1 != null)
            localHandler1.removeCallbacks(this.mPendingCheckForLongPress);
          recycleVelocityTracker();
        case 6:
        case 5:
        }
        while (true)
        {
          if (this.mEdgeGlowTop != null)
          {
            this.mEdgeGlowTop.onRelease();
            this.mEdgeGlowBottom.onRelease();
          }
          this.mActivePointerId = -1;
          break;
          if (this.mFlingRunnable == null)
          {
            FlingRunnable localFlingRunnable1 = new FlingRunnable();
            this.mFlingRunnable = localFlingRunnable1;
          }
          this.mFlingRunnable.startSpringback();
        }
        onSecondaryPointerUp(paramMotionEvent);
        int i2 = this.mMotionX;
        int i3 = pointToPosition(i2, this.mMotionY);
        if (i3 >= 0)
        {
          this.mMotionViewOriginalLeft = getChildAt(i3 - this.mFirstPosition).getLeft();
          this.mMotionPosition = i3;
        }
        this.mLastX = i2;
        continue;
        int j = paramMotionEvent.getActionIndex();
        int k = paramMotionEvent.getPointerId(j);
        int m = (int)paramMotionEvent.getX(j);
        int n = (int)paramMotionEvent.getY(j);
        this.mMotionCorrection = 0;
        this.mActivePointerId = k;
        this.mMotionX = m;
        this.mMotionY = n;
        int i1 = pointToPosition(m, n);
        if (i1 >= 0)
        {
          this.mMotionViewOriginalLeft = getChildAt(i1 - this.mFirstPosition).getLeft();
          this.mMotionPosition = i1;
        }
        this.mLastX = m;
      }
    }
  }

  public void onTouchModeChanged(boolean paramBoolean)
  {
    if (paramBoolean)
    {
      hideSelector();
      if ((getWidth() > 0) && (getChildCount() > 0))
        layoutChildren();
      updateSelectorState();
    }
    do
    {
      int i;
      do
      {
        return;
        i = this.mTouchMode;
      }
      while ((i != 5) && (i != 6));
      if (this.mFlingRunnable != null)
        this.mFlingRunnable.endFling();
      if (this.mPositionScroller != null)
        this.mPositionScroller.stop();
    }
    while (getScrollX() == 0);
    this.mViewHelper.setScrollX(0);
    finishGlows();
    invalidate();
  }

  public void onWindowFocusChanged(boolean paramBoolean)
  {
    super.onWindowFocusChanged(paramBoolean);
    int i;
    if (isInTouchMode())
    {
      i = 0;
      if (paramBoolean)
        break label107;
      setChildrenDrawingCacheEnabled(false);
      if (this.mFlingRunnable != null)
      {
        removeCallbacks(this.mFlingRunnable);
        this.mFlingRunnable.endFling();
        if (this.mPositionScroller != null)
          this.mPositionScroller.stop();
        if (getScrollX() != 0)
        {
          this.mViewHelper.setScrollX(0);
          finishGlows();
          invalidate();
        }
      }
      if (i == 1)
        this.mResurrectToPosition = this.mSelectedPosition;
    }
    while (true)
    {
      this.mLastTouchMode = i;
      return;
      i = 1;
      break;
      label107: if ((i != this.mLastTouchMode) && (this.mLastTouchMode != -1))
        if (i == 1)
        {
          resurrectSelection();
        }
        else
        {
          hideSelector();
          this.mLayoutMode = 0;
          layoutChildren();
        }
    }
  }

  @TargetApi(16)
  public boolean performAccessibilityAction(int paramInt, Bundle paramBundle)
  {
    if (super.performAccessibilityAction(paramInt, paramBundle))
      return true;
    switch (paramInt)
    {
    default:
      return false;
    case 4096:
      if ((isEnabled()) && (getLastVisiblePosition() < -1 + getCount()))
      {
        smoothScrollBy(getWidth() - this.mListPadding.left - this.mListPadding.right, 200);
        return true;
      }
      return false;
    case 8192:
    }
    if ((isEnabled()) && (this.mFirstPosition > 0))
    {
      smoothScrollBy(-(getWidth() - this.mListPadding.left - this.mListPadding.right), 200);
      return true;
    }
    return false;
  }

  @TargetApi(14)
  protected boolean performButtonActionOnTouchDown(MotionEvent paramMotionEvent)
  {
    return (Build.VERSION.SDK_INT >= 14) && ((0x2 & paramMotionEvent.getButtonState()) != 0) && (showContextMenu(paramMotionEvent.getX(), paramMotionEvent.getY(), paramMotionEvent.getMetaState()));
  }

  public boolean performItemClick(View paramView, int paramInt, long paramLong)
  {
    int i = 1;
    int j = this.mChoiceMode;
    boolean bool1 = false;
    boolean bool2;
    label121: int k;
    if (j != 0)
    {
      bool1 = true;
      if ((this.mChoiceMode != 2) && ((Build.VERSION.SDK_INT < 11) || (this.mChoiceMode != 3) || (this.mChoiceActionMode == null)))
        break label238;
      if (!this.mCheckStates.get(paramInt, false))
        break label199;
      bool2 = false;
      this.mCheckStates.put(paramInt, bool2);
      if ((this.mCheckedIdStates != null) && (this.mAdapter.hasStableIds()))
      {
        if (!bool2)
          break label205;
        this.mCheckedIdStates.put(this.mAdapter.getItemId(paramInt), Integer.valueOf(paramInt));
      }
      if (!bool2)
        break label225;
      this.mCheckedItemCount = (1 + this.mCheckedItemCount);
      label136: if (this.mChoiceActionMode != null)
      {
        ((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback).onItemCheckedStateChanged((ActionMode)this.mChoiceActionMode, paramInt, paramLong, bool2);
        i = 0;
      }
      k = 1;
    }
    label199: label205: label225: label238: int m;
    do
    {
      if (k != 0)
        updateOnScreenCheckedViews();
      if (i != 0)
        bool1 |= super.performItemClick(paramView, paramInt, paramLong);
      return bool1;
      bool2 = true;
      break;
      this.mCheckedIdStates.delete(this.mAdapter.getItemId(paramInt));
      break label121;
      this.mCheckedItemCount = (-1 + this.mCheckedItemCount);
      break label136;
      m = this.mChoiceMode;
      k = 0;
    }
    while (m != 1);
    int n;
    if (this.mCheckStates.get(paramInt, false))
    {
      n = 0;
      label268: if (n == 0)
        break label353;
      this.mCheckStates.clear();
      this.mCheckStates.put(paramInt, true);
      if ((this.mCheckedIdStates != null) && (this.mAdapter.hasStableIds()))
      {
        this.mCheckedIdStates.clear();
        this.mCheckedIdStates.put(this.mAdapter.getItemId(paramInt), Integer.valueOf(paramInt));
      }
    }
    for (this.mCheckedItemCount = 1; ; this.mCheckedItemCount = 0)
      label353: 
      do
      {
        k = 1;
        break;
        n = 1;
        break label268;
      }
      while ((this.mCheckStates.size() != 0) && (this.mCheckStates.valueAt(0)));
  }

  boolean performLongPress(View paramView, int paramInt, long paramLong)
  {
    boolean bool = true;
    if ((Build.VERSION.SDK_INT >= 11) && (this.mChoiceMode == 3))
      if (this.mChoiceActionMode == null)
      {
        ActionMode localActionMode = startActionMode((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback);
        this.mChoiceActionMode = localActionMode;
        if (localActionMode != null)
        {
          setItemChecked(paramInt, bool);
          performHapticFeedback(0);
        }
      }
    do
    {
      return bool;
      AdapterView.OnItemLongClickListener localOnItemLongClickListener = this.mOnItemLongClickListener;
      bool = false;
      if (localOnItemLongClickListener != null)
        bool = this.mOnItemLongClickListener.onItemLongClick(this, paramView, paramInt, paramLong);
      if (!bool)
      {
        this.mContextMenuInfo = createContextMenuInfo(paramView, paramInt, paramLong);
        bool = super.showContextMenuForChild(this);
      }
    }
    while (!bool);
    performHapticFeedback(0);
    return bool;
  }

  public long pointToColId(int paramInt1, int paramInt2)
  {
    int i = pointToPosition(paramInt1, paramInt2);
    if (i >= 0)
      return this.mAdapter.getItemId(i);
    return -9223372036854775808L;
  }

  public int pointToPosition(int paramInt1, int paramInt2)
  {
    Rect localRect = this.mTouchFrame;
    if (localRect == null)
    {
      this.mTouchFrame = new Rect();
      localRect = this.mTouchFrame;
    }
    for (int i = -1 + getChildCount(); ; i--)
    {
      if (i < 0)
        return -1;
      View localView = getChildAt(i);
      if (localView.getVisibility() == 0)
      {
        localView.getHitRect(localRect);
        if (localRect.contains(paramInt1, paramInt2))
          return i + this.mFirstPosition;
      }
    }
  }

  protected void positionSelector(int paramInt, View paramView)
  {
    if (paramInt != -1)
      this.mSelectorPosition = paramInt;
    Rect localRect = this.mSelectorRect;
    localRect.set(paramView.getLeft(), paramView.getTop(), paramView.getRight(), paramView.getBottom());
    if ((paramView instanceof SelectionBoundsAdjuster))
      ((SelectionBoundsAdjuster)paramView).adjustListItemSelectionBounds(localRect);
    positionSelector(localRect.left, localRect.top, localRect.right, localRect.bottom);
    boolean bool1 = this.mIsChildViewEnabled;
    if (paramView.isEnabled() != bool1)
      if (!bool1)
        break label114;
    label114: for (boolean bool2 = false; ; bool2 = true)
    {
      this.mIsChildViewEnabled = bool2;
      if (getSelectedItemPosition() != -1)
        refreshDrawableState();
      return;
    }
  }

  @SuppressLint({"NewApi"})
  public void reclaimViews(List<View> paramList)
  {
    int i = getChildCount();
    RecyclerListener localRecyclerListener = this.mRecycler.mRecyclerListener;
    for (int j = 0; ; j++)
    {
      if (j >= i)
      {
        this.mRecycler.reclaimScrapViews(paramList);
        removeAllViewsInLayout();
        return;
      }
      View localView = getChildAt(j);
      LayoutParams localLayoutParams = (LayoutParams)localView.getLayoutParams();
      if ((localLayoutParams != null) && (this.mRecycler.shouldRecycleViewType(localLayoutParams.viewType)))
      {
        paramList.add(localView);
        if (Build.VERSION.SDK_INT >= 14)
          localView.setAccessibilityDelegate(null);
        if (localRecyclerListener != null)
          localRecyclerListener.onMovedToScrapHeap(localView);
      }
    }
  }

  protected int reconcileSelectedPosition()
  {
    int i = this.mSelectedPosition;
    if (i < 0)
      i = this.mResurrectToPosition;
    return Math.min(Math.max(0, i), -1 + this.mItemCount);
  }

  void reportScrollStateChange(int paramInt)
  {
    if ((paramInt != this.mLastScrollState) && (this.mOnScrollListener != null))
    {
      this.mLastScrollState = paramInt;
      this.mOnScrollListener.onScrollStateChanged(this, paramInt);
    }
  }

  public void requestDisallowInterceptTouchEvent(boolean paramBoolean)
  {
    if (paramBoolean)
      recycleVelocityTracker();
    super.requestDisallowInterceptTouchEvent(paramBoolean);
  }

  public void requestLayout()
  {
    if ((!this.mBlockLayoutRequests) && (!this.mInLayout))
      super.requestLayout();
  }

  void requestLayoutIfNecessary()
  {
    if (getChildCount() > 0)
    {
      resetList();
      requestLayout();
      invalidate();
    }
  }

  protected void resetList()
  {
    removeAllViewsInLayout();
    this.mFirstPosition = 0;
    this.mDataChanged = false;
    this.mPositionScrollAfterLayout = null;
    this.mNeedSync = false;
    this.mPendingSync = null;
    this.mOldSelectedPosition = -1;
    this.mOldSelectedColId = -9223372036854775808L;
    setSelectedPositionInt(-1);
    setNextSelectedPositionInt(-1);
    this.mSelectedLeft = 0;
    this.mSelectorPosition = -1;
    this.mSelectorRect.setEmpty();
    invalidate();
  }

  boolean resurrectSelection()
  {
    int i = getChildCount();
    if (i <= 0)
      return false;
    int j = 0;
    int k = this.mListPadding.left;
    int m = getRight() - getLeft() - this.mListPadding.right;
    int n = this.mFirstPosition;
    int i1 = this.mResurrectToPosition;
    boolean bool = true;
    int i3;
    View localView2;
    int i10;
    int i7;
    if ((i1 >= n) && (i1 < n + i))
    {
      i3 = i1;
      localView2 = getChildAt(i3 - this.mFirstPosition);
      j = localView2.getLeft();
      i10 = localView2.getRight();
      if (j < k)
      {
        j = k + getHorizontalFadingEdgeLength();
        this.mResurrectToPosition = -1;
        removeCallbacks(this.mFlingRunnable);
        if (this.mPositionScroller != null)
          this.mPositionScroller.stop();
        this.mTouchMode = -1;
        clearScrollingCache();
        this.mSpecificLeft = j;
        i7 = lookForSelectablePosition(i3, bool);
        if ((i7 < n) || (i7 > getLastVisiblePosition()))
          break label432;
        this.mLayoutMode = 4;
        updateSelectorState();
        setSelectionInt(i7);
        invokeOnItemScrollListener();
      }
    }
    while (true)
    {
      reportScrollStateChange(0);
      if (i7 < 0)
        break label438;
      return true;
      if (i10 <= m)
        break;
      j = m - localView2.getMeasuredWidth() - getHorizontalFadingEdgeLength();
      break;
      if (i1 < n)
      {
        i3 = n;
        for (int i8 = 0; ; i8++)
        {
          if (i8 >= i)
            break label316;
          int i9 = getChildAt(i8).getLeft();
          if (i8 == 0)
          {
            j = i9;
            if ((n > 0) || (i9 < k))
              k += getHorizontalFadingEdgeLength();
          }
          if (i9 >= k)
          {
            i3 = n + i8;
            j = i9;
            break;
          }
        }
        label316: break;
      }
      int i2 = this.mItemCount;
      i3 = -1 + (n + i);
      for (int i4 = i - 1; ; i4--)
      {
        bool = false;
        if (i4 < 0)
          break;
        View localView1 = getChildAt(i4);
        int i5 = localView1.getLeft();
        int i6 = localView1.getRight();
        if (i4 == i - 1)
        {
          j = i5;
          if ((n + i < i2) || (i6 > m))
            m -= getHorizontalFadingEdgeLength();
        }
        if (i6 <= m)
        {
          i3 = n + i4;
          j = i5;
          bool = false;
          break;
        }
      }
      label432: i7 = -1;
    }
    label438: return false;
  }

  protected boolean resurrectSelectionIfNeeded()
  {
    if ((this.mSelectedPosition < 0) && (resurrectSelection()))
    {
      updateSelectorState();
      return true;
    }
    return false;
  }

  public void sendAccessibilityEvent(int paramInt)
  {
    if (paramInt == 4096)
    {
      int i = getFirstVisiblePosition();
      int j = getLastVisiblePosition();
      if ((this.mLastAccessibilityScrollEventFromIndex == i) && (this.mLastAccessibilityScrollEventToIndex == j))
        return;
      this.mLastAccessibilityScrollEventFromIndex = i;
      this.mLastAccessibilityScrollEventToIndex = j;
    }
    super.sendAccessibilityEvent(paramInt);
  }

  public void setAdapter(ListAdapter paramListAdapter)
  {
    if (paramListAdapter != null)
    {
      this.mAdapterHasStableIds = this.mAdapter.hasStableIds();
      if ((this.mChoiceMode != 0) && (this.mAdapterHasStableIds) && (this.mCheckedIdStates == null))
        this.mCheckedIdStates = new LongSparseArray();
    }
    if (this.mCheckStates != null)
      this.mCheckStates.clear();
    if (this.mCheckedIdStates != null)
      this.mCheckedIdStates.clear();
  }

  public void setCacheColorHint(int paramInt)
  {
    int i;
    if (paramInt != this.mCacheColorHint)
    {
      this.mCacheColorHint = paramInt;
      i = getChildCount();
    }
    for (int j = 0; ; j++)
    {
      if (j >= i)
      {
        this.mRecycler.setCacheColorHint(paramInt);
        return;
      }
      getChildAt(j).setDrawingCacheBackgroundColor(paramInt);
    }
  }

  @TargetApi(11)
  public void setChoiceMode(int paramInt)
  {
    this.mChoiceMode = paramInt;
    if ((Build.VERSION.SDK_INT >= 11) && (this.mChoiceActionMode != null))
    {
      if (Build.VERSION.SDK_INT >= 11)
        ((ActionMode)this.mChoiceActionMode).finish();
      this.mChoiceActionMode = null;
    }
    if (this.mChoiceMode != 0)
    {
      if (this.mCheckStates == null)
        this.mCheckStates = new SparseBooleanArray();
      if ((this.mCheckedIdStates == null) && (this.mAdapter != null) && (this.mAdapter.hasStableIds()))
        this.mCheckedIdStates = new LongSparseArray();
      if ((Build.VERSION.SDK_INT >= 11) && (this.mChoiceMode == 3))
      {
        clearChoices();
        setLongClickable(true);
      }
    }
  }

  public void setDrawSelectorOnTop(boolean paramBoolean)
  {
    this.mDrawSelectorOnTop = paramBoolean;
  }

  public void setFriction(float paramFloat)
  {
    if (this.mFlingRunnable == null)
      this.mFlingRunnable = new FlingRunnable();
    this.mFlingRunnable.mScroller.setFriction(paramFloat);
  }

  public void setItemChecked(int paramInt, boolean paramBoolean)
  {
    if (this.mChoiceMode == 0);
    label274: label420: 
    while (true)
    {
      return;
      if ((Build.VERSION.SDK_INT >= 11) && (paramBoolean) && (this.mChoiceMode == 3) && (this.mChoiceActionMode == null))
      {
        if ((this.mMultiChoiceModeCallback == null) || (!((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback).hasWrappedCallback()))
          throw new IllegalStateException("AbsListView: attempted to start selection mode for CHOICE_MODE_MULTIPLE_MODAL but no choice mode callback was supplied. Call setMultiChoiceModeListener to set a callback.");
        this.mChoiceActionMode = startActionMode((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback);
      }
      if ((this.mChoiceMode == 2) || ((Build.VERSION.SDK_INT >= 11) && (this.mChoiceMode == 3)))
      {
        boolean bool = this.mCheckStates.get(paramInt);
        this.mCheckStates.put(paramInt, paramBoolean);
        if ((this.mCheckedIdStates != null) && (this.mAdapter.hasStableIds()))
        {
          if (paramBoolean)
            this.mCheckedIdStates.put(this.mAdapter.getItemId(paramInt), Integer.valueOf(paramInt));
        }
        else
        {
          if (bool != paramBoolean)
          {
            if (!paramBoolean)
              break label274;
            this.mCheckedItemCount = (1 + this.mCheckedItemCount);
          }
          label186: if (this.mChoiceActionMode != null)
          {
            long l = this.mAdapter.getItemId(paramInt);
            ((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback).onItemCheckedStateChanged((ActionMode)this.mChoiceActionMode, paramInt, l, paramBoolean);
          }
        }
      }
      while (true)
      {
        if ((this.mInLayout) || (this.mBlockLayoutRequests))
          break label420;
        this.mDataChanged = true;
        rememberSyncState();
        requestLayout();
        return;
        this.mCheckedIdStates.delete(this.mAdapter.getItemId(paramInt));
        break;
        this.mCheckedItemCount = (-1 + this.mCheckedItemCount);
        break label186;
        if ((this.mCheckedIdStates != null) && (this.mAdapter.hasStableIds()));
        for (int i = 1; ; i = 0)
        {
          if ((paramBoolean) || (isItemChecked(paramInt)))
          {
            this.mCheckStates.clear();
            if (i != 0)
              this.mCheckedIdStates.clear();
          }
          if (!paramBoolean)
            break label393;
          this.mCheckStates.put(paramInt, true);
          if (i != 0)
            this.mCheckedIdStates.put(this.mAdapter.getItemId(paramInt), Integer.valueOf(paramInt));
          this.mCheckedItemCount = 1;
          break;
        }
        if ((this.mCheckStates.size() == 0) || (!this.mCheckStates.valueAt(0)))
          this.mCheckedItemCount = 0;
      }
    }
  }

  @TargetApi(11)
  public void setMultiChoiceModeListener(MultiChoiceModeListener paramMultiChoiceModeListener)
  {
    if (Build.VERSION.SDK_INT >= 11)
    {
      if (this.mMultiChoiceModeCallback == null)
        this.mMultiChoiceModeCallback = new MultiChoiceModeWrapper(this);
      ((MultiChoiceModeWrapper)this.mMultiChoiceModeCallback).setWrapped(paramMultiChoiceModeListener);
      return;
    }
    Log.e("AbsListView", "setMultiChoiceModeListener not supported for this version of Android");
  }

  public void setOnScrollListener(OnScrollListener paramOnScrollListener)
  {
    this.mOnScrollListener = paramOnScrollListener;
    invokeOnItemScrollListener();
  }

  public void setOverScrollEffectPadding(int paramInt1, int paramInt2)
  {
    this.mGlowPaddingTop = paramInt1;
    this.mGlowPaddingBottom = paramInt2;
  }

  public void setOverScrollMode(int paramInt)
  {
    Context localContext;
    if (paramInt != 2)
      if (this.mEdgeGlowTop == null)
      {
        localContext = getContext();
        this.mEdgeGlowTop = new EdgeEffect(localContext, 1);
      }
    for (this.mEdgeGlowBottom = new EdgeEffect(localContext, 1); ; this.mEdgeGlowBottom = null)
    {
      super.setOverScrollMode(paramInt);
      return;
      this.mEdgeGlowTop = null;
    }
  }

  public void setRecyclerListener(RecyclerListener paramRecyclerListener)
  {
    this.mRecycler.mRecyclerListener = paramRecyclerListener;
  }

  public void setScrollIndicators(View paramView1, View paramView2)
  {
    this.mScrollLeft = paramView1;
    this.mScrollRight = paramView2;
  }

  public void setScrollingCacheEnabled(boolean paramBoolean)
  {
    if ((this.mScrollingCacheEnabled) && (!paramBoolean))
      clearScrollingCache();
    this.mScrollingCacheEnabled = paramBoolean;
  }

  public abstract void setSelectionInt(int paramInt);

  public void setSelector(int paramInt)
  {
    setSelector(getResources().getDrawable(paramInt));
  }

  public void setSelector(Drawable paramDrawable)
  {
    if (this.mSelector != null)
    {
      this.mSelector.setCallback(null);
      unscheduleDrawable(this.mSelector);
    }
    this.mSelector = paramDrawable;
    Rect localRect = new Rect();
    paramDrawable.getPadding(localRect);
    this.mSelectionLeftPadding = localRect.left;
    this.mSelectionTopPadding = localRect.top;
    this.mSelectionRightPadding = localRect.right;
    this.mSelectionBottomPadding = localRect.bottom;
    paramDrawable.setCallback(this);
    updateSelectorState();
  }

  public void setSmoothScrollbarEnabled(boolean paramBoolean)
  {
    this.mSmoothScrollbarEnabled = paramBoolean;
  }

  public void setStackFromRight(boolean paramBoolean)
  {
    if (this.mStackFromRight != paramBoolean)
    {
      this.mStackFromRight = paramBoolean;
      requestLayoutIfNecessary();
    }
  }

  public void setTranscriptMode(int paramInt)
  {
    this.mTranscriptMode = paramInt;
  }

  public void setVelocityScale(float paramFloat)
  {
    this.mVelocityScale = paramFloat;
  }

  protected void setVisibleRangeHint(int paramInt1, int paramInt2)
  {
  }

  protected boolean shouldShowSelector()
  {
    return ((hasFocus()) && (!isInTouchMode())) || (touchModeDrawsInPressedState());
  }

  public boolean showContextMenu(float paramFloat1, float paramFloat2, int paramInt)
  {
    int i = pointToPosition((int)paramFloat1, (int)paramFloat2);
    if (i != -1)
    {
      long l = this.mAdapter.getItemId(i);
      View localView = getChildAt(i - this.mFirstPosition);
      if (localView != null)
      {
        this.mContextMenuInfo = createContextMenuInfo(localView, i, l);
        return super.showContextMenuForChild(this);
      }
    }
    return showContextMenu(paramFloat1, paramFloat2, paramInt);
  }

  public boolean showContextMenuForChild(View paramView)
  {
    int i = getPositionForView(paramView);
    if (i >= 0)
    {
      long l = this.mAdapter.getItemId(i);
      AdapterView.OnItemLongClickListener localOnItemLongClickListener = this.mOnItemLongClickListener;
      boolean bool = false;
      if (localOnItemLongClickListener != null)
        bool = this.mOnItemLongClickListener.onItemLongClick(this, paramView, i, l);
      if (!bool)
      {
        this.mContextMenuInfo = createContextMenuInfo(getChildAt(i - this.mFirstPosition), i, l);
        bool = super.showContextMenuForChild(paramView);
      }
      return bool;
    }
    return false;
  }

  public void smoothScrollBy(int paramInt1, int paramInt2)
  {
    smoothScrollBy(paramInt1, paramInt2, false);
  }

  public void smoothScrollBy(int paramInt1, int paramInt2, boolean paramBoolean)
  {
    if (this.mFlingRunnable == null)
      this.mFlingRunnable = new FlingRunnable();
    int i = this.mFirstPosition;
    int j = getChildCount();
    int k = i + j;
    int m = getPaddingLeft();
    int n = getWidth() - getPaddingRight();
    if ((paramInt1 == 0) || (this.mItemCount == 0) || (j == 0) || ((i == 0) && (getChildAt(0).getLeft() == m) && (paramInt1 < 0)) || ((k == this.mItemCount) && (getChildAt(j - 1).getRight() == n) && (paramInt1 > 0)))
    {
      this.mFlingRunnable.endFling();
      if (this.mPositionScroller != null)
        this.mPositionScroller.stop();
      return;
    }
    reportScrollStateChange(2);
    this.mFlingRunnable.startScroll(paramInt1, paramInt2, paramBoolean);
  }

  protected void smoothScrollByOffset(int paramInt)
  {
    int i = -1;
    float f;
    if (paramInt < 0)
    {
      i = getFirstVisiblePosition();
      if (i > -1)
      {
        View localView = getChildAt(i - getFirstVisiblePosition());
        if (localView != null)
        {
          Rect localRect = new Rect();
          if (localView.getGlobalVisibleRect(localRect))
          {
            int j = localView.getWidth() * localView.getHeight();
            f = localRect.width() * localRect.height() / j;
            if ((paramInt >= 0) || (f >= 0.75F))
              break label125;
            i++;
          }
        }
      }
    }
    while (true)
    {
      smoothScrollToPosition(Math.max(0, Math.min(getCount(), i + paramInt)));
      return;
      if (paramInt <= 0)
        break;
      i = getLastVisiblePosition();
      break;
      label125: if ((paramInt > 0) && (f < 0.75F))
        i--;
    }
  }

  public void smoothScrollToPosition(int paramInt)
  {
    if (this.mPositionScroller == null)
      this.mPositionScroller = new PositionScroller();
    this.mPositionScroller.start(paramInt);
  }

  public void smoothScrollToPosition(int paramInt1, int paramInt2)
  {
    if (this.mPositionScroller == null)
      this.mPositionScroller = new PositionScroller();
    this.mPositionScroller.start(paramInt1, paramInt2);
  }

  public void smoothScrollToPositionFromLeft(int paramInt1, int paramInt2)
  {
    if (this.mPositionScroller == null)
      this.mPositionScroller = new PositionScroller();
    this.mPositionScroller.startWithOffset(paramInt1, paramInt2);
  }

  public void smoothScrollToPositionFromLeft(int paramInt1, int paramInt2, int paramInt3)
  {
    if (this.mPositionScroller == null)
      this.mPositionScroller = new PositionScroller();
    this.mPositionScroller.startWithOffset(paramInt1, paramInt2, paramInt3);
  }

  boolean touchModeDrawsInPressedState()
  {
    switch (this.mTouchMode)
    {
    default:
      return false;
    case 1:
    case 2:
    }
    return true;
  }

  boolean trackMotionScroll(int paramInt1, int paramInt2)
  {
    int i = getChildCount();
    if (i == 0)
      return true;
    int j = getChildAt(0).getLeft();
    int k = getChildAt(i - 1).getRight();
    Rect localRect = this.mListPadding;
    int m = 0 - j;
    int n = k - (getWidth() - 0);
    int i1 = getWidth() - getPaddingRight() - getPaddingLeft();
    int i2;
    int i3;
    label102: int i4;
    label125: int i5;
    label148: label171: int i6;
    if (paramInt1 < 0)
    {
      i2 = Math.max(-(i1 - 1), paramInt1);
      if (paramInt2 >= 0)
        break label235;
      i3 = Math.max(-(i1 - 1), paramInt2);
      i4 = this.mFirstPosition;
      if (i4 != 0)
        break label248;
      this.mFirstPositionDistanceGuess = (j - localRect.left);
      if (i4 + i != this.mItemCount)
        break label262;
      this.mLastPositionDistanceGuess = (k + localRect.right);
      if ((i4 != 0) || (j < localRect.left) || (i3 < 0))
        break label276;
      i5 = 1;
      if ((i4 + i != this.mItemCount) || (k > getWidth() - localRect.right) || (i3 > 0))
        break label282;
      i6 = 1;
    }
    while (true)
      if ((i5 != 0) || (i6 != 0))
      {
        if (i3 != 0)
        {
          return true;
          i2 = Math.min(i1 - 1, paramInt1);
          break;
          label235: i3 = Math.min(i1 - 1, paramInt2);
          break label102;
          label248: this.mFirstPositionDistanceGuess = (i3 + this.mFirstPositionDistanceGuess);
          break label125;
          label262: this.mLastPositionDistanceGuess = (i3 + this.mLastPositionDistanceGuess);
          break label148;
          label276: i5 = 0;
          break label171;
          label282: i6 = 0;
          continue;
        }
        return false;
      }
    boolean bool1;
    int i7;
    int i8;
    int i9;
    int i10;
    int i17;
    int i18;
    if (i3 < 0)
    {
      bool1 = true;
      boolean bool2 = isInTouchMode();
      if (bool2)
        hideSelector();
      i7 = getHeaderViewsCount();
      i8 = this.mItemCount - getFooterViewsCount();
      i9 = 0;
      i10 = 0;
      if (!bool1)
        break label593;
      i17 = -i3;
      i18 = 0;
      label349: int i19 = i18;
      i9 = 0;
      if (i19 < i)
        break label527;
      label362: this.mMotionViewNewLeft = (i2 + this.mMotionViewOriginalLeft);
      this.mBlockLayoutRequests = true;
      if (i10 > 0)
      {
        detachViewsFromParent(i9, i10);
        this.mRecycler.removeSkippedScrap();
      }
      if (!awakenScrollBars())
        invalidate();
      offsetChildrenLeftAndRight(i3);
      if (bool1)
        this.mFirstPosition = (i10 + this.mFirstPosition);
      int i14 = Math.abs(i3);
      if ((m < i14) || (n < i14))
        fillGap(bool1);
      if ((bool2) || (this.mSelectedPosition == -1))
        break label675;
      int i16 = this.mSelectedPosition - this.mFirstPosition;
      if ((i16 >= 0) && (i16 < getChildCount()))
        positionSelector(this.mSelectedPosition, getChildAt(i16));
    }
    while (true)
    {
      this.mBlockLayoutRequests = false;
      invokeOnItemScrollListener();
      return false;
      bool1 = false;
      break;
      label527: View localView2 = getChildAt(i18);
      int i20 = localView2.getRight();
      i9 = 0;
      if (i20 >= i17)
        break label362;
      i10++;
      int i21 = i4 + i18;
      if ((i21 >= i7) && (i21 < i8))
        this.mRecycler.addScrapView(localView2, i21);
      i18++;
      break label349;
      label593: int i11 = getWidth() - i3;
      for (int i12 = i - 1; ; i12--)
      {
        if (i12 < 0)
          break label673;
        View localView1 = getChildAt(i12);
        if (localView1.getLeft() <= i11)
          break;
        i9 = i12;
        i10++;
        int i13 = i4 + i12;
        if ((i13 >= i7) && (i13 < i8))
          this.mRecycler.addScrapView(localView1, i13);
      }
      label673: break label362;
      label675: if (this.mSelectorPosition != -1)
      {
        int i15 = this.mSelectorPosition - this.mFirstPosition;
        if ((i15 >= 0) && (i15 < getChildCount()))
          positionSelector(-1, getChildAt(i15));
      }
      else
      {
        this.mSelectorRect.setEmpty();
      }
    }
  }

  protected void updateScrollIndicators()
  {
    int m;
    label50: int n;
    label64: int j;
    label98: View localView1;
    label133: int k;
    if (this.mScrollLeft != null)
    {
      if (this.mFirstPosition > 0)
      {
        m = 1;
        if ((m == 0) && (getChildCount() > 0))
        {
          if (getChildAt(0).getLeft() >= this.mListPadding.left)
            break label158;
          m = 1;
        }
        View localView2 = this.mScrollLeft;
        if (m == 0)
          break label164;
        n = 0;
        localView2.setVisibility(n);
      }
    }
    else if (this.mScrollRight != null)
    {
      int i = getChildCount();
      if (i + this.mFirstPosition >= this.mItemCount)
        break label170;
      j = 1;
      if ((j == 0) && (i > 0))
      {
        if (getChildAt(i - 1).getRight() <= getRight() - this.mListPadding.right)
          break label175;
        j = 1;
      }
      localView1 = this.mScrollRight;
      k = 0;
      if (j == 0)
        break label180;
    }
    while (true)
    {
      localView1.setVisibility(k);
      return;
      m = 0;
      break;
      label158: m = 0;
      break label50;
      label164: n = 4;
      break label64;
      label170: j = 0;
      break label98;
      label175: j = 0;
      break label133;
      label180: k = 4;
    }
  }

  void updateSelectorState()
  {
    if (this.mSelector != null)
    {
      if (shouldShowSelector())
        this.mSelector.setState(getDrawableState());
    }
    else
      return;
    this.mSelector.setState(STATESET_NOTHING);
  }

  public boolean verifyDrawable(Drawable paramDrawable)
  {
    return (this.mSelector == paramDrawable) || (super.verifyDrawable(paramDrawable));
  }

  public class AdapterDataSetObserver extends AdapterView<ListAdapter>.AdapterDataSetObserver
  {
    public AdapterDataSetObserver()
    {
      super();
    }

    public void onChanged()
    {
      Log.i("AbsListView", "onChanged");
      super.onChanged();
    }

    public void onInvalidated()
    {
      Log.i("AbsListView", "onInvalidated");
      super.onInvalidated();
    }
  }

  private class CheckForKeyLongPress extends AbsHListView.WindowRunnnable
    implements Runnable
  {
    private CheckForKeyLongPress()
    {
      super(null);
    }

    public void run()
    {
      View localView;
      if ((AbsHListView.this.isPressed()) && (AbsHListView.this.mSelectedPosition >= 0))
      {
        int i = AbsHListView.this.mSelectedPosition - AbsHListView.this.mFirstPosition;
        localView = AbsHListView.this.getChildAt(i);
        if (AbsHListView.this.mDataChanged)
          break label110;
        boolean bool1 = sameWindow();
        boolean bool2 = false;
        if (bool1)
          bool2 = AbsHListView.this.performLongPress(localView, AbsHListView.this.mSelectedPosition, AbsHListView.this.mSelectedColId);
        if (bool2)
        {
          AbsHListView.this.setPressed(false);
          localView.setPressed(false);
        }
      }
      label110: 
      do
      {
        return;
        AbsHListView.this.setPressed(false);
      }
      while (localView == null);
      localView.setPressed(false);
    }
  }

  private class CheckForLongPress extends AbsHListView.WindowRunnnable
    implements Runnable
  {
    private CheckForLongPress()
    {
      super(null);
    }

    public void run()
    {
      int i = AbsHListView.this.mMotionPosition;
      View localView = AbsHListView.this.getChildAt(i - AbsHListView.this.mFirstPosition);
      if (localView != null)
      {
        int j = AbsHListView.this.mMotionPosition;
        long l = AbsHListView.this.mAdapter.getItemId(AbsHListView.this.mMotionPosition);
        boolean bool1 = sameWindow();
        boolean bool2 = false;
        if (bool1)
        {
          boolean bool3 = AbsHListView.this.mDataChanged;
          bool2 = false;
          if (!bool3)
            bool2 = AbsHListView.this.performLongPress(localView, j, l);
        }
        if (bool2)
        {
          AbsHListView.this.mTouchMode = -1;
          AbsHListView.this.setPressed(false);
          localView.setPressed(false);
        }
      }
      else
      {
        return;
      }
      AbsHListView.this.mTouchMode = 2;
    }
  }

  final class CheckForTap
    implements Runnable
  {
    CheckForTap()
    {
    }

    public void run()
    {
      int i;
      boolean bool;
      Drawable localDrawable;
      if (AbsHListView.this.mTouchMode == 0)
      {
        AbsHListView.this.mTouchMode = 1;
        View localView = AbsHListView.this.getChildAt(AbsHListView.this.mMotionPosition - AbsHListView.this.mFirstPosition);
        if ((localView != null) && (!localView.hasFocusable()))
        {
          AbsHListView.this.mLayoutMode = 0;
          if (AbsHListView.this.mDataChanged)
            break label253;
          localView.setPressed(true);
          AbsHListView.this.setPressed(true);
          AbsHListView.this.layoutChildren();
          AbsHListView.this.positionSelector(AbsHListView.this.mMotionPosition, localView);
          AbsHListView.this.refreshDrawableState();
          i = ViewConfiguration.getLongPressTimeout();
          bool = AbsHListView.this.isLongClickable();
          if (AbsHListView.this.mSelector != null)
          {
            localDrawable = AbsHListView.this.mSelector.getCurrent();
            if ((localDrawable != null) && ((localDrawable instanceof TransitionDrawable)))
            {
              if (!bool)
                break label233;
              ((TransitionDrawable)localDrawable).startTransition(i);
            }
          }
        }
      }
      while (bool)
      {
        if (AbsHListView.this.mPendingCheckForLongPress == null)
          AbsHListView.this.mPendingCheckForLongPress = new AbsHListView.CheckForLongPress(AbsHListView.this, null);
        AbsHListView.this.mPendingCheckForLongPress.rememberWindowAttachCount();
        AbsHListView.this.postDelayed(AbsHListView.this.mPendingCheckForLongPress, i);
        return;
        label233: ((TransitionDrawable)localDrawable).resetTransition();
      }
      AbsHListView.this.mTouchMode = 2;
      return;
      label253: AbsHListView.this.mTouchMode = 2;
    }
  }

  private class FlingRunnable
    implements Runnable
  {
    private static final int FLYWHEEL_TIMEOUT = 40;
    private final Runnable mCheckFlywheel = new Runnable()
    {
      public void run()
      {
        int i = AbsHListView.this.mActivePointerId;
        VelocityTracker localVelocityTracker = AbsHListView.this.mVelocityTracker;
        OverScroller localOverScroller = AbsHListView.FlingRunnable.this.mScroller;
        if ((localVelocityTracker == null) || (i == -1))
          return;
        localVelocityTracker.computeCurrentVelocity(1000, AbsHListView.this.mMaximumVelocity);
        float f = -localVelocityTracker.getXVelocity(i);
        if ((Math.abs(f) >= AbsHListView.this.mMinimumVelocity) && (localOverScroller.isScrollingInDirection(f, 0.0F)))
        {
          AbsHListView.this.postDelayed(this, 40L);
          return;
        }
        AbsHListView.FlingRunnable.this.endFling();
        AbsHListView.this.mTouchMode = 3;
        AbsHListView.this.reportScrollStateChange(1);
      }
    };
    private int mLastFlingX;
    private final OverScroller mScroller = new OverScroller(AbsHListView.this.getContext());

    FlingRunnable()
    {
    }

    void edgeReached(int paramInt)
    {
      this.mScroller.notifyHorizontalEdgeReached(AbsHListView.this.getScrollX(), 0, AbsHListView.this.mOverflingDistance);
      int i = AbsHListView.this.getOverScrollMode();
      int j;
      if ((i == 0) || ((i == 1) && (!AbsHListView.this.contentFits())))
      {
        AbsHListView.this.mTouchMode = 6;
        j = (int)this.mScroller.getCurrVelocity();
        if (paramInt > 0)
          AbsHListView.this.mEdgeGlowTop.onAbsorb(j);
      }
      while (true)
      {
        AbsHListView.this.invalidate();
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
        AbsHListView.this.mEdgeGlowBottom.onAbsorb(j);
        continue;
        AbsHListView.this.mTouchMode = -1;
        if (AbsHListView.this.mPositionScroller != null)
          AbsHListView.this.mPositionScroller.stop();
      }
    }

    void endFling()
    {
      AbsHListView.this.mTouchMode = -1;
      AbsHListView.this.removeCallbacks(this);
      AbsHListView.this.removeCallbacks(this.mCheckFlywheel);
      AbsHListView.this.reportScrollStateChange(0);
      AbsHListView.this.clearScrollingCache();
      this.mScroller.abortAnimation();
      AbsHListView.this.overScrollBy(0, 0, 0, 0, 0, 0, 0, 0, false);
    }

    void flywheelTouch()
    {
      AbsHListView.this.postDelayed(this.mCheckFlywheel, 40L);
    }

    public void run()
    {
      switch (AbsHListView.this.mTouchMode)
      {
      case 5:
      default:
        endFling();
      case 3:
        do
          return;
        while (this.mScroller.isFinished());
      case 4:
        if (AbsHListView.this.mDataChanged)
          AbsHListView.this.layoutChildren();
        if ((AbsHListView.this.mItemCount == 0) || (AbsHListView.this.getChildCount() == 0))
        {
          endFling();
          return;
        }
        OverScroller localOverScroller2 = this.mScroller;
        boolean bool1 = localOverScroller2.computeScrollOffset();
        int i2 = localOverScroller2.getCurrX();
        int i3 = this.mLastFlingX - i2;
        int i5;
        label195: View localView2;
        int i6;
        boolean bool2;
        if (i3 > 0)
        {
          AbsHListView.this.mMotionPosition = AbsHListView.this.mFirstPosition;
          View localView3 = AbsHListView.this.getChildAt(0);
          AbsHListView.this.mMotionViewOriginalLeft = localView3.getLeft();
          i5 = Math.min(-1 + (AbsHListView.this.getWidth() - AbsHListView.this.getPaddingRight() - AbsHListView.this.getPaddingLeft()), i3);
          localView2 = AbsHListView.this.getChildAt(AbsHListView.this.mMotionPosition - AbsHListView.this.mFirstPosition);
          i6 = 0;
          if (localView2 != null)
            i6 = localView2.getLeft();
          bool2 = AbsHListView.this.trackMotionScroll(i5, i5);
          if ((!bool2) || (i5 == 0))
            break label413;
        }
        label413: for (int i7 = 1; ; i7 = 0)
        {
          if (i7 == 0)
            break label419;
          if (localView2 != null)
          {
            int i8 = -(i5 - (localView2.getLeft() - i6));
            AbsHListView.this.overScrollBy(i8, 0, AbsHListView.this.getScrollX(), 0, 0, 0, AbsHListView.this.mOverflingDistance, 0, false);
          }
          if (!bool1)
            break;
          edgeReached(i5);
          return;
          int i4 = -1 + AbsHListView.this.getChildCount();
          AbsHListView.this.mMotionPosition = (i4 + AbsHListView.this.mFirstPosition);
          View localView1 = AbsHListView.this.getChildAt(i4);
          AbsHListView.this.mMotionViewOriginalLeft = localView1.getLeft();
          i5 = Math.max(-(-1 + (AbsHListView.this.getWidth() - AbsHListView.this.getPaddingRight() - AbsHListView.this.getPaddingLeft())), i3);
          break label195;
        }
        label419: if ((bool1) && (i7 == 0))
        {
          if (bool2)
            AbsHListView.this.invalidate();
          this.mLastFlingX = i2;
          AbsHListView.this.mViewHelper.postOnAnimation(this);
          return;
        }
        endFling();
        return;
      case 6:
      }
      OverScroller localOverScroller1 = this.mScroller;
      if (localOverScroller1.computeScrollOffset())
      {
        int i = AbsHListView.this.getScrollX();
        int j = localOverScroller1.getCurrX();
        int k = j - i;
        if (AbsHListView.this.overScrollBy(k, 0, i, 0, 0, 0, AbsHListView.this.mOverflingDistance, 0, false))
        {
          int m;
          if ((i <= 0) && (j > 0))
          {
            m = 1;
            if ((i < 0) || (j >= 0))
              break label586;
          }
          label586: for (int n = 1; ; n = 0)
          {
            if ((m == 0) && (n == 0))
              break label592;
            int i1 = (int)localOverScroller1.getCurrVelocity();
            if (n != 0)
              i1 = -i1;
            localOverScroller1.abortAnimation();
            start(i1);
            return;
            m = 0;
            break;
          }
          label592: startSpringback();
          return;
        }
        AbsHListView.this.invalidate();
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
      }
      endFling();
    }

    void start(int paramInt)
    {
      if (paramInt < 0);
      for (int i = 2147483647; ; i = 0)
      {
        this.mLastFlingX = i;
        this.mScroller.setInterpolator(null);
        this.mScroller.fling(i, 0, paramInt, 0, 0, 2147483647, 0, 2147483647);
        AbsHListView.this.mTouchMode = 4;
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
      }
    }

    void startOverfling(int paramInt)
    {
      this.mScroller.setInterpolator(null);
      this.mScroller.fling(AbsHListView.this.getScrollX(), 0, paramInt, 0, -2147483648, 2147483647, 0, 0, AbsHListView.this.getWidth(), 0);
      AbsHListView.this.mTouchMode = 6;
      AbsHListView.this.invalidate();
      AbsHListView.this.mViewHelper.postOnAnimation(this);
    }

    void startScroll(int paramInt1, int paramInt2, boolean paramBoolean)
    {
      int i;
      OverScroller localOverScroller;
      if (paramInt1 < 0)
      {
        i = 2147483647;
        this.mLastFlingX = i;
        localOverScroller = this.mScroller;
        if (!paramBoolean)
          break label75;
      }
      label75: for (Interpolator localInterpolator = AbsHListView.sLinearInterpolator; ; localInterpolator = null)
      {
        localOverScroller.setInterpolator(localInterpolator);
        this.mScroller.startScroll(i, 0, paramInt1, 0, paramInt2);
        AbsHListView.this.mTouchMode = 4;
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
        i = 0;
        break;
      }
    }

    void startSpringback()
    {
      if (this.mScroller.springBack(AbsHListView.this.getScrollX(), 0, 0, 0, 0, 0))
      {
        AbsHListView.this.mTouchMode = 6;
        AbsHListView.this.invalidate();
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
      }
      AbsHListView.this.mTouchMode = -1;
      AbsHListView.this.reportScrollStateChange(0);
    }
  }

  public static class LayoutParams extends ViewGroup.LayoutParams
  {
    public boolean forceAdd;
    public long itemId = -1L;
    public boolean recycledHeaderFooter;
    public int scrappedFromPosition;
    public int viewType;

    public LayoutParams(int paramInt1, int paramInt2)
    {
      super(paramInt2);
    }

    public LayoutParams(int paramInt1, int paramInt2, int paramInt3)
    {
      super(paramInt2);
      this.viewType = paramInt3;
    }

    public LayoutParams(Context paramContext, AttributeSet paramAttributeSet)
    {
      super(paramAttributeSet);
    }

    public LayoutParams(ViewGroup.LayoutParams paramLayoutParams)
    {
      super();
    }
  }

  @TargetApi(14)
  class ListItemAccessibilityDelegate extends AccessibilityDelegateCompat
  {
    ListItemAccessibilityDelegate()
    {
    }

    public void onInitializeAccessibilityNodeInfo(View paramView, AccessibilityNodeInfoCompat paramAccessibilityNodeInfoCompat)
    {
      super.onInitializeAccessibilityNodeInfo(paramView, paramAccessibilityNodeInfoCompat);
      int i = AbsHListView.this.getPositionForView(paramView);
      ListAdapter localListAdapter = (ListAdapter)AbsHListView.this.getAdapter();
      if ((i == -1) || (localListAdapter == null))
        break label37;
      label37: 
      while ((!AbsHListView.this.isEnabled()) || (!localListAdapter.isEnabled(i)))
        return;
      if (i == AbsHListView.this.getSelectedItemPosition())
      {
        paramAccessibilityNodeInfoCompat.setSelected(true);
        paramAccessibilityNodeInfoCompat.addAction(8);
      }
      while (true)
      {
        if (AbsHListView.this.isClickable())
        {
          paramAccessibilityNodeInfoCompat.addAction(16);
          paramAccessibilityNodeInfoCompat.setClickable(true);
        }
        if (!AbsHListView.this.isLongClickable())
          break;
        paramAccessibilityNodeInfoCompat.addAction(32);
        paramAccessibilityNodeInfoCompat.setLongClickable(true);
        return;
        paramAccessibilityNodeInfoCompat.addAction(4);
      }
    }

    public boolean performAccessibilityAction(View paramView, int paramInt, Bundle paramBundle)
    {
      if (super.performAccessibilityAction(paramView, paramInt, paramBundle))
        return true;
      int i = AbsHListView.this.getPositionForView(paramView);
      ListAdapter localListAdapter = (ListAdapter)AbsHListView.this.getAdapter();
      if ((i == -1) || (localListAdapter == null))
        return false;
      if ((!AbsHListView.this.isEnabled()) || (!localListAdapter.isEnabled(i)))
        return false;
      long l = AbsHListView.this.getItemIdAtPosition(i);
      switch (paramInt)
      {
      default:
        return false;
      case 8:
        if (AbsHListView.this.getSelectedItemPosition() == i)
        {
          AbsHListView.this.setSelection(-1);
          return true;
        }
        return false;
      case 4:
        if (AbsHListView.this.getSelectedItemPosition() != i)
        {
          AbsHListView.this.setSelection(i);
          return true;
        }
        return false;
      case 16:
        if (AbsHListView.this.isClickable())
          return AbsHListView.this.performItemClick(paramView, i, l);
        return false;
      case 32:
      }
      if (AbsHListView.this.isLongClickable())
        return AbsHListView.this.performLongPress(paramView, i, l);
      return false;
    }
  }

  public static abstract interface OnScrollListener
  {
    public static final int SCROLL_STATE_FLING = 2;
    public static final int SCROLL_STATE_IDLE = 0;
    public static final int SCROLL_STATE_TOUCH_SCROLL = 1;

    public abstract void onScroll(AbsHListView paramAbsHListView, int paramInt1, int paramInt2, int paramInt3);

    public abstract void onScrollStateChanged(AbsHListView paramAbsHListView, int paramInt);
  }

  private class PerformClick extends AbsHListView.WindowRunnnable
    implements Runnable
  {
    int mClickMotionPosition;

    private PerformClick()
    {
      super(null);
    }

    public void run()
    {
      if (AbsHListView.this.mDataChanged);
      ListAdapter localListAdapter;
      int i;
      View localView;
      do
      {
        do
        {
          return;
          localListAdapter = AbsHListView.this.mAdapter;
          i = this.mClickMotionPosition;
        }
        while ((localListAdapter == null) || (AbsHListView.this.mItemCount <= 0) || (i == -1) || (i >= localListAdapter.getCount()) || (!sameWindow()));
        localView = AbsHListView.this.getChildAt(i - AbsHListView.this.mFirstPosition);
      }
      while (localView == null);
      AbsHListView.this.performItemClick(localView, i, localListAdapter.getItemId(i));
    }
  }

  public class PositionScroller
    implements Runnable
  {
    private static final int MOVE_DOWN_BOUND = 3;
    private static final int MOVE_DOWN_POS = 1;
    private static final int MOVE_OFFSET = 5;
    private static final int MOVE_UP_BOUND = 4;
    private static final int MOVE_UP_POS = 2;
    private static final int SCROLL_DURATION = 200;
    private int mBoundPos;
    private final int mExtraScroll = ViewConfiguration.get(AbsHListView.this.getContext()).getScaledFadingEdgeLength();
    private int mLastSeenPos;
    private int mMode;
    private int mOffsetFromLeft;
    private int mScrollDuration;
    private int mTargetPos;

    PositionScroller()
    {
    }

    public void run()
    {
      int i = AbsHListView.this.getWidth();
      int j = AbsHListView.this.mFirstPosition;
      switch (this.mMode)
      {
      default:
      case 1:
      case 3:
      case 2:
      case 4:
        int i14;
        int i15;
        do
        {
          int i8;
          do
          {
            View localView2;
            do
            {
              int i21;
              int i22;
              do
              {
                int i18;
                do
                {
                  int i23;
                  int i24;
                  do
                  {
                    return;
                    i23 = -1 + AbsHListView.this.getChildCount();
                    i24 = j + i23;
                  }
                  while (i23 < 0);
                  if (i24 == this.mLastSeenPos)
                  {
                    AbsHListView.this.mViewHelper.postOnAnimation(this);
                    return;
                  }
                  View localView4 = AbsHListView.this.getChildAt(i23);
                  int i25 = localView4.getWidth();
                  int i26 = i - localView4.getLeft();
                  if (i24 < -1 + AbsHListView.this.mItemCount);
                  for (int i27 = Math.max(AbsHListView.this.mListPadding.right, this.mExtraScroll); ; i27 = AbsHListView.this.mListPadding.right)
                  {
                    int i28 = i27 + (i25 - i26);
                    AbsHListView.this.smoothScrollBy(i28, this.mScrollDuration, true);
                    this.mLastSeenPos = i24;
                    if (i24 >= this.mTargetPos)
                      break;
                    AbsHListView.this.mViewHelper.postOnAnimation(this);
                    return;
                  }
                  i18 = AbsHListView.this.getChildCount();
                }
                while ((j == this.mBoundPos) || (i18 <= 1) || (j + i18 >= AbsHListView.this.mItemCount));
                int i19 = j + 1;
                if (i19 == this.mLastSeenPos)
                {
                  AbsHListView.this.mViewHelper.postOnAnimation(this);
                  return;
                }
                View localView3 = AbsHListView.this.getChildAt(1);
                int i20 = localView3.getWidth();
                i21 = localView3.getLeft();
                i22 = Math.max(AbsHListView.this.mListPadding.right, this.mExtraScroll);
                if (i19 < this.mBoundPos)
                {
                  AbsHListView.this.smoothScrollBy(Math.max(0, i20 + i21 - i22), this.mScrollDuration, true);
                  this.mLastSeenPos = i19;
                  AbsHListView.this.mViewHelper.postOnAnimation(this);
                  return;
                }
              }
              while (i21 <= i22);
              AbsHListView.this.smoothScrollBy(i21 - i22, this.mScrollDuration, true);
              return;
              if (j == this.mLastSeenPos)
              {
                AbsHListView.this.mViewHelper.postOnAnimation(this);
                return;
              }
              localView2 = AbsHListView.this.getChildAt(0);
            }
            while (localView2 == null);
            int i16 = localView2.getLeft();
            if (j > 0);
            for (int i17 = Math.max(this.mExtraScroll, AbsHListView.this.mListPadding.left); ; i17 = AbsHListView.this.mListPadding.left)
            {
              AbsHListView.this.smoothScrollBy(i16 - i17, this.mScrollDuration, true);
              this.mLastSeenPos = j;
              if (j <= this.mTargetPos)
                break;
              AbsHListView.this.mViewHelper.postOnAnimation(this);
              return;
            }
            i8 = -2 + AbsHListView.this.getChildCount();
          }
          while (i8 < 0);
          int i9 = j + i8;
          if (i9 == this.mLastSeenPos)
          {
            AbsHListView.this.mViewHelper.postOnAnimation(this);
            return;
          }
          View localView1 = AbsHListView.this.getChildAt(i8);
          int i10 = localView1.getWidth();
          int i11 = localView1.getLeft();
          int i12 = i - i11;
          int i13 = Math.max(AbsHListView.this.mListPadding.left, this.mExtraScroll);
          this.mLastSeenPos = i9;
          if (i9 > this.mBoundPos)
          {
            AbsHListView.this.smoothScrollBy(-(i12 - i13), this.mScrollDuration, true);
            AbsHListView.this.mViewHelper.postOnAnimation(this);
            return;
          }
          i14 = i - i13;
          i15 = i11 + i10;
        }
        while (i14 <= i15);
        AbsHListView.this.smoothScrollBy(-(i14 - i15), this.mScrollDuration, true);
        return;
      case 5:
      }
      if (this.mLastSeenPos == j)
      {
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
      }
      this.mLastSeenPos = j;
      int k = AbsHListView.this.getChildCount();
      int m = this.mTargetPos;
      int n = -1 + (j + k);
      int i1;
      if (m < j)
        i1 = 1 + (j - m);
      float f;
      while (true)
      {
        f = Math.min(Math.abs(i1 / k), 1.0F);
        if (m >= j)
          break;
        int i6 = (int)(f * -AbsHListView.this.getWidth());
        int i7 = (int)(f * this.mScrollDuration);
        AbsHListView.this.smoothScrollBy(i6, i7, true);
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
        i1 = 0;
        if (m > n)
          i1 = m - n;
      }
      if (m > n)
      {
        int i4 = (int)(f * AbsHListView.this.getWidth());
        int i5 = (int)(f * this.mScrollDuration);
        AbsHListView.this.smoothScrollBy(i4, i5, true);
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
      }
      int i2 = AbsHListView.this.getChildAt(m - j).getLeft() - this.mOffsetFromLeft;
      int i3 = (int)(this.mScrollDuration * (Math.abs(i2) / AbsHListView.this.getWidth()));
      AbsHListView.this.smoothScrollBy(i2, i3, true);
    }

    void scrollToVisible(int paramInt1, int paramInt2, int paramInt3)
    {
      int i = AbsHListView.this.mFirstPosition;
      int j = -1 + (i + AbsHListView.this.getChildCount());
      int k = AbsHListView.this.mListPadding.left;
      int m = AbsHListView.this.getWidth() - AbsHListView.this.mListPadding.right;
      if ((paramInt1 < i) || (paramInt1 > j))
        Log.w("AbsListView", "scrollToVisible called with targetPos " + paramInt1 + " not visible [" + i + ", " + j + "]");
      if ((paramInt2 < i) || (paramInt2 > j))
        paramInt2 = -1;
      View localView1 = AbsHListView.this.getChildAt(paramInt1 - i);
      int n = localView1.getLeft();
      int i1 = localView1.getRight();
      int i2 = 0;
      if (i1 > m)
        i2 = i1 - m;
      if (n < k)
        i2 = n - k;
      if (i2 == 0)
        return;
      int i3;
      int i4;
      int i5;
      if (paramInt2 >= 0)
      {
        View localView2 = AbsHListView.this.getChildAt(paramInt2 - i);
        i3 = localView2.getLeft();
        i4 = localView2.getRight();
        i5 = Math.abs(i2);
        if ((i2 >= 0) || (i4 + i5 <= m))
          break label267;
      }
      for (i2 = Math.max(0, i4 - m); ; i2 = Math.min(0, i3 - k))
        label267: 
        do
        {
          AbsHListView.this.smoothScrollBy(i2, paramInt3);
          return;
        }
        while ((i2 <= 0) || (i3 - i5 >= k));
    }

    void start(final int paramInt)
    {
      stop();
      if (AbsHListView.this.mDataChanged)
        AbsHListView.this.mPositionScrollAfterLayout = new Runnable()
        {
          public void run()
          {
            AbsHListView.PositionScroller.this.start(paramInt);
          }
        };
      int i;
      do
      {
        return;
        i = AbsHListView.this.getChildCount();
      }
      while (i == 0);
      int j = AbsHListView.this.mFirstPosition;
      int k = -1 + (j + i);
      int m = Math.max(0, Math.min(-1 + AbsHListView.this.getCount(), paramInt));
      int n;
      if (m < j)
      {
        n = 1 + (j - m);
        this.mMode = 2;
        if (n <= 0)
          break label174;
      }
      label174: for (this.mScrollDuration = (200 / n); ; this.mScrollDuration = 200)
      {
        this.mTargetPos = m;
        this.mBoundPos = -1;
        this.mLastSeenPos = -1;
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
        if (m > k)
        {
          n = 1 + (m - k);
          this.mMode = 1;
          break;
        }
        scrollToVisible(m, -1, 200);
        return;
      }
    }

    void start(final int paramInt1, final int paramInt2)
    {
      stop();
      if (paramInt2 == -1)
        start(paramInt1);
      int j;
      int k;
      int m;
      int i4;
      do
      {
        int i;
        do
        {
          return;
          if (AbsHListView.this.mDataChanged)
          {
            AbsHListView.this.mPositionScrollAfterLayout = new Runnable()
            {
              public void run()
              {
                AbsHListView.PositionScroller.this.start(paramInt1, paramInt2);
              }
            };
            return;
          }
          i = AbsHListView.this.getChildCount();
        }
        while (i == 0);
        j = AbsHListView.this.mFirstPosition;
        k = -1 + (j + i);
        m = Math.max(0, Math.min(-1 + AbsHListView.this.getCount(), paramInt1));
        if (m >= j)
          break;
        i4 = k - paramInt2;
      }
      while (i4 < 1);
      int i5 = 1 + (j - m);
      int i6 = i4 - 1;
      int i3;
      if (i6 < i5)
      {
        i3 = i6;
        this.mMode = 4;
        label141: if (i3 <= 0)
          break label272;
      }
      label272: for (this.mScrollDuration = (200 / i3); ; this.mScrollDuration = 200)
      {
        this.mTargetPos = m;
        this.mBoundPos = paramInt2;
        this.mLastSeenPos = -1;
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
        i3 = i5;
        this.mMode = 2;
        break label141;
        if (m > k)
        {
          int n = paramInt2 - j;
          if (n < 1)
            break;
          int i1 = 1 + (m - k);
          int i2 = n - 1;
          if (i2 < i1)
          {
            i3 = i2;
            this.mMode = 3;
            break label141;
          }
          i3 = i1;
          this.mMode = 1;
          break label141;
        }
        scrollToVisible(m, paramInt2, 200);
        return;
      }
    }

    void startWithOffset(int paramInt1, int paramInt2)
    {
      startWithOffset(paramInt1, paramInt2, 200);
    }

    void startWithOffset(final int paramInt1, final int paramInt2, final int paramInt3)
    {
      stop();
      if (AbsHListView.this.mDataChanged)
        AbsHListView.this.mPositionScrollAfterLayout = new Runnable()
        {
          public void run()
          {
            AbsHListView.PositionScroller.this.startWithOffset(paramInt1, paramInt2, paramInt3);
          }
        };
      int i;
      do
      {
        return;
        i = AbsHListView.this.getChildCount();
      }
      while (i == 0);
      int j = paramInt2 + AbsHListView.this.getPaddingLeft();
      this.mTargetPos = Math.max(0, Math.min(-1 + AbsHListView.this.getCount(), paramInt1));
      this.mOffsetFromLeft = j;
      this.mBoundPos = -1;
      this.mLastSeenPos = -1;
      this.mMode = 5;
      int k = AbsHListView.this.mFirstPosition;
      int m = -1 + (k + i);
      int i1;
      float f;
      if (this.mTargetPos < k)
      {
        i1 = k - this.mTargetPos;
        f = i1 / i;
        if (f >= 1.0F)
          break label229;
      }
      while (true)
      {
        this.mScrollDuration = paramInt3;
        this.mLastSeenPos = -1;
        AbsHListView.this.mViewHelper.postOnAnimation(this);
        return;
        if (this.mTargetPos > m)
        {
          i1 = this.mTargetPos - m;
          break;
        }
        int n = AbsHListView.this.getChildAt(this.mTargetPos - k).getLeft();
        AbsHListView.this.smoothScrollBy(n - j, paramInt3, false);
        return;
        label229: paramInt3 = (int)(paramInt3 / f);
      }
    }

    public void stop()
    {
      AbsHListView.this.removeCallbacks(this);
    }
  }

  public class RecycleBin
  {
    private View[] mActiveViews = new View[0];
    private ArrayList<View> mCurrentScrap;
    private int mFirstActivePosition;
    private AbsHListView.RecyclerListener mRecyclerListener;
    private ArrayList<View>[] mScrapViews;
    private ArrayList<View> mSkippedScrap;
    private SparseArrayCompat<View> mTransientStateViews;
    private int mViewTypeCount;

    public RecycleBin()
    {
    }

    @SuppressLint({"NewApi"})
    private void pruneScrapViews()
    {
      int i = this.mActiveViews.length;
      int j = this.mViewTypeCount;
      ArrayList[] arrayOfArrayList = this.mScrapViews;
      int k = 0;
      if (k >= j)
        if (this.mTransientStateViews == null);
      for (int i5 = 0; ; i5++)
      {
        if (i5 >= this.mTransientStateViews.size())
        {
          return;
          ArrayList localArrayList = arrayOfArrayList[k];
          int m = localArrayList.size();
          int n = m - i;
          int i1 = m - 1;
          int i2 = 0;
          int i4;
          for (int i3 = i1; ; i3 = i4)
          {
            if (i2 >= n)
            {
              k++;
              break;
            }
            AbsHListView localAbsHListView = AbsHListView.this;
            i4 = i3 - 1;
            localAbsHListView.removeDetachedView((View)localArrayList.remove(i3), false);
            i2++;
          }
        }
        if (!((View)this.mTransientStateViews.valueAt(i5)).hasTransientState())
        {
          this.mTransientStateViews.removeAt(i5);
          i5--;
        }
      }
    }

    @SuppressLint({"NewApi"})
    public void addScrapView(View paramView, int paramInt)
    {
      AbsHListView.LayoutParams localLayoutParams = (AbsHListView.LayoutParams)paramView.getLayoutParams();
      if (localLayoutParams == null)
        return;
      localLayoutParams.scrappedFromPosition = paramInt;
      int i = localLayoutParams.viewType;
      if (Build.VERSION.SDK_INT >= 16);
      for (boolean bool = paramView.hasTransientState(); ; bool = false)
      {
        if ((shouldRecycleViewType(i)) && (!bool))
          break label134;
        if ((i != -2) || (bool))
        {
          if (this.mSkippedScrap == null)
            this.mSkippedScrap = new ArrayList();
          this.mSkippedScrap.add(paramView);
        }
        if (!bool)
          break;
        if (this.mTransientStateViews == null)
          this.mTransientStateViews = new SparseArrayCompat();
        paramView.onStartTemporaryDetach();
        this.mTransientStateViews.put(paramInt, paramView);
        return;
      }
      label134: paramView.onStartTemporaryDetach();
      if (this.mViewTypeCount == 1)
        this.mCurrentScrap.add(paramView);
      while (true)
      {
        if (Build.VERSION.SDK_INT >= 14)
          paramView.setAccessibilityDelegate(null);
        if (this.mRecyclerListener == null)
          break;
        this.mRecyclerListener.onMovedToScrapHeap(paramView);
        return;
        this.mScrapViews[i].add(paramView);
      }
    }

    public void clear()
    {
      if (this.mViewTypeCount == 1)
      {
        ArrayList localArrayList2 = this.mCurrentScrap;
        int n = localArrayList2.size();
        for (int i1 = 0; ; i1++)
        {
          if (i1 >= n)
          {
            if (this.mTransientStateViews != null)
              this.mTransientStateViews.clear();
            return;
          }
          AbsHListView.this.removeDetachedView((View)localArrayList2.remove(n - 1 - i1), false);
        }
      }
      int i = this.mViewTypeCount;
      int j = 0;
      label82: ArrayList localArrayList1;
      int k;
      if (j < i)
      {
        localArrayList1 = this.mScrapViews[j];
        k = localArrayList1.size();
      }
      for (int m = 0; ; m++)
      {
        if (m >= k)
        {
          j++;
          break label82;
          break;
        }
        AbsHListView.this.removeDetachedView((View)localArrayList1.remove(k - 1 - m), false);
      }
    }

    void clearTransientStateViews()
    {
      if (this.mTransientStateViews != null)
        this.mTransientStateViews.clear();
    }

    public void fillActiveViews(int paramInt1, int paramInt2)
    {
      if (this.mActiveViews.length < paramInt1)
        this.mActiveViews = new View[paramInt1];
      this.mFirstActivePosition = paramInt2;
      View[] arrayOfView = this.mActiveViews;
      for (int i = 0; ; i++)
      {
        if (i >= paramInt1)
          return;
        View localView = AbsHListView.this.getChildAt(i);
        AbsHListView.LayoutParams localLayoutParams = (AbsHListView.LayoutParams)localView.getLayoutParams();
        if ((localLayoutParams != null) && (localLayoutParams.viewType != -2))
          arrayOfView[i] = localView;
      }
    }

    public View getActiveView(int paramInt)
    {
      int i = paramInt - this.mFirstActivePosition;
      View[] arrayOfView = this.mActiveViews;
      if ((i >= 0) && (i < arrayOfView.length))
      {
        View localView = arrayOfView[i];
        arrayOfView[i] = null;
        return localView;
      }
      return null;
    }

    View getScrapView(int paramInt)
    {
      if (this.mViewTypeCount == 1)
        return AbsHListView.retrieveFromScrap(this.mCurrentScrap, paramInt);
      int i = AbsHListView.this.mAdapter.getItemViewType(paramInt);
      if ((i >= 0) && (i < this.mScrapViews.length))
        return AbsHListView.retrieveFromScrap(this.mScrapViews[i], paramInt);
      return null;
    }

    View getTransientStateView(int paramInt)
    {
      if (this.mTransientStateViews == null);
      int i;
      do
      {
        return null;
        i = this.mTransientStateViews.indexOfKey(paramInt);
      }
      while (i < 0);
      View localView = (View)this.mTransientStateViews.valueAt(i);
      this.mTransientStateViews.removeAt(i);
      return localView;
    }

    public void markChildrenDirty()
    {
      ArrayList localArrayList2;
      int i3;
      int n;
      if (this.mViewTypeCount == 1)
      {
        localArrayList2 = this.mCurrentScrap;
        int i2 = localArrayList2.size();
        i3 = 0;
        if (i3 >= i2)
          if (this.mTransientStateViews != null)
            n = this.mTransientStateViews.size();
      }
      for (int i1 = 0; ; i1++)
      {
        if (i1 >= n)
        {
          return;
          ((View)localArrayList2.get(i3)).forceLayout();
          i3++;
          break;
          int i = this.mViewTypeCount;
          int j = 0;
          label84: ArrayList localArrayList1;
          int k;
          if (j < i)
          {
            localArrayList1 = this.mScrapViews[j];
            k = localArrayList1.size();
          }
          for (int m = 0; ; m++)
          {
            if (m >= k)
            {
              j++;
              break label84;
              break;
            }
            ((View)localArrayList1.get(m)).forceLayout();
          }
        }
        ((View)this.mTransientStateViews.valueAt(i1)).forceLayout();
      }
    }

    void reclaimScrapViews(List<View> paramList)
    {
      if (this.mViewTypeCount == 1)
        paramList.addAll(this.mCurrentScrap);
      while (true)
      {
        return;
        int i = this.mViewTypeCount;
        ArrayList[] arrayOfArrayList = this.mScrapViews;
        for (int j = 0; j < i; j++)
          paramList.addAll(arrayOfArrayList[j]);
      }
    }

    public void removeSkippedScrap()
    {
      if (this.mSkippedScrap == null)
        return;
      int i = this.mSkippedScrap.size();
      for (int j = 0; ; j++)
      {
        if (j >= i)
        {
          this.mSkippedScrap.clear();
          return;
        }
        AbsHListView.this.removeDetachedView((View)this.mSkippedScrap.get(j), false);
      }
    }

    @SuppressLint({"NewApi"})
    public void scrapActiveViews()
    {
      View[] arrayOfView = this.mActiveViews;
      int i;
      if (this.mRecyclerListener != null)
      {
        i = 1;
        if (this.mViewTypeCount <= 1)
          break label51;
      }
      ArrayList localArrayList;
      int k;
      label51: for (int j = 1; ; j = 0)
      {
        localArrayList = this.mCurrentScrap;
        k = -1 + arrayOfView.length;
        if (k >= 0)
          break label56;
        pruneScrapViews();
        return;
        i = 0;
        break;
      }
      label56: View localView = arrayOfView[k];
      AbsHListView.LayoutParams localLayoutParams;
      int m;
      boolean bool;
      if (localView != null)
      {
        localLayoutParams = (AbsHListView.LayoutParams)localView.getLayoutParams();
        m = localLayoutParams.viewType;
        arrayOfView[k] = null;
        if (Build.VERSION.SDK_INT < 16)
          break label185;
        bool = localView.hasTransientState();
        label104: if ((shouldRecycleViewType(m)) && (!bool))
          break label191;
        if ((m != -2) || (bool))
          AbsHListView.this.removeDetachedView(localView, false);
        if (bool)
        {
          if (this.mTransientStateViews == null)
            this.mTransientStateViews = new SparseArrayCompat();
          this.mTransientStateViews.put(k + this.mFirstActivePosition, localView);
        }
      }
      while (true)
      {
        k--;
        break;
        label185: bool = false;
        break label104;
        label191: if (j != 0)
          localArrayList = this.mScrapViews[m];
        localView.onStartTemporaryDetach();
        localLayoutParams.scrappedFromPosition = (k + this.mFirstActivePosition);
        localArrayList.add(localView);
        if (Build.VERSION.SDK_INT >= 14)
          localView.setAccessibilityDelegate(null);
        if (i != 0)
          this.mRecyclerListener.onMovedToScrapHeap(localView);
      }
    }

    void setCacheColorHint(int paramInt)
    {
      ArrayList localArrayList2;
      int i3;
      View[] arrayOfView;
      int n;
      if (this.mViewTypeCount == 1)
      {
        localArrayList2 = this.mCurrentScrap;
        int i2 = localArrayList2.size();
        i3 = 0;
        if (i3 >= i2)
        {
          arrayOfView = this.mActiveViews;
          n = arrayOfView.length;
        }
      }
      for (int i1 = 0; ; i1++)
      {
        if (i1 >= n)
        {
          return;
          ((View)localArrayList2.get(i3)).setDrawingCacheBackgroundColor(paramInt);
          i3++;
          break;
          int i = this.mViewTypeCount;
          int j = 0;
          label80: ArrayList localArrayList1;
          int k;
          if (j < i)
          {
            localArrayList1 = this.mScrapViews[j];
            k = localArrayList1.size();
          }
          for (int m = 0; ; m++)
          {
            if (m >= k)
            {
              j++;
              break label80;
              break;
            }
            ((View)localArrayList1.get(m)).setDrawingCacheBackgroundColor(paramInt);
          }
        }
        View localView = arrayOfView[i1];
        if (localView != null)
          localView.setDrawingCacheBackgroundColor(paramInt);
      }
    }

    public void setViewTypeCount(int paramInt)
    {
      if (paramInt < 1)
        throw new IllegalArgumentException("Can't have a viewTypeCount < 1");
      ArrayList[] arrayOfArrayList = new ArrayList[paramInt];
      for (int i = 0; ; i++)
      {
        if (i >= paramInt)
        {
          this.mViewTypeCount = paramInt;
          this.mCurrentScrap = arrayOfArrayList[0];
          this.mScrapViews = arrayOfArrayList;
          return;
        }
        arrayOfArrayList[i] = new ArrayList();
      }
    }

    public boolean shouldRecycleViewType(int paramInt)
    {
      return paramInt >= 0;
    }
  }

  public static abstract interface RecyclerListener
  {
    public abstract void onMovedToScrapHeap(View paramView);
  }

  static class SavedState extends View.BaseSavedState
  {
    public static final Parcelable.Creator<SavedState> CREATOR = new Parcelable.Creator()
    {
      public AbsHListView.SavedState createFromParcel(Parcel paramAnonymousParcel)
      {
        return new AbsHListView.SavedState(paramAnonymousParcel, null);
      }

      public AbsHListView.SavedState[] newArray(int paramAnonymousInt)
      {
        return new AbsHListView.SavedState[paramAnonymousInt];
      }
    };
    LongSparseArray<Integer> checkIdState;
    SparseBooleanArray checkState;
    int checkedItemCount;
    String filter;
    long firstId;
    boolean inActionMode;
    int position;
    long selectedId;
    int viewLeft;
    int width;

    private SavedState(Parcel paramParcel)
    {
      super();
      this.selectedId = paramParcel.readLong();
      this.firstId = paramParcel.readLong();
      this.viewLeft = paramParcel.readInt();
      this.position = paramParcel.readInt();
      this.width = paramParcel.readInt();
      this.filter = paramParcel.readString();
      boolean bool;
      int i;
      if (paramParcel.readByte() != 0)
      {
        bool = true;
        this.inActionMode = bool;
        this.checkedItemCount = paramParcel.readInt();
        this.checkState = paramParcel.readSparseBooleanArray();
        i = paramParcel.readInt();
        if (i > 0)
          this.checkIdState = new LongSparseArray();
      }
      for (int j = 0; ; j++)
      {
        if (j >= i)
        {
          return;
          bool = false;
          break;
        }
        long l = paramParcel.readLong();
        int k = paramParcel.readInt();
        this.checkIdState.put(l, Integer.valueOf(k));
      }
    }

    SavedState(Parcelable paramParcelable)
    {
      super();
    }

    public String toString()
    {
      return "AbsListView.SavedState{" + Integer.toHexString(System.identityHashCode(this)) + " selectedId=" + this.selectedId + " firstId=" + this.firstId + " viewLeft=" + this.viewLeft + " position=" + this.position + " width=" + this.width + " filter=" + this.filter + " checkState=" + this.checkState + "}";
    }

    public void writeToParcel(Parcel paramParcel, int paramInt)
    {
      super.writeToParcel(paramParcel, paramInt);
      paramParcel.writeLong(this.selectedId);
      paramParcel.writeLong(this.firstId);
      paramParcel.writeInt(this.viewLeft);
      paramParcel.writeInt(this.position);
      paramParcel.writeInt(this.width);
      paramParcel.writeString(this.filter);
      int i;
      int j;
      if (this.inActionMode)
      {
        i = 1;
        paramParcel.writeByte((byte)i);
        paramParcel.writeInt(this.checkedItemCount);
        paramParcel.writeSparseBooleanArray(this.checkState);
        if (this.checkIdState == null)
          break label123;
        j = this.checkIdState.size();
        label101: paramParcel.writeInt(j);
      }
      for (int k = 0; ; k++)
      {
        if (k >= j)
        {
          return;
          i = 0;
          break;
          label123: j = 0;
          break label101;
        }
        paramParcel.writeLong(this.checkIdState.keyAt(k));
        paramParcel.writeInt(((Integer)this.checkIdState.valueAt(k)).intValue());
      }
    }
  }

  public static abstract interface SelectionBoundsAdjuster
  {
    public abstract void adjustListItemSelectionBounds(Rect paramRect);
  }

  private class WindowRunnnable
  {
    private int mOriginalAttachCount;

    private WindowRunnnable()
    {
    }

    public void rememberWindowAttachCount()
    {
      this.mOriginalAttachCount = AbsHListView.this.getWindowAttachCount();
    }

    public boolean sameWindow()
    {
      return (AbsHListView.this.hasWindowFocus()) && (AbsHListView.this.getWindowAttachCount() == this.mOriginalAttachCount);
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     it.sephiroth.android.library.widget.AbsHListView
 * JD-Core Version:    0.6.2
 */