package org.apache.commons.codec.binary;

import org.apache.commons.codec.BinaryDecoder;
import org.apache.commons.codec.BinaryEncoder;
import org.apache.commons.codec.DecoderException;
import org.apache.commons.codec.EncoderException;

public class Base64
  implements BinaryEncoder, BinaryDecoder
{
  static final int BASELENGTH = 255;
  static final byte[] CHUNK_SEPARATOR = "\r\n".getBytes();
  static final int CHUNK_SIZE = 76;
  static final int EIGHTBIT = 8;
  static final int FOURBYTE = 4;
  static final int LOOKUPLENGTH = 64;
  static final byte PAD = 61;
  static final int SIGN = -128;
  static final int SIXTEENBIT = 16;
  static final int TWENTYFOURBITGROUP = 24;
  private static byte[] base64Alphabet = new byte['ÿ'];
  private static byte[] lookUpBase64Alphabet = new byte[64];

  static
  {
    for (int i = 0; i < 255; i++)
      base64Alphabet[i] = -1;
    for (int j = 90; j >= 65; j--)
      base64Alphabet[j] = ((byte)(j - 65));
    for (int k = 122; k >= 97; k--)
      base64Alphabet[k] = ((byte)(26 + (k - 97)));
    for (int m = 57; m >= 48; m--)
      base64Alphabet[m] = ((byte)(52 + (m - 48)));
    base64Alphabet[43] = 62;
    base64Alphabet[47] = 63;
    for (int n = 0; n <= 25; n++)
      lookUpBase64Alphabet[n] = ((byte)(n + 65));
    int i1 = 26;
    for (int i2 = 0; i1 <= 51; i2++)
    {
      lookUpBase64Alphabet[i1] = ((byte)(i2 + 97));
      i1++;
    }
    int i3 = 52;
    for (int i4 = 0; i3 <= 61; i4++)
    {
      lookUpBase64Alphabet[i3] = ((byte)(i4 + 48));
      i3++;
    }
    lookUpBase64Alphabet[62] = 43;
    lookUpBase64Alphabet[63] = 47;
  }

  public static byte[] decodeBase64(byte[] paramArrayOfByte)
  {
    byte[] arrayOfByte1 = discardNonBase64(paramArrayOfByte);
    if (arrayOfByte1.length == 0)
    {
      arrayOfByte2 = new byte[0];
      return arrayOfByte2;
    }
    int i = arrayOfByte1.length / 4;
    int j = 0;
    int k = arrayOfByte1.length;
    while (arrayOfByte1[(k - 1)] == 61)
    {
      k--;
      if (k == 0)
        return new byte[0];
    }
    byte[] arrayOfByte2 = new byte[k - i];
    int m = 0;
    label61: int i1;
    int i2;
    int i3;
    int i4;
    if (m < i)
    {
      int n = m * 4;
      i1 = arrayOfByte1[(n + 2)];
      i2 = arrayOfByte1[(n + 3)];
      i3 = base64Alphabet[arrayOfByte1[n]];
      i4 = base64Alphabet[arrayOfByte1[(n + 1)]];
      if ((i1 == 61) || (i2 == 61))
        break label201;
      int i6 = base64Alphabet[i1];
      int i7 = base64Alphabet[i2];
      arrayOfByte2[j] = ((byte)(i3 << 2 | i4 >> 4));
      arrayOfByte2[(j + 1)] = ((byte)((i4 & 0xF) << 4 | 0xF & i6 >> 2));
      arrayOfByte2[(j + 2)] = ((byte)(i7 | i6 << 6));
    }
    while (true)
    {
      j += 3;
      m++;
      break label61;
      break;
      label201: if (i1 == 61)
      {
        arrayOfByte2[j] = ((byte)(i3 << 2 | i4 >> 4));
      }
      else if (i2 == 61)
      {
        int i5 = base64Alphabet[i1];
        arrayOfByte2[j] = ((byte)(i3 << 2 | i4 >> 4));
        arrayOfByte2[(j + 1)] = ((byte)((i4 & 0xF) << 4 | 0xF & i5 >> 2));
      }
    }
  }

  static byte[] discardNonBase64(byte[] paramArrayOfByte)
  {
    byte[] arrayOfByte1 = new byte[paramArrayOfByte.length];
    int i = 0;
    for (int j = 0; j < paramArrayOfByte.length; j++)
      if (isBase64(paramArrayOfByte[j]))
      {
        int k = i + 1;
        arrayOfByte1[i] = paramArrayOfByte[j];
        i = k;
      }
    byte[] arrayOfByte2 = new byte[i];
    System.arraycopy(arrayOfByte1, 0, arrayOfByte2, 0, i);
    return arrayOfByte2;
  }

  static byte[] discardWhitespace(byte[] paramArrayOfByte)
  {
    byte[] arrayOfByte1 = new byte[paramArrayOfByte.length];
    int i = 0;
    for (int j = 0; j < paramArrayOfByte.length; j++)
      switch (paramArrayOfByte[j])
      {
      default:
        int k = i + 1;
        arrayOfByte1[i] = paramArrayOfByte[j];
        i = k;
      case 9:
      case 10:
      case 13:
      case 32:
      }
    byte[] arrayOfByte2 = new byte[i];
    System.arraycopy(arrayOfByte1, 0, arrayOfByte2, 0, i);
    return arrayOfByte2;
  }

  public static byte[] encodeBase64(byte[] paramArrayOfByte)
  {
    return encodeBase64(paramArrayOfByte, false);
  }

  public static byte[] encodeBase64(byte[] paramArrayOfByte, boolean paramBoolean)
  {
    int i = 8 * paramArrayOfByte.length;
    int j = i % 24;
    int k = i / 24;
    int m;
    int n;
    label46: byte[] arrayOfByte;
    int i1;
    int i2;
    int i3;
    int i4;
    label77: int i16;
    int i17;
    int i18;
    int i19;
    int i20;
    int i21;
    label142: int i22;
    if (j != 0)
    {
      m = 4 * (k + 1);
      n = 0;
      if (paramBoolean)
      {
        if (CHUNK_SEPARATOR.length != 0)
          break label309;
        n = 0;
        m += n * CHUNK_SEPARATOR.length;
      }
      arrayOfByte = new byte[m];
      i1 = 0;
      i2 = 76;
      i3 = 0;
      i4 = 0;
      if (i4 >= k)
        break label368;
      int i15 = i4 * 3;
      i16 = paramArrayOfByte[i15];
      i17 = paramArrayOfByte[(i15 + 1)];
      i18 = paramArrayOfByte[(i15 + 2)];
      i19 = (byte)(i17 & 0xF);
      i20 = (byte)(i16 & 0x3);
      if ((i16 & 0xFFFFFF80) != 0)
        break label325;
      i21 = (byte)(i16 >> 2);
      if ((i17 & 0xFFFFFF80) != 0)
        break label339;
      i22 = (byte)(i17 >> 4);
      label157: if ((i18 & 0xFFFFFF80) != 0)
        break label353;
    }
    label309: label325: label339: label353: for (int i23 = (byte)(i18 >> 6); ; i23 = (byte)(0xFC ^ i18 >> 6))
    {
      arrayOfByte[i1] = lookUpBase64Alphabet[i21];
      arrayOfByte[(i1 + 1)] = lookUpBase64Alphabet[(i22 | i20 << 4)];
      arrayOfByte[(i1 + 2)] = lookUpBase64Alphabet[(i23 | i19 << 2)];
      arrayOfByte[(i1 + 3)] = lookUpBase64Alphabet[(i18 & 0x3F)];
      i1 += 4;
      if ((paramBoolean) && (i1 == i2))
      {
        System.arraycopy(CHUNK_SEPARATOR, 0, arrayOfByte, i1, CHUNK_SEPARATOR.length);
        i3++;
        i2 = 76 * (i3 + 1) + i3 * CHUNK_SEPARATOR.length;
        i1 += CHUNK_SEPARATOR.length;
      }
      i4++;
      break label77;
      m = k * 4;
      break;
      n = (int)Math.ceil(m / 76.0F);
      break label46;
      i21 = (byte)(0xC0 ^ i16 >> 2);
      break label142;
      i22 = (byte)(0xF0 ^ i17 >> 4);
      break label157;
    }
    label368: int i5 = i4 * 3;
    if (j == 8)
    {
      i12 = paramArrayOfByte[i5];
      i13 = (byte)(i12 & 0x3);
      if ((i12 & 0xFFFFFF80) == 0)
      {
        i14 = (byte)(i12 >> 2);
        arrayOfByte[i1] = lookUpBase64Alphabet[i14];
        arrayOfByte[(i1 + 1)] = lookUpBase64Alphabet[(i13 << 4)];
        arrayOfByte[(i1 + 2)] = 61;
        arrayOfByte[(i1 + 3)] = 61;
      }
    }
    while (j != 16)
      while (true)
      {
        int i12;
        int i13;
        if ((paramBoolean) && (i3 < n))
          System.arraycopy(CHUNK_SEPARATOR, 0, arrayOfByte, m - CHUNK_SEPARATOR.length, CHUNK_SEPARATOR.length);
        return arrayOfByte;
        int i14 = (byte)(0xC0 ^ i12 >> 2);
      }
    int i6 = paramArrayOfByte[i5];
    int i7 = paramArrayOfByte[(i5 + 1)];
    int i8 = (byte)(i7 & 0xF);
    int i9 = (byte)(i6 & 0x3);
    int i10;
    if ((i6 & 0xFFFFFF80) == 0)
    {
      i10 = (byte)(i6 >> 2);
      label550: if ((i7 & 0xFFFFFF80) != 0)
        break label635;
    }
    label635: for (int i11 = (byte)(i7 >> 4); ; i11 = (byte)(0xF0 ^ i7 >> 4))
    {
      arrayOfByte[i1] = lookUpBase64Alphabet[i10];
      arrayOfByte[(i1 + 1)] = lookUpBase64Alphabet[(i11 | i9 << 4)];
      arrayOfByte[(i1 + 2)] = lookUpBase64Alphabet[(i8 << 2)];
      arrayOfByte[(i1 + 3)] = 61;
      break;
      i10 = (byte)(0xC0 ^ i6 >> 2);
      break label550;
    }
  }

  public static byte[] encodeBase64Chunked(byte[] paramArrayOfByte)
  {
    return encodeBase64(paramArrayOfByte, true);
  }

  public static boolean isArrayByteBase64(byte[] paramArrayOfByte)
  {
    byte[] arrayOfByte = discardWhitespace(paramArrayOfByte);
    int i = arrayOfByte.length;
    if (i == 0);
    while (true)
    {
      return true;
      for (int j = 0; j < i; j++)
        if (!isBase64(arrayOfByte[j]))
          return false;
    }
  }

  private static boolean isBase64(byte paramByte)
  {
    if (paramByte == 61);
    while (base64Alphabet[paramByte] != -1)
      return true;
    return false;
  }

  public Object decode(Object paramObject)
    throws DecoderException
  {
    if (!(paramObject instanceof byte[]))
      throw new DecoderException("Parameter supplied to Base64 decode is not a byte[]");
    return decode((byte[])paramObject);
  }

  public byte[] decode(byte[] paramArrayOfByte)
  {
    return decodeBase64(paramArrayOfByte);
  }

  public Object encode(Object paramObject)
    throws EncoderException
  {
    if (!(paramObject instanceof byte[]))
      throw new EncoderException("Parameter supplied to Base64 encode is not a byte[]");
    return encode((byte[])paramObject);
  }

  public byte[] encode(byte[] paramArrayOfByte)
  {
    return encodeBase64(paramArrayOfByte, false);
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     org.apache.commons.codec.binary.Base64
 * JD-Core Version:    0.6.2
 */