package com.actionbarsherlock.app;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.drawable.Drawable;
import android.support.v4.app.FragmentTransaction;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewDebug.ExportedProperty;
import android.view.ViewGroup.LayoutParams;
import android.view.ViewGroup.MarginLayoutParams;
import android.widget.SpinnerAdapter;

public abstract class ActionBar
{
  public static final int DISPLAY_HOME_AS_UP = 4;
  public static final int DISPLAY_SHOW_CUSTOM = 16;
  public static final int DISPLAY_SHOW_HOME = 2;
  public static final int DISPLAY_SHOW_TITLE = 8;
  public static final int DISPLAY_USE_LOGO = 1;
  public static final int NAVIGATION_MODE_LIST = 1;
  public static final int NAVIGATION_MODE_STANDARD = 0;
  public static final int NAVIGATION_MODE_TABS = 2;

  public abstract void addOnMenuVisibilityListener(OnMenuVisibilityListener paramOnMenuVisibilityListener);

  public abstract void addTab(Tab paramTab);

  public abstract void addTab(Tab paramTab, int paramInt);

  public abstract void addTab(Tab paramTab, int paramInt, boolean paramBoolean);

  public abstract void addTab(Tab paramTab, boolean paramBoolean);

  public abstract View getCustomView();

  public abstract int getDisplayOptions();

  public abstract int getHeight();

  public abstract int getNavigationItemCount();

  public abstract int getNavigationMode();

  public abstract int getSelectedNavigationIndex();

  public abstract Tab getSelectedTab();

  public abstract CharSequence getSubtitle();

  public abstract Tab getTabAt(int paramInt);

  public abstract int getTabCount();

  public Context getThemedContext()
  {
    return null;
  }

  public abstract CharSequence getTitle();

  public abstract void hide();

  public abstract boolean isShowing();

  public abstract Tab newTab();

  public abstract void removeAllTabs();

  public abstract void removeOnMenuVisibilityListener(OnMenuVisibilityListener paramOnMenuVisibilityListener);

  public abstract void removeTab(Tab paramTab);

  public abstract void removeTabAt(int paramInt);

  public abstract void selectTab(Tab paramTab);

  public abstract void setBackgroundDrawable(Drawable paramDrawable);

  public abstract void setCustomView(int paramInt);

  public abstract void setCustomView(View paramView);

  public abstract void setCustomView(View paramView, LayoutParams paramLayoutParams);

  public abstract void setDisplayHomeAsUpEnabled(boolean paramBoolean);

  public abstract void setDisplayOptions(int paramInt);

  public abstract void setDisplayOptions(int paramInt1, int paramInt2);

  public abstract void setDisplayShowCustomEnabled(boolean paramBoolean);

  public abstract void setDisplayShowHomeEnabled(boolean paramBoolean);

  public abstract void setDisplayShowTitleEnabled(boolean paramBoolean);

  public abstract void setDisplayUseLogoEnabled(boolean paramBoolean);

  public void setHomeButtonEnabled(boolean paramBoolean)
  {
  }

  public abstract void setIcon(int paramInt);

  public abstract void setIcon(Drawable paramDrawable);

  public abstract void setListNavigationCallbacks(SpinnerAdapter paramSpinnerAdapter, OnNavigationListener paramOnNavigationListener);

  public abstract void setLogo(int paramInt);

  public abstract void setLogo(Drawable paramDrawable);

  public abstract void setNavigationMode(int paramInt);

  public abstract void setSelectedNavigationItem(int paramInt);

  public void setSplitBackgroundDrawable(Drawable paramDrawable)
  {
  }

  public void setStackedBackgroundDrawable(Drawable paramDrawable)
  {
  }

  public abstract void setSubtitle(int paramInt);

  public abstract void setSubtitle(CharSequence paramCharSequence);

  public abstract void setTitle(int paramInt);

  public abstract void setTitle(CharSequence paramCharSequence);

  public abstract void show();

  public static class LayoutParams extends ViewGroup.MarginLayoutParams
  {
    private static final int[] ATTRS = { 16842931 };

    @ViewDebug.ExportedProperty(mapping={@android.view.ViewDebug.IntToString(from=-1, to="NONE"), @android.view.ViewDebug.IntToString(from=0, to="NONE"), @android.view.ViewDebug.IntToString(from=48, to="TOP"), @android.view.ViewDebug.IntToString(from=80, to="BOTTOM"), @android.view.ViewDebug.IntToString(from=3, to="LEFT"), @android.view.ViewDebug.IntToString(from=5, to="RIGHT"), @android.view.ViewDebug.IntToString(from=16, to="CENTER_VERTICAL"), @android.view.ViewDebug.IntToString(from=112, to="FILL_VERTICAL"), @android.view.ViewDebug.IntToString(from=1, to="CENTER_HORIZONTAL"), @android.view.ViewDebug.IntToString(from=7, to="FILL_HORIZONTAL"), @android.view.ViewDebug.IntToString(from=17, to="CENTER"), @android.view.ViewDebug.IntToString(from=119, to="FILL")})
    public int gravity = -1;

    public LayoutParams(int paramInt)
    {
      this(-2, -1, paramInt);
    }

    public LayoutParams(int paramInt1, int paramInt2)
    {
      super(paramInt2);
      this.gravity = 19;
    }

    public LayoutParams(int paramInt1, int paramInt2, int paramInt3)
    {
      super(paramInt2);
      this.gravity = paramInt3;
    }

    public LayoutParams(Context paramContext, AttributeSet paramAttributeSet)
    {
      super(paramAttributeSet);
      TypedArray localTypedArray = paramContext.obtainStyledAttributes(paramAttributeSet, ATTRS);
      this.gravity = localTypedArray.getInt(0, -1);
      localTypedArray.recycle();
    }

    public LayoutParams(ViewGroup.LayoutParams paramLayoutParams)
    {
      super();
    }

    public LayoutParams(LayoutParams paramLayoutParams)
    {
      super();
      this.gravity = paramLayoutParams.gravity;
    }
  }

  public static abstract interface OnMenuVisibilityListener
  {
    public abstract void onMenuVisibilityChanged(boolean paramBoolean);
  }

  public static abstract interface OnNavigationListener
  {
    public abstract boolean onNavigationItemSelected(int paramInt, long paramLong);
  }

  public static abstract class Tab
  {
    public static final int INVALID_POSITION = -1;

    public abstract CharSequence getContentDescription();

    public abstract View getCustomView();

    public abstract Drawable getIcon();

    public abstract int getPosition();

    public abstract Object getTag();

    public abstract CharSequence getText();

    public abstract void select();

    public abstract Tab setContentDescription(int paramInt);

    public abstract Tab setContentDescription(CharSequence paramCharSequence);

    public abstract Tab setCustomView(int paramInt);

    public abstract Tab setCustomView(View paramView);

    public abstract Tab setIcon(int paramInt);

    public abstract Tab setIcon(Drawable paramDrawable);

    public abstract Tab setTabListener(ActionBar.TabListener paramTabListener);

    public abstract Tab setTag(Object paramObject);

    public abstract Tab setText(int paramInt);

    public abstract Tab setText(CharSequence paramCharSequence);
  }

  public static abstract interface TabListener
  {
    public abstract void onTabReselected(ActionBar.Tab paramTab, FragmentTransaction paramFragmentTransaction);

    public abstract void onTabSelected(ActionBar.Tab paramTab, FragmentTransaction paramFragmentTransaction);

    public abstract void onTabUnselected(ActionBar.Tab paramTab, FragmentTransaction paramFragmentTransaction);
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.actionbarsherlock.app.ActionBar
 * JD-Core Version:    0.6.2
 */