package com.actionbarsherlock.internal;

import android.app.Activity;
import android.content.Context;
import android.content.res.Resources.Theme;
import android.util.Log;
import android.util.TypedValue;
import android.view.ContextThemeWrapper;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.view.Window;
import com.actionbarsherlock.ActionBarSherlock;
import com.actionbarsherlock.ActionBarSherlock.Implementation;
import com.actionbarsherlock.ActionBarSherlock.OnActionModeFinishedListener;
import com.actionbarsherlock.ActionBarSherlock.OnActionModeStartedListener;
import com.actionbarsherlock.app.ActionBar;
import com.actionbarsherlock.internal.app.ActionBarWrapper;
import com.actionbarsherlock.internal.view.menu.MenuItemWrapper;
import com.actionbarsherlock.internal.view.menu.MenuWrapper;
import com.actionbarsherlock.view.MenuInflater;

@ActionBarSherlock.Implementation(api=14)
public class ActionBarSherlockNative extends ActionBarSherlock
{
  private ActionBarWrapper mActionBar;
  private ActionModeWrapper mActionMode;
  private MenuWrapper mMenu;

  public ActionBarSherlockNative(Activity paramActivity, int paramInt)
  {
    super(paramActivity, paramInt);
  }

  private void initActionBar()
  {
    if ((this.mActionBar != null) || (this.mActivity.getActionBar() == null))
      return;
    this.mActionBar = new ActionBarWrapper(this.mActivity);
  }

  public void addContentView(View paramView, ViewGroup.LayoutParams paramLayoutParams)
  {
    Log.d("ActionBarSherlock", "[addContentView] view: " + paramView + ", params: " + paramLayoutParams);
    this.mActivity.getWindow().addContentView(paramView, paramLayoutParams);
    initActionBar();
  }

  public boolean dispatchCreateOptionsMenu(Menu paramMenu)
  {
    Log.d("ActionBarSherlock", "[dispatchCreateOptionsMenu] menu: " + paramMenu);
    if ((this.mMenu == null) || (paramMenu != this.mMenu.unwrap()))
      this.mMenu = new MenuWrapper(paramMenu);
    boolean bool = callbackCreateOptionsMenu(this.mMenu);
    Log.d("ActionBarSherlock", "[dispatchCreateOptionsMenu] returning " + bool);
    return bool;
  }

  public void dispatchInvalidateOptionsMenu()
  {
    Log.d("ActionBarSherlock", "[dispatchInvalidateOptionsMenu]");
    this.mActivity.getWindow().invalidatePanelMenu(0);
    if (this.mMenu != null)
      this.mMenu.invalidate();
  }

  public boolean dispatchOptionsItemSelected(android.view.MenuItem paramMenuItem)
  {
    Log.d("ActionBarSherlock", "[dispatchOptionsItemSelected] item: " + paramMenuItem.getTitleCondensed());
    if (this.mMenu == null)
      if (paramMenuItem.getItemId() != 16908332)
        throw new IllegalStateException("Non-home action item clicked before onCreateOptionsMenu with ID " + paramMenuItem.getItemId());
    for (Object localObject = new MenuItemWrapper(paramMenuItem); ; localObject = this.mMenu.findItem(paramMenuItem))
    {
      boolean bool = callbackOptionsItemSelected((com.actionbarsherlock.view.MenuItem)localObject);
      Log.d("ActionBarSherlock", "[dispatchOptionsItemSelected] returning " + bool);
      return bool;
    }
  }

  public boolean dispatchPrepareOptionsMenu(Menu paramMenu)
  {
    Log.d("ActionBarSherlock", "[dispatchPrepareOptionsMenu] menu: " + paramMenu);
    boolean bool = callbackPrepareOptionsMenu(this.mMenu);
    Log.d("ActionBarSherlock", "[dispatchPrepareOptionsMenu] returning " + bool);
    return bool;
  }

  public ActionBar getActionBar()
  {
    Log.d("ActionBarSherlock", "[getActionBar]");
    initActionBar();
    return this.mActionBar;
  }

  protected Context getThemedContext()
  {
    Object localObject = this.mActivity;
    TypedValue localTypedValue = new TypedValue();
    this.mActivity.getTheme().resolveAttribute(16843671, localTypedValue, true);
    if (localTypedValue.resourceId != 0)
      localObject = new ContextThemeWrapper((Context)localObject, localTypedValue.resourceId);
    return localObject;
  }

  public boolean hasFeature(int paramInt)
  {
    Log.d("ActionBarSherlock", "[hasFeature] feature: " + paramInt);
    boolean bool = this.mActivity.getWindow().hasFeature(paramInt);
    Log.d("ActionBarSherlock", "[hasFeature] returning " + bool);
    return bool;
  }

  public boolean requestFeature(int paramInt)
  {
    Log.d("ActionBarSherlock", "[requestFeature] featureId: " + paramInt);
    boolean bool = this.mActivity.getWindow().requestFeature(paramInt);
    Log.d("ActionBarSherlock", "[requestFeature] returning " + bool);
    return bool;
  }

  public void setContentView(int paramInt)
  {
    Log.d("ActionBarSherlock", "[setContentView] layoutResId: " + paramInt);
    this.mActivity.getWindow().setContentView(paramInt);
    initActionBar();
  }

  public void setContentView(View paramView, ViewGroup.LayoutParams paramLayoutParams)
  {
    Log.d("ActionBarSherlock", "[setContentView] view: " + paramView + ", params: " + paramLayoutParams);
    this.mActivity.getWindow().setContentView(paramView, paramLayoutParams);
    initActionBar();
  }

  public void setProgress(int paramInt)
  {
    Log.d("ActionBarSherlock", "[setProgress] progress: " + paramInt);
    this.mActivity.setProgress(paramInt);
  }

  public void setProgressBarIndeterminate(boolean paramBoolean)
  {
    Log.d("ActionBarSherlock", "[setProgressBarIndeterminate] indeterminate: " + paramBoolean);
    this.mActivity.setProgressBarIndeterminate(paramBoolean);
  }

  public void setProgressBarIndeterminateVisibility(boolean paramBoolean)
  {
    Log.d("ActionBarSherlock", "[setProgressBarIndeterminateVisibility] visible: " + paramBoolean);
    this.mActivity.setProgressBarIndeterminateVisibility(paramBoolean);
  }

  public void setProgressBarVisibility(boolean paramBoolean)
  {
    Log.d("ActionBarSherlock", "[setProgressBarVisibility] visible: " + paramBoolean);
    this.mActivity.setProgressBarVisibility(paramBoolean);
  }

  public void setSecondaryProgress(int paramInt)
  {
    Log.d("ActionBarSherlock", "[setSecondaryProgress] secondaryProgress: " + paramInt);
    this.mActivity.setSecondaryProgress(paramInt);
  }

  public void setTitle(CharSequence paramCharSequence)
  {
    Log.d("ActionBarSherlock", "[setTitle] title: " + paramCharSequence);
    this.mActivity.getWindow().setTitle(paramCharSequence);
  }

  public void setUiOptions(int paramInt)
  {
    Log.d("ActionBarSherlock", "[setUiOptions] uiOptions: " + paramInt);
    this.mActivity.getWindow().setUiOptions(paramInt);
  }

  public void setUiOptions(int paramInt1, int paramInt2)
  {
    Log.d("ActionBarSherlock", "[setUiOptions] uiOptions: " + paramInt1 + ", mask: " + paramInt2);
    this.mActivity.getWindow().setUiOptions(paramInt1, paramInt2);
  }

  public com.actionbarsherlock.view.ActionMode startActionMode(com.actionbarsherlock.view.ActionMode.Callback paramCallback)
  {
    Log.d("ActionBarSherlock", "[startActionMode] callback: " + paramCallback);
    if (this.mActionMode != null)
      this.mActionMode.finish();
    ActionModeCallbackWrapper localActionModeCallbackWrapper = null;
    if (paramCallback != null)
      localActionModeCallbackWrapper = new ActionModeCallbackWrapper(paramCallback);
    if (this.mActivity.startActionMode(localActionModeCallbackWrapper) == null)
      this.mActionMode = null;
    if (((this.mActivity instanceof ActionBarSherlock.OnActionModeStartedListener)) && (this.mActionMode != null))
      ((ActionBarSherlock.OnActionModeStartedListener)this.mActivity).onActionModeStarted(this.mActionMode);
    return this.mActionMode;
  }

  private class ActionModeCallbackWrapper
    implements android.view.ActionMode.Callback
  {
    private final com.actionbarsherlock.view.ActionMode.Callback mCallback;

    public ActionModeCallbackWrapper(com.actionbarsherlock.view.ActionMode.Callback arg2)
    {
      Object localObject;
      this.mCallback = localObject;
    }

    public boolean onActionItemClicked(android.view.ActionMode paramActionMode, android.view.MenuItem paramMenuItem)
    {
      return this.mCallback.onActionItemClicked(ActionBarSherlockNative.this.mActionMode, ActionBarSherlockNative.this.mActionMode.getMenu().findItem(paramMenuItem));
    }

    public boolean onCreateActionMode(android.view.ActionMode paramActionMode, Menu paramMenu)
    {
      ActionBarSherlockNative.this.mActionMode = new ActionBarSherlockNative.ActionModeWrapper(ActionBarSherlockNative.this, paramActionMode);
      return this.mCallback.onCreateActionMode(ActionBarSherlockNative.this.mActionMode, ActionBarSherlockNative.this.mActionMode.getMenu());
    }

    public void onDestroyActionMode(android.view.ActionMode paramActionMode)
    {
      this.mCallback.onDestroyActionMode(ActionBarSherlockNative.this.mActionMode);
      if ((ActionBarSherlockNative.this.mActivity instanceof ActionBarSherlock.OnActionModeFinishedListener))
        ((ActionBarSherlock.OnActionModeFinishedListener)ActionBarSherlockNative.this.mActivity).onActionModeFinished(ActionBarSherlockNative.this.mActionMode);
    }

    public boolean onPrepareActionMode(android.view.ActionMode paramActionMode, Menu paramMenu)
    {
      return this.mCallback.onPrepareActionMode(ActionBarSherlockNative.this.mActionMode, ActionBarSherlockNative.this.mActionMode.getMenu());
    }
  }

  private class ActionModeWrapper extends com.actionbarsherlock.view.ActionMode
  {
    private final android.view.ActionMode mActionMode;
    private MenuWrapper mMenu = null;

    ActionModeWrapper(android.view.ActionMode arg2)
    {
      Object localObject;
      this.mActionMode = localObject;
    }

    public void finish()
    {
      this.mActionMode.finish();
    }

    public View getCustomView()
    {
      return this.mActionMode.getCustomView();
    }

    public MenuWrapper getMenu()
    {
      if (this.mMenu == null)
        this.mMenu = new MenuWrapper(this.mActionMode.getMenu());
      return this.mMenu;
    }

    public MenuInflater getMenuInflater()
    {
      return ActionBarSherlockNative.this.getMenuInflater();
    }

    public CharSequence getSubtitle()
    {
      return this.mActionMode.getSubtitle();
    }

    public Object getTag()
    {
      return this.mActionMode.getTag();
    }

    public CharSequence getTitle()
    {
      return this.mActionMode.getTitle();
    }

    public void invalidate()
    {
      this.mActionMode.invalidate();
      if (this.mMenu != null)
        this.mMenu.invalidate();
    }

    public void setCustomView(View paramView)
    {
      this.mActionMode.setCustomView(paramView);
    }

    public void setSubtitle(int paramInt)
    {
      this.mActionMode.setSubtitle(paramInt);
    }

    public void setSubtitle(CharSequence paramCharSequence)
    {
      this.mActionMode.setSubtitle(paramCharSequence);
    }

    public void setTag(Object paramObject)
    {
      this.mActionMode.setTag(paramObject);
    }

    public void setTitle(int paramInt)
    {
      this.mActionMode.setTitle(paramInt);
    }

    public void setTitle(CharSequence paramCharSequence)
    {
      this.mActionMode.setTitle(paramCharSequence);
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.actionbarsherlock.internal.ActionBarSherlockNative
 * JD-Core Version:    0.6.2
 */