package com.commonsware.cwac.camera;

import android.annotation.TargetApi;
import android.content.Context;
import android.graphics.Bitmap;
import android.hardware.Camera;
import android.hardware.Camera.CameraInfo;
import android.hardware.Camera.Parameters;
import android.hardware.Camera.ShutterCallback;
import android.hardware.Camera.Size;
import android.media.CamcorderProfile;
import android.media.MediaActionSound;
import android.media.MediaRecorder;
import android.media.MediaScannerConnection;
import android.os.Build.VERSION;
import android.os.Environment;
import android.util.Log;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileDescriptor;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

public class SimpleCameraHost
  implements CameraHost
{
  private static final String[] SCAN_TYPES = { "image/jpeg" };
  private int cameraId = -1;
  private Context ctxt = null;
  private boolean mirrorFFC = false;
  private File photoDirectory = null;
  private DeviceProfile profile = null;
  private CameraHost.RecordingHint recordingHint = null;
  private boolean scanSavedImage = true;
  private boolean useFrontFacingCamera = false;
  private boolean useFullBleedPreview = true;
  private boolean useSingleShotMode = false;
  private File videoDirectory = null;

  public SimpleCameraHost(Context paramContext)
  {
    this.ctxt = paramContext.getApplicationContext();
  }

  private void initCameraId()
  {
    int i = Camera.getNumberOfCameras();
    int j = -1;
    Camera.CameraInfo localCameraInfo;
    if (i > 0)
      localCameraInfo = new Camera.CameraInfo();
    for (int k = 0; ; k++)
    {
      j = 0;
      if (k >= i);
      while (true)
      {
        this.cameraId = j;
        return;
        Camera.getCameraInfo(k, localCameraInfo);
        if ((localCameraInfo.facing == 0) && (!useFrontFacingCamera()))
        {
          j = k;
        }
        else
        {
          if ((localCameraInfo.facing != 1) || (!useFrontFacingCamera()))
            break;
          j = k;
        }
      }
    }
  }

  private void initDeviceProfile(Context paramContext)
  {
    this.profile = DeviceProfile.getInstance(paramContext);
  }

  private void initPhotoDirectory()
  {
    this.photoDirectory = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DCIM);
  }

  private void initRecordingHint()
  {
    this.recordingHint = CameraHost.RecordingHint.ANY;
  }

  private void initVideoDirectory()
  {
    this.videoDirectory = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_MOVIES);
  }

  public Camera.Parameters adjustPictureParameters(PictureTransaction paramPictureTransaction, Camera.Parameters paramParameters)
  {
    return paramParameters;
  }

  public Camera.Parameters adjustPreviewParameters(Camera.Parameters paramParameters)
  {
    return paramParameters;
  }

  public void autoFocusAvailable()
  {
  }

  public void autoFocusUnavailable()
  {
  }

  public void configureRecorderAudio(int paramInt, MediaRecorder paramMediaRecorder)
  {
    paramMediaRecorder.setAudioSource(5);
  }

  public void configureRecorderOutput(int paramInt, MediaRecorder paramMediaRecorder)
  {
    paramMediaRecorder.setOutputFile(getVideoPath().getAbsolutePath());
  }

  @TargetApi(11)
  public void configureRecorderProfile(int paramInt, MediaRecorder paramMediaRecorder)
  {
    if ((Build.VERSION.SDK_INT < 11) || (CamcorderProfile.hasProfile(paramInt, 1)))
    {
      paramMediaRecorder.setProfile(CamcorderProfile.get(paramInt, 1));
      return;
    }
    if ((Build.VERSION.SDK_INT >= 11) && (CamcorderProfile.hasProfile(paramInt, 0)))
    {
      paramMediaRecorder.setProfile(CamcorderProfile.get(paramInt, 0));
      return;
    }
    throw new IllegalStateException("cannot find valid CamcorderProfile");
  }

  public int getCameraId()
  {
    if (this.cameraId == -1)
      initCameraId();
    return this.cameraId;
  }

  public DeviceProfile getDeviceProfile()
  {
    if (this.profile == null)
      initDeviceProfile(this.ctxt);
    return this.profile;
  }

  protected File getPhotoDirectory()
  {
    if (this.photoDirectory == null)
      initPhotoDirectory();
    return this.photoDirectory;
  }

  protected String getPhotoFilename()
  {
    String str = new SimpleDateFormat("yyyyMMdd_HHmmss", Locale.US).format(new Date());
    return "Photo_" + str + ".jpg";
  }

  protected File getPhotoPath()
  {
    File localFile = getPhotoDirectory();
    localFile.mkdirs();
    return new File(localFile, getPhotoFilename());
  }

  public Camera.Size getPictureSize(PictureTransaction paramPictureTransaction, Camera.Parameters paramParameters)
  {
    return CameraUtils.getLargestPictureSize(this, paramParameters);
  }

  @TargetApi(11)
  public Camera.Size getPreferredPreviewSizeForVideo(int paramInt1, int paramInt2, int paramInt3, Camera.Parameters paramParameters, Camera.Size paramSize)
  {
    if (paramSize != null)
      return paramSize;
    if (Build.VERSION.SDK_INT >= 11)
      return paramParameters.getPreferredPreviewSizeForVideo();
    return null;
  }

  public Camera.Size getPreviewSize(int paramInt1, int paramInt2, int paramInt3, Camera.Parameters paramParameters)
  {
    return CameraUtils.getBestAspectPreviewSize(paramInt1, paramInt2, paramInt3, paramParameters);
  }

  public CameraHost.RecordingHint getRecordingHint()
  {
    if (this.recordingHint == null)
      initRecordingHint();
    return this.recordingHint;
  }

  public Camera.ShutterCallback getShutterCallback()
  {
    return null;
  }

  protected File getVideoDirectory()
  {
    if (this.videoDirectory == null)
      initVideoDirectory();
    return this.videoDirectory;
  }

  protected String getVideoFilename()
  {
    String str = new SimpleDateFormat("yyyyMMdd_HHmmss", Locale.US).format(new Date());
    return "Video_" + str + ".mp4";
  }

  protected File getVideoPath()
  {
    File localFile = getVideoDirectory();
    localFile.mkdirs();
    return new File(localFile, getVideoFilename());
  }

  public void handleException(Exception paramException)
  {
    Log.e(getClass().getSimpleName(), "Exception in setPreviewDisplay()", paramException);
  }

  public float maxPictureCleanupHeapUsage()
  {
    return 1.0F;
  }

  public boolean mirrorFFC()
  {
    return this.mirrorFFC;
  }

  @TargetApi(16)
  public void onAutoFocus(boolean paramBoolean, Camera paramCamera)
  {
    if ((paramBoolean) && (Build.VERSION.SDK_INT >= 16))
      new MediaActionSound().play(1);
  }

  public void onCameraFail(CameraHost.FailureReason paramFailureReason)
  {
    Object[] arrayOfObject = new Object[1];
    arrayOfObject[0] = Integer.valueOf(paramFailureReason.value);
    Log.e("CWAC-Camera", String.format("Camera access failed: %d", arrayOfObject));
  }

  public void saveImage(PictureTransaction paramPictureTransaction, Bitmap paramBitmap)
  {
  }

  public void saveImage(PictureTransaction paramPictureTransaction, byte[] paramArrayOfByte)
  {
    File localFile = getPhotoPath();
    if (localFile.exists())
      localFile.delete();
    try
    {
      FileOutputStream localFileOutputStream = new FileOutputStream(localFile.getPath());
      BufferedOutputStream localBufferedOutputStream = new BufferedOutputStream(localFileOutputStream);
      localBufferedOutputStream.write(paramArrayOfByte);
      localBufferedOutputStream.flush();
      localFileOutputStream.getFD().sync();
      localBufferedOutputStream.close();
      if (scanSavedImage())
      {
        Context localContext = this.ctxt;
        String[] arrayOfString = new String[1];
        arrayOfString[0] = localFile.getPath();
        MediaScannerConnection.scanFile(localContext, arrayOfString, SCAN_TYPES, null);
      }
      return;
    }
    catch (IOException localIOException)
    {
      handleException(localIOException);
    }
  }

  protected boolean scanSavedImage()
  {
    return this.scanSavedImage;
  }

  protected boolean useFrontFacingCamera()
  {
    return this.useFrontFacingCamera;
  }

  public boolean useFullBleedPreview()
  {
    return this.useFullBleedPreview;
  }

  public boolean useSingleShotMode()
  {
    return this.useSingleShotMode;
  }

  public static class Builder
  {
    private SimpleCameraHost host = null;

    public Builder(Context paramContext)
    {
      this(new SimpleCameraHost(paramContext));
    }

    public Builder(SimpleCameraHost paramSimpleCameraHost)
    {
      this.host = paramSimpleCameraHost;
    }

    public SimpleCameraHost build()
    {
      return this.host;
    }

    public Builder cameraId(int paramInt)
    {
      this.host.cameraId = paramInt;
      return this;
    }

    public Builder deviceProfile(DeviceProfile paramDeviceProfile)
    {
      this.host.profile = paramDeviceProfile;
      return this;
    }

    public Builder mirrorFFC(boolean paramBoolean)
    {
      this.host.mirrorFFC = paramBoolean;
      return this;
    }

    public Builder photoDirectory(File paramFile)
    {
      this.host.photoDirectory = paramFile;
      return this;
    }

    public Builder recordingHint(CameraHost.RecordingHint paramRecordingHint)
    {
      this.host.recordingHint = paramRecordingHint;
      return this;
    }

    public Builder scanSavedImage(boolean paramBoolean)
    {
      this.host.scanSavedImage = paramBoolean;
      return this;
    }

    public Builder useFrontFacingCamera(boolean paramBoolean)
    {
      this.host.useFrontFacingCamera = paramBoolean;
      return this;
    }

    public Builder useFullBleedPreview(boolean paramBoolean)
    {
      this.host.useFullBleedPreview = paramBoolean;
      return this;
    }

    public Builder useSingleShotMode(boolean paramBoolean)
    {
      this.host.useSingleShotMode = paramBoolean;
      return this;
    }

    public Builder videoDirectory(File paramFile)
    {
      this.host.videoDirectory = paramFile;
      return this;
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.commonsware.cwac.camera.SimpleCameraHost
 * JD-Core Version:    0.6.2
 */