package com.loopj.android.http;

import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.util.Log;
import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import org.apache.http.Header;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.StatusLine;
import org.apache.http.client.HttpResponseException;
import org.apache.http.util.ByteArrayBuffer;

public abstract class AsyncHttpResponseHandler
  implements ResponseHandlerInterface
{
  protected static final int BUFFER_SIZE = 4096;
  protected static final int CANCEL_MESSAGE = 6;
  public static final String DEFAULT_CHARSET = "UTF-8";
  protected static final int FAILURE_MESSAGE = 1;
  protected static final int FINISH_MESSAGE = 3;
  private static final String LOG_TAG = "AsyncHttpResponseHandler";
  protected static final int PROGRESS_MESSAGE = 4;
  protected static final int RETRY_MESSAGE = 5;
  protected static final int START_MESSAGE = 2;
  protected static final int SUCCESS_MESSAGE;
  private final Handler handler = new ResponderHandler(this);
  private Header[] requestHeaders = null;
  private URI requestURI = null;
  private String responseCharset = "UTF-8";
  private Boolean useSynchronousMode = Boolean.valueOf(false);

  public AsyncHttpResponseHandler()
  {
    postRunnable(null);
  }

  public String getCharset()
  {
    if (this.responseCharset == null)
      return "UTF-8";
    return this.responseCharset;
  }

  public Header[] getRequestHeaders()
  {
    return this.requestHeaders;
  }

  public URI getRequestURI()
  {
    return this.requestURI;
  }

  byte[] getResponseData(HttpEntity paramHttpEntity)
    throws IOException
  {
    int i = 4096;
    Object localObject1 = null;
    InputStream localInputStream;
    long l;
    if (paramHttpEntity != null)
    {
      localInputStream = paramHttpEntity.getContent();
      localObject1 = null;
      if (localInputStream != null)
      {
        l = paramHttpEntity.getContentLength();
        if (l > 2147483647L)
          throw new IllegalArgumentException("HTTP entity too large to be buffered in memory");
        if (l >= 0L)
          break label124;
      }
    }
    try
    {
      while (true)
      {
        ByteArrayBuffer localByteArrayBuffer = new ByteArrayBuffer(i);
        try
        {
          byte[] arrayOfByte1 = new byte[4096];
          int j = 0;
          while (true)
          {
            int k = localInputStream.read(arrayOfByte1);
            if (k != -1)
            {
              boolean bool = Thread.currentThread().isInterrupted();
              if (!bool);
            }
            else
            {
              localInputStream.close();
              byte[] arrayOfByte2 = localByteArrayBuffer.toByteArray();
              localObject1 = arrayOfByte2;
              return localObject1;
              label124: i = (int)l;
              break;
            }
            j += k;
            localByteArrayBuffer.append(arrayOfByte1, 0, k);
            sendProgressMessage(j, (int)l);
          }
        }
        finally
        {
          localInputStream.close();
        }
      }
    }
    catch (OutOfMemoryError localOutOfMemoryError)
    {
      System.gc();
    }
    throw new IOException("File too large to fit into available memory");
  }

  public boolean getUseSynchronousMode()
  {
    return this.useSynchronousMode.booleanValue();
  }

  protected void handleMessage(Message paramMessage)
  {
    switch (paramMessage.what)
    {
    default:
      return;
    case 0:
      Object[] arrayOfObject4 = (Object[])paramMessage.obj;
      if ((arrayOfObject4 != null) && (arrayOfObject4.length >= 3))
      {
        onSuccess(((Integer)arrayOfObject4[0]).intValue(), (Header[])arrayOfObject4[1], (byte[])arrayOfObject4[2]);
        return;
      }
      Log.e("AsyncHttpResponseHandler", "SUCCESS_MESSAGE didn't got enough params");
      return;
    case 1:
      Object[] arrayOfObject3 = (Object[])paramMessage.obj;
      if ((arrayOfObject3 != null) && (arrayOfObject3.length >= 4))
      {
        onFailure(((Integer)arrayOfObject3[0]).intValue(), (Header[])arrayOfObject3[1], (byte[])arrayOfObject3[2], (Throwable)arrayOfObject3[3]);
        return;
      }
      Log.e("AsyncHttpResponseHandler", "FAILURE_MESSAGE didn't got enough params");
      return;
    case 2:
      onStart();
      return;
    case 3:
      onFinish();
      return;
    case 4:
      Object[] arrayOfObject2 = (Object[])paramMessage.obj;
      if ((arrayOfObject2 != null) && (arrayOfObject2.length >= 2))
        try
        {
          onProgress(((Integer)arrayOfObject2[0]).intValue(), ((Integer)arrayOfObject2[1]).intValue());
          return;
        }
        catch (Throwable localThrowable)
        {
          Log.e("AsyncHttpResponseHandler", "custom onProgress contains an error", localThrowable);
          return;
        }
      Log.e("AsyncHttpResponseHandler", "PROGRESS_MESSAGE didn't got enough params");
      return;
    case 5:
      Object[] arrayOfObject1 = (Object[])paramMessage.obj;
      if ((arrayOfObject1 != null) && (arrayOfObject1.length == 1))
      {
        onRetry(((Integer)arrayOfObject1[0]).intValue());
        return;
      }
      Log.e("AsyncHttpResponseHandler", "RETRY_MESSAGE didn't get enough params");
      return;
    case 6:
    }
    onCancel();
  }

  protected Message obtainMessage(int paramInt, Object paramObject)
  {
    return this.handler.obtainMessage(paramInt, paramObject);
  }

  public void onCancel()
  {
    Log.d("AsyncHttpResponseHandler", "Request got cancelled");
  }

  public abstract void onFailure(int paramInt, Header[] paramArrayOfHeader, byte[] paramArrayOfByte, Throwable paramThrowable);

  public void onFinish()
  {
  }

  public void onProgress(int paramInt1, int paramInt2)
  {
    Object[] arrayOfObject = new Object[3];
    arrayOfObject[0] = Integer.valueOf(paramInt1);
    arrayOfObject[1] = Integer.valueOf(paramInt2);
    if (paramInt2 > 0);
    for (int i = 100 * (paramInt1 / paramInt2); ; i = -1)
    {
      arrayOfObject[2] = Integer.valueOf(i);
      Log.v("AsyncHttpResponseHandler", String.format("Progress %d from %d (%d%%)", arrayOfObject));
      return;
    }
  }

  public void onRetry(int paramInt)
  {
    Object[] arrayOfObject = new Object[1];
    arrayOfObject[0] = Integer.valueOf(paramInt);
    Log.d("AsyncHttpResponseHandler", String.format("Request retry no. %d", arrayOfObject));
  }

  public void onStart()
  {
  }

  public abstract void onSuccess(int paramInt, Header[] paramArrayOfHeader, byte[] paramArrayOfByte);

  protected void postRunnable(Runnable paramRunnable)
  {
    if (Looper.myLooper() == null);
    for (int i = 1; ; i = 0)
    {
      if (i != 0)
        Looper.prepare();
      if (paramRunnable != null)
        this.handler.post(paramRunnable);
      if (i != 0)
        Looper.loop();
      return;
    }
  }

  public final void sendCancelMessage()
  {
    sendMessage(obtainMessage(6, null));
  }

  public final void sendFailureMessage(int paramInt, Header[] paramArrayOfHeader, byte[] paramArrayOfByte, Throwable paramThrowable)
  {
    Object[] arrayOfObject = new Object[4];
    arrayOfObject[0] = Integer.valueOf(paramInt);
    arrayOfObject[1] = paramArrayOfHeader;
    arrayOfObject[2] = paramArrayOfByte;
    arrayOfObject[3] = paramThrowable;
    sendMessage(obtainMessage(1, arrayOfObject));
  }

  public final void sendFinishMessage()
  {
    sendMessage(obtainMessage(3, null));
  }

  protected void sendMessage(Message paramMessage)
  {
    if (getUseSynchronousMode())
      handleMessage(paramMessage);
    while (Thread.currentThread().isInterrupted())
      return;
    this.handler.sendMessage(paramMessage);
  }

  public final void sendProgressMessage(int paramInt1, int paramInt2)
  {
    Object[] arrayOfObject = new Object[2];
    arrayOfObject[0] = Integer.valueOf(paramInt1);
    arrayOfObject[1] = Integer.valueOf(paramInt2);
    sendMessage(obtainMessage(4, arrayOfObject));
  }

  public void sendResponseMessage(HttpResponse paramHttpResponse)
    throws IOException
  {
    StatusLine localStatusLine;
    byte[] arrayOfByte;
    if (!Thread.currentThread().isInterrupted())
    {
      localStatusLine = paramHttpResponse.getStatusLine();
      arrayOfByte = getResponseData(paramHttpResponse.getEntity());
      if (!Thread.currentThread().isInterrupted())
      {
        if (localStatusLine.getStatusCode() < 300)
          break label85;
        sendFailureMessage(localStatusLine.getStatusCode(), paramHttpResponse.getAllHeaders(), arrayOfByte, new HttpResponseException(localStatusLine.getStatusCode(), localStatusLine.getReasonPhrase()));
      }
    }
    return;
    label85: sendSuccessMessage(localStatusLine.getStatusCode(), paramHttpResponse.getAllHeaders(), arrayOfByte);
  }

  public final void sendRetryMessage(int paramInt)
  {
    Object[] arrayOfObject = new Object[1];
    arrayOfObject[0] = Integer.valueOf(paramInt);
    sendMessage(obtainMessage(5, arrayOfObject));
  }

  public final void sendStartMessage()
  {
    sendMessage(obtainMessage(2, null));
  }

  public final void sendSuccessMessage(int paramInt, Header[] paramArrayOfHeader, byte[] paramArrayOfByte)
  {
    Object[] arrayOfObject = new Object[3];
    arrayOfObject[0] = Integer.valueOf(paramInt);
    arrayOfObject[1] = paramArrayOfHeader;
    arrayOfObject[2] = paramArrayOfByte;
    sendMessage(obtainMessage(0, arrayOfObject));
  }

  public void setCharset(String paramString)
  {
    this.responseCharset = paramString;
  }

  public void setRequestHeaders(Header[] paramArrayOfHeader)
  {
    this.requestHeaders = paramArrayOfHeader;
  }

  public void setRequestURI(URI paramURI)
  {
    this.requestURI = paramURI;
  }

  public void setUseSynchronousMode(boolean paramBoolean)
  {
    this.useSynchronousMode = Boolean.valueOf(paramBoolean);
  }

  private static class ResponderHandler extends Handler
  {
    private final AsyncHttpResponseHandler mResponder;

    ResponderHandler(AsyncHttpResponseHandler paramAsyncHttpResponseHandler)
    {
      this.mResponder = paramAsyncHttpResponseHandler;
    }

    public void handleMessage(Message paramMessage)
    {
      this.mResponder.handleMessage(paramMessage);
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.loopj.android.http.AsyncHttpResponseHandler
 * JD-Core Version:    0.6.2
 */