package com.loopj.android.http;

import android.util.Log;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import org.apache.http.HttpEntity;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.utils.URLEncodedUtils;
import org.apache.http.message.BasicNameValuePair;

public class RequestParams
{
  protected static final String LOG_TAG = "RequestParams";
  protected String contentEncoding = "UTF-8";
  protected ConcurrentHashMap<String, FileWrapper> fileParams;
  protected boolean isRepeatable;
  protected ConcurrentHashMap<String, StreamWrapper> streamParams;
  protected ConcurrentHashMap<String, String> urlParams;
  protected ConcurrentHashMap<String, Object> urlParamsWithObjects;
  protected boolean useJsonStreamer;

  public RequestParams()
  {
    this(null);
  }

  public RequestParams(String paramString1, String paramString2)
  {
    this(new HashMap()
    {
    });
  }

  public RequestParams(Map<String, String> paramMap)
  {
    init();
    Iterator localIterator;
    if (paramMap != null)
      localIterator = paramMap.entrySet().iterator();
    while (true)
    {
      if (!localIterator.hasNext())
        return;
      Map.Entry localEntry = (Map.Entry)localIterator.next();
      put((String)localEntry.getKey(), (String)localEntry.getValue());
    }
  }

  public RequestParams(Object[] paramArrayOfObject)
  {
    init();
    int i = paramArrayOfObject.length;
    if (i % 2 != 0)
      throw new IllegalArgumentException("Supplied arguments must be even");
    for (int j = 0; ; j += 2)
    {
      if (j >= i)
        return;
      put(String.valueOf(paramArrayOfObject[j]), String.valueOf(paramArrayOfObject[(j + 1)]));
    }
  }

  private HttpEntity createFormEntity()
  {
    try
    {
      UrlEncodedFormEntity localUrlEncodedFormEntity = new UrlEncodedFormEntity(getParamsList(), this.contentEncoding);
      return localUrlEncodedFormEntity;
    }
    catch (UnsupportedEncodingException localUnsupportedEncodingException)
    {
      Log.e("RequestParams", "createFormEntity failed", localUnsupportedEncodingException);
    }
    return null;
  }

  private HttpEntity createJsonStreamerEntity()
    throws IOException
  {
    boolean bool;
    JsonStreamerEntity localJsonStreamerEntity;
    Iterator localIterator1;
    label44: Iterator localIterator2;
    label67: Iterator localIterator3;
    label91: Iterator localIterator4;
    if ((this.fileParams.isEmpty()) && (this.streamParams.isEmpty()))
    {
      bool = false;
      localJsonStreamerEntity = new JsonStreamerEntity(bool);
      localIterator1 = this.urlParams.entrySet().iterator();
      if (localIterator1.hasNext())
        break label132;
      localIterator2 = this.urlParamsWithObjects.entrySet().iterator();
      if (localIterator2.hasNext())
        break label167;
      localIterator3 = this.fileParams.entrySet().iterator();
      if (localIterator3.hasNext())
        break label203;
      localIterator4 = this.streamParams.entrySet().iterator();
    }
    while (true)
    {
      if (!localIterator4.hasNext())
      {
        return localJsonStreamerEntity;
        bool = true;
        break;
        label132: Map.Entry localEntry1 = (Map.Entry)localIterator1.next();
        localJsonStreamerEntity.addPart((String)localEntry1.getKey(), localEntry1.getValue());
        break label44;
        label167: Map.Entry localEntry2 = (Map.Entry)localIterator2.next();
        localJsonStreamerEntity.addPart((String)localEntry2.getKey(), localEntry2.getValue());
        break label67;
        label203: Map.Entry localEntry3 = (Map.Entry)localIterator3.next();
        FileWrapper localFileWrapper = (FileWrapper)localEntry3.getValue();
        localJsonStreamerEntity.addPart((String)localEntry3.getKey(), new FileInputStream(localFileWrapper.file), localFileWrapper.file.getName(), localFileWrapper.contentType);
        break label91;
      }
      Map.Entry localEntry4 = (Map.Entry)localIterator4.next();
      StreamWrapper localStreamWrapper = (StreamWrapper)localEntry4.getValue();
      if (localStreamWrapper.inputStream != null)
        localJsonStreamerEntity.addPart((String)localEntry4.getKey(), localStreamWrapper.inputStream, localStreamWrapper.name, localStreamWrapper.contentType);
    }
  }

  private HttpEntity createMultipartEntity(ResponseHandlerInterface paramResponseHandlerInterface)
    throws IOException
  {
    SimpleMultipartEntity localSimpleMultipartEntity = new SimpleMultipartEntity(paramResponseHandlerInterface);
    localSimpleMultipartEntity.setIsRepeatable(this.isRepeatable);
    Iterator localIterator1 = this.urlParams.entrySet().iterator();
    Iterator localIterator2;
    label55: Iterator localIterator3;
    label79: Iterator localIterator4;
    if (!localIterator1.hasNext())
    {
      localIterator2 = getParamsList(null, this.urlParamsWithObjects).iterator();
      if (localIterator2.hasNext())
        break label153;
      localIterator3 = this.streamParams.entrySet().iterator();
      if (localIterator3.hasNext())
        break label182;
      localIterator4 = this.fileParams.entrySet().iterator();
    }
    while (true)
    {
      if (!localIterator4.hasNext())
      {
        return localSimpleMultipartEntity;
        Map.Entry localEntry1 = (Map.Entry)localIterator1.next();
        localSimpleMultipartEntity.addPart((String)localEntry1.getKey(), (String)localEntry1.getValue());
        break;
        label153: BasicNameValuePair localBasicNameValuePair = (BasicNameValuePair)localIterator2.next();
        localSimpleMultipartEntity.addPart(localBasicNameValuePair.getName(), localBasicNameValuePair.getValue());
        break label55;
        label182: Map.Entry localEntry2 = (Map.Entry)localIterator3.next();
        StreamWrapper localStreamWrapper = (StreamWrapper)localEntry2.getValue();
        if (localStreamWrapper.inputStream == null)
          break label79;
        localSimpleMultipartEntity.addPart((String)localEntry2.getKey(), localStreamWrapper.name, localStreamWrapper.inputStream, localStreamWrapper.contentType);
        break label79;
      }
      Map.Entry localEntry3 = (Map.Entry)localIterator4.next();
      FileWrapper localFileWrapper = (FileWrapper)localEntry3.getValue();
      localSimpleMultipartEntity.addPart((String)localEntry3.getKey(), localFileWrapper.file, localFileWrapper.contentType);
    }
  }

  private List<BasicNameValuePair> getParamsList(String paramString, Object paramObject)
  {
    LinkedList localLinkedList = new LinkedList();
    Map localMap;
    Iterator localIterator3;
    if ((paramObject instanceof Map))
    {
      localMap = (Map)paramObject;
      ArrayList localArrayList = new ArrayList(localMap.keySet());
      Collections.sort(localArrayList);
      localIterator3 = localArrayList.iterator();
      if (localIterator3.hasNext());
    }
    label319: 
    do
      while (true)
      {
        return localLinkedList;
        String str = (String)localIterator3.next();
        Object localObject3 = localMap.get(str);
        if (localObject3 == null)
          break;
        if (paramString == null);
        while (true)
        {
          localLinkedList.addAll(getParamsList(str, localObject3));
          break;
          str = String.format("%s[%s]", new Object[] { paramString, str });
        }
        if ((paramObject instanceof List))
        {
          Iterator localIterator2 = ((List)paramObject).iterator();
          while (localIterator2.hasNext())
          {
            Object localObject2 = localIterator2.next();
            localLinkedList.addAll(getParamsList(String.format("%s[]", new Object[] { paramString }), localObject2));
          }
        }
        else if ((paramObject instanceof Object[]))
        {
          for (Object localObject1 : (Object[])paramObject)
            localLinkedList.addAll(getParamsList(String.format("%s[]", new Object[] { paramString }), localObject1));
        }
        else
        {
          if (!(paramObject instanceof Set))
            break label319;
          Iterator localIterator1 = ((Set)paramObject).iterator();
          while (localIterator1.hasNext())
            localLinkedList.addAll(getParamsList(paramString, localIterator1.next()));
        }
      }
    while (!(paramObject instanceof String));
    localLinkedList.add(new BasicNameValuePair(paramString, (String)paramObject));
    return localLinkedList;
  }

  private void init()
  {
    this.urlParams = new ConcurrentHashMap();
    this.streamParams = new ConcurrentHashMap();
    this.fileParams = new ConcurrentHashMap();
    this.urlParamsWithObjects = new ConcurrentHashMap();
  }

  public void add(String paramString1, String paramString2)
  {
    Object localObject;
    if ((paramString1 != null) && (paramString2 != null))
    {
      localObject = this.urlParamsWithObjects.get(paramString1);
      if (localObject == null)
      {
        localObject = new HashSet();
        put(paramString1, localObject);
      }
      if (!(localObject instanceof List))
        break label54;
      ((List)localObject).add(paramString2);
    }
    label54: 
    while (!(localObject instanceof Set))
      return;
    ((Set)localObject).add(paramString2);
  }

  public HttpEntity getEntity(ResponseHandlerInterface paramResponseHandlerInterface)
    throws IOException
  {
    if (this.useJsonStreamer)
      return createJsonStreamerEntity();
    if ((this.streamParams.isEmpty()) && (this.fileParams.isEmpty()))
      return createFormEntity();
    return createMultipartEntity(paramResponseHandlerInterface);
  }

  protected String getParamString()
  {
    return URLEncodedUtils.format(getParamsList(), this.contentEncoding);
  }

  protected List<BasicNameValuePair> getParamsList()
  {
    LinkedList localLinkedList = new LinkedList();
    Iterator localIterator = this.urlParams.entrySet().iterator();
    while (true)
    {
      if (!localIterator.hasNext())
      {
        localLinkedList.addAll(getParamsList(null, this.urlParamsWithObjects));
        return localLinkedList;
      }
      Map.Entry localEntry = (Map.Entry)localIterator.next();
      localLinkedList.add(new BasicNameValuePair((String)localEntry.getKey(), (String)localEntry.getValue()));
    }
  }

  public void put(String paramString, File paramFile)
    throws FileNotFoundException
  {
    put(paramString, paramFile, null);
  }

  public void put(String paramString1, File paramFile, String paramString2)
    throws FileNotFoundException
  {
    if ((paramFile == null) || (!paramFile.exists()))
      throw new FileNotFoundException();
    if (paramString1 != null)
      this.fileParams.put(paramString1, new FileWrapper(paramFile, paramString2));
  }

  public void put(String paramString, InputStream paramInputStream)
  {
    put(paramString, paramInputStream, null);
  }

  public void put(String paramString1, InputStream paramInputStream, String paramString2)
  {
    put(paramString1, paramInputStream, paramString2, null);
  }

  public void put(String paramString1, InputStream paramInputStream, String paramString2, String paramString3)
  {
    if ((paramString1 != null) && (paramInputStream != null))
      this.streamParams.put(paramString1, new StreamWrapper(paramInputStream, paramString2, paramString3));
  }

  public void put(String paramString, Object paramObject)
  {
    if ((paramString != null) && (paramObject != null))
      this.urlParamsWithObjects.put(paramString, paramObject);
  }

  public void put(String paramString1, String paramString2)
  {
    if ((paramString1 != null) && (paramString2 != null))
      this.urlParams.put(paramString1, paramString2);
  }

  public void remove(String paramString)
  {
    this.urlParams.remove(paramString);
    this.streamParams.remove(paramString);
    this.fileParams.remove(paramString);
    this.urlParamsWithObjects.remove(paramString);
  }

  public void setContentEncoding(String paramString)
  {
    if (paramString != null)
    {
      this.contentEncoding = paramString;
      return;
    }
    Log.d("RequestParams", "setContentEncoding called with null attribute");
  }

  public void setHttpEntityIsRepeatable(boolean paramBoolean)
  {
    this.isRepeatable = paramBoolean;
  }

  public void setUseJsonStreamer(boolean paramBoolean)
  {
    this.useJsonStreamer = paramBoolean;
  }

  public String toString()
  {
    StringBuilder localStringBuilder = new StringBuilder();
    Iterator localIterator1 = this.urlParams.entrySet().iterator();
    Iterator localIterator2;
    label44: Iterator localIterator3;
    label68: Iterator localIterator4;
    if (!localIterator1.hasNext())
    {
      localIterator2 = this.streamParams.entrySet().iterator();
      if (localIterator2.hasNext())
        break label173;
      localIterator3 = this.fileParams.entrySet().iterator();
      if (localIterator3.hasNext())
        break label234;
      localIterator4 = getParamsList(null, this.urlParamsWithObjects).iterator();
    }
    while (true)
    {
      if (!localIterator4.hasNext())
      {
        return localStringBuilder.toString();
        Map.Entry localEntry1 = (Map.Entry)localIterator1.next();
        if (localStringBuilder.length() > 0)
          localStringBuilder.append("&");
        localStringBuilder.append((String)localEntry1.getKey());
        localStringBuilder.append("=");
        localStringBuilder.append((String)localEntry1.getValue());
        break;
        label173: Map.Entry localEntry2 = (Map.Entry)localIterator2.next();
        if (localStringBuilder.length() > 0)
          localStringBuilder.append("&");
        localStringBuilder.append((String)localEntry2.getKey());
        localStringBuilder.append("=");
        localStringBuilder.append("STREAM");
        break label44;
        label234: Map.Entry localEntry3 = (Map.Entry)localIterator3.next();
        if (localStringBuilder.length() > 0)
          localStringBuilder.append("&");
        localStringBuilder.append((String)localEntry3.getKey());
        localStringBuilder.append("=");
        localStringBuilder.append("FILE");
        break label68;
      }
      BasicNameValuePair localBasicNameValuePair = (BasicNameValuePair)localIterator4.next();
      if (localStringBuilder.length() > 0)
        localStringBuilder.append("&");
      localStringBuilder.append(localBasicNameValuePair.getName());
      localStringBuilder.append("=");
      localStringBuilder.append(localBasicNameValuePair.getValue());
    }
  }

  public static class FileWrapper
  {
    public String contentType;
    public File file;

    public FileWrapper(File paramFile, String paramString)
    {
      this.file = paramFile;
      this.contentType = paramString;
    }
  }

  public static class StreamWrapper
  {
    public String contentType;
    public InputStream inputStream;
    public String name;

    public StreamWrapper(InputStream paramInputStream, String paramString1, String paramString2)
    {
      this.inputStream = paramInputStream;
      this.name = paramString1;
      this.contentType = paramString2;
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.loopj.android.http.RequestParams
 * JD-Core Version:    0.6.2
 */