package com.manuelpeinado.refreshactionitem;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff.Mode;
import android.graphics.PorterDuffXfermode;
import android.graphics.RectF;
import android.graphics.Xfermode;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.view.View;

class ProgressIndicator extends View
{
  private static final float INNER_RADIUS_RATIO = 0.84F;
  private static final float PADDING = 4.0F;
  private static final Xfermode PORTER_DUFF_CLEAR = new PorterDuffXfermode(PorterDuff.Mode.CLEAR);
  private Bitmap mBitmap;
  private int mColorBackground = -16777216;
  private int mColorForeground = -1;
  private float mPadding;
  private final Paint mPaintBackground = new Paint();
  private final Paint mPaintErase = new Paint();
  private final Paint mPaintForeground = new Paint();
  private boolean mPieStyle;
  private final RectF mRect = new RectF();
  private final RectF mRectInner = new RectF();
  private float mValue;

  public ProgressIndicator(Context paramContext)
  {
    this(paramContext, null);
  }

  public ProgressIndicator(Context paramContext, AttributeSet paramAttributeSet)
  {
    super(paramContext, paramAttributeSet);
    Resources localResources = paramContext.getResources();
    this.mPadding = (4.0F * localResources.getDisplayMetrics().density + localResources.getDimension(R.dimen.abs__action_bar_icon_vertical_padding));
    this.mPaintForeground.setColor(this.mColorForeground);
    this.mPaintForeground.setAntiAlias(true);
    this.mPaintBackground.setColor(this.mColorBackground);
    this.mPaintBackground.setAntiAlias(true);
    this.mPaintErase.setXfermode(PORTER_DUFF_CLEAR);
    this.mPaintErase.setAntiAlias(true);
  }

  private void updateBitmap()
  {
    if ((this.mRect == null) || (this.mRect.width() == 0.0F))
      return;
    this.mBitmap = Bitmap.createBitmap((int)this.mRect.width(), (int)this.mRect.height(), Bitmap.Config.ARGB_8888);
    Canvas localCanvas = new Canvas(this.mBitmap);
    localCanvas.drawArc(this.mRect, -90.0F, 360.0F, true, this.mPaintBackground);
    if (this.mValue < 0.01F)
      localCanvas.drawLine(this.mRect.width() / 2.0F, this.mRect.height() / 2.0F, this.mRect.width() / 2.0F, 0.0F, this.mPaintForeground);
    float f = 360.0F * this.mValue;
    localCanvas.drawArc(this.mRect, -90.0F, f, true, this.mPaintForeground);
    if (!this.mPieStyle)
      localCanvas.drawArc(this.mRectInner, -90.0F, 360.0F, true, this.mPaintErase);
    postInvalidate();
  }

  public boolean getIsPieStyle()
  {
    return this.mPieStyle;
  }

  protected void onDraw(Canvas paramCanvas)
  {
    paramCanvas.drawBitmap(this.mBitmap, getWidth() / 2 - this.mBitmap.getWidth() / 2, getHeight() / 2 - this.mBitmap.getHeight() / 2, null);
  }

  protected void onSizeChanged(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    float f1 = paramInt1 - 2.0F * this.mPadding;
    float f2 = paramInt2 - 2.0F * this.mPadding;
    float f3 = Math.min(f1 / 2.0F, f2 / 2.0F);
    this.mRect.set(0.0F, 0.0F, f1, f2);
    float f4 = f3 * 0.84F;
    this.mRectInner.set(f1 / 2.0F - f4, f2 / 2.0F - f4, f4 + f1 / 2.0F, f4 + f2 / 2.0F);
    updateBitmap();
  }

  public void setBackgroundColor(int paramInt)
  {
    this.mColorBackground = paramInt;
    this.mPaintBackground.setColor(paramInt);
    invalidate();
  }

  public void setForegroundColor(int paramInt)
  {
    this.mColorForeground = paramInt;
    this.mPaintForeground.setColor(paramInt);
    invalidate();
  }

  public void setPieStyle(boolean paramBoolean)
  {
    if (this.mPieStyle == paramBoolean)
      return;
    this.mPieStyle = paramBoolean;
    updateBitmap();
  }

  public void setValue(float paramFloat)
  {
    try
    {
      this.mValue = paramFloat;
      updateBitmap();
      return;
    }
    finally
    {
      localObject = finally;
      throw localObject;
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.manuelpeinado.refreshactionitem.ProgressIndicator
 * JD-Core Version:    0.6.2
 */