package com.mywickr.gui;

import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.graphics.RectF;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.view.View;
import com.mywickr.wickr.R.styleable;

public class CircleProgressBar extends View
{
  private DrawMode drawMode = DrawMode.DRAW_MODE_STROKE;
  private float height = 48.0F * getResources().getDisplayMetrics().density;
  private int max = 100;
  private Paint nonProgressPainter;
  private RectF oval = new RectF();
  private int progress = 0;
  int progressColor = 16777215;
  private Paint progressPainter;
  private float strokeWidth;
  int trackColor = 8947848;
  private float width = 48.0F * getResources().getDisplayMetrics().density;

  public CircleProgressBar(Context paramContext, AttributeSet paramAttributeSet)
  {
    super(paramContext, paramAttributeSet);
    TypedArray localTypedArray = paramContext.obtainStyledAttributes(paramAttributeSet, R.styleable.CircleProgressBar);
    this.trackColor = localTypedArray.getColor(3, -16777216);
    this.progressColor = localTypedArray.getColor(2, -3355444);
    this.progress = localTypedArray.getInteger(0, 0);
    this.max = localTypedArray.getInteger(4, 100);
    this.drawMode = DrawMode.drawModeFromString(localTypedArray.getString(1));
    adjustDrawingProperties();
    localTypedArray.recycle();
  }

  private float getProgressFloat()
  {
    return this.progress / this.max;
  }

  protected void adjustDrawingProperties()
  {
    this.progressPainter = new Paint();
    this.progressPainter.setColor(this.progressColor);
    Paint localPaint1 = this.progressPainter;
    Paint.Style localStyle1;
    Paint localPaint2;
    if (this.drawMode == DrawMode.DRAW_MODE_STROKE)
    {
      localStyle1 = Paint.Style.STROKE;
      localPaint1.setStyle(localStyle1);
      this.progressPainter.setAntiAlias(true);
      this.nonProgressPainter = new Paint();
      this.nonProgressPainter.setColor(this.trackColor);
      localPaint2 = this.nonProgressPainter;
      if (this.drawMode != DrawMode.DRAW_MODE_STROKE)
        break label118;
    }
    label118: for (Paint.Style localStyle2 = Paint.Style.STROKE; ; localStyle2 = Paint.Style.FILL)
    {
      localPaint2.setStyle(localStyle2);
      this.nonProgressPainter.setAntiAlias(true);
      return;
      localStyle1 = Paint.Style.FILL;
      break;
    }
  }

  protected void adjustScale()
  {
    this.strokeWidth = (0.1F * this.width);
    this.progressPainter.setStrokeWidth(this.strokeWidth);
    this.nonProgressPainter.setStrokeWidth(this.strokeWidth);
  }

  protected void generateBounds()
  {
    float f = this.strokeWidth / 2.0F;
    this.oval.set(f, f, this.width - f, this.height - f);
  }

  public int getMax()
  {
    return this.max;
  }

  public int getProgress()
  {
    return this.progress;
  }

  protected void onDraw(Canvas paramCanvas)
  {
    RectF localRectF1 = this.oval;
    boolean bool1;
    RectF localRectF2;
    float f;
    if (this.drawMode != DrawMode.DRAW_MODE_STROKE)
    {
      bool1 = true;
      paramCanvas.drawArc(localRectF1, 270.0F, 360.0F, bool1, this.nonProgressPainter);
      localRectF2 = this.oval;
      f = 360.0F * getProgressFloat();
      if (this.drawMode == DrawMode.DRAW_MODE_STROKE)
        break label81;
    }
    label81: for (boolean bool2 = true; ; bool2 = false)
    {
      paramCanvas.drawArc(localRectF2, 270.0F, f, bool2, this.progressPainter);
      return;
      bool1 = false;
      break;
    }
  }

  protected void onSizeChanged(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    this.width = paramInt1;
    this.height = this.width;
    adjustScale();
    generateBounds();
    super.onSizeChanged(paramInt1, paramInt2, paramInt3, paramInt4);
  }

  public void setDrawMode(DrawMode paramDrawMode)
  {
    this.drawMode = paramDrawMode;
    adjustDrawingProperties();
    invalidate();
  }

  public void setMax(int paramInt)
  {
    this.max = paramInt;
    invalidate();
  }

  public void setProgress(int paramInt)
  {
    this.progress = paramInt;
    invalidate();
  }

  public void setProgressColor(int paramInt)
  {
    this.progressColor = paramInt;
    adjustDrawingProperties();
    invalidate();
  }

  public void setTrackColor(int paramInt)
  {
    this.trackColor = paramInt;
    adjustDrawingProperties();
    invalidate();
  }

  public static enum DrawMode
  {
    static
    {
      DRAW_MODE_FILL = new DrawMode("DRAW_MODE_FILL", 1);
      DrawMode[] arrayOfDrawMode = new DrawMode[2];
      arrayOfDrawMode[0] = DRAW_MODE_STROKE;
      arrayOfDrawMode[1] = DRAW_MODE_FILL;
    }

    static DrawMode drawModeFromString(String paramString)
    {
      if (paramString == null)
        return DRAW_MODE_FILL;
      if (paramString.equalsIgnoreCase("stroke"))
        return DRAW_MODE_STROKE;
      return DRAW_MODE_FILL;
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.gui.CircleProgressBar
 * JD-Core Version:    0.6.2
 */