package com.mywickr.services;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.os.AsyncTask;
import android.os.Binder;
import android.os.IBinder;
import android.os.StatFs;
import com.mywickr.interfaces.WickrShredderInterface;
import com.mywickr.wickr.WickrAppClock;
import com.mywickr.wickr.WickrAppClockInterface;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Arrays;

public class ShredderService extends Service
  implements WickrAppClockInterface
{
  public static final String AF_SPEED = "af_speed";
  private static IBinder mBinder = null;
  private final int BLOCK_SIZE = 4997120;
  private OneWriteThread backgroundThread = null;
  WickrAppClock clock = null;
  private int currentSpeed = 0;
  private int fileCount = 0;
  private File fileDirectory = null;
  private boolean needsResume = false;
  byte[] randomBytes;
  private SuperShredOperation shredOperation = null;
  private WickrShredderInterface shredderGui = null;
  private ShredderServiceStatus status;

  public void cancelSuperShred()
  {
    if (this.shredOperation != null)
      this.shredOperation.notifyCancel();
  }

  public int clockIntervalFromPriority(int paramInt)
  {
    return 2000 * (9 - paramInt);
  }

  public void delete(File paramFile)
    throws IOException
  {
    if (paramFile.isDirectory())
    {
      if (paramFile.list().length == 0)
      {
        paramFile.delete();
        return;
      }
      String[] arrayOfString = paramFile.list();
      int i = arrayOfString.length;
      for (int j = 0; ; j++)
      {
        if (j >= i)
        {
          if (paramFile.list().length != 0)
            break;
          paramFile.delete();
          return;
        }
        delete(new File(paramFile, arrayOfString[j]));
      }
    }
    paramFile.delete();
  }

  public void doSuperShred()
  {
    if (this.status != ShredderServiceStatus.SHREDDER_FULL_RUN)
    {
      this.shredOperation = new SuperShredOperation(null);
      this.shredOperation.execute(new Void[0]);
    }
  }

  public boolean doWriteFile(boolean paramBoolean)
  {
    try
    {
      this.randomBytes = new byte[4096];
      Arrays.fill(this.randomBytes, (byte)0);
      FileOutputStream localFileOutputStream = new FileOutputStream(new File(this.fileDirectory, "aftemp" + this.fileCount), true);
      int i = 0;
      while (true)
      {
        if (i >= 4997120)
        {
          localFileOutputStream.close();
          this.fileCount = (1 + this.fileCount);
          if ((paramBoolean) && (this.fileCount > 10))
          {
            delete(this.fileDirectory);
            this.fileDirectory = getApplicationContext().getDir("sfs", 0);
            this.fileCount = 0;
          }
          this.randomBytes = null;
          return true;
        }
        localFileOutputStream.write(this.randomBytes);
        int j = this.randomBytes.length;
        i += j;
      }
    }
    catch (Exception localException)
    {
      this.fileCount = 0;
    }
    return false;
  }

  public IBinder onBind(Intent paramIntent)
  {
    return mBinder;
  }

  public void onCreate()
  {
    this.fileDirectory = getApplicationContext().getDir("sfs", 32768);
    try
    {
      delete(this.fileDirectory);
      label23: this.fileDirectory = getApplicationContext().getDir("sfs", 32768);
      mBinder = new ShredderBinder();
      this.status = ShredderServiceStatus.SHREDDER_STOPPED;
      super.onCreate();
      return;
    }
    catch (Exception localException)
    {
      break label23;
    }
  }

  public void onDestroy()
  {
    pause();
    stop();
    mBinder = null;
    this.randomBytes = null;
    try
    {
      delete(this.fileDirectory);
      label25: this.fileDirectory = getApplicationContext().getDir("sfs", 0);
      super.onDestroy();
      return;
    }
    catch (Exception localException)
    {
      break label25;
    }
  }

  public int onStartCommand(Intent paramIntent, int paramInt1, int paramInt2)
  {
    if (paramIntent == null)
      stopSelf();
    do
    {
      return 1;
      this.currentSpeed = paramIntent.getIntExtra("af_speed", 0);
    }
    while (this.currentSpeed <= 0);
    resume();
    return 1;
  }

  public void pause()
  {
    try
    {
      if (this.status == ShredderServiceStatus.SHREDDER_RUNNING)
      {
        delete(this.fileDirectory);
        this.fileDirectory = getApplicationContext().getDir("sfs", 0);
        this.clock.removeListener(this);
        this.clock.stop();
        this.clock = null;
        this.fileCount = 0;
        this.status = ShredderServiceStatus.SHREDDER_PAUSED;
      }
      return;
    }
    catch (Exception localException)
    {
      localException.printStackTrace();
    }
  }

  public void resume()
  {
    if (this.status != ShredderServiceStatus.SHREDDER_RUNNING)
    {
      this.clock = new WickrAppClock(0L, 0L, clockIntervalFromPriority(this.currentSpeed));
      this.clock.addListener(this);
      this.clock.start();
      this.status = ShredderServiceStatus.SHREDDER_RUNNING;
      this.shredOperation = null;
    }
  }

  public void setNewPriorityLevel(int paramInt)
  {
    pause();
    this.currentSpeed = (paramInt + 1);
    resume();
  }

  public void setShredderGUI(WickrShredderInterface paramWickrShredderInterface)
  {
    this.shredderGui = paramWickrShredderInterface;
  }

  public void stop()
  {
    pause();
    System.gc();
    this.status = ShredderServiceStatus.SHREDDER_STOPPED;
  }

  public void wickrAppClockDidTick()
  {
    if (this.backgroundThread == null)
      this.backgroundThread = new OneWriteThread();
    this.backgroundThread.run();
  }

  class OneWriteThread extends Thread
  {
    OneWriteThread()
    {
    }

    public void run()
    {
      if (!ShredderService.this.doWriteFile(true))
      {
        ShredderService.this.stop();
        ShredderService.this.stopSelf();
      }
    }
  }

  public class ShredderBinder extends Binder
  {
    public ShredderBinder()
    {
    }

    public ShredderService getService()
    {
      return ShredderService.this;
    }
  }

  private class SuperShredOperation extends AsyncTask<Void, Integer, Void>
  {
    private boolean shouldCancel = false;
    private long totalAmountToWrite = 0L;
    private long totalAmountWritten = 0L;

    private SuperShredOperation()
    {
    }

    protected Void doInBackground(Void[] paramArrayOfVoid)
    {
      StatFs localStatFs = new StatFs(ShredderService.this.fileDirectory.getAbsolutePath());
      int i = localStatFs.getAvailableBlocks();
      int j = localStatFs.getBlockSize();
      this.totalAmountToWrite = (i * j);
      while (true)
      {
        if (!ShredderService.this.doWriteFile(false));
        try
        {
          label84: 
          do
          {
            ShredderService.this.delete(ShredderService.this.fileDirectory);
            ShredderService.this.fileDirectory = ShredderService.this.getApplicationContext().getDir("sfs", 0);
            ShredderService.this.fileCount = 0;
            return null;
          }
          while (this.shouldCancel);
          ShredderService localShredderService = ShredderService.this;
          localShredderService.fileCount = (1 + localShredderService.fileCount);
          this.totalAmountWritten = (4997120L + this.totalAmountWritten);
          publishProgress(new Integer[] { null });
        }
        catch (Exception localException)
        {
          break label84;
        }
      }
    }

    protected void notifyCancel()
    {
      this.shouldCancel = true;
    }

    protected void onPostExecute(Void paramVoid)
    {
      if (ShredderService.this.shredderGui != null)
        ShredderService.this.shredderGui.shredderHasEnded(this.shouldCancel);
      ShredderService.this.status = ShredderServiceStatus.SHREDDER_STOPPED;
      if (ShredderService.this.needsResume)
        ShredderService.this.resume();
    }

    protected void onPreExecute()
    {
      if (ShredderService.this.shredderGui != null)
        ShredderService.this.shredderGui.shredderHasStarted();
      if (ShredderService.this.status == ShredderServiceStatus.SHREDDER_RUNNING)
      {
        ShredderService.this.needsResume = true;
        ShredderService.this.pause();
      }
      ShredderService.this.status = ShredderServiceStatus.SHREDDER_FULL_RUN;
    }

    protected void onProgressUpdate(Integer[] paramArrayOfInteger)
    {
      if (ShredderService.this.shredderGui != null)
      {
        float f = (float)this.totalAmountWritten / (float)this.totalAmountToWrite;
        if (f > 1.0F)
          f = 1.0F;
        ShredderService.this.shredderGui.shredderHasProgress(100.0F * f);
      }
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.services.ShredderService
 * JD-Core Version:    0.6.2
 */