package com.mywickr.wickr;

import android.app.AlertDialog;
import android.app.AlertDialog.Builder;
import android.content.ContentResolver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.content.res.Resources;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.Bitmap.CompressFormat;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.graphics.Matrix;
import android.net.Uri;
import android.os.AsyncTask;
import android.util.DisplayMetrics;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ImageView.ScaleType;
import android.widget.LinearLayout.LayoutParams;
import com.mywickr.gui.WickrAttachmentImageView;
import com.mywickr.gui.details.ConvoDetailActivity;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;

public class WickrAttachmentManager
{
  public static boolean attachmentInProgress = false;
  public static int attachmentsInBytes;
  public static int currentAttachmentIndex = 0;
  public static byte[] oneImage;
  public static Bitmap sendingBitmap = null;
  Context mContext;
  ArrayList<WickrAttachment> mWickrAttachments = new ArrayList();

  static
  {
    attachmentsInBytes = 0;
  }

  public WickrAttachmentManager(Context paramContext)
  {
    this.mContext = paramContext;
  }

  public static int calculateInSampleSize(BitmapFactory.Options paramOptions, int paramInt1, int paramInt2)
  {
    int i = paramOptions.outHeight;
    int j = paramOptions.outWidth;
    int k = 1;
    int n;
    if ((i > paramInt2) || (j > paramInt1))
    {
      int m = Math.round(i / paramInt2);
      n = Math.round(j / paramInt1);
      if (m < n)
        k = m;
    }
    else
    {
      return k;
    }
    return n;
  }

  public static int getOrientation(Uri paramUri, Context paramContext)
  {
    Cursor localCursor = paramContext.getContentResolver().query(paramUri, new String[] { "orientation" }, null, null, null);
    try
    {
      if (localCursor.moveToFirst())
      {
        int i = localCursor.getInt(0);
        return i;
      }
      return -1;
    }
    finally
    {
      localCursor.close();
    }
  }

  public static Bitmap rotateBitmap(Bitmap paramBitmap)
  {
    Matrix localMatrix = new Matrix();
    localMatrix.postRotate(90.0F);
    Bitmap localBitmap = Bitmap.createBitmap(paramBitmap, 0, 0, paramBitmap.getWidth(), paramBitmap.getHeight(), localMatrix, true);
    sendingBitmap = localBitmap;
    return localBitmap;
  }

  public void addImageFromGallery(Intent paramIntent)
  {
    attachmentInProgress = true;
    new GalleryImageHandler(null).execute(new Object[] { paramIntent });
  }

  public void addImageFromWickrCamera()
  {
    attachmentInProgress = true;
    CameraImageHandler localCameraImageHandler = new CameraImageHandler(null);
    Object[] arrayOfObject = new Object[1];
    arrayOfObject[0] = oneImage;
    localCameraImageHandler.execute(arrayOfObject);
  }

  public void addVideo(Intent paramIntent)
  {
    attachmentInProgress = true;
    new CameraVideoHandler(null).execute(new Object[] { paramIntent });
  }

  public ArrayList<WickrAttachment> getAttachments()
  {
    if (currentAttachmentIndex > 0)
      return this.mWickrAttachments;
    return null;
  }

  public void imagePopup(final WickrAttachmentImageView paramWickrAttachmentImageView)
  {
    AlertDialog.Builder localBuilder = new AlertDialog.Builder(this.mContext);
    localBuilder.setTitle("Remove");
    localBuilder.setMessage("Remove attachment?").setCancelable(true).setPositiveButton("Yes", new DialogInterface.OnClickListener()
    {
      public void onClick(DialogInterface paramAnonymousDialogInterface, int paramAnonymousInt)
      {
        int i = paramWickrAttachmentImageView.getImageId();
        WickrAttachmentManager.this.removeAttachmentFromArrayList(i);
        ConvoDetailActivity.removeAttachmentView(paramWickrAttachmentImageView, WickrAttachmentManager.currentAttachmentIndex);
        paramAnonymousDialogInterface.cancel();
      }
    }).setNegativeButton("Cancel", new DialogInterface.OnClickListener()
    {
      public void onClick(DialogInterface paramAnonymousDialogInterface, int paramAnonymousInt)
      {
        paramAnonymousDialogInterface.cancel();
      }
    });
    localBuilder.create().show();
  }

  public void placeImage(int paramInt, boolean paramBoolean)
  {
    final WickrAttachmentImageView localWickrAttachmentImageView = new WickrAttachmentImageView(this.mContext, paramInt);
    localWickrAttachmentImageView.setImageBitmap(sendingBitmap);
    if (paramBoolean)
      localWickrAttachmentImageView.setColorFilter(-65536);
    localWickrAttachmentImageView.setClickable(true);
    localWickrAttachmentImageView.setScaleType(ImageView.ScaleType.CENTER_CROP);
    int i = (int)(0.5F + 8.0F * this.mContext.getResources().getDisplayMetrics().density);
    LinearLayout.LayoutParams localLayoutParams = new LinearLayout.LayoutParams(-2, -2);
    localLayoutParams.setMargins(i, i, i, i);
    localWickrAttachmentImageView.setLayoutParams(localLayoutParams);
    localWickrAttachmentImageView.setOnClickListener(new View.OnClickListener()
    {
      public void onClick(View paramAnonymousView)
      {
        WickrAttachmentManager.this.imagePopup(localWickrAttachmentImageView);
      }
    });
    ConvoDetailActivity.addAttachmentView(localWickrAttachmentImageView);
    sendingBitmap = null;
  }

  void removeAttachmentFromArrayList(int paramInt)
  {
    Iterator localIterator = this.mWickrAttachments.iterator();
    WickrAttachment localWickrAttachment;
    do
    {
      if (!localIterator.hasNext())
        return;
      localWickrAttachment = (WickrAttachment)localIterator.next();
    }
    while (localWickrAttachment.getID() != paramInt);
    this.mWickrAttachments.remove(localWickrAttachment);
  }

  private class CameraImageHandler extends WickrAttachmentManager.ImageHandler
  {
    private CameraImageHandler()
    {
      super();
    }

    protected byte[] doInBackground(Object[] paramArrayOfObject)
    {
      BitmapFactory.Options localOptions = new BitmapFactory.Options();
      localOptions.inJustDecodeBounds = true;
      WickrAttachmentManager.sendingBitmap = BitmapFactory.decodeByteArray(WickrAttachmentManager.oneImage, 0, WickrAttachmentManager.oneImage.length, localOptions);
      if (localOptions.outHeight > localOptions.outWidth);
      for (localOptions.inSampleSize = WickrAttachmentManager.calculateInSampleSize(localOptions, 640, 960); ; localOptions.inSampleSize = WickrAttachmentManager.calculateInSampleSize(localOptions, 960, 640))
      {
        localOptions.inJustDecodeBounds = false;
        WickrAttachmentManager.sendingBitmap = BitmapFactory.decodeByteArray(WickrAttachmentManager.oneImage, 0, WickrAttachmentManager.oneImage.length, localOptions);
        return super.doInBackground(paramArrayOfObject);
      }
    }
  }

  private class CameraVideoHandler extends AsyncTask<Object, Void, byte[]>
  {
    Boolean success = Boolean.valueOf(false);

    private CameraVideoHandler()
    {
    }

    protected byte[] doInBackground(Object[] paramArrayOfObject)
    {
      File localFile = new File(new File(WickrAttachmentManager.this.mContext.getFilesDir() + "/temp_vids"), "video.mp4");
      try
      {
        FileInputStream localFileInputStream = new FileInputStream(localFile.getAbsoluteFile());
        ByteArrayOutputStream localByteArrayOutputStream = new ByteArrayOutputStream();
        byte[] arrayOfByte1 = new byte[1024];
        while (true)
        {
          int i = localFileInputStream.read(arrayOfByte1);
          if (i <= 0)
          {
            byte[] arrayOfByte2 = localByteArrayOutputStream.toByteArray();
            localByteArrayOutputStream.close();
            localFileInputStream.close();
            this.success = Boolean.valueOf(true);
            return arrayOfByte2;
          }
          localByteArrayOutputStream.write(arrayOfByte1, 0, i);
        }
      }
      catch (FileNotFoundException localFileNotFoundException)
      {
        localFileNotFoundException.printStackTrace();
        return null;
      }
      catch (IOException localIOException)
      {
        while (true)
          localIOException.printStackTrace();
      }
    }

    protected void onPostExecute(byte[] paramArrayOfByte)
    {
      if ((this.success.booleanValue()) && (paramArrayOfByte != null))
      {
        WickrAttachmentManager.this.mWickrAttachments.add(new WickrAttachment(paramArrayOfByte, WickrAttachmentManager.currentAttachmentIndex));
        WickrAttachmentManager.attachmentsInBytes += paramArrayOfByte.length;
        WickrAttachmentManager.currentAttachmentIndex = 1 + WickrAttachmentManager.currentAttachmentIndex;
        WickrAttachmentManager.attachmentInProgress = false;
        WickrAttachmentManager.sendingBitmap = BitmapFactory.decodeResource(WickrAttachmentManager.this.mContext.getResources(), 2130837732);
        WickrAttachmentManager.this.placeImage(WickrAttachmentManager.currentAttachmentIndex, true);
      }
      while (true)
      {
        WickrAttachmentManager.attachmentInProgress = false;
        super.onPostExecute(paramArrayOfByte);
        return;
        WickrUtil.showDialog(WickrAttachmentManager.this.mContext, "There was an error attaching the video you selected");
      }
    }
  }

  private class GalleryImageHandler extends WickrAttachmentManager.ImageHandler
  {
    private InputStream stream = null;

    private GalleryImageHandler()
    {
      super();
    }

    protected byte[] doInBackground(Object[] paramArrayOfObject)
    {
      Intent localIntent = (Intent)paramArrayOfObject[0];
      BitmapFactory.Options localOptions = new BitmapFactory.Options();
      localOptions.inJustDecodeBounds = true;
      try
      {
        this.stream = WickrAttachmentManager.this.mContext.getContentResolver().openInputStream(localIntent.getData());
        WickrAttachmentManager.sendingBitmap = BitmapFactory.decodeStream(this.stream, null, localOptions);
        this.stream.close();
        if (localOptions.outHeight > localOptions.outWidth)
        {
          localOptions.inSampleSize = WickrAttachmentManager.calculateInSampleSize(localOptions, 640, 960);
          localOptions.inJustDecodeBounds = false;
        }
      }
      catch (Exception localException1)
      {
        try
        {
          while (true)
          {
            this.stream = WickrAttachmentManager.this.mContext.getContentResolver().openInputStream(localIntent.getData());
            WickrAttachmentManager.sendingBitmap = BitmapFactory.decodeStream(this.stream, null, localOptions);
            this.stream.close();
            this.stream = null;
            if (WickrAttachmentManager.getOrientation(localIntent.getData(), WickrAttachmentManager.this.mContext) != 0)
              WickrAttachmentManager.rotateBitmap(WickrAttachmentManager.sendingBitmap);
            return super.doInBackground(paramArrayOfObject);
            localException1 = localException1;
            localException1.printStackTrace();
          }
          localOptions.inSampleSize = WickrAttachmentManager.calculateInSampleSize(localOptions, 960, 640);
        }
        catch (Exception localException2)
        {
          while (true)
            localException2.printStackTrace();
        }
      }
    }
  }

  public class ImageHandler extends AsyncTask<Object, Void, byte[]>
  {
    protected Boolean success = Boolean.valueOf(false);

    public ImageHandler()
    {
    }

    protected void adjustBitmapOptionsToConstraints(BitmapFactory.Options paramOptions)
    {
      if (paramOptions.outHeight > paramOptions.outWidth);
      for (paramOptions.inSampleSize = WickrAttachmentManager.calculateInSampleSize(paramOptions, 640, 960); ; paramOptions.inSampleSize = WickrAttachmentManager.calculateInSampleSize(paramOptions, 960, 640))
      {
        paramOptions.inJustDecodeBounds = false;
        return;
      }
    }

    protected byte[] doInBackground(Object[] paramArrayOfObject)
    {
      ByteArrayOutputStream localByteArrayOutputStream = new ByteArrayOutputStream();
      WickrAttachmentManager.sendingBitmap.compress(Bitmap.CompressFormat.JPEG, 80, localByteArrayOutputStream);
      byte[] arrayOfByte = localByteArrayOutputStream.toByteArray();
      try
      {
        WickrAttachmentManager.oneImage = null;
        localByteArrayOutputStream.close();
        this.success = Boolean.valueOf(true);
        return arrayOfByte;
      }
      catch (Exception localException)
      {
        while (true)
          localException.printStackTrace();
      }
    }

    protected void onPostExecute(byte[] paramArrayOfByte)
    {
      if (this.success.booleanValue())
      {
        WickrAttachmentManager.this.placeImage(WickrAttachmentManager.currentAttachmentIndex, false);
        WickrAttachmentManager.this.mWickrAttachments.add(new WickrAttachment(paramArrayOfByte, WickrAttachmentManager.currentAttachmentIndex));
        WickrAttachmentManager.attachmentsInBytes += paramArrayOfByte.length;
        WickrAttachmentManager.currentAttachmentIndex = 1 + WickrAttachmentManager.currentAttachmentIndex;
        WickrAttachmentManager.attachmentInProgress = false;
      }
      super.onPostExecute(paramArrayOfByte);
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.wickr.WickrAttachmentManager
 * JD-Core Version:    0.6.2
 */