package com.mywickr.wickr;

import android.content.Context;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.Iterator;
import net.sqlcipher.database.SQLiteDatabase;

public abstract class WickrMessage extends WickrDBObject
{
  protected WickrAttachment[] attchments;
  protected byte[] audioBody;
  protected String cachedText;
  protected byte[] cachedTextEnc;
  protected WickrConvo convo = null;
  protected ArrayList<WickrError> errors = null;
  protected boolean isUnlocked = false;
  protected byte[] msgBlob;
  protected WickrMsgClass msgClass;
  protected String msgIDSecure;
  protected long msgTimestamp;
  protected String msgType;
  protected String srvMsgID;
  protected WickrStatus unlockStatus;
  protected String vGroupID;

  static
  {
    System.loadLibrary("wickrCore");
  }

  protected static native WickrStatus activeSessionCloseDecodeCtx(String paramString);

  protected static native byte[] activeSessionDecodeCtxGetAttach(String paramString, int paramInt, WickrStatus paramWickrStatus);

  protected static native byte[] activeSessionDecodeCtxGetAudioBody(String paramString, WickrStatus paramWickrStatus);

  protected static native int activeSessionDecodeCtxGetNumAttach(String paramString, WickrStatus paramWickrStatus);

  public static void deleteMsgWithID(String paramString)
  {
    WickrQuearyBuilder localWickrQuearyBuilder = new WickrQuearyBuilder();
    localWickrQuearyBuilder.PARAMETER = new String[] { "convo" };
    String[] arrayOfString = new String[2];
    arrayOfString[0] = "msgID";
    arrayOfString[1] = ("\"" + paramString + "\"");
    localWickrQuearyBuilder.WHERE_CLAUSE = arrayOfString;
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(localWickrQuearyBuilder.getSelectWickrMessage(), null);
    if (localCursor.getCount() > 0);
    while (true)
    {
      if (!localCursor.moveToNext())
        return;
      WickrConvo localWickrConvo = WickrConvo.getConvoWithID(localCursor.getInt(0));
      if (localWickrConvo != null)
      {
        ArrayList localArrayList = localWickrConvo.getMessages(true);
        if (localArrayList != null)
        {
          Object localObject = null;
          Iterator localIterator = localArrayList.iterator();
          while (true)
          {
            if (!localIterator.hasNext())
            {
              if (localObject == null)
                break;
              if (localObject.isInbox())
              {
                WickrInbox localWickrInbox = (WickrInbox)localObject;
                if (localWickrInbox.getInboxState().equals(WickrInboxState.WICKR_INBOX_UNOPENED))
                  localWickrInbox.getConvo().decrementUnreadMessages();
              }
              localObject.delete();
              break;
            }
            WickrMessage localWickrMessage = (WickrMessage)localIterator.next();
            if (localWickrMessage.getSrvMsgID().equalsIgnoreCase(paramString))
              localObject = localWickrMessage;
          }
        }
        localWickrConvo.decrementUnreadMessages();
        WickrDBAdapter.writableDatabase.delete("Wickr_Message", "msgID=\"" + paramString + "\"", null);
      }
      else
      {
        WickrDBAdapter.writableDatabase.delete("Wickr_Message", "msgID=\"" + paramString + "\"", null);
      }
    }
  }

  public static void deleteOldMessages()
  {
    ArrayList localArrayList = WickrConvo.getConvoList();
    Iterator localIterator;
    if (localArrayList != null)
      localIterator = localArrayList.iterator();
    while (true)
    {
      if (!localIterator.hasNext())
        return;
      WickrConvo localWickrConvo = (WickrConvo)localIterator.next();
      if (localWickrConvo.getMessages(true) != null)
        localWickrConvo.cleanUp();
    }
  }

  private ArrayList<WickrError> fetchErrors()
  {
    ArrayList localArrayList = new ArrayList();
    WickrQuearyBuilder localWickrQuearyBuilder = new WickrQuearyBuilder();
    localWickrQuearyBuilder.PARAMETER = new String[] { "_id" };
    String[] arrayOfString = new String[2];
    arrayOfString[0] = "msgRef";
    arrayOfString[1] = ("=" + this.id);
    localWickrQuearyBuilder.WHERE_CLAUSE = arrayOfString;
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(localWickrQuearyBuilder.getSelectWickrError(), null);
    while (true)
    {
      if (!localCursor.moveToNext())
      {
        localCursor.close();
        return localArrayList;
      }
      localArrayList.add(new WickrError(localCursor.getInt(0), this));
    }
  }

  public static String getDate(WickrMessage paramWickrMessage)
  {
    Date localDate = new Date(1000L * paramWickrMessage.getMsgTimestamp());
    Calendar localCalendar1 = Calendar.getInstance();
    localCalendar1.setTime(localDate);
    Calendar localCalendar2 = Calendar.getInstance();
    int i = localCalendar2.get(1);
    int j = localCalendar2.get(6);
    int k;
    if ((localCalendar1.get(1) == i) && (localCalendar1.get(6) == j))
    {
      k = 1;
      if ((localCalendar1.get(1) != i) || (localCalendar1.get(6) != j - 1))
        break label108;
    }
    label108: for (int m = 1; ; m = 0)
    {
      if (k == 0)
        break label114;
      return "Today";
      k = 0;
      break;
    }
    label114: if (m != 0)
      return "Yesterday";
    return new SimpleDateFormat("MMMM d, yyyy").format(localDate);
  }

  public static String isDateChanged(WickrMessage paramWickrMessage1, WickrMessage paramWickrMessage2)
  {
    Date localDate1 = new Date(1000L * paramWickrMessage1.getMsgTimestamp());
    Date localDate2 = new Date(1000L * paramWickrMessage2.getMsgTimestamp());
    Calendar localCalendar1 = Calendar.getInstance();
    Calendar localCalendar2 = Calendar.getInstance();
    localCalendar1.setTime(localDate1);
    localCalendar2.setTime(localDate2);
    int i;
    int m;
    if ((localCalendar1.get(1) == localCalendar2.get(1)) && (localCalendar1.get(6) == localCalendar2.get(6)))
    {
      i = 1;
      if (i != 0)
        break label219;
      Calendar localCalendar3 = Calendar.getInstance();
      int j = localCalendar3.get(1);
      int k = localCalendar3.get(6);
      if ((localCalendar1.get(1) != j) || (localCalendar1.get(6) != k))
        break label184;
      m = 1;
      label142: if ((localCalendar1.get(1) != j) || (localCalendar1.get(6) != k - 1))
        break label190;
    }
    label184: label190: for (int n = 1; ; n = 0)
    {
      if (m == 0)
        break label196;
      return "Today";
      i = 0;
      break;
      m = 0;
      break label142;
    }
    label196: if (n != 0)
      return "Yesterday";
    return new SimpleDateFormat("MMMM d, yyyy").format(localDate1);
    label219: return "";
  }

  public static boolean processFailedUploads()
  {
    WickrQuearyBuilder localWickrQuearyBuilder = new WickrQuearyBuilder();
    localWickrQuearyBuilder.PARAMETER = new String[] { "_id" };
    localWickrQuearyBuilder.WHERE_CLAUSE = new String[] { "class", "=2 AND ", "tMsgID", " NOT NULL" };
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(localWickrQuearyBuilder.getSelectWickrMessage(), null);
    int i = localCursor.getCount();
    boolean bool = false;
    if (i > 0);
    while (true)
    {
      if (!localCursor.moveToNext())
      {
        localCursor.close();
        return bool;
      }
      WickrOutbox localWickrOutbox = new WickrOutbox(localCursor.getInt(0), null);
      if ((!WickrSession.getActiveSession().getUploadQueue().msgIsUploading(localWickrOutbox)) && (localWickrOutbox.getErrors().size() == 0))
      {
        new WickrError(new WickrAPICode(9), "There was an network error while uploading your message", localCursor.getInt(0)).save();
        bool = true;
      }
    }
  }

  protected native String activeSessionGetMsgText(byte[] paramArrayOfByte, boolean paramBoolean, WickrStatus paramWickrStatus);

  protected native String activeSessionGetObscureMsgID(WickrStatus paramWickrStatus);

  protected native WickrStatus activeSessionOpenDecodeCtx(boolean paramBoolean, byte[] paramArrayOfByte);

  public void clearCache()
  {
    clearUnlock();
    this.attchments = null;
    this.audioBody = null;
    this.cachedText = null;
    this.msgBlob = null;
    System.gc();
  }

  public void clearUnlock()
  {
    activeSessionCloseDecodeCtx(getSrvMsgID());
    this.isUnlocked = false;
  }

  public void delete()
  {
    if (this.convo != null)
    {
      ArrayList localArrayList = this.convo.getMessages(true);
      if (localArrayList != null)
        localArrayList.remove(this);
    }
    try
    {
      refreshErrors();
      Iterator localIterator = getErrors().iterator();
      while (true)
      {
        boolean bool = localIterator.hasNext();
        if (!bool)
        {
          label52: deleteSafe();
          return;
        }
        ((WickrError)localIterator.next()).delete();
      }
    }
    catch (Exception localException)
    {
      break label52;
    }
  }

  public void deleteSafe()
  {
    WickrDBAdapter.writableDatabase.delete("Wickr_Message", "_id=" + this.id, null);
    destroyMsgBlob();
    super.delete();
  }

  protected void destroyMsgBlob()
  {
    WickrSession.getActiveSession().getContext().deleteFile(getBlobFilePath());
  }

  public WickrAttachment[] getAttachments()
  {
    int j;
    if ((this.attchments == null) && (hasAttachments()))
    {
      if (!this.isUnlocked)
        break label114;
      int i = activeSessionDecodeCtxGetNumAttach(getSrvMsgID(), this.unlockStatus);
      this.attchments = new WickrAttachment[i];
      if (i > 0)
      {
        j = 0;
        if (j < i)
          break label57;
      }
    }
    label57: label114: 
    do
    {
      while (true)
      {
        return this.attchments;
        byte[] arrayOfByte = activeSessionDecodeCtxGetAttach(getSrvMsgID(), j, this.unlockStatus);
        if (!this.unlockStatus.isError())
          try
          {
            WickrAttachment localWickrAttachment = new WickrAttachment(arrayOfByte);
            this.attchments[j] = localWickrAttachment;
            j++;
          }
          catch (Exception localException)
          {
            while (true)
              localException.printStackTrace();
          }
      }
      setUnlockStatus(unlock());
    }
    while (!this.isUnlocked);
    return getAttachments();
  }

  public byte[] getAudioBody()
  {
    if (this.audioBody == null)
    {
      if (!this.isUnlocked)
        break label34;
      this.audioBody = activeSessionDecodeCtxGetAudioBody(getSrvMsgID(), this.unlockStatus);
    }
    label34: 
    do
    {
      return this.audioBody;
      setUnlockStatus(unlock());
    }
    while (!this.isUnlocked);
    return getAudioBody();
  }

  protected String getBlobFilePath()
  {
    return getMsgIDSecure() + ".wic";
  }

  public String getCachedText()
  {
    if (this.cachedTextEnc == null)
    {
      setUnlockStatus(unlock());
      if (this.isUnlocked)
        return getCachedText();
      return "Decryption Error!";
    }
    if (this.cachedText != null)
      return this.cachedText;
    this.cachedText = activeSessionGetMsgText(this.cachedTextEnc, isInbox(), this.unlockStatus);
    if ((this.cachedText == null) || (this.unlockStatus.isError()))
      this.cachedText = "Decryption Error!";
    return this.cachedText;
  }

  public byte[] getCachedTextEnc()
  {
    return this.cachedTextEnc;
  }

  public WickrConvo getConvo()
  {
    return this.convo;
  }

  public ArrayList<WickrError> getErrors()
  {
    if (this.errors == null)
      this.errors = fetchErrors();
    return this.errors;
  }

  public String getMessageTypeString()
  {
    return this.msgType;
  }

  public byte[] getMsgBlob()
  {
    if (this.msgBlob != null)
      return this.msgBlob;
    try
    {
      FileInputStream localFileInputStream = WickrSession.getActiveSession().getContext().openFileInput(getBlobFilePath());
      ByteArrayOutputStream localByteArrayOutputStream = new ByteArrayOutputStream();
      byte[] arrayOfByte = new byte[1024];
      while (true)
      {
        int i = localFileInputStream.read(arrayOfByte);
        if (i == -1)
        {
          this.msgBlob = localByteArrayOutputStream.toByteArray();
          localByteArrayOutputStream.close();
          localFileInputStream.close();
          return this.msgBlob;
        }
        localByteArrayOutputStream.write(arrayOfByte, 0, i);
      }
    }
    catch (Exception localException)
    {
      while (true)
        this.msgBlob = null;
    }
  }

  public byte[] getMsgBlobForLocal()
  {
    return this.msgBlob;
  }

  public WickrMsgClass getMsgClass()
  {
    if (this.msgClass == null)
      if (this.msgType.charAt(0) != '1')
        break label32;
    label32: for (this.msgClass = WickrMsgClass.WICKR_TXT_MESSAGE; ; this.msgClass = WickrMsgClass.WICKR_AUDIO_MESSAGE)
      return this.msgClass;
  }

  public String getMsgIDSecure()
  {
    return this.msgIDSecure;
  }

  public long getMsgTimestamp()
  {
    return this.msgTimestamp;
  }

  public String getSrvMsgID()
  {
    return this.srvMsgID;
  }

  public String getTimestampText()
  {
    return WickrUtil.formatTimestamp(getMsgTimestamp());
  }

  public WickrStatus getUnlockStatus()
  {
    return this.unlockStatus;
  }

  public String getvGroupID()
  {
    return this.vGroupID;
  }

  public boolean hasAttachments()
  {
    for (int i = 1; ; i++)
    {
      if (i >= this.msgType.length())
        return false;
      if (this.msgType.charAt(i) != '0')
        return true;
    }
  }

  public boolean hasMsgBlob()
  {
    if (this.msgBlob != null)
      return true;
    try
    {
      WickrSession.getActiveSession().getContext().openFileInput(getBlobFilePath()).close();
      return true;
    }
    catch (Exception localException)
    {
    }
    return false;
  }

  public boolean isInbox()
  {
    return getClass().getName().equalsIgnoreCase("com.mywickr.wickr.WickrInbox");
  }

  public int numAttachments()
  {
    int i = 0;
    for (int j = 1; ; j++)
    {
      if (j >= this.msgType.length())
        return i;
      if (this.msgType.charAt(j) != '0')
        i++;
    }
  }

  public void refreshErrors()
  {
    this.errors = fetchErrors();
  }

  public boolean save()
  {
    return super.save();
  }

  public void setConvo(WickrConvo paramWickrConvo)
  {
    changeMade();
    this.convo = paramWickrConvo;
    save();
  }

  public void setSrvMsgID(String paramString)
  {
    this.srvMsgID = paramString;
    this.msgIDSecure = activeSessionGetObscureMsgID(new WickrStatus(0));
    changeMade();
    save();
  }

  protected void setUnlockStatus(WickrStatus paramWickrStatus)
  {
    this.unlockStatus = paramWickrStatus;
    if (!paramWickrStatus.isError())
      this.isUnlocked = true;
  }

  public WickrStatus unlock()
  {
    return activeSessionOpenDecodeCtx(isInbox(), getMsgBlob());
  }

  protected void writeToFile()
  {
    try
    {
      FileOutputStream localFileOutputStream = WickrSession.getActiveSession().getContext().openFileOutput(getBlobFilePath(), 0);
      localFileOutputStream.write(this.msgBlob);
      localFileOutputStream.close();
      return;
    }
    catch (FileNotFoundException localFileNotFoundException)
    {
      localFileNotFoundException.printStackTrace();
      return;
    }
    catch (IOException localIOException)
    {
      localIOException.printStackTrace();
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.wickr.WickrMessage
 * JD-Core Version:    0.6.2
 */