package com.mywickr.wickr;

public abstract class WickrOperation
{
  private boolean canceled;
  private boolean executing;
  private boolean finished;
  protected float progress = 0.0F;
  private WickrProgressInterface progressInterface = null;
  private WickrQueueInterface queue = null;
  private WickrStatusDisplayInterface statusInterface = null;

  public WickrOperation(WickrQueueInterface paramWickrQueueInterface)
  {
    this.queue = paramWickrQueueInterface;
  }

  public void cancel()
  {
    this.canceled = true;
    complete();
  }

  public void complete()
  {
    this.executing = false;
    this.finished = true;
    if (this.queue != null)
    {
      this.queue.operationCompleted(this);
      this.queue = null;
    }
  }

  public abstract String getID();

  public float getProgress()
  {
    return this.progress;
  }

  protected WickrProgressInterface getProgressDisplayInterface()
  {
    return this.progressInterface;
  }

  protected abstract Runnable getRunnable();

  protected WickrStatusDisplayInterface getStatusDisplayInterface()
  {
    return this.statusInterface;
  }

  public boolean isCanceled()
  {
    return this.canceled;
  }

  public boolean isExecuting()
  {
    return this.executing;
  }

  public boolean isFinished()
  {
    return this.finished;
  }

  public void setProgressDisplayInterface(WickrProgressInterface paramWickrProgressInterface)
  {
    this.progressInterface = paramWickrProgressInterface;
  }

  public void setStatusDisplayInterface(WickrStatusDisplayInterface paramWickrStatusDisplayInterface)
  {
    this.statusInterface = paramWickrStatusDisplayInterface;
  }

  public void start()
  {
    if (!this.canceled)
    {
      this.executing = true;
      if (this.statusInterface != null)
        this.statusInterface.setStatus("Encoding");
      new Thread(getRunnable()).start();
      return;
    }
    complete();
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.wickr.WickrOperation
 * JD-Core Version:    0.6.2
 */