package com.mywickr.wickr;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import com.mywickr.interfaces.WickrAccountsInterface;
import com.mywickr.interfaces.WickrDeviceBackupInterface;
import com.mywickr.interfaces.WickrPrivacyManInterface;
import com.mywickr.services.ShredderService;
import com.mywickr.services.ShredderService.ShredderBinder;
import com.mywickr.services.WickrDownloadManagerService;
import com.mywickr.services.WickrDownloadManagerService.DownloadBinder;
import com.mywickr.services.WickrUploadManagerService;
import com.mywickr.services.WickrUploadManagerService.UploadBinder;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;

public class WickrSession extends WickrManager
{
  private static WickrSession activeSession = null;
  private WickrAccount account;
  private WickrDeviceMan accountManager;
  private WickrComposeCtx activeCompose = null;
  private Context appContext;
  private String appID = null;
  private WickrContactMan contactManager;
  private long defaultSDTime = 0L;
  private WickrDownloadManagerService downloadService = null;
  private ServiceConnection downloadServiceConnection = new ServiceConnection()
  {
    public void onServiceConnected(ComponentName paramAnonymousComponentName, IBinder paramAnonymousIBinder)
    {
      WickrSession.this.downloadService = ((WickrDownloadManagerService.DownloadBinder)paramAnonymousIBinder).getService();
    }

    public void onServiceDisconnected(ComponentName paramAnonymousComponentName)
    {
      WickrSession.this.downloadService = null;
    }
  };
  private WickrAsyncHttp globalHttpClient;
  private boolean isBackground = false;
  private WickrUserKeyUpdateMan keyUpdateManager;
  private long lastSessionLock = 0L;
  private WickrAppClock localClock = null;
  private WickrPrivacyMan privacyManager;
  private ServiceConnection serviceConnection = new ServiceConnection()
  {
    public void onServiceConnected(ComponentName paramAnonymousComponentName, IBinder paramAnonymousIBinder)
    {
      WickrSession.this.shredderService = ((ShredderService.ShredderBinder)paramAnonymousIBinder).getService();
    }

    public void onServiceDisconnected(ComponentName paramAnonymousComponentName)
    {
      WickrSession.this.shredderService = null;
    }
  };
  private long sessionLock = 0L;
  private ShredderService shredderService = null;
  private WickrStateSyncMan stateSyncManager;
  private WickrUploadQueue uploadQueue;
  private WickrUploadManagerService uploadService = null;
  private ServiceConnection uploadServiceConnection = new ServiceConnection()
  {
    public void onServiceConnected(ComponentName paramAnonymousComponentName, IBinder paramAnonymousIBinder)
    {
      WickrSession.this.uploadService = ((WickrUploadManagerService.UploadBinder)paramAnonymousIBinder).getService();
    }

    public void onServiceDisconnected(ComponentName paramAnonymousComponentName)
    {
      WickrSession.this.uploadService = null;
    }
  };
  private String userName = null;

  static
  {
    System.loadLibrary("wickrCore");
  }

  private WickrSession(WickrAccount paramWickrAccount, String paramString1, String paramString2, Context paramContext)
  {
    if (activeSession == null)
    {
      setStatus(attemptLogin(paramWickrAccount, paramString1, paramString2));
      if (!getStatus().isError())
      {
        activeSession = this;
        this.appContext = paramContext;
        this.account = paramWickrAccount;
        this.privacyManager = new WickrPrivacyMan(paramWickrAccount.getID());
        this.accountManager = new WickrDeviceMan();
        this.contactManager = new WickrContactMan();
        this.keyUpdateManager = new WickrUserKeyUpdateMan();
        this.stateSyncManager = new WickrStateSyncMan();
        this.uploadQueue = new WickrUploadQueue(this.appContext);
        this.globalHttpClient = new WickrAsyncHttp(this.appContext, true);
      }
    }
  }

  private static native WickrPasswordCache activeSessionCachePassword(String paramString, WickrStatus paramWickrStatus);

  private static native String activeSessionGetAppID(WickrStatus paramWickrStatus);

  private static native long activeSessionGetDefaultSD(WickrStatus paramWickrStatus);

  private static native long activeSessionGetSessionLock(WickrStatus paramWickrStatus);

  private static native String activeSessionGetUsername(WickrStatus paramWickrStatus);

  private static native String activeSessionLoginString(WickrStatus paramWickrStatus, String paramString, boolean paramBoolean, String[] paramArrayOfString);

  private static native WickrLoginReceipt activeSessionProcessLoginResult(byte[] paramArrayOfByte);

  private static native byte[] activeSessionSetDefaultSD(long paramLong, WickrStatus paramWickrStatus);

  private static native byte[] activeSessionSetSessionLock(long paramLong, WickrStatus paramWickrStatus);

  private static native WickrStatus attemptLogin(WickrAccount paramWickrAccount, String paramString1, String paramString2);

  public static void clearPasswordCache(Context paramContext)
  {
    try
    {
      if ((getActiveSession() != null) && (getActiveSession().getSessionLock() == -1000000L))
        getActiveSession().setSessionLockTime(3600L);
      new File(paramContext.getFilesDir() + "/pcd.wic").delete();
      new File(paramContext.getFilesDir() + "/pcc.wic").delete();
      return;
    }
    catch (Exception localException)
    {
      localException.printStackTrace();
    }
  }

  public static WickrSession getActiveSession()
  {
    return activeSession;
  }

  private long getLastApid()
  {
    return this.account.getLastApid();
  }

  public static WickrSession initializeSession(WickrAccount paramWickrAccount, String paramString1, String paramString2, Context paramContext)
  {
    if (activeSession != null);
    try
    {
      logoutActiveSession();
      return new WickrSession(paramWickrAccount, paramString1, paramString2, paramContext);
    }
    catch (Exception localException)
    {
      while (true)
        localException.printStackTrace();
    }
  }

  public static native String libWickrVersion();

  private static native void logoutActiveSession();

  private static native String recoverCachedPassword(String paramString, byte[] paramArrayOfByte1, byte[] paramArrayOfByte2, WickrStatus paramWickrStatus);

  public static String retreiveCachedPassword(Context paramContext)
  {
    while (true)
    {
      ByteArrayOutputStream localByteArrayOutputStream2;
      byte[] arrayOfByte3;
      int j;
      try
      {
        FileInputStream localFileInputStream1 = paramContext.openFileInput("pcc.wic");
        FileInputStream localFileInputStream2 = paramContext.openFileInput("pcd.wic");
        ByteArrayOutputStream localByteArrayOutputStream1 = new ByteArrayOutputStream();
        byte[] arrayOfByte1 = new byte[1024];
        int i = localFileInputStream1.read(arrayOfByte1);
        if (i == -1)
        {
          byte[] arrayOfByte2 = localByteArrayOutputStream1.toByteArray();
          localByteArrayOutputStream1.close();
          localByteArrayOutputStream2 = new ByteArrayOutputStream();
          arrayOfByte3 = new byte[1024];
          j = localFileInputStream2.read(arrayOfByte3);
          if (j == -1)
          {
            byte[] arrayOfByte4 = localByteArrayOutputStream2.toByteArray();
            localByteArrayOutputStream2.close();
            WickrStatus localWickrStatus = new WickrStatus(0);
            String str = recoverCachedPassword(WickrUtil.getDeviceIdentifier(paramContext), arrayOfByte2, arrayOfByte4, localWickrStatus);
            localFileInputStream1.close();
            localFileInputStream2.close();
            if ((localWickrStatus.isError()) || (str == null))
              break;
            return str;
          }
        }
        else
        {
          localByteArrayOutputStream1.write(arrayOfByte1, 0, i);
          continue;
        }
      }
      catch (Exception localException)
      {
        clearPasswordCache(paramContext);
        return null;
      }
      localByteArrayOutputStream2.write(arrayOfByte3, 0, j);
    }
    clearPasswordCache(paramContext);
    return null;
  }

  private static native WickrStatus sessionUnlock(String paramString);

  public void appDidGoToBackground()
  {
    this.lastSessionLock = getLocalAppTime();
    this.localClock.stop();
    unbindDownloadService();
    if (isAutoShredderEnabeled())
      stopShredderService();
    this.isBackground = true;
    WickrUser.clearUserCache();
  }

  public void appDidResume()
  {
    this.isBackground = false;
    this.localClock.start();
    if (isAutoShredderEnabeled())
      startShredderService();
    bindDownloadService();
    bindUploadService();
    startUploadService();
    checkForNewMessages();
  }

  public boolean appIsBackground()
  {
    return this.isBackground;
  }

  public boolean attemptSessionUnlock(String paramString)
  {
    return !sessionUnlock(paramString).isError();
  }

  public void bindDownloadService()
  {
    getContext().bindService(new Intent(getContext(), WickrDownloadManagerService.class), this.downloadServiceConnection, 1);
  }

  public void bindUploadService()
  {
    getContext().bindService(new Intent(getContext(), WickrUploadManagerService.class), this.uploadServiceConnection, 1);
  }

  // ERROR //
  public WickrStatus cachePassword(String paramString)
  {
    // Byte code:
    //   0: aload_1
    //   1: aload_0
    //   2: invokevirtual 114	com/mywickr/wickr/WickrSession:getStatus	()Lcom/mywickr/wickr/WickrStatus;
    //   5: invokestatic 372	com/mywickr/wickr/WickrSession:activeSessionCachePassword	(Ljava/lang/String;Lcom/mywickr/wickr/WickrStatus;)Lcom/mywickr/wickr/WickrPasswordCache;
    //   8: astore_2
    //   9: iconst_0
    //   10: istore_3
    //   11: aload_0
    //   12: invokevirtual 375	com/mywickr/wickr/WickrSession:isErrorState	()Z
    //   15: ifne +73 -> 88
    //   18: invokestatic 199	com/mywickr/wickr/WickrSession:getActiveSession	()Lcom/mywickr/wickr/WickrSession;
    //   21: invokevirtual 352	com/mywickr/wickr/WickrSession:getContext	()Landroid/content/Context;
    //   24: ldc_w 262
    //   27: iconst_0
    //   28: invokevirtual 379	android/content/Context:openFileOutput	(Ljava/lang/String;I)Ljava/io/FileOutputStream;
    //   31: astore 10
    //   33: aload 10
    //   35: aload_2
    //   36: invokevirtual 384	com/mywickr/wickr/WickrPasswordCache:getKeyToCacheData	()[B
    //   39: invokevirtual 389	java/io/FileOutputStream:write	([B)V
    //   42: aload 10
    //   44: invokevirtual 390	java/io/FileOutputStream:close	()V
    //   47: invokestatic 199	com/mywickr/wickr/WickrSession:getActiveSession	()Lcom/mywickr/wickr/WickrSession;
    //   50: invokevirtual 352	com/mywickr/wickr/WickrSession:getContext	()Landroid/content/Context;
    //   53: ldc_w 268
    //   56: iconst_0
    //   57: invokevirtual 379	android/content/Context:openFileOutput	(Ljava/lang/String;I)Ljava/io/FileOutputStream;
    //   60: astore 8
    //   62: aload 8
    //   64: aload_2
    //   65: invokevirtual 393	com/mywickr/wickr/WickrPasswordCache:getEncLocalData	()[B
    //   68: invokevirtual 389	java/io/FileOutputStream:write	([B)V
    //   71: aload 8
    //   73: invokevirtual 390	java/io/FileOutputStream:close	()V
    //   76: iload_3
    //   77: ifne +11 -> 88
    //   80: aload_0
    //   81: ldc2_w 204
    //   84: invokevirtual 211	com/mywickr/wickr/WickrSession:setSessionLockTime	(J)Lcom/mywickr/wickr/WickrStatus;
    //   87: pop
    //   88: aload_0
    //   89: invokevirtual 114	com/mywickr/wickr/WickrSession:getStatus	()Lcom/mywickr/wickr/WickrStatus;
    //   92: areturn
    //   93: astore 9
    //   95: aload 9
    //   97: invokevirtual 394	java/io/FileNotFoundException:printStackTrace	()V
    //   100: iconst_0
    //   101: istore_3
    //   102: goto -55 -> 47
    //   105: astore 4
    //   107: aload 4
    //   109: invokevirtual 395	java/io/IOException:printStackTrace	()V
    //   112: iconst_1
    //   113: istore_3
    //   114: goto -67 -> 47
    //   117: astore 7
    //   119: aload 7
    //   121: invokevirtual 394	java/io/FileNotFoundException:printStackTrace	()V
    //   124: goto -48 -> 76
    //   127: astore 5
    //   129: aload 5
    //   131: invokevirtual 395	java/io/IOException:printStackTrace	()V
    //   134: iconst_1
    //   135: istore_3
    //   136: goto -60 -> 76
    //
    // Exception table:
    //   from	to	target	type
    //   18	47	93	java/io/FileNotFoundException
    //   18	47	105	java/io/IOException
    //   47	76	117	java/io/FileNotFoundException
    //   47	76	127	java/io/IOException
  }

  public void checkForNewMessages()
  {
    Intent localIntent = new Intent(getContext(), WickrDownloadManagerService.class);
    getContext().startService(localIntent);
  }

  public boolean closeSession(boolean paramBoolean)
  {
    if ((this.downloadService != null) && (this.uploadQueue != null) && ((this.uploadQueue.getOperations().length > 0) || (this.downloadService.isDownloading())) && (!paramBoolean))
      return false;
    if (activeSession != null)
    {
      activeSession = null;
      if (this.localClock != null)
        this.localClock.stop();
    }
    getKeyUpdateMan().cancelAll();
    if (this.downloadService != null)
      this.downloadService.cancelAllTransfers();
    stopShredderService();
    stopDownloadService();
    this.uploadQueue.cancelAllOperations();
    WickrConvo.clearConvoList();
    WickrUser.clearUserCache();
    logoutActiveSession();
    return true;
  }

  public String getAppID()
  {
    if (this.appID == null)
    {
      this.appID = activeSessionGetAppID(getStatus());
      if ((isErrorState()) && (this.appID == null))
        return null;
    }
    return this.appID;
  }

  public int getAutoShredderSpeed()
  {
    return this.account.getAutoShredderSpeed();
  }

  public WickrContactMan getContactManager()
  {
    return this.contactManager;
  }

  public Context getContext()
  {
    return this.appContext;
  }

  public long getDefaultSDTime()
  {
    if (this.defaultSDTime == 0L)
      this.defaultSDTime = activeSessionGetDefaultSD(getStatus());
    if (isErrorState())
      return -1L;
    return this.defaultSDTime;
  }

  public WickrDeviceMan getDeviceManager()
  {
    return this.accountManager;
  }

  public String getGCMPushID()
  {
    return this.account.getGCMPushID();
  }

  public long getHighECID()
  {
    return this.account.getHighECID();
  }

  public WickrAsyncHttp getHttpClient()
  {
    return this.globalHttpClient;
  }

  public WickrUserKeyUpdateMan getKeyUpdateMan()
  {
    return this.keyUpdateManager;
  }

  public WickrAppClock getLocalAppClock()
  {
    return this.localClock;
  }

  public long getLocalAppTime()
  {
    if (this.localClock != null)
      return this.localClock.getCurrentTime();
    return -1L;
  }

  public boolean getNeedsWizard()
  {
    return this.account.getIsNewUser();
  }

  public WickrPrivacyMan getPrivacyList()
  {
    return this.privacyManager;
  }

  public String getServerLoginString(String paramString, boolean paramBoolean)
  {
    if (!isErrorState())
    {
      String str = activeSessionLoginString(getStatus(), paramString, paramBoolean, WickrInbox.getUnopenedMessageIDs());
      if (isErrorState())
        str = null;
      return str;
    }
    return null;
  }

  public long getSessionLock()
  {
    if (this.sessionLock == 0L)
      this.sessionLock = activeSessionGetSessionLock(getStatus());
    if (isErrorState())
      return -1L;
    return this.sessionLock;
  }

  public ShredderService getShredderService()
  {
    return this.shredderService;
  }

  public WickrStateSyncMan getStateSyncMan()
  {
    return this.stateSyncManager;
  }

  public WickrUploadQueue getUploadQueue()
  {
    return this.uploadQueue;
  }

  public String getUserName()
  {
    if (this.userName == null)
      this.userName = activeSessionGetUsername(getStatus());
    if (isErrorState())
      return null;
    return this.userName;
  }

  public boolean getWasSynced()
  {
    return this.account.getWasSynced();
  }

  public boolean isAutoShredderEnabeled()
  {
    return this.account.getAutoShredderEnabled();
  }

  public long lastSessionLockTime()
  {
    return this.lastSessionLock;
  }

  public boolean logout(boolean paramBoolean)
  {
    clearPasswordCache(getContext());
    return closeSession(paramBoolean);
  }

  public void markWizardCompletion()
  {
    this.account.setIsNewUser(false);
    this.account.save();
  }

  public WickrLoginReceipt processLoginResult(byte[] paramArrayOfByte)
  {
    WickrLoginReceipt localWickrLoginReceipt = activeSessionProcessLoginResult(paramArrayOfByte);
    if ((localWickrLoginReceipt != null) && (!localWickrLoginReceipt.getStatusCode().isError()))
    {
      if (this.localClock != null)
        break label140;
      this.localClock = new WickrAppClock(localWickrLoginReceipt.getServerTime(), 1L, 1000L);
    }
    while (true)
    {
      appDidResume();
      getStateSyncMan().syncByDeletingIDs(localWickrLoginReceipt.getInvalidMsgID());
      boolean bool = WickrMessage.processFailedUploads();
      WickrMessage.deleteOldMessages();
      WickrKeyPair.deleteExpired();
      WickrKeyPair.deleteOldFallbacks();
      WickrKeyPair.markKeyExpireTimes();
      if (localWickrLoginReceipt.needsNewFallback())
        WickrKeyPairFactory.createKeys(20, true);
      if (localWickrLoginReceipt.lastPrivacyUpdate() > getPrivacyList().getLastUpdate())
        getPrivacyList().update();
      if (bool)
        new Handler(Looper.getMainLooper()).post(new Runnable()
        {
          public void run()
          {
            WickrUtil.showDialog(WickrSession.this.getContext(), "Message uploads failed while you were away. Please resend if necessary.");
          }
        });
      return localWickrLoginReceipt;
      label140: this.localClock.setCurrentTime(localWickrLoginReceipt.getServerTime());
    }
  }

  public void setAccountManagerGUI(WickrAccountsInterface paramWickrAccountsInterface)
  {
    this.accountManager.setAccountGUIManager(paramWickrAccountsInterface);
  }

  public void setAutoShredderEnabeled(boolean paramBoolean)
  {
    this.account.setAutoShredderEnabled(paramBoolean);
    this.account.save();
    if (paramBoolean)
    {
      startShredderService();
      return;
    }
    stopShredderService();
  }

  public void setAutoShredderSpeed(int paramInt)
  {
    this.account.setAutoShredderSpeed(paramInt);
    this.account.save();
    if (this.shredderService != null)
      this.shredderService.setNewPriorityLevel(paramInt);
  }

  public void setBackupGUI(WickrDeviceBackupInterface paramWickrDeviceBackupInterface)
  {
    this.contactManager.setBackupGUIManager(paramWickrDeviceBackupInterface);
  }

  public WickrStatus setDefaultSDTime(long paramLong)
  {
    byte[] arrayOfByte = activeSessionSetDefaultSD(paramLong, getStatus());
    if (!isErrorState())
    {
      this.account.setDefSelfDestructSecure(arrayOfByte);
      this.defaultSDTime = paramLong;
      this.account.changeMade();
      this.account.save();
    }
    return getStatus();
  }

  public void setGCMPushID(String paramString)
  {
    this.account.setGCMPushID(paramString);
    this.account.save();
  }

  public void setHighECID(long paramLong)
  {
    this.account.setHighECID(paramLong);
    this.account.save();
  }

  public void setLastApid(long paramLong)
  {
    this.account.setLastAPID(paramLong);
    this.account.save();
  }

  public void setPrivacyManagerGUI(WickrPrivacyManInterface paramWickrPrivacyManInterface)
  {
    this.privacyManager.setPrivacyGUIManager(paramWickrPrivacyManInterface);
  }

  public WickrStatus setSessionLockTime(long paramLong)
  {
    boolean bool1 = getSessionLock() < -1000000L;
    int i = 0;
    if (!bool1)
    {
      boolean bool2 = paramLong < -1000000L;
      i = 0;
      if (bool2)
        i = 1;
    }
    byte[] arrayOfByte = activeSessionSetSessionLock(paramLong, getStatus());
    if (!isErrorState())
    {
      this.account.setSessionLockSecure(arrayOfByte);
      this.sessionLock = paramLong;
      this.account.changeMade();
      this.account.save();
      if (i != 0)
        clearPasswordCache(getContext());
    }
    return getStatus();
  }

  public void startShredderService()
  {
    if (isAutoShredderEnabeled())
    {
      getContext().bindService(new Intent(getContext(), ShredderService.class), this.serviceConnection, 1);
      Intent localIntent = new Intent(getContext(), ShredderService.class);
      localIntent.putExtra("af_speed", getAutoShredderSpeed());
      getContext().startService(localIntent);
    }
  }

  public void startUploadService()
  {
    Intent localIntent = new Intent(getContext(), WickrUploadManagerService.class);
    getContext().startService(localIntent);
  }

  public void stopDownloadService()
  {
    try
    {
      if (this.downloadService != null)
      {
        this.downloadService.cancelAllTransfers();
        getContext().stopService(new Intent(getContext(), WickrDownloadManagerService.class));
        unbindDownloadService();
      }
      return;
    }
    catch (Exception localException)
    {
      localException.printStackTrace();
    }
  }

  public void stopShredderService()
  {
    try
    {
      if (this.shredderService != null)
      {
        getContext().stopService(new Intent(getContext(), ShredderService.class));
        getContext().unbindService(this.serviceConnection);
      }
      return;
    }
    catch (Exception localException)
    {
      localException.printStackTrace();
    }
  }

  public void unbindDownloadService()
  {
    try
    {
      if (this.downloadService != null)
        getContext().unbindService(this.downloadServiceConnection);
      return;
    }
    catch (Exception localException)
    {
      localException.printStackTrace();
    }
  }

  public void updateDownloadServiceStatus()
  {
    if (this.downloadService != null)
      this.downloadService.updateGUI();
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.wickr.WickrSession
 * JD-Core Version:    0.6.2
 */