package com.mywickr.wickr;

import android.content.ContentValues;
import android.graphics.Bitmap;
import android.graphics.Bitmap.CompressFormat;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import java.io.ByteArrayOutputStream;
import java.security.InvalidParameterException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.concurrent.ConcurrentHashMap;
import net.sqlcipher.database.SQLiteDatabase;

public class WickrUser extends WickrDBObject
{
  private static WickrCache<WickrUser> userImageCache;
  private static ConcurrentHashMap<String, WickrUser> userInfoCache = null;
  private ArrayList<WickrApp> apps = null;
  private boolean didCheckImage = false;
  private boolean isDecoded = false;
  private boolean isHidden;
  private boolean isOnPrivacyList = false;
  private WickrSession session = null;
  private String userAlias = null;
  private String userAliasHash = null;
  private byte[] userAliasSecure = null;
  private String userIDHash = null;
  private byte[] userIDSecure = null;
  private Bitmap userImage = null;
  private String userName = null;
  private byte[] userNameSecure = null;

  static
  {
    System.loadLibrary("wickrCore");
  }

  public WickrUser(int paramInt)
  {
    if (paramInt != -1)
    {
      this.id = paramInt;
      refreshFromDB();
      addUserToCache(this);
    }
  }

  private WickrUser(String paramString1, String paramString2, byte[] paramArrayOfByte1, byte[] paramArrayOfByte2, byte[] paramArrayOfByte3, int paramInt)
  {
    this(getIDForExistingUser(paramString1));
    this.userIDHash = paramString1;
    this.userIDSecure = paramArrayOfByte1;
    this.userNameSecure = paramArrayOfByte3;
    updateUserAliasInfo(paramString2, paramArrayOfByte2, paramArrayOfByte3);
    addUserToCache(this);
  }

  private static native WickrUser activeComposeProcessUQueryResultInfo(byte[] paramArrayOfByte, String paramString, WickrAPICode paramWickrAPICode, WickrStatus paramWickrStatus);

  private static native WickrUser activeSessionCreateUserWithUsername(String paramString, WickrStatus paramWickrStatus);

  private native byte[] activeSessionDecodeUserImage(byte[] paramArrayOfByte, WickrStatus paramWickrStatus);

  private native void activeSessionDecodeUserProperties(WickrStatus paramWickrStatus);

  private native byte[] activeSessionEncodeUserImage(byte[] paramArrayOfByte, WickrStatus paramWickrStatus);

  private native byte[] activeSessionEncodeUserName(String paramString, WickrStatus paramWickrStatus);

  private static native String activeSessionGetSecureAlias(String paramString, WickrStatus paramWickrStatus);

  private static native String activeSessionQueryUserString(String paramString, int paramInt, long paramLong, WickrStatus paramWickrStatus);

  private native String activeSessionQueryUserStringID(long paramLong, WickrStatus paramWickrStatus);

  public static void addUserImageToImageCache(WickrUser paramWickrUser)
  {
    if (userImageCache == null)
      userImageCache = new WickrCache(new WickrCacheInterface()
      {
        public void cacheEvictedObject(WickrCache<WickrUser> paramAnonymousWickrCache, WickrUser paramAnonymousWickrUser)
        {
          paramAnonymousWickrUser.userImage.recycle();
          paramAnonymousWickrUser.userImage = null;
          paramAnonymousWickrUser.didCheckImage = false;
        }
      }
      , WickrUtil.numberOfUserImageToCache());
    userImageCache.cacheElement(paramWickrUser);
  }

  private static void addUserToCache(WickrUser paramWickrUser)
  {
    getUserCache().put(paramWickrUser.getUserIDHash(), paramWickrUser);
  }

  private static void cacheAllUsers()
  {
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery("SELECT userIDHash FROM Wickr_User", null);
    while (true)
    {
      if (!localCursor.moveToNext())
      {
        localCursor.close();
        return;
      }
      getUserWithID(localCursor.getString(0));
    }
  }

  public static void clearUserCache()
  {
    userInfoCache = null;
    userImageCache = null;
    System.gc();
  }

  public static WickrUser createNewUserWithUname(String paramString)
  {
    WickrUser localWickrUser = getUserWithAlias(paramString);
    if (localWickrUser == null)
    {
      WickrStatus localWickrStatus = new WickrStatus(1);
      localWickrUser = activeSessionCreateUserWithUsername(paramString, localWickrStatus);
      if (localWickrStatus.isError())
        return null;
    }
    return localWickrUser;
  }

  public static WickrAPICode createUserWithQueryResult(byte[] paramArrayOfByte, String paramString)
  {
    WickrAPICode localWickrAPICode = new WickrAPICode(0);
    WickrStatus localWickrStatus = new WickrStatus(1);
    WickrUser localWickrUser = activeComposeProcessUQueryResultInfo(paramArrayOfByte, paramString, localWickrAPICode, localWickrStatus);
    if ((!localWickrAPICode.isError()) && (!localWickrStatus.isError()))
    {
      localWickrUser.setIsHidden(false);
      localWickrUser.save();
    }
    return localWickrAPICode;
  }

  private ArrayList<WickrApp> getAppsInternal()
  {
    if (this.apps == null)
      loadApps();
    return this.apps;
  }

  private static int getIDForExistingUser(String paramString)
  {
    String[] arrayOfString1 = { "_id" };
    String[] arrayOfString2 = new String[3];
    arrayOfString2[0] = "userIDHash";
    arrayOfString2[1] = "=";
    arrayOfString2[2] = ("\"" + paramString + "\"");
    String str = getQueary(arrayOfString1, arrayOfString2);
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(str, null);
    int i = -1;
    while (true)
    {
      if (!localCursor.moveToNext())
      {
        localCursor.close();
        return i;
      }
      if (localCursor.getCount() > 0)
        i = localCursor.getInt(0);
    }
  }

  private static String getQueary(String[] paramArrayOfString1, String[] paramArrayOfString2)
  {
    WickrQuearyBuilder localWickrQuearyBuilder = new WickrQuearyBuilder();
    localWickrQuearyBuilder.PARAMETER = paramArrayOfString1;
    localWickrQuearyBuilder.WHERE_CLAUSE = paramArrayOfString2;
    return localWickrQuearyBuilder.getSelectWickrUser();
  }

  private static ConcurrentHashMap<String, WickrUser> getUserCache()
  {
    if (userInfoCache == null)
    {
      userInfoCache = new ConcurrentHashMap();
      cacheAllUsers();
    }
    return userInfoCache;
  }

  public static ArrayList<WickrUser> getUserCacheList()
  {
    ArrayList localArrayList = new ArrayList();
    Iterator localIterator = getUserCache().values().iterator();
    while (true)
    {
      if (!localIterator.hasNext())
        return localArrayList;
      WickrUser localWickrUser = (WickrUser)localIterator.next();
      if (!localWickrUser.isHidden)
        localArrayList.add(localWickrUser);
    }
  }

  public static ArrayList<String> getUserCacheNames()
  {
    ArrayList localArrayList = new ArrayList();
    Iterator localIterator = getUserCache().values().iterator();
    while (true)
    {
      if (!localIterator.hasNext())
        return localArrayList;
      WickrUser localWickrUser = (WickrUser)localIterator.next();
      if (!localWickrUser.isHidden)
        localArrayList.add(localWickrUser.getUserAlias());
    }
  }

  public static String getUserQueryString(String paramString, WickrAliasType paramWickrAliasType)
  {
    WickrStatus localWickrStatus = new WickrStatus(1);
    String str = activeSessionQueryUserString(paramString, paramWickrAliasType.getValue(), WickrSession.getActiveSession().getLocalAppTime(), localWickrStatus);
    if (localWickrStatus.isError())
      str = null;
    return str;
  }

  public static WickrUser getUserWithAlias(String paramString)
  {
    String str1;
    if (paramString != null)
    {
      WickrStatus localWickrStatus = new WickrStatus(1);
      str1 = activeSessionGetSecureAlias(paramString, localWickrStatus);
      if ((!localWickrStatus.isError()) && (str1 != null));
    }
    else
    {
      return null;
    }
    String[] arrayOfString1 = { "userIDHash" };
    String[] arrayOfString2 = new String[3];
    arrayOfString2[0] = "userAliasHash";
    arrayOfString2[1] = "=";
    arrayOfString2[2] = ("\"" + str1 + "\"");
    String str2 = getQueary(arrayOfString1, arrayOfString2);
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(str2, null);
    int i = localCursor.getCount();
    WickrUser localWickrUser = null;
    if (i > 0);
    while (true)
    {
      if (!localCursor.moveToNext())
      {
        localCursor.close();
        return localWickrUser;
      }
      localWickrUser = getUserWithID(localCursor.getString(0));
    }
  }

  public static WickrUser getUserWithID(String paramString)
  {
    WickrUser localWickrUser1 = (WickrUser)getUserCache().get(paramString);
    if (localWickrUser1 != null)
      return localWickrUser1;
    String[] arrayOfString1 = { "_id" };
    String[] arrayOfString2 = new String[3];
    arrayOfString2[0] = "userIDHash";
    arrayOfString2[1] = "=";
    arrayOfString2[2] = ("\"" + paramString + "\"");
    String str = getQueary(arrayOfString1, arrayOfString2);
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(str, null);
    int i = localCursor.getCount();
    WickrUser localWickrUser2 = null;
    if (i == 0)
    {
      localCursor.close();
      return null;
    }
    while (localCursor.moveToNext())
      localWickrUser2 = new WickrUser(localCursor.getInt(0));
    localCursor.close();
    return localWickrUser2;
  }

  public static WickrUser getUserWithID(String paramString1, String paramString2, byte[] paramArrayOfByte1, byte[] paramArrayOfByte2, byte[] paramArrayOfByte3, int paramInt)
  {
    WickrUser localWickrUser = getUserWithID(paramString1);
    if (localWickrUser != null)
    {
      localWickrUser.updateUserAliasInfo(paramString2, paramArrayOfByte2, paramArrayOfByte3);
      return localWickrUser;
    }
    return new WickrUser(paramString1, paramString2, paramArrayOfByte1, paramArrayOfByte2, paramArrayOfByte3, paramInt);
  }

  private void loadUserImage()
  {
    if (!this.didCheckImage)
    {
      String[] arrayOfString1 = { "userImageSec" };
      String[] arrayOfString2 = new String[2];
      arrayOfString2[0] = "_id";
      arrayOfString2[1] = ("=" + this.id);
      String str = getQueary(arrayOfString1, arrayOfString2);
      net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(str, null);
      byte[] arrayOfByte2;
      BitmapFactory.Options localOptions;
      for (byte[] arrayOfByte1 = null; ; arrayOfByte1 = localCursor.getBlob(0))
        if (!localCursor.moveToNext())
        {
          localCursor.close();
          WickrStatus localWickrStatus = new WickrStatus(0);
          arrayOfByte2 = activeSessionDecodeUserImage(arrayOfByte1, localWickrStatus);
          if ((localWickrStatus.isError()) || (arrayOfByte2 == null))
            break label245;
          localOptions = new BitmapFactory.Options();
          localOptions.inJustDecodeBounds = true;
          this.userImage = BitmapFactory.decodeByteArray(arrayOfByte2, 0, arrayOfByte2.length, localOptions);
          if ((localOptions.outWidth <= 500) && (localOptions.outHeight <= 500))
            break;
          localOptions.inSampleSize = WickrAttachmentManager.calculateInSampleSize(localOptions, 100, 100);
          localOptions.inJustDecodeBounds = false;
          setUserImage(BitmapFactory.decodeByteArray(arrayOfByte2, 0, arrayOfByte2.length, localOptions));
          return;
        }
      localOptions.inJustDecodeBounds = false;
      this.userImage = BitmapFactory.decodeByteArray(arrayOfByte2, 0, arrayOfByte2.length, localOptions);
      addUserImageToImageCache(this);
    }
    label245: this.didCheckImage = true;
  }

  private void setUserImageSec(byte[] paramArrayOfByte)
  {
    new ContentValues();
    ContentValues localContentValues = new ContentValues();
    localContentValues.put("userImageSec", paramArrayOfByte);
    WickrDBAdapter.writableDatabase.update("Wickr_User", localContentValues, "_id=" + this.id, null);
    this.didCheckImage = false;
  }

  private void updateUserAliasInfo(String paramString, byte[] paramArrayOfByte1, byte[] paramArrayOfByte2)
  {
    if ((this.userAliasHash != null) && (this.userAliasSecure != null))
    {
      if (WickrUtil.aliasTypeFromString(getUserAlias()) != WickrAliasType.WICKR_USERNAME_ALIAS)
      {
        this.userAliasHash = paramString;
        this.userAliasSecure = paramArrayOfByte1;
        this.isDecoded = false;
        changeMade();
      }
      if (this.userNameSecure == null)
      {
        this.userNameSecure = paramArrayOfByte2;
        this.isDecoded = false;
        changeMade();
      }
      save();
      return;
    }
    this.userAliasHash = paramString;
    this.userAliasSecure = paramArrayOfByte1;
    this.userNameSecure = paramArrayOfByte2;
    changeMade();
  }

  public void addApp(WickrApp paramWickrApp)
  {
    WickrApp localWickrApp = getAppWithID(paramWickrApp.getAppIDHash());
    if (localWickrApp == null)
    {
      changeMade();
      getAppsInternal().add(paramWickrApp);
      save();
      return;
    }
    localWickrApp.updateInfo(paramWickrApp);
  }

  public void clearAppKeyInfo()
  {
    for (int i = 0; ; i++)
    {
      if (i >= getAppsInternal().size())
      {
        changeMade();
        save();
        return;
      }
      ((WickrApp)getAppsInternal().get(i)).clearKeyInfo();
    }
  }

  public void clearSuspendedApps()
  {
    WickrApp[] arrayOfWickrApp = getApps();
    int i = arrayOfWickrApp.length;
    for (int j = 0; ; j++)
    {
      if (j >= i)
        return;
      WickrApp localWickrApp = arrayOfWickrApp[j];
      if (localWickrApp.getDevIDSecure() == null)
      {
        localWickrApp.delete();
        this.apps.remove(localWickrApp);
      }
    }
  }

  public void delete()
  {
    getUserCache().remove(getUserIDHash());
    WickrDBAdapter.writableDatabase.delete("Wickr_User", "_id=" + this.id, null);
    super.delete();
  }

  public boolean equals(Object paramObject)
  {
    return getUserIDHash().equals(((WickrUser)paramObject).getUserIDHash());
  }

  public WickrApp getAppWithID(String paramString)
  {
    for (int i = 0; ; i++)
    {
      WickrApp localWickrApp;
      if (i >= getAppsInternal().size())
        localWickrApp = null;
      do
      {
        return localWickrApp;
        localWickrApp = (WickrApp)getAppsInternal().get(i);
      }
      while (localWickrApp.getAppIDHash().equalsIgnoreCase(paramString));
    }
  }

  public WickrApp[] getApps()
  {
    return (WickrApp[])getAppsInternal().toArray(new WickrApp[getAppsInternal().size()]);
  }

  public String getInfoQueryString()
  {
    WickrStatus localWickrStatus = new WickrStatus(1);
    String str = activeSessionQueryUserStringID(WickrSession.getActiveSession().getLocalAppTime(), localWickrStatus);
    setIsHidden(false);
    if (localWickrStatus.isError())
      str = null;
    return str;
  }

  public String getPrimaryName()
  {
    if (getUserName() != null)
      return getUserName();
    return getUserAlias();
  }

  public String getSecondaryName()
  {
    return getUserAlias();
  }

  public String getUserAlias()
  {
    if (!this.isDecoded)
    {
      WickrStatus localWickrStatus = new WickrStatus(0);
      activeSessionDecodeUserProperties(localWickrStatus);
      localWickrStatus.isError();
    }
    return this.userAlias;
  }

  public String getUserAliasHash()
  {
    return this.userAliasHash;
  }

  public byte[] getUserAliasSecure()
  {
    return this.userAliasSecure;
  }

  public String getUserIDHash()
  {
    return this.userIDHash;
  }

  public byte[] getUserIDSecure()
  {
    return this.userIDSecure;
  }

  public Bitmap getUserImage()
  {
    if (this.userImage != null)
      return this.userImage;
    loadUserImage();
    return this.userImage;
  }

  public String getUserName()
  {
    if (!this.isDecoded)
    {
      WickrStatus localWickrStatus = new WickrStatus(0);
      activeSessionDecodeUserProperties(localWickrStatus);
      localWickrStatus.isError();
    }
    return this.userName;
  }

  public byte[] getUserNameSecure()
  {
    return this.userNameSecure;
  }

  public boolean isHidden()
  {
    return this.isHidden;
  }

  public boolean isOnPrivacyList()
  {
    return this.isOnPrivacyList;
  }

  public void loadApps()
  {
    this.apps = new ArrayList();
    WickrQuearyBuilder localWickrQuearyBuilder = new WickrQuearyBuilder();
    localWickrQuearyBuilder.PARAMETER = new String[] { "_id" };
    String[] arrayOfString = new String[3];
    arrayOfString[0] = "user";
    arrayOfString[1] = "=";
    arrayOfString[2] = ("\"" + this.userIDHash + "\"");
    localWickrQuearyBuilder.WHERE_CLAUSE = arrayOfString;
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery(localWickrQuearyBuilder.getSelectWickrApp(), null);
    this.apps = new ArrayList();
    while (true)
    {
      if (!localCursor.moveToNext())
      {
        localCursor.close();
        return;
      }
      this.apps.add(new WickrApp(localCursor.getInt(0), this));
    }
  }

  public void refreshFromDB()
  {
    net.sqlcipher.Cursor localCursor = WickrDBAdapter.readablDatabase.rawQuery("SELECT userIDHash, userAliasHash, userIDSec, userAlias, privacyMan, userNameSec, isHidden from Wickr_User where _id = " + this.id, null);
    if (!localCursor.moveToNext())
    {
      this.isDecoded = false;
      this.didCheckImage = false;
      localCursor.close();
      return;
    }
    this.userIDHash = localCursor.getString(0);
    this.userAliasHash = localCursor.getString(1);
    this.userIDSecure = localCursor.getBlob(2);
    this.userAliasSecure = localCursor.getBlob(3);
    boolean bool1;
    if (localCursor.getInt(4) > 0)
    {
      bool1 = true;
      label110: this.isOnPrivacyList = bool1;
      this.userNameSecure = localCursor.getBlob(5);
      if (localCursor.getInt(6) == 0)
        break label157;
    }
    label157: for (boolean bool2 = true; ; bool2 = false)
    {
      this.isHidden = bool2;
      this.apps = null;
      break;
      bool1 = false;
      break label110;
    }
  }

  public boolean refreshUserWithQueryResult(byte[] paramArrayOfByte)
  {
    WickrAPICode localWickrAPICode = new WickrAPICode(0);
    WickrStatus localWickrStatus = new WickrStatus(1);
    WickrUser localWickrUser = activeComposeProcessUQueryResultInfo(paramArrayOfByte, getUserAlias(), localWickrAPICode, localWickrStatus);
    if ((localWickrAPICode.isError()) || (localWickrStatus.isError()))
      return false;
    WickrApp[] arrayOfWickrApp1 = localWickrUser.getApps();
    WickrApp[] arrayOfWickrApp2 = getApps();
    int i = 0;
    if (i >= arrayOfWickrApp1.length)
    {
      save();
      return true;
    }
    WickrApp localWickrApp = arrayOfWickrApp1[i];
    int j = 1;
    for (int k = 0; ; k++)
    {
      if (k >= arrayOfWickrApp2.length)
      {
        if (j != 0)
          addApp(localWickrApp);
        i++;
        break;
      }
      if (arrayOfWickrApp2[k].getAppIDHash().equalsIgnoreCase(localWickrApp.getAppIDHash()))
        j = 0;
    }
  }

  public boolean save()
  {
    boolean bool1 = super.save();
    boolean bool2 = false;
    if (!bool1);
    label265: 
    while (true)
    {
      return bool2;
      new ContentValues();
      ContentValues localContentValues = new ContentValues();
      localContentValues.put("userIDHash", this.userIDHash);
      localContentValues.put("UserIDSec", this.userIDSecure);
      localContentValues.put("userAliasHash", this.userAliasHash);
      localContentValues.put("userAlias", this.userAliasSecure);
      localContentValues.put("userNameSec", this.userNameSecure);
      if (this.isOnPrivacyList)
      {
        localContentValues.put("privacyMan", Integer.valueOf(WickrSession.getActiveSession().getPrivacyList().getID()));
        label116: localContentValues.put("isHidden", Boolean.valueOf(this.isHidden));
        localContentValues.put("account", Integer.valueOf(1));
        if (this.id == -1)
          break label245;
        WickrDBAdapter.writableDatabase.update("Wickr_User", localContentValues, "_id=" + this.id, null);
      }
      for (bool2 = false; ; bool2 = true)
      {
        if (this.apps == null)
          break label265;
        for (int i = 0; i < this.apps.size(); i++)
          ((WickrApp)this.apps.get(i)).save();
        break;
        localContentValues.put("privacyMan", Integer.valueOf(0));
        break label116;
        label245: this.id = ((int)WickrDBAdapter.writableDatabase.replace("Wickr_User", null, localContentValues));
      }
    }
  }

  public void setIsHidden(boolean paramBoolean)
  {
    if ((!paramBoolean) && (this.userAliasSecure != null))
    {
      this.isHidden = paramBoolean;
      changeMade();
      save();
    }
  }

  public void setIsOnPrivacyList(boolean paramBoolean)
  {
    changeMade();
    this.isOnPrivacyList = paramBoolean;
    save();
  }

  public void setUserImage(Bitmap paramBitmap)
    throws InvalidParameterException
  {
    this.didCheckImage = false;
    if (paramBitmap == null)
    {
      if (this.userImage != null)
      {
        this.userImage.recycle();
        this.userImage = null;
        userImageCache.uncacheElement(this);
      }
      setUserImageSec(null);
      return;
    }
    WickrStatus localWickrStatus = new WickrStatus(0);
    ByteArrayOutputStream localByteArrayOutputStream = new ByteArrayOutputStream();
    if (!paramBitmap.compress(Bitmap.CompressFormat.JPEG, 50, localByteArrayOutputStream))
      throw new InvalidParameterException("The image selected is not in a valid format");
    byte[] arrayOfByte = activeSessionEncodeUserImage(localByteArrayOutputStream.toByteArray(), localWickrStatus);
    if (localWickrStatus.isError())
      throw new InvalidParameterException("The image selected is not in a valid format");
    this.userImage = paramBitmap;
    addUserImageToImageCache(this);
    setUserImageSec(arrayOfByte);
  }

  public void setUserName(String paramString)
    throws InvalidParameterException
  {
    if (paramString == null)
    {
      this.userNameSecure = null;
      this.userName = null;
      changeMade();
      save();
      return;
    }
    WickrStatus localWickrStatus = new WickrStatus(0);
    byte[] arrayOfByte = activeSessionEncodeUserName(paramString, localWickrStatus);
    if (localWickrStatus.isError())
      throw new InvalidParameterException("The name you entered is not valid");
    this.userNameSecure = arrayOfByte;
    this.userName = paramString;
    changeMade();
    save();
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.mywickr.wickr.WickrUser
 * JD-Core Version:    0.6.2
 */