package com.neovisionaries.i18n;

import java.util.Currency;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

public enum CountryCode
{
  private static final Map<String, CountryCode> alpha3Map;
  private static final Map<Integer, CountryCode> numericMap;
  private final String alpha3;
  private final Assignment assignment;
  private final String name;
  private final int numeric;

  static
  {
    // Byte code:
    //   0: iconst_0
    //   1: istore_0
    //   2: new 2	com/neovisionaries/i18n/CountryCode
    //   5: dup
    //   6: ldc_w 280
    //   9: iconst_0
    //   10: ldc_w 282
    //   13: ldc_w 284
    //   16: bipush 20
    //   18: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   21: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   24: putstatic 295	com/neovisionaries/i18n/CountryCode:AD	Lcom/neovisionaries/i18n/CountryCode;
    //   27: new 2	com/neovisionaries/i18n/CountryCode
    //   30: dup
    //   31: ldc_w 296
    //   34: iconst_1
    //   35: ldc_w 298
    //   38: ldc_w 300
    //   41: sipush 784
    //   44: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   47: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   50: putstatic 302	com/neovisionaries/i18n/CountryCode:AE	Lcom/neovisionaries/i18n/CountryCode;
    //   53: new 2	com/neovisionaries/i18n/CountryCode
    //   56: dup
    //   57: ldc_w 303
    //   60: iconst_2
    //   61: ldc_w 305
    //   64: ldc_w 307
    //   67: iconst_4
    //   68: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   71: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   74: putstatic 309	com/neovisionaries/i18n/CountryCode:AF	Lcom/neovisionaries/i18n/CountryCode;
    //   77: new 2	com/neovisionaries/i18n/CountryCode
    //   80: dup
    //   81: ldc_w 310
    //   84: iconst_3
    //   85: ldc_w 312
    //   88: ldc_w 314
    //   91: bipush 28
    //   93: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   96: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   99: putstatic 316	com/neovisionaries/i18n/CountryCode:AG	Lcom/neovisionaries/i18n/CountryCode;
    //   102: new 2	com/neovisionaries/i18n/CountryCode
    //   105: dup
    //   106: ldc_w 317
    //   109: iconst_4
    //   110: ldc_w 319
    //   113: ldc_w 321
    //   116: sipush 660
    //   119: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   122: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   125: putstatic 323	com/neovisionaries/i18n/CountryCode:AI	Lcom/neovisionaries/i18n/CountryCode;
    //   128: new 2	com/neovisionaries/i18n/CountryCode
    //   131: dup
    //   132: ldc_w 324
    //   135: iconst_5
    //   136: ldc_w 326
    //   139: ldc_w 328
    //   142: bipush 8
    //   144: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   147: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   150: putstatic 330	com/neovisionaries/i18n/CountryCode:AL	Lcom/neovisionaries/i18n/CountryCode;
    //   153: new 2	com/neovisionaries/i18n/CountryCode
    //   156: dup
    //   157: ldc_w 331
    //   160: bipush 6
    //   162: ldc_w 333
    //   165: ldc_w 335
    //   168: bipush 51
    //   170: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   173: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   176: putstatic 337	com/neovisionaries/i18n/CountryCode:AM	Lcom/neovisionaries/i18n/CountryCode;
    //   179: new 2	com/neovisionaries/i18n/CountryCode
    //   182: dup
    //   183: ldc_w 338
    //   186: bipush 7
    //   188: ldc_w 340
    //   191: ldc_w 342
    //   194: sipush 530
    //   197: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   200: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   203: putstatic 347	com/neovisionaries/i18n/CountryCode:AN	Lcom/neovisionaries/i18n/CountryCode;
    //   206: new 2	com/neovisionaries/i18n/CountryCode
    //   209: dup
    //   210: ldc_w 348
    //   213: bipush 8
    //   215: ldc_w 350
    //   218: ldc_w 352
    //   221: bipush 24
    //   223: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   226: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   229: putstatic 354	com/neovisionaries/i18n/CountryCode:AO	Lcom/neovisionaries/i18n/CountryCode;
    //   232: new 2	com/neovisionaries/i18n/CountryCode
    //   235: dup
    //   236: ldc_w 355
    //   239: bipush 9
    //   241: ldc_w 357
    //   244: ldc_w 359
    //   247: bipush 10
    //   249: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   252: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   255: putstatic 361	com/neovisionaries/i18n/CountryCode:AQ	Lcom/neovisionaries/i18n/CountryCode;
    //   258: new 2	com/neovisionaries/i18n/CountryCode
    //   261: dup
    //   262: ldc_w 362
    //   265: bipush 10
    //   267: ldc_w 364
    //   270: ldc_w 366
    //   273: bipush 32
    //   275: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   278: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   281: putstatic 368	com/neovisionaries/i18n/CountryCode:AR	Lcom/neovisionaries/i18n/CountryCode;
    //   284: new 2	com/neovisionaries/i18n/CountryCode
    //   287: dup
    //   288: ldc_w 369
    //   291: bipush 11
    //   293: ldc_w 371
    //   296: ldc_w 373
    //   299: bipush 16
    //   301: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   304: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   307: putstatic 375	com/neovisionaries/i18n/CountryCode:AS	Lcom/neovisionaries/i18n/CountryCode;
    //   310: new 2	com/neovisionaries/i18n/CountryCode
    //   313: dup
    //   314: ldc_w 376
    //   317: bipush 12
    //   319: ldc_w 378
    //   322: ldc_w 380
    //   325: bipush 40
    //   327: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   330: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   333: putstatic 382	com/neovisionaries/i18n/CountryCode:AT	Lcom/neovisionaries/i18n/CountryCode;
    //   336: new 2	com/neovisionaries/i18n/CountryCode
    //   339: dup
    //   340: ldc_w 383
    //   343: bipush 13
    //   345: ldc_w 385
    //   348: ldc_w 387
    //   351: bipush 36
    //   353: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   356: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   359: putstatic 389	com/neovisionaries/i18n/CountryCode:AU	Lcom/neovisionaries/i18n/CountryCode;
    //   362: new 2	com/neovisionaries/i18n/CountryCode
    //   365: dup
    //   366: ldc_w 390
    //   369: bipush 14
    //   371: ldc_w 392
    //   374: ldc_w 394
    //   377: sipush 533
    //   380: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   383: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   386: putstatic 396	com/neovisionaries/i18n/CountryCode:AW	Lcom/neovisionaries/i18n/CountryCode;
    //   389: new 2	com/neovisionaries/i18n/CountryCode
    //   392: dup
    //   393: ldc_w 397
    //   396: bipush 15
    //   398: ldc_w 399
    //   401: ldc_w 401
    //   404: sipush 248
    //   407: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   410: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   413: putstatic 403	com/neovisionaries/i18n/CountryCode:AX	Lcom/neovisionaries/i18n/CountryCode;
    //   416: new 2	com/neovisionaries/i18n/CountryCode
    //   419: dup
    //   420: ldc_w 404
    //   423: bipush 16
    //   425: ldc_w 406
    //   428: ldc_w 408
    //   431: bipush 31
    //   433: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   436: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   439: putstatic 410	com/neovisionaries/i18n/CountryCode:AZ	Lcom/neovisionaries/i18n/CountryCode;
    //   442: new 2	com/neovisionaries/i18n/CountryCode
    //   445: dup
    //   446: ldc_w 411
    //   449: bipush 17
    //   451: ldc_w 413
    //   454: ldc_w 415
    //   457: bipush 70
    //   459: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   462: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   465: putstatic 417	com/neovisionaries/i18n/CountryCode:BA	Lcom/neovisionaries/i18n/CountryCode;
    //   468: new 2	com/neovisionaries/i18n/CountryCode
    //   471: dup
    //   472: ldc_w 418
    //   475: bipush 18
    //   477: ldc_w 420
    //   480: ldc_w 422
    //   483: bipush 52
    //   485: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   488: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   491: putstatic 424	com/neovisionaries/i18n/CountryCode:BB	Lcom/neovisionaries/i18n/CountryCode;
    //   494: new 2	com/neovisionaries/i18n/CountryCode
    //   497: dup
    //   498: ldc_w 425
    //   501: bipush 19
    //   503: ldc_w 427
    //   506: ldc_w 429
    //   509: bipush 50
    //   511: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   514: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   517: putstatic 431	com/neovisionaries/i18n/CountryCode:BD	Lcom/neovisionaries/i18n/CountryCode;
    //   520: new 2	com/neovisionaries/i18n/CountryCode
    //   523: dup
    //   524: ldc_w 432
    //   527: bipush 20
    //   529: ldc_w 434
    //   532: ldc_w 436
    //   535: bipush 56
    //   537: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   540: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   543: putstatic 438	com/neovisionaries/i18n/CountryCode:BE	Lcom/neovisionaries/i18n/CountryCode;
    //   546: new 2	com/neovisionaries/i18n/CountryCode
    //   549: dup
    //   550: ldc_w 439
    //   553: bipush 21
    //   555: ldc_w 441
    //   558: ldc_w 443
    //   561: sipush 854
    //   564: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   567: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   570: putstatic 445	com/neovisionaries/i18n/CountryCode:BF	Lcom/neovisionaries/i18n/CountryCode;
    //   573: new 2	com/neovisionaries/i18n/CountryCode
    //   576: dup
    //   577: ldc_w 446
    //   580: bipush 22
    //   582: ldc_w 448
    //   585: ldc_w 450
    //   588: bipush 100
    //   590: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   593: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   596: putstatic 452	com/neovisionaries/i18n/CountryCode:BG	Lcom/neovisionaries/i18n/CountryCode;
    //   599: new 2	com/neovisionaries/i18n/CountryCode
    //   602: dup
    //   603: ldc_w 453
    //   606: bipush 23
    //   608: ldc_w 455
    //   611: ldc_w 457
    //   614: bipush 48
    //   616: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   619: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   622: putstatic 459	com/neovisionaries/i18n/CountryCode:BH	Lcom/neovisionaries/i18n/CountryCode;
    //   625: new 2	com/neovisionaries/i18n/CountryCode
    //   628: dup
    //   629: ldc_w 460
    //   632: bipush 24
    //   634: ldc_w 462
    //   637: ldc_w 464
    //   640: bipush 108
    //   642: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   645: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   648: putstatic 466	com/neovisionaries/i18n/CountryCode:BI	Lcom/neovisionaries/i18n/CountryCode;
    //   651: new 2	com/neovisionaries/i18n/CountryCode
    //   654: dup
    //   655: ldc_w 467
    //   658: bipush 25
    //   660: ldc_w 469
    //   663: ldc_w 471
    //   666: sipush 204
    //   669: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   672: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   675: putstatic 473	com/neovisionaries/i18n/CountryCode:BJ	Lcom/neovisionaries/i18n/CountryCode;
    //   678: new 2	com/neovisionaries/i18n/CountryCode
    //   681: dup
    //   682: ldc_w 474
    //   685: bipush 26
    //   687: ldc_w 476
    //   690: ldc_w 478
    //   693: sipush 652
    //   696: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   699: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   702: putstatic 480	com/neovisionaries/i18n/CountryCode:BL	Lcom/neovisionaries/i18n/CountryCode;
    //   705: new 2	com/neovisionaries/i18n/CountryCode
    //   708: dup
    //   709: ldc_w 481
    //   712: bipush 27
    //   714: ldc_w 483
    //   717: ldc_w 485
    //   720: bipush 60
    //   722: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   725: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   728: putstatic 487	com/neovisionaries/i18n/CountryCode:BM	Lcom/neovisionaries/i18n/CountryCode;
    //   731: new 2	com/neovisionaries/i18n/CountryCode
    //   734: dup
    //   735: ldc_w 488
    //   738: bipush 28
    //   740: ldc_w 490
    //   743: ldc_w 492
    //   746: bipush 96
    //   748: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   751: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   754: putstatic 494	com/neovisionaries/i18n/CountryCode:BN	Lcom/neovisionaries/i18n/CountryCode;
    //   757: new 2	com/neovisionaries/i18n/CountryCode
    //   760: dup
    //   761: ldc_w 495
    //   764: bipush 29
    //   766: ldc_w 497
    //   769: ldc_w 499
    //   772: bipush 68
    //   774: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   777: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   780: putstatic 501	com/neovisionaries/i18n/CountryCode:BO	Lcom/neovisionaries/i18n/CountryCode;
    //   783: new 2	com/neovisionaries/i18n/CountryCode
    //   786: dup
    //   787: ldc_w 502
    //   790: bipush 30
    //   792: ldc_w 504
    //   795: ldc_w 506
    //   798: sipush 535
    //   801: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   804: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   807: putstatic 508	com/neovisionaries/i18n/CountryCode:BQ	Lcom/neovisionaries/i18n/CountryCode;
    //   810: new 2	com/neovisionaries/i18n/CountryCode
    //   813: dup
    //   814: ldc_w 509
    //   817: bipush 31
    //   819: ldc_w 511
    //   822: ldc_w 513
    //   825: bipush 76
    //   827: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   830: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   833: putstatic 515	com/neovisionaries/i18n/CountryCode:BR	Lcom/neovisionaries/i18n/CountryCode;
    //   836: new 2	com/neovisionaries/i18n/CountryCode
    //   839: dup
    //   840: ldc_w 516
    //   843: bipush 32
    //   845: ldc_w 518
    //   848: ldc_w 520
    //   851: bipush 44
    //   853: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   856: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   859: putstatic 522	com/neovisionaries/i18n/CountryCode:BS	Lcom/neovisionaries/i18n/CountryCode;
    //   862: new 2	com/neovisionaries/i18n/CountryCode
    //   865: dup
    //   866: ldc_w 523
    //   869: bipush 33
    //   871: ldc_w 525
    //   874: ldc_w 527
    //   877: bipush 64
    //   879: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   882: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   885: putstatic 529	com/neovisionaries/i18n/CountryCode:BT	Lcom/neovisionaries/i18n/CountryCode;
    //   888: new 2	com/neovisionaries/i18n/CountryCode
    //   891: dup
    //   892: ldc_w 530
    //   895: bipush 34
    //   897: ldc_w 532
    //   900: ldc_w 534
    //   903: bipush 104
    //   905: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   908: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   911: putstatic 536	com/neovisionaries/i18n/CountryCode:BU	Lcom/neovisionaries/i18n/CountryCode;
    //   914: new 2	com/neovisionaries/i18n/CountryCode
    //   917: dup
    //   918: ldc_w 537
    //   921: bipush 35
    //   923: ldc_w 539
    //   926: ldc_w 541
    //   929: bipush 74
    //   931: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   934: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   937: putstatic 543	com/neovisionaries/i18n/CountryCode:BV	Lcom/neovisionaries/i18n/CountryCode;
    //   940: new 2	com/neovisionaries/i18n/CountryCode
    //   943: dup
    //   944: ldc_w 544
    //   947: bipush 36
    //   949: ldc_w 546
    //   952: ldc_w 548
    //   955: bipush 72
    //   957: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   960: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   963: putstatic 550	com/neovisionaries/i18n/CountryCode:BW	Lcom/neovisionaries/i18n/CountryCode;
    //   966: new 2	com/neovisionaries/i18n/CountryCode
    //   969: dup
    //   970: ldc_w 551
    //   973: bipush 37
    //   975: ldc_w 553
    //   978: ldc_w 555
    //   981: bipush 112
    //   983: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   986: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   989: putstatic 557	com/neovisionaries/i18n/CountryCode:BY	Lcom/neovisionaries/i18n/CountryCode;
    //   992: new 2	com/neovisionaries/i18n/CountryCode
    //   995: dup
    //   996: ldc_w 558
    //   999: bipush 38
    //   1001: ldc_w 560
    //   1004: ldc_w 562
    //   1007: bipush 84
    //   1009: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1012: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1015: putstatic 564	com/neovisionaries/i18n/CountryCode:BZ	Lcom/neovisionaries/i18n/CountryCode;
    //   1018: new 566	com/neovisionaries/i18n/CountryCode$1
    //   1021: dup
    //   1022: ldc_w 567
    //   1025: bipush 39
    //   1027: ldc_w 569
    //   1030: ldc_w 571
    //   1033: bipush 124
    //   1035: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1038: invokespecial 572	com/neovisionaries/i18n/CountryCode$1:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1041: putstatic 574	com/neovisionaries/i18n/CountryCode:CA	Lcom/neovisionaries/i18n/CountryCode;
    //   1044: new 2	com/neovisionaries/i18n/CountryCode
    //   1047: dup
    //   1048: ldc_w 575
    //   1051: bipush 40
    //   1053: ldc_w 577
    //   1056: ldc_w 579
    //   1059: sipush 166
    //   1062: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1065: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1068: putstatic 581	com/neovisionaries/i18n/CountryCode:CC	Lcom/neovisionaries/i18n/CountryCode;
    //   1071: new 2	com/neovisionaries/i18n/CountryCode
    //   1074: dup
    //   1075: ldc_w 582
    //   1078: bipush 41
    //   1080: ldc_w 584
    //   1083: ldc_w 586
    //   1086: sipush 180
    //   1089: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1092: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1095: putstatic 588	com/neovisionaries/i18n/CountryCode:CD	Lcom/neovisionaries/i18n/CountryCode;
    //   1098: new 2	com/neovisionaries/i18n/CountryCode
    //   1101: dup
    //   1102: ldc_w 589
    //   1105: bipush 42
    //   1107: ldc_w 591
    //   1110: ldc_w 593
    //   1113: sipush 140
    //   1116: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1119: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1122: putstatic 595	com/neovisionaries/i18n/CountryCode:CF	Lcom/neovisionaries/i18n/CountryCode;
    //   1125: new 2	com/neovisionaries/i18n/CountryCode
    //   1128: dup
    //   1129: ldc_w 596
    //   1132: bipush 43
    //   1134: ldc_w 598
    //   1137: ldc_w 600
    //   1140: sipush 178
    //   1143: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1146: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1149: putstatic 602	com/neovisionaries/i18n/CountryCode:CG	Lcom/neovisionaries/i18n/CountryCode;
    //   1152: new 2	com/neovisionaries/i18n/CountryCode
    //   1155: dup
    //   1156: ldc_w 603
    //   1159: bipush 44
    //   1161: ldc_w 605
    //   1164: ldc_w 607
    //   1167: sipush 756
    //   1170: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1173: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1176: putstatic 609	com/neovisionaries/i18n/CountryCode:CH	Lcom/neovisionaries/i18n/CountryCode;
    //   1179: new 2	com/neovisionaries/i18n/CountryCode
    //   1182: dup
    //   1183: ldc_w 610
    //   1186: bipush 45
    //   1188: ldc_w 612
    //   1191: ldc_w 614
    //   1194: sipush 384
    //   1197: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1200: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1203: putstatic 616	com/neovisionaries/i18n/CountryCode:CI	Lcom/neovisionaries/i18n/CountryCode;
    //   1206: new 2	com/neovisionaries/i18n/CountryCode
    //   1209: dup
    //   1210: ldc_w 617
    //   1213: bipush 46
    //   1215: ldc_w 619
    //   1218: ldc_w 621
    //   1221: sipush 184
    //   1224: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1227: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1230: putstatic 623	com/neovisionaries/i18n/CountryCode:CK	Lcom/neovisionaries/i18n/CountryCode;
    //   1233: new 2	com/neovisionaries/i18n/CountryCode
    //   1236: dup
    //   1237: ldc_w 624
    //   1240: bipush 47
    //   1242: ldc_w 626
    //   1245: ldc_w 628
    //   1248: sipush 152
    //   1251: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1254: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1257: putstatic 630	com/neovisionaries/i18n/CountryCode:CL	Lcom/neovisionaries/i18n/CountryCode;
    //   1260: new 2	com/neovisionaries/i18n/CountryCode
    //   1263: dup
    //   1264: ldc_w 631
    //   1267: bipush 48
    //   1269: ldc_w 633
    //   1272: ldc_w 635
    //   1275: bipush 120
    //   1277: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1280: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1283: putstatic 637	com/neovisionaries/i18n/CountryCode:CM	Lcom/neovisionaries/i18n/CountryCode;
    //   1286: new 639	com/neovisionaries/i18n/CountryCode$2
    //   1289: dup
    //   1290: ldc_w 640
    //   1293: bipush 49
    //   1295: ldc_w 642
    //   1298: ldc_w 644
    //   1301: sipush 156
    //   1304: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1307: invokespecial 645	com/neovisionaries/i18n/CountryCode$2:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1310: putstatic 647	com/neovisionaries/i18n/CountryCode:CN	Lcom/neovisionaries/i18n/CountryCode;
    //   1313: new 2	com/neovisionaries/i18n/CountryCode
    //   1316: dup
    //   1317: ldc_w 648
    //   1320: bipush 50
    //   1322: ldc_w 650
    //   1325: ldc_w 652
    //   1328: sipush 170
    //   1331: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1334: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1337: putstatic 654	com/neovisionaries/i18n/CountryCode:CO	Lcom/neovisionaries/i18n/CountryCode;
    //   1340: new 2	com/neovisionaries/i18n/CountryCode
    //   1343: dup
    //   1344: ldc_w 655
    //   1347: bipush 51
    //   1349: ldc_w 657
    //   1352: ldc_w 659
    //   1355: sipush 188
    //   1358: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1361: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1364: putstatic 661	com/neovisionaries/i18n/CountryCode:CR	Lcom/neovisionaries/i18n/CountryCode;
    //   1367: new 2	com/neovisionaries/i18n/CountryCode
    //   1370: dup
    //   1371: ldc_w 662
    //   1374: bipush 52
    //   1376: ldc_w 664
    //   1379: ldc_w 666
    //   1382: sipush 891
    //   1385: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1388: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1391: putstatic 668	com/neovisionaries/i18n/CountryCode:CS	Lcom/neovisionaries/i18n/CountryCode;
    //   1394: new 2	com/neovisionaries/i18n/CountryCode
    //   1397: dup
    //   1398: ldc_w 669
    //   1401: bipush 53
    //   1403: ldc_w 671
    //   1406: ldc_w 673
    //   1409: sipush 192
    //   1412: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1415: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1418: putstatic 675	com/neovisionaries/i18n/CountryCode:CU	Lcom/neovisionaries/i18n/CountryCode;
    //   1421: new 2	com/neovisionaries/i18n/CountryCode
    //   1424: dup
    //   1425: ldc_w 676
    //   1428: bipush 54
    //   1430: ldc_w 678
    //   1433: ldc_w 680
    //   1436: sipush 132
    //   1439: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1442: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1445: putstatic 682	com/neovisionaries/i18n/CountryCode:CV	Lcom/neovisionaries/i18n/CountryCode;
    //   1448: new 2	com/neovisionaries/i18n/CountryCode
    //   1451: dup
    //   1452: ldc_w 683
    //   1455: bipush 55
    //   1457: ldc_w 685
    //   1460: ldc_w 687
    //   1463: sipush 531
    //   1466: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1469: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1472: putstatic 689	com/neovisionaries/i18n/CountryCode:CW	Lcom/neovisionaries/i18n/CountryCode;
    //   1475: new 2	com/neovisionaries/i18n/CountryCode
    //   1478: dup
    //   1479: ldc_w 690
    //   1482: bipush 56
    //   1484: ldc_w 692
    //   1487: ldc_w 694
    //   1490: sipush 162
    //   1493: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1496: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1499: putstatic 696	com/neovisionaries/i18n/CountryCode:CX	Lcom/neovisionaries/i18n/CountryCode;
    //   1502: new 2	com/neovisionaries/i18n/CountryCode
    //   1505: dup
    //   1506: ldc_w 697
    //   1509: bipush 57
    //   1511: ldc_w 699
    //   1514: ldc_w 701
    //   1517: sipush 196
    //   1520: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1523: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1526: putstatic 703	com/neovisionaries/i18n/CountryCode:CY	Lcom/neovisionaries/i18n/CountryCode;
    //   1529: new 2	com/neovisionaries/i18n/CountryCode
    //   1532: dup
    //   1533: ldc_w 704
    //   1536: bipush 58
    //   1538: ldc_w 706
    //   1541: ldc_w 708
    //   1544: sipush 203
    //   1547: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1550: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1553: putstatic 710	com/neovisionaries/i18n/CountryCode:CZ	Lcom/neovisionaries/i18n/CountryCode;
    //   1556: new 712	com/neovisionaries/i18n/CountryCode$3
    //   1559: dup
    //   1560: ldc_w 713
    //   1563: bipush 59
    //   1565: ldc_w 715
    //   1568: ldc_w 717
    //   1571: sipush 276
    //   1574: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1577: invokespecial 718	com/neovisionaries/i18n/CountryCode$3:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1580: putstatic 720	com/neovisionaries/i18n/CountryCode:DE	Lcom/neovisionaries/i18n/CountryCode;
    //   1583: new 2	com/neovisionaries/i18n/CountryCode
    //   1586: dup
    //   1587: ldc_w 721
    //   1590: bipush 60
    //   1592: ldc_w 723
    //   1595: ldc_w 725
    //   1598: sipush 262
    //   1601: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1604: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1607: putstatic 727	com/neovisionaries/i18n/CountryCode:DJ	Lcom/neovisionaries/i18n/CountryCode;
    //   1610: new 2	com/neovisionaries/i18n/CountryCode
    //   1613: dup
    //   1614: ldc_w 728
    //   1617: bipush 61
    //   1619: ldc_w 730
    //   1622: ldc_w 732
    //   1625: sipush 208
    //   1628: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1631: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1634: putstatic 734	com/neovisionaries/i18n/CountryCode:DK	Lcom/neovisionaries/i18n/CountryCode;
    //   1637: new 2	com/neovisionaries/i18n/CountryCode
    //   1640: dup
    //   1641: ldc_w 735
    //   1644: bipush 62
    //   1646: ldc_w 737
    //   1649: ldc_w 739
    //   1652: sipush 212
    //   1655: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1658: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1661: putstatic 741	com/neovisionaries/i18n/CountryCode:DM	Lcom/neovisionaries/i18n/CountryCode;
    //   1664: new 2	com/neovisionaries/i18n/CountryCode
    //   1667: dup
    //   1668: ldc_w 742
    //   1671: bipush 63
    //   1673: ldc_w 744
    //   1676: ldc_w 746
    //   1679: sipush 214
    //   1682: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1685: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1688: putstatic 748	com/neovisionaries/i18n/CountryCode:DO	Lcom/neovisionaries/i18n/CountryCode;
    //   1691: new 2	com/neovisionaries/i18n/CountryCode
    //   1694: dup
    //   1695: ldc_w 749
    //   1698: bipush 64
    //   1700: ldc_w 751
    //   1703: ldc_w 753
    //   1706: bipush 12
    //   1708: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1711: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1714: putstatic 755	com/neovisionaries/i18n/CountryCode:DZ	Lcom/neovisionaries/i18n/CountryCode;
    //   1717: new 2	com/neovisionaries/i18n/CountryCode
    //   1720: dup
    //   1721: ldc_w 756
    //   1724: bipush 65
    //   1726: ldc_w 758
    //   1729: ldc_w 760
    //   1732: sipush 218
    //   1735: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1738: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1741: putstatic 762	com/neovisionaries/i18n/CountryCode:EC	Lcom/neovisionaries/i18n/CountryCode;
    //   1744: new 2	com/neovisionaries/i18n/CountryCode
    //   1747: dup
    //   1748: ldc_w 763
    //   1751: bipush 66
    //   1753: ldc_w 765
    //   1756: ldc_w 767
    //   1759: sipush 233
    //   1762: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1765: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1768: putstatic 769	com/neovisionaries/i18n/CountryCode:EE	Lcom/neovisionaries/i18n/CountryCode;
    //   1771: new 2	com/neovisionaries/i18n/CountryCode
    //   1774: dup
    //   1775: ldc_w 770
    //   1778: bipush 67
    //   1780: ldc_w 772
    //   1783: ldc_w 774
    //   1786: sipush 818
    //   1789: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1792: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1795: putstatic 776	com/neovisionaries/i18n/CountryCode:EG	Lcom/neovisionaries/i18n/CountryCode;
    //   1798: new 2	com/neovisionaries/i18n/CountryCode
    //   1801: dup
    //   1802: ldc_w 777
    //   1805: bipush 68
    //   1807: ldc_w 779
    //   1810: ldc_w 781
    //   1813: sipush 732
    //   1816: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1819: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1822: putstatic 783	com/neovisionaries/i18n/CountryCode:EH	Lcom/neovisionaries/i18n/CountryCode;
    //   1825: new 2	com/neovisionaries/i18n/CountryCode
    //   1828: dup
    //   1829: ldc_w 784
    //   1832: bipush 69
    //   1834: ldc_w 786
    //   1837: ldc_w 788
    //   1840: sipush 232
    //   1843: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1846: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1849: putstatic 790	com/neovisionaries/i18n/CountryCode:ER	Lcom/neovisionaries/i18n/CountryCode;
    //   1852: new 2	com/neovisionaries/i18n/CountryCode
    //   1855: dup
    //   1856: ldc_w 791
    //   1859: bipush 70
    //   1861: ldc_w 793
    //   1864: ldc_w 795
    //   1867: sipush 724
    //   1870: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1873: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1876: putstatic 797	com/neovisionaries/i18n/CountryCode:ES	Lcom/neovisionaries/i18n/CountryCode;
    //   1879: new 2	com/neovisionaries/i18n/CountryCode
    //   1882: dup
    //   1883: ldc_w 798
    //   1886: bipush 71
    //   1888: ldc_w 800
    //   1891: ldc_w 802
    //   1894: sipush 231
    //   1897: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1900: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1903: putstatic 804	com/neovisionaries/i18n/CountryCode:ET	Lcom/neovisionaries/i18n/CountryCode;
    //   1906: new 2	com/neovisionaries/i18n/CountryCode
    //   1909: dup
    //   1910: ldc_w 805
    //   1913: bipush 72
    //   1915: ldc_w 807
    //   1918: ldc_w 809
    //   1921: sipush 246
    //   1924: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1927: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1930: putstatic 811	com/neovisionaries/i18n/CountryCode:FI	Lcom/neovisionaries/i18n/CountryCode;
    //   1933: new 2	com/neovisionaries/i18n/CountryCode
    //   1936: dup
    //   1937: ldc_w 812
    //   1940: bipush 73
    //   1942: ldc_w 814
    //   1945: ldc_w 816
    //   1948: sipush 242
    //   1951: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1954: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1957: putstatic 818	com/neovisionaries/i18n/CountryCode:FJ	Lcom/neovisionaries/i18n/CountryCode;
    //   1960: new 2	com/neovisionaries/i18n/CountryCode
    //   1963: dup
    //   1964: ldc_w 819
    //   1967: bipush 74
    //   1969: ldc_w 821
    //   1972: ldc_w 823
    //   1975: sipush 238
    //   1978: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   1981: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   1984: putstatic 825	com/neovisionaries/i18n/CountryCode:FK	Lcom/neovisionaries/i18n/CountryCode;
    //   1987: new 2	com/neovisionaries/i18n/CountryCode
    //   1990: dup
    //   1991: ldc_w 826
    //   1994: bipush 75
    //   1996: ldc_w 828
    //   1999: ldc_w 830
    //   2002: sipush 583
    //   2005: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2008: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2011: putstatic 832	com/neovisionaries/i18n/CountryCode:FM	Lcom/neovisionaries/i18n/CountryCode;
    //   2014: new 2	com/neovisionaries/i18n/CountryCode
    //   2017: dup
    //   2018: ldc_w 833
    //   2021: bipush 76
    //   2023: ldc_w 835
    //   2026: ldc_w 837
    //   2029: sipush 234
    //   2032: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2035: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2038: putstatic 839	com/neovisionaries/i18n/CountryCode:FO	Lcom/neovisionaries/i18n/CountryCode;
    //   2041: new 841	com/neovisionaries/i18n/CountryCode$4
    //   2044: dup
    //   2045: ldc_w 842
    //   2048: bipush 77
    //   2050: ldc_w 844
    //   2053: ldc_w 846
    //   2056: sipush 250
    //   2059: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2062: invokespecial 847	com/neovisionaries/i18n/CountryCode$4:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2065: putstatic 849	com/neovisionaries/i18n/CountryCode:FR	Lcom/neovisionaries/i18n/CountryCode;
    //   2068: new 2	com/neovisionaries/i18n/CountryCode
    //   2071: dup
    //   2072: ldc_w 850
    //   2075: bipush 78
    //   2077: ldc_w 852
    //   2080: ldc_w 854
    //   2083: sipush 266
    //   2086: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2089: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2092: putstatic 856	com/neovisionaries/i18n/CountryCode:GA	Lcom/neovisionaries/i18n/CountryCode;
    //   2095: new 858	com/neovisionaries/i18n/CountryCode$5
    //   2098: dup
    //   2099: ldc_w 859
    //   2102: bipush 79
    //   2104: ldc_w 861
    //   2107: ldc_w 863
    //   2110: sipush 826
    //   2113: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2116: invokespecial 864	com/neovisionaries/i18n/CountryCode$5:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2119: putstatic 866	com/neovisionaries/i18n/CountryCode:GB	Lcom/neovisionaries/i18n/CountryCode;
    //   2122: new 2	com/neovisionaries/i18n/CountryCode
    //   2125: dup
    //   2126: ldc_w 867
    //   2129: bipush 80
    //   2131: ldc_w 869
    //   2134: ldc_w 871
    //   2137: sipush 308
    //   2140: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2143: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2146: putstatic 873	com/neovisionaries/i18n/CountryCode:GD	Lcom/neovisionaries/i18n/CountryCode;
    //   2149: new 2	com/neovisionaries/i18n/CountryCode
    //   2152: dup
    //   2153: ldc_w 874
    //   2156: bipush 81
    //   2158: ldc_w 876
    //   2161: ldc_w 878
    //   2164: sipush 268
    //   2167: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2170: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2173: putstatic 880	com/neovisionaries/i18n/CountryCode:GE	Lcom/neovisionaries/i18n/CountryCode;
    //   2176: new 2	com/neovisionaries/i18n/CountryCode
    //   2179: dup
    //   2180: ldc_w 881
    //   2183: bipush 82
    //   2185: ldc_w 883
    //   2188: ldc_w 885
    //   2191: sipush 254
    //   2194: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2197: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2200: putstatic 887	com/neovisionaries/i18n/CountryCode:GF	Lcom/neovisionaries/i18n/CountryCode;
    //   2203: new 2	com/neovisionaries/i18n/CountryCode
    //   2206: dup
    //   2207: ldc_w 888
    //   2210: bipush 83
    //   2212: ldc_w 890
    //   2215: ldc_w 892
    //   2218: sipush 831
    //   2221: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2224: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2227: putstatic 894	com/neovisionaries/i18n/CountryCode:GG	Lcom/neovisionaries/i18n/CountryCode;
    //   2230: new 2	com/neovisionaries/i18n/CountryCode
    //   2233: dup
    //   2234: ldc_w 895
    //   2237: bipush 84
    //   2239: ldc_w 897
    //   2242: ldc_w 899
    //   2245: sipush 288
    //   2248: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2251: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2254: putstatic 901	com/neovisionaries/i18n/CountryCode:GH	Lcom/neovisionaries/i18n/CountryCode;
    //   2257: new 2	com/neovisionaries/i18n/CountryCode
    //   2260: dup
    //   2261: ldc_w 902
    //   2264: bipush 85
    //   2266: ldc_w 904
    //   2269: ldc_w 906
    //   2272: sipush 292
    //   2275: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2278: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2281: putstatic 908	com/neovisionaries/i18n/CountryCode:GI	Lcom/neovisionaries/i18n/CountryCode;
    //   2284: new 2	com/neovisionaries/i18n/CountryCode
    //   2287: dup
    //   2288: ldc_w 909
    //   2291: bipush 86
    //   2293: ldc_w 911
    //   2296: ldc_w 913
    //   2299: sipush 304
    //   2302: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2305: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2308: putstatic 915	com/neovisionaries/i18n/CountryCode:GL	Lcom/neovisionaries/i18n/CountryCode;
    //   2311: new 2	com/neovisionaries/i18n/CountryCode
    //   2314: dup
    //   2315: ldc_w 916
    //   2318: bipush 87
    //   2320: ldc_w 918
    //   2323: ldc_w 920
    //   2326: sipush 270
    //   2329: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2332: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2335: putstatic 922	com/neovisionaries/i18n/CountryCode:GM	Lcom/neovisionaries/i18n/CountryCode;
    //   2338: new 2	com/neovisionaries/i18n/CountryCode
    //   2341: dup
    //   2342: ldc_w 923
    //   2345: bipush 88
    //   2347: ldc_w 925
    //   2350: ldc_w 927
    //   2353: sipush 324
    //   2356: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2359: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2362: putstatic 929	com/neovisionaries/i18n/CountryCode:GN	Lcom/neovisionaries/i18n/CountryCode;
    //   2365: new 2	com/neovisionaries/i18n/CountryCode
    //   2368: dup
    //   2369: ldc_w 930
    //   2372: bipush 89
    //   2374: ldc_w 932
    //   2377: ldc_w 934
    //   2380: sipush 312
    //   2383: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2386: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2389: putstatic 936	com/neovisionaries/i18n/CountryCode:GP	Lcom/neovisionaries/i18n/CountryCode;
    //   2392: new 2	com/neovisionaries/i18n/CountryCode
    //   2395: dup
    //   2396: ldc_w 937
    //   2399: bipush 90
    //   2401: ldc_w 939
    //   2404: ldc_w 941
    //   2407: sipush 226
    //   2410: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2413: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2416: putstatic 943	com/neovisionaries/i18n/CountryCode:GQ	Lcom/neovisionaries/i18n/CountryCode;
    //   2419: new 2	com/neovisionaries/i18n/CountryCode
    //   2422: dup
    //   2423: ldc_w 944
    //   2426: bipush 91
    //   2428: ldc_w 946
    //   2431: ldc_w 948
    //   2434: sipush 300
    //   2437: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2440: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2443: putstatic 950	com/neovisionaries/i18n/CountryCode:GR	Lcom/neovisionaries/i18n/CountryCode;
    //   2446: new 2	com/neovisionaries/i18n/CountryCode
    //   2449: dup
    //   2450: ldc_w 951
    //   2453: bipush 92
    //   2455: ldc_w 953
    //   2458: ldc_w 955
    //   2461: sipush 239
    //   2464: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2467: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2470: putstatic 957	com/neovisionaries/i18n/CountryCode:GS	Lcom/neovisionaries/i18n/CountryCode;
    //   2473: new 2	com/neovisionaries/i18n/CountryCode
    //   2476: dup
    //   2477: ldc_w 958
    //   2480: bipush 93
    //   2482: ldc_w 960
    //   2485: ldc_w 962
    //   2488: sipush 320
    //   2491: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2494: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2497: putstatic 964	com/neovisionaries/i18n/CountryCode:GT	Lcom/neovisionaries/i18n/CountryCode;
    //   2500: new 2	com/neovisionaries/i18n/CountryCode
    //   2503: dup
    //   2504: ldc_w 965
    //   2507: bipush 94
    //   2509: ldc_w 967
    //   2512: ldc_w 969
    //   2515: sipush 316
    //   2518: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2521: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2524: putstatic 971	com/neovisionaries/i18n/CountryCode:GU	Lcom/neovisionaries/i18n/CountryCode;
    //   2527: new 2	com/neovisionaries/i18n/CountryCode
    //   2530: dup
    //   2531: ldc_w 972
    //   2534: bipush 95
    //   2536: ldc_w 974
    //   2539: ldc_w 976
    //   2542: sipush 624
    //   2545: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2548: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2551: putstatic 978	com/neovisionaries/i18n/CountryCode:GW	Lcom/neovisionaries/i18n/CountryCode;
    //   2554: new 2	com/neovisionaries/i18n/CountryCode
    //   2557: dup
    //   2558: ldc_w 979
    //   2561: bipush 96
    //   2563: ldc_w 981
    //   2566: ldc_w 983
    //   2569: sipush 328
    //   2572: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2575: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2578: putstatic 985	com/neovisionaries/i18n/CountryCode:GY	Lcom/neovisionaries/i18n/CountryCode;
    //   2581: new 2	com/neovisionaries/i18n/CountryCode
    //   2584: dup
    //   2585: ldc_w 986
    //   2588: bipush 97
    //   2590: ldc_w 988
    //   2593: ldc_w 990
    //   2596: sipush 344
    //   2599: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2602: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2605: putstatic 992	com/neovisionaries/i18n/CountryCode:HK	Lcom/neovisionaries/i18n/CountryCode;
    //   2608: new 2	com/neovisionaries/i18n/CountryCode
    //   2611: dup
    //   2612: ldc_w 993
    //   2615: bipush 98
    //   2617: ldc_w 995
    //   2620: ldc_w 997
    //   2623: sipush 334
    //   2626: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2629: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2632: putstatic 999	com/neovisionaries/i18n/CountryCode:HM	Lcom/neovisionaries/i18n/CountryCode;
    //   2635: new 2	com/neovisionaries/i18n/CountryCode
    //   2638: dup
    //   2639: ldc_w 1000
    //   2642: bipush 99
    //   2644: ldc_w 1002
    //   2647: ldc_w 1004
    //   2650: sipush 340
    //   2653: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2656: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2659: putstatic 1006	com/neovisionaries/i18n/CountryCode:HN	Lcom/neovisionaries/i18n/CountryCode;
    //   2662: new 2	com/neovisionaries/i18n/CountryCode
    //   2665: dup
    //   2666: ldc_w 1007
    //   2669: bipush 100
    //   2671: ldc_w 1009
    //   2674: ldc_w 1011
    //   2677: sipush 191
    //   2680: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2683: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2686: putstatic 1013	com/neovisionaries/i18n/CountryCode:HR	Lcom/neovisionaries/i18n/CountryCode;
    //   2689: new 2	com/neovisionaries/i18n/CountryCode
    //   2692: dup
    //   2693: ldc_w 1014
    //   2696: bipush 101
    //   2698: ldc_w 1016
    //   2701: ldc_w 1018
    //   2704: sipush 332
    //   2707: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2710: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2713: putstatic 1020	com/neovisionaries/i18n/CountryCode:HT	Lcom/neovisionaries/i18n/CountryCode;
    //   2716: new 2	com/neovisionaries/i18n/CountryCode
    //   2719: dup
    //   2720: ldc_w 1021
    //   2723: bipush 102
    //   2725: ldc_w 1023
    //   2728: ldc_w 1025
    //   2731: sipush 348
    //   2734: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2737: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2740: putstatic 1027	com/neovisionaries/i18n/CountryCode:HU	Lcom/neovisionaries/i18n/CountryCode;
    //   2743: new 2	com/neovisionaries/i18n/CountryCode
    //   2746: dup
    //   2747: ldc_w 1028
    //   2750: bipush 103
    //   2752: ldc_w 1030
    //   2755: ldc_w 1032
    //   2758: sipush 360
    //   2761: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2764: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2767: putstatic 1034	com/neovisionaries/i18n/CountryCode:ID	Lcom/neovisionaries/i18n/CountryCode;
    //   2770: new 2	com/neovisionaries/i18n/CountryCode
    //   2773: dup
    //   2774: ldc_w 1035
    //   2777: bipush 104
    //   2779: ldc_w 1037
    //   2782: ldc_w 1039
    //   2785: sipush 372
    //   2788: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2791: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2794: putstatic 1041	com/neovisionaries/i18n/CountryCode:IE	Lcom/neovisionaries/i18n/CountryCode;
    //   2797: new 2	com/neovisionaries/i18n/CountryCode
    //   2800: dup
    //   2801: ldc_w 1042
    //   2804: bipush 105
    //   2806: ldc_w 1044
    //   2809: ldc_w 1046
    //   2812: sipush 376
    //   2815: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2818: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2821: putstatic 1048	com/neovisionaries/i18n/CountryCode:IL	Lcom/neovisionaries/i18n/CountryCode;
    //   2824: new 2	com/neovisionaries/i18n/CountryCode
    //   2827: dup
    //   2828: ldc_w 1049
    //   2831: bipush 106
    //   2833: ldc_w 1051
    //   2836: ldc_w 1053
    //   2839: sipush 833
    //   2842: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2845: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2848: putstatic 1055	com/neovisionaries/i18n/CountryCode:IM	Lcom/neovisionaries/i18n/CountryCode;
    //   2851: new 2	com/neovisionaries/i18n/CountryCode
    //   2854: dup
    //   2855: ldc_w 1056
    //   2858: bipush 107
    //   2860: ldc_w 1058
    //   2863: ldc_w 1060
    //   2866: sipush 356
    //   2869: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2872: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2875: putstatic 1062	com/neovisionaries/i18n/CountryCode:IN	Lcom/neovisionaries/i18n/CountryCode;
    //   2878: new 2	com/neovisionaries/i18n/CountryCode
    //   2881: dup
    //   2882: ldc_w 1063
    //   2885: bipush 108
    //   2887: ldc_w 1065
    //   2890: ldc_w 1067
    //   2893: bipush 86
    //   2895: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2898: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2901: putstatic 1069	com/neovisionaries/i18n/CountryCode:IO	Lcom/neovisionaries/i18n/CountryCode;
    //   2904: new 2	com/neovisionaries/i18n/CountryCode
    //   2907: dup
    //   2908: ldc_w 1070
    //   2911: bipush 109
    //   2913: ldc_w 1072
    //   2916: ldc_w 1074
    //   2919: sipush 368
    //   2922: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2925: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2928: putstatic 1076	com/neovisionaries/i18n/CountryCode:IQ	Lcom/neovisionaries/i18n/CountryCode;
    //   2931: new 2	com/neovisionaries/i18n/CountryCode
    //   2934: dup
    //   2935: ldc_w 1077
    //   2938: bipush 110
    //   2940: ldc_w 1079
    //   2943: ldc_w 1081
    //   2946: sipush 364
    //   2949: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2952: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2955: putstatic 1083	com/neovisionaries/i18n/CountryCode:IR	Lcom/neovisionaries/i18n/CountryCode;
    //   2958: new 2	com/neovisionaries/i18n/CountryCode
    //   2961: dup
    //   2962: ldc_w 1084
    //   2965: bipush 111
    //   2967: ldc_w 1086
    //   2970: ldc_w 1088
    //   2973: sipush 352
    //   2976: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   2979: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   2982: putstatic 1090	com/neovisionaries/i18n/CountryCode:IS	Lcom/neovisionaries/i18n/CountryCode;
    //   2985: new 1092	com/neovisionaries/i18n/CountryCode$6
    //   2988: dup
    //   2989: ldc_w 1093
    //   2992: bipush 112
    //   2994: ldc_w 1095
    //   2997: ldc_w 1097
    //   3000: sipush 380
    //   3003: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3006: invokespecial 1098	com/neovisionaries/i18n/CountryCode$6:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3009: putstatic 1100	com/neovisionaries/i18n/CountryCode:IT	Lcom/neovisionaries/i18n/CountryCode;
    //   3012: new 2	com/neovisionaries/i18n/CountryCode
    //   3015: dup
    //   3016: ldc_w 1101
    //   3019: bipush 113
    //   3021: ldc_w 1103
    //   3024: ldc_w 1105
    //   3027: sipush 832
    //   3030: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3033: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3036: putstatic 1107	com/neovisionaries/i18n/CountryCode:JE	Lcom/neovisionaries/i18n/CountryCode;
    //   3039: new 2	com/neovisionaries/i18n/CountryCode
    //   3042: dup
    //   3043: ldc_w 1108
    //   3046: bipush 114
    //   3048: ldc_w 1110
    //   3051: ldc_w 1112
    //   3054: sipush 388
    //   3057: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3060: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3063: putstatic 1114	com/neovisionaries/i18n/CountryCode:JM	Lcom/neovisionaries/i18n/CountryCode;
    //   3066: new 2	com/neovisionaries/i18n/CountryCode
    //   3069: dup
    //   3070: ldc_w 1115
    //   3073: bipush 115
    //   3075: ldc_w 1117
    //   3078: ldc_w 1119
    //   3081: sipush 400
    //   3084: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3087: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3090: putstatic 1121	com/neovisionaries/i18n/CountryCode:JO	Lcom/neovisionaries/i18n/CountryCode;
    //   3093: new 1123	com/neovisionaries/i18n/CountryCode$7
    //   3096: dup
    //   3097: ldc_w 1124
    //   3100: bipush 116
    //   3102: ldc_w 1126
    //   3105: ldc_w 1128
    //   3108: sipush 392
    //   3111: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3114: invokespecial 1129	com/neovisionaries/i18n/CountryCode$7:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3117: putstatic 1131	com/neovisionaries/i18n/CountryCode:JP	Lcom/neovisionaries/i18n/CountryCode;
    //   3120: new 2	com/neovisionaries/i18n/CountryCode
    //   3123: dup
    //   3124: ldc_w 1132
    //   3127: bipush 117
    //   3129: ldc_w 1134
    //   3132: ldc_w 1136
    //   3135: sipush 404
    //   3138: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3141: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3144: putstatic 1138	com/neovisionaries/i18n/CountryCode:KE	Lcom/neovisionaries/i18n/CountryCode;
    //   3147: new 2	com/neovisionaries/i18n/CountryCode
    //   3150: dup
    //   3151: ldc_w 1139
    //   3154: bipush 118
    //   3156: ldc_w 1141
    //   3159: ldc_w 1143
    //   3162: sipush 417
    //   3165: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3168: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3171: putstatic 1145	com/neovisionaries/i18n/CountryCode:KG	Lcom/neovisionaries/i18n/CountryCode;
    //   3174: new 2	com/neovisionaries/i18n/CountryCode
    //   3177: dup
    //   3178: ldc_w 1146
    //   3181: bipush 119
    //   3183: ldc_w 1148
    //   3186: ldc_w 1150
    //   3189: bipush 116
    //   3191: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3194: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3197: putstatic 1152	com/neovisionaries/i18n/CountryCode:KH	Lcom/neovisionaries/i18n/CountryCode;
    //   3200: new 2	com/neovisionaries/i18n/CountryCode
    //   3203: dup
    //   3204: ldc_w 1153
    //   3207: bipush 120
    //   3209: ldc_w 1155
    //   3212: ldc_w 1157
    //   3215: sipush 296
    //   3218: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3221: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3224: putstatic 1159	com/neovisionaries/i18n/CountryCode:KI	Lcom/neovisionaries/i18n/CountryCode;
    //   3227: new 2	com/neovisionaries/i18n/CountryCode
    //   3230: dup
    //   3231: ldc_w 1160
    //   3234: bipush 121
    //   3236: ldc_w 1162
    //   3239: ldc_w 1164
    //   3242: sipush 174
    //   3245: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3248: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3251: putstatic 1166	com/neovisionaries/i18n/CountryCode:KM	Lcom/neovisionaries/i18n/CountryCode;
    //   3254: new 2	com/neovisionaries/i18n/CountryCode
    //   3257: dup
    //   3258: ldc_w 1167
    //   3261: bipush 122
    //   3263: ldc_w 1169
    //   3266: ldc_w 1171
    //   3269: sipush 659
    //   3272: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3275: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3278: putstatic 1173	com/neovisionaries/i18n/CountryCode:KN	Lcom/neovisionaries/i18n/CountryCode;
    //   3281: new 2	com/neovisionaries/i18n/CountryCode
    //   3284: dup
    //   3285: ldc_w 1174
    //   3288: bipush 123
    //   3290: ldc_w 1176
    //   3293: ldc_w 1178
    //   3296: sipush 408
    //   3299: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3302: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3305: putstatic 1180	com/neovisionaries/i18n/CountryCode:KP	Lcom/neovisionaries/i18n/CountryCode;
    //   3308: new 1182	com/neovisionaries/i18n/CountryCode$8
    //   3311: dup
    //   3312: ldc_w 1183
    //   3315: bipush 124
    //   3317: ldc_w 1185
    //   3320: ldc_w 1187
    //   3323: sipush 410
    //   3326: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3329: invokespecial 1188	com/neovisionaries/i18n/CountryCode$8:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3332: putstatic 1190	com/neovisionaries/i18n/CountryCode:KR	Lcom/neovisionaries/i18n/CountryCode;
    //   3335: new 2	com/neovisionaries/i18n/CountryCode
    //   3338: dup
    //   3339: ldc_w 1191
    //   3342: bipush 125
    //   3344: ldc_w 1193
    //   3347: ldc_w 1195
    //   3350: sipush 414
    //   3353: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3356: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3359: putstatic 1197	com/neovisionaries/i18n/CountryCode:KW	Lcom/neovisionaries/i18n/CountryCode;
    //   3362: new 2	com/neovisionaries/i18n/CountryCode
    //   3365: dup
    //   3366: ldc_w 1198
    //   3369: bipush 126
    //   3371: ldc_w 1200
    //   3374: ldc_w 1202
    //   3377: sipush 136
    //   3380: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3383: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3386: putstatic 1204	com/neovisionaries/i18n/CountryCode:KY	Lcom/neovisionaries/i18n/CountryCode;
    //   3389: new 2	com/neovisionaries/i18n/CountryCode
    //   3392: dup
    //   3393: ldc_w 1205
    //   3396: bipush 127
    //   3398: ldc_w 1207
    //   3401: ldc_w 1209
    //   3404: sipush 398
    //   3407: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3410: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3413: putstatic 1211	com/neovisionaries/i18n/CountryCode:KZ	Lcom/neovisionaries/i18n/CountryCode;
    //   3416: new 2	com/neovisionaries/i18n/CountryCode
    //   3419: dup
    //   3420: ldc_w 1212
    //   3423: sipush 128
    //   3426: ldc_w 1214
    //   3429: ldc_w 1216
    //   3432: sipush 418
    //   3435: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3438: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3441: putstatic 1218	com/neovisionaries/i18n/CountryCode:LA	Lcom/neovisionaries/i18n/CountryCode;
    //   3444: new 2	com/neovisionaries/i18n/CountryCode
    //   3447: dup
    //   3448: ldc_w 1219
    //   3451: sipush 129
    //   3454: ldc_w 1221
    //   3457: ldc_w 1223
    //   3460: sipush 422
    //   3463: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3466: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3469: putstatic 1225	com/neovisionaries/i18n/CountryCode:LB	Lcom/neovisionaries/i18n/CountryCode;
    //   3472: new 2	com/neovisionaries/i18n/CountryCode
    //   3475: dup
    //   3476: ldc_w 1226
    //   3479: sipush 130
    //   3482: ldc_w 1228
    //   3485: ldc_w 1230
    //   3488: sipush 662
    //   3491: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3494: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3497: putstatic 1232	com/neovisionaries/i18n/CountryCode:LC	Lcom/neovisionaries/i18n/CountryCode;
    //   3500: new 2	com/neovisionaries/i18n/CountryCode
    //   3503: dup
    //   3504: ldc_w 1233
    //   3507: sipush 131
    //   3510: ldc_w 1235
    //   3513: ldc_w 1237
    //   3516: sipush 438
    //   3519: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3522: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3525: putstatic 1239	com/neovisionaries/i18n/CountryCode:LI	Lcom/neovisionaries/i18n/CountryCode;
    //   3528: new 2	com/neovisionaries/i18n/CountryCode
    //   3531: dup
    //   3532: ldc_w 1240
    //   3535: sipush 132
    //   3538: ldc_w 1242
    //   3541: ldc_w 1244
    //   3544: sipush 144
    //   3547: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3550: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3553: putstatic 1246	com/neovisionaries/i18n/CountryCode:LK	Lcom/neovisionaries/i18n/CountryCode;
    //   3556: new 2	com/neovisionaries/i18n/CountryCode
    //   3559: dup
    //   3560: ldc_w 1247
    //   3563: sipush 133
    //   3566: ldc_w 1249
    //   3569: ldc_w 1251
    //   3572: sipush 430
    //   3575: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3578: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3581: putstatic 1253	com/neovisionaries/i18n/CountryCode:LR	Lcom/neovisionaries/i18n/CountryCode;
    //   3584: new 2	com/neovisionaries/i18n/CountryCode
    //   3587: dup
    //   3588: ldc_w 1254
    //   3591: sipush 134
    //   3594: ldc_w 1256
    //   3597: ldc_w 1258
    //   3600: sipush 426
    //   3603: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3606: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3609: putstatic 1260	com/neovisionaries/i18n/CountryCode:LS	Lcom/neovisionaries/i18n/CountryCode;
    //   3612: new 2	com/neovisionaries/i18n/CountryCode
    //   3615: dup
    //   3616: ldc_w 1261
    //   3619: sipush 135
    //   3622: ldc_w 1263
    //   3625: ldc_w 1265
    //   3628: sipush 440
    //   3631: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3634: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3637: putstatic 1267	com/neovisionaries/i18n/CountryCode:LT	Lcom/neovisionaries/i18n/CountryCode;
    //   3640: new 2	com/neovisionaries/i18n/CountryCode
    //   3643: dup
    //   3644: ldc_w 1268
    //   3647: sipush 136
    //   3650: ldc_w 1270
    //   3653: ldc_w 1272
    //   3656: sipush 442
    //   3659: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3662: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3665: putstatic 1274	com/neovisionaries/i18n/CountryCode:LU	Lcom/neovisionaries/i18n/CountryCode;
    //   3668: new 2	com/neovisionaries/i18n/CountryCode
    //   3671: dup
    //   3672: ldc_w 1275
    //   3675: sipush 137
    //   3678: ldc_w 1277
    //   3681: ldc_w 1279
    //   3684: sipush 428
    //   3687: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3690: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3693: putstatic 1281	com/neovisionaries/i18n/CountryCode:LV	Lcom/neovisionaries/i18n/CountryCode;
    //   3696: new 2	com/neovisionaries/i18n/CountryCode
    //   3699: dup
    //   3700: ldc_w 1282
    //   3703: sipush 138
    //   3706: ldc_w 1284
    //   3709: ldc_w 1286
    //   3712: sipush 434
    //   3715: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3718: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3721: putstatic 1288	com/neovisionaries/i18n/CountryCode:LY	Lcom/neovisionaries/i18n/CountryCode;
    //   3724: new 2	com/neovisionaries/i18n/CountryCode
    //   3727: dup
    //   3728: ldc_w 1289
    //   3731: sipush 139
    //   3734: ldc_w 1291
    //   3737: ldc_w 1293
    //   3740: sipush 504
    //   3743: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3746: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3749: putstatic 1295	com/neovisionaries/i18n/CountryCode:MA	Lcom/neovisionaries/i18n/CountryCode;
    //   3752: new 2	com/neovisionaries/i18n/CountryCode
    //   3755: dup
    //   3756: ldc_w 1296
    //   3759: sipush 140
    //   3762: ldc_w 1298
    //   3765: ldc_w 1300
    //   3768: sipush 492
    //   3771: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3774: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3777: putstatic 1302	com/neovisionaries/i18n/CountryCode:MC	Lcom/neovisionaries/i18n/CountryCode;
    //   3780: new 2	com/neovisionaries/i18n/CountryCode
    //   3783: dup
    //   3784: ldc_w 1303
    //   3787: sipush 141
    //   3790: ldc_w 1305
    //   3793: ldc_w 1307
    //   3796: sipush 498
    //   3799: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3802: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3805: putstatic 1309	com/neovisionaries/i18n/CountryCode:MD	Lcom/neovisionaries/i18n/CountryCode;
    //   3808: new 2	com/neovisionaries/i18n/CountryCode
    //   3811: dup
    //   3812: ldc_w 1310
    //   3815: sipush 142
    //   3818: ldc_w 1312
    //   3821: ldc_w 1314
    //   3824: sipush 499
    //   3827: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3830: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3833: putstatic 1316	com/neovisionaries/i18n/CountryCode:ME	Lcom/neovisionaries/i18n/CountryCode;
    //   3836: new 2	com/neovisionaries/i18n/CountryCode
    //   3839: dup
    //   3840: ldc_w 1317
    //   3843: sipush 143
    //   3846: ldc_w 1319
    //   3849: ldc_w 1321
    //   3852: sipush 663
    //   3855: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3858: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3861: putstatic 1323	com/neovisionaries/i18n/CountryCode:MF	Lcom/neovisionaries/i18n/CountryCode;
    //   3864: new 2	com/neovisionaries/i18n/CountryCode
    //   3867: dup
    //   3868: ldc_w 1324
    //   3871: sipush 144
    //   3874: ldc_w 1326
    //   3877: ldc_w 1328
    //   3880: sipush 450
    //   3883: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3886: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3889: putstatic 1330	com/neovisionaries/i18n/CountryCode:MG	Lcom/neovisionaries/i18n/CountryCode;
    //   3892: new 2	com/neovisionaries/i18n/CountryCode
    //   3895: dup
    //   3896: ldc_w 1331
    //   3899: sipush 145
    //   3902: ldc_w 1333
    //   3905: ldc_w 1335
    //   3908: sipush 584
    //   3911: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3914: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3917: putstatic 1337	com/neovisionaries/i18n/CountryCode:MH	Lcom/neovisionaries/i18n/CountryCode;
    //   3920: new 2	com/neovisionaries/i18n/CountryCode
    //   3923: dup
    //   3924: ldc_w 1338
    //   3927: sipush 146
    //   3930: ldc_w 1340
    //   3933: ldc_w 1342
    //   3936: sipush 807
    //   3939: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3942: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3945: putstatic 1344	com/neovisionaries/i18n/CountryCode:MK	Lcom/neovisionaries/i18n/CountryCode;
    //   3948: new 2	com/neovisionaries/i18n/CountryCode
    //   3951: dup
    //   3952: ldc_w 1345
    //   3955: sipush 147
    //   3958: ldc_w 1347
    //   3961: ldc_w 1349
    //   3964: sipush 466
    //   3967: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3970: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   3973: putstatic 1351	com/neovisionaries/i18n/CountryCode:ML	Lcom/neovisionaries/i18n/CountryCode;
    //   3976: new 2	com/neovisionaries/i18n/CountryCode
    //   3979: dup
    //   3980: ldc_w 1352
    //   3983: sipush 148
    //   3986: ldc_w 1354
    //   3989: ldc_w 1356
    //   3992: bipush 104
    //   3994: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   3997: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4000: putstatic 1358	com/neovisionaries/i18n/CountryCode:MM	Lcom/neovisionaries/i18n/CountryCode;
    //   4003: new 2	com/neovisionaries/i18n/CountryCode
    //   4006: dup
    //   4007: ldc_w 1359
    //   4010: sipush 149
    //   4013: ldc_w 1361
    //   4016: ldc_w 1363
    //   4019: sipush 496
    //   4022: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4025: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4028: putstatic 1365	com/neovisionaries/i18n/CountryCode:MN	Lcom/neovisionaries/i18n/CountryCode;
    //   4031: new 2	com/neovisionaries/i18n/CountryCode
    //   4034: dup
    //   4035: ldc_w 1366
    //   4038: sipush 150
    //   4041: ldc_w 1368
    //   4044: ldc_w 1300
    //   4047: sipush 446
    //   4050: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4053: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4056: putstatic 1370	com/neovisionaries/i18n/CountryCode:MO	Lcom/neovisionaries/i18n/CountryCode;
    //   4059: new 2	com/neovisionaries/i18n/CountryCode
    //   4062: dup
    //   4063: ldc_w 1371
    //   4066: sipush 151
    //   4069: ldc_w 1373
    //   4072: ldc_w 1375
    //   4075: sipush 580
    //   4078: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4081: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4084: putstatic 1377	com/neovisionaries/i18n/CountryCode:MP	Lcom/neovisionaries/i18n/CountryCode;
    //   4087: new 2	com/neovisionaries/i18n/CountryCode
    //   4090: dup
    //   4091: ldc_w 1378
    //   4094: sipush 152
    //   4097: ldc_w 1380
    //   4100: ldc_w 1382
    //   4103: sipush 474
    //   4106: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4109: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4112: putstatic 1384	com/neovisionaries/i18n/CountryCode:MQ	Lcom/neovisionaries/i18n/CountryCode;
    //   4115: new 2	com/neovisionaries/i18n/CountryCode
    //   4118: dup
    //   4119: ldc_w 1385
    //   4122: sipush 153
    //   4125: ldc_w 1387
    //   4128: ldc_w 1389
    //   4131: sipush 478
    //   4134: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4137: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4140: putstatic 1391	com/neovisionaries/i18n/CountryCode:MR	Lcom/neovisionaries/i18n/CountryCode;
    //   4143: new 2	com/neovisionaries/i18n/CountryCode
    //   4146: dup
    //   4147: ldc_w 1392
    //   4150: sipush 154
    //   4153: ldc_w 1394
    //   4156: ldc_w 1396
    //   4159: sipush 500
    //   4162: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4165: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4168: putstatic 1398	com/neovisionaries/i18n/CountryCode:MS	Lcom/neovisionaries/i18n/CountryCode;
    //   4171: new 2	com/neovisionaries/i18n/CountryCode
    //   4174: dup
    //   4175: ldc_w 1399
    //   4178: sipush 155
    //   4181: ldc_w 1401
    //   4184: ldc_w 1403
    //   4187: sipush 470
    //   4190: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4193: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4196: putstatic 1405	com/neovisionaries/i18n/CountryCode:MT	Lcom/neovisionaries/i18n/CountryCode;
    //   4199: new 2	com/neovisionaries/i18n/CountryCode
    //   4202: dup
    //   4203: ldc_w 1406
    //   4206: sipush 156
    //   4209: ldc_w 1408
    //   4212: ldc_w 1410
    //   4215: sipush 480
    //   4218: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4221: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4224: putstatic 1412	com/neovisionaries/i18n/CountryCode:MU	Lcom/neovisionaries/i18n/CountryCode;
    //   4227: new 2	com/neovisionaries/i18n/CountryCode
    //   4230: dup
    //   4231: ldc_w 1413
    //   4234: sipush 157
    //   4237: ldc_w 1415
    //   4240: ldc_w 1417
    //   4243: sipush 462
    //   4246: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4249: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4252: putstatic 1419	com/neovisionaries/i18n/CountryCode:MV	Lcom/neovisionaries/i18n/CountryCode;
    //   4255: new 2	com/neovisionaries/i18n/CountryCode
    //   4258: dup
    //   4259: ldc_w 1420
    //   4262: sipush 158
    //   4265: ldc_w 1422
    //   4268: ldc_w 1424
    //   4271: sipush 454
    //   4274: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4277: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4280: putstatic 1426	com/neovisionaries/i18n/CountryCode:MW	Lcom/neovisionaries/i18n/CountryCode;
    //   4283: new 2	com/neovisionaries/i18n/CountryCode
    //   4286: dup
    //   4287: ldc_w 1427
    //   4290: sipush 159
    //   4293: ldc_w 1429
    //   4296: ldc_w 1431
    //   4299: sipush 484
    //   4302: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4305: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4308: putstatic 1433	com/neovisionaries/i18n/CountryCode:MX	Lcom/neovisionaries/i18n/CountryCode;
    //   4311: new 2	com/neovisionaries/i18n/CountryCode
    //   4314: dup
    //   4315: ldc_w 1434
    //   4318: sipush 160
    //   4321: ldc_w 1436
    //   4324: ldc_w 1438
    //   4327: sipush 458
    //   4330: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4333: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4336: putstatic 1440	com/neovisionaries/i18n/CountryCode:MY	Lcom/neovisionaries/i18n/CountryCode;
    //   4339: new 2	com/neovisionaries/i18n/CountryCode
    //   4342: dup
    //   4343: ldc_w 1441
    //   4346: sipush 161
    //   4349: ldc_w 1443
    //   4352: ldc_w 1445
    //   4355: sipush 508
    //   4358: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4361: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4364: putstatic 1447	com/neovisionaries/i18n/CountryCode:MZ	Lcom/neovisionaries/i18n/CountryCode;
    //   4367: new 2	com/neovisionaries/i18n/CountryCode
    //   4370: dup
    //   4371: ldc_w 1448
    //   4374: sipush 162
    //   4377: ldc_w 1450
    //   4380: ldc_w 1452
    //   4383: sipush 516
    //   4386: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4389: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4392: putstatic 1454	com/neovisionaries/i18n/CountryCode:NA	Lcom/neovisionaries/i18n/CountryCode;
    //   4395: new 2	com/neovisionaries/i18n/CountryCode
    //   4398: dup
    //   4399: ldc_w 1455
    //   4402: sipush 163
    //   4405: ldc_w 1457
    //   4408: ldc_w 1459
    //   4411: sipush 540
    //   4414: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4417: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4420: putstatic 1461	com/neovisionaries/i18n/CountryCode:NC	Lcom/neovisionaries/i18n/CountryCode;
    //   4423: new 2	com/neovisionaries/i18n/CountryCode
    //   4426: dup
    //   4427: ldc_w 1462
    //   4430: sipush 164
    //   4433: ldc_w 1464
    //   4436: ldc_w 1466
    //   4439: sipush 562
    //   4442: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4445: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4448: putstatic 1468	com/neovisionaries/i18n/CountryCode:NE	Lcom/neovisionaries/i18n/CountryCode;
    //   4451: new 2	com/neovisionaries/i18n/CountryCode
    //   4454: dup
    //   4455: ldc_w 1469
    //   4458: sipush 165
    //   4461: ldc_w 1471
    //   4464: ldc_w 1473
    //   4467: sipush 574
    //   4470: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4473: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4476: putstatic 1475	com/neovisionaries/i18n/CountryCode:NF	Lcom/neovisionaries/i18n/CountryCode;
    //   4479: new 2	com/neovisionaries/i18n/CountryCode
    //   4482: dup
    //   4483: ldc_w 1476
    //   4486: sipush 166
    //   4489: ldc_w 1478
    //   4492: ldc_w 1480
    //   4495: sipush 566
    //   4498: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4501: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4504: putstatic 1482	com/neovisionaries/i18n/CountryCode:NG	Lcom/neovisionaries/i18n/CountryCode;
    //   4507: new 2	com/neovisionaries/i18n/CountryCode
    //   4510: dup
    //   4511: ldc_w 1483
    //   4514: sipush 167
    //   4517: ldc_w 1485
    //   4520: ldc_w 1487
    //   4523: sipush 558
    //   4526: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4529: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4532: putstatic 1489	com/neovisionaries/i18n/CountryCode:NI	Lcom/neovisionaries/i18n/CountryCode;
    //   4535: new 2	com/neovisionaries/i18n/CountryCode
    //   4538: dup
    //   4539: ldc_w 1490
    //   4542: sipush 168
    //   4545: ldc_w 1492
    //   4548: ldc_w 1494
    //   4551: sipush 528
    //   4554: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4557: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4560: putstatic 1496	com/neovisionaries/i18n/CountryCode:NL	Lcom/neovisionaries/i18n/CountryCode;
    //   4563: new 2	com/neovisionaries/i18n/CountryCode
    //   4566: dup
    //   4567: ldc_w 1497
    //   4570: sipush 169
    //   4573: ldc_w 1499
    //   4576: ldc_w 1501
    //   4579: sipush 578
    //   4582: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4585: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4588: putstatic 1503	com/neovisionaries/i18n/CountryCode:NO	Lcom/neovisionaries/i18n/CountryCode;
    //   4591: new 2	com/neovisionaries/i18n/CountryCode
    //   4594: dup
    //   4595: ldc_w 1504
    //   4598: sipush 170
    //   4601: ldc_w 1506
    //   4604: ldc_w 1508
    //   4607: sipush 524
    //   4610: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4613: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4616: putstatic 1510	com/neovisionaries/i18n/CountryCode:NP	Lcom/neovisionaries/i18n/CountryCode;
    //   4619: new 2	com/neovisionaries/i18n/CountryCode
    //   4622: dup
    //   4623: ldc_w 1511
    //   4626: sipush 171
    //   4629: ldc_w 1513
    //   4632: ldc_w 1515
    //   4635: sipush 520
    //   4638: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4641: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4644: putstatic 1517	com/neovisionaries/i18n/CountryCode:NR	Lcom/neovisionaries/i18n/CountryCode;
    //   4647: new 2	com/neovisionaries/i18n/CountryCode
    //   4650: dup
    //   4651: ldc_w 1518
    //   4654: sipush 172
    //   4657: ldc_w 1520
    //   4660: ldc_w 1522
    //   4663: sipush 536
    //   4666: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4669: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4672: putstatic 1524	com/neovisionaries/i18n/CountryCode:NT	Lcom/neovisionaries/i18n/CountryCode;
    //   4675: new 2	com/neovisionaries/i18n/CountryCode
    //   4678: dup
    //   4679: ldc_w 1525
    //   4682: sipush 173
    //   4685: ldc_w 1527
    //   4688: ldc_w 1529
    //   4691: sipush 570
    //   4694: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4697: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4700: putstatic 1531	com/neovisionaries/i18n/CountryCode:NU	Lcom/neovisionaries/i18n/CountryCode;
    //   4703: new 2	com/neovisionaries/i18n/CountryCode
    //   4706: dup
    //   4707: ldc_w 1532
    //   4710: sipush 174
    //   4713: ldc_w 1534
    //   4716: ldc_w 1536
    //   4719: sipush 554
    //   4722: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4725: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4728: putstatic 1538	com/neovisionaries/i18n/CountryCode:NZ	Lcom/neovisionaries/i18n/CountryCode;
    //   4731: new 2	com/neovisionaries/i18n/CountryCode
    //   4734: dup
    //   4735: ldc_w 1539
    //   4738: sipush 175
    //   4741: ldc_w 1541
    //   4744: ldc_w 1543
    //   4747: sipush 512
    //   4750: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4753: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4756: putstatic 1545	com/neovisionaries/i18n/CountryCode:OM	Lcom/neovisionaries/i18n/CountryCode;
    //   4759: new 2	com/neovisionaries/i18n/CountryCode
    //   4762: dup
    //   4763: ldc_w 1546
    //   4766: sipush 176
    //   4769: ldc_w 1548
    //   4772: ldc_w 1550
    //   4775: sipush 591
    //   4778: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4781: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4784: putstatic 1552	com/neovisionaries/i18n/CountryCode:PA	Lcom/neovisionaries/i18n/CountryCode;
    //   4787: new 2	com/neovisionaries/i18n/CountryCode
    //   4790: dup
    //   4791: ldc_w 1553
    //   4794: sipush 177
    //   4797: ldc_w 1555
    //   4800: ldc_w 1557
    //   4803: sipush 604
    //   4806: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4809: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4812: putstatic 1559	com/neovisionaries/i18n/CountryCode:PE	Lcom/neovisionaries/i18n/CountryCode;
    //   4815: new 2	com/neovisionaries/i18n/CountryCode
    //   4818: dup
    //   4819: ldc_w 1560
    //   4822: sipush 178
    //   4825: ldc_w 1562
    //   4828: ldc_w 1564
    //   4831: sipush 258
    //   4834: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4837: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4840: putstatic 1566	com/neovisionaries/i18n/CountryCode:PF	Lcom/neovisionaries/i18n/CountryCode;
    //   4843: new 2	com/neovisionaries/i18n/CountryCode
    //   4846: dup
    //   4847: ldc_w 1567
    //   4850: sipush 179
    //   4853: ldc_w 1569
    //   4856: ldc_w 1571
    //   4859: sipush 598
    //   4862: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4865: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4868: putstatic 1573	com/neovisionaries/i18n/CountryCode:PG	Lcom/neovisionaries/i18n/CountryCode;
    //   4871: new 2	com/neovisionaries/i18n/CountryCode
    //   4874: dup
    //   4875: ldc_w 1574
    //   4878: sipush 180
    //   4881: ldc_w 1576
    //   4884: ldc_w 1578
    //   4887: sipush 608
    //   4890: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4893: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4896: putstatic 1580	com/neovisionaries/i18n/CountryCode:PH	Lcom/neovisionaries/i18n/CountryCode;
    //   4899: new 2	com/neovisionaries/i18n/CountryCode
    //   4902: dup
    //   4903: ldc_w 1581
    //   4906: sipush 181
    //   4909: ldc_w 1583
    //   4912: ldc_w 1585
    //   4915: sipush 586
    //   4918: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4921: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4924: putstatic 1587	com/neovisionaries/i18n/CountryCode:PK	Lcom/neovisionaries/i18n/CountryCode;
    //   4927: new 2	com/neovisionaries/i18n/CountryCode
    //   4930: dup
    //   4931: ldc_w 1588
    //   4934: sipush 182
    //   4937: ldc_w 1590
    //   4940: ldc_w 1592
    //   4943: sipush 616
    //   4946: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4949: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4952: putstatic 1594	com/neovisionaries/i18n/CountryCode:PL	Lcom/neovisionaries/i18n/CountryCode;
    //   4955: new 2	com/neovisionaries/i18n/CountryCode
    //   4958: dup
    //   4959: ldc_w 1595
    //   4962: sipush 183
    //   4965: ldc_w 1597
    //   4968: ldc_w 1599
    //   4971: sipush 666
    //   4974: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   4977: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   4980: putstatic 1601	com/neovisionaries/i18n/CountryCode:PM	Lcom/neovisionaries/i18n/CountryCode;
    //   4983: new 2	com/neovisionaries/i18n/CountryCode
    //   4986: dup
    //   4987: ldc_w 1602
    //   4990: sipush 184
    //   4993: ldc_w 1604
    //   4996: ldc_w 1606
    //   4999: sipush 612
    //   5002: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5005: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5008: putstatic 1608	com/neovisionaries/i18n/CountryCode:PN	Lcom/neovisionaries/i18n/CountryCode;
    //   5011: new 2	com/neovisionaries/i18n/CountryCode
    //   5014: dup
    //   5015: ldc_w 1609
    //   5018: sipush 185
    //   5021: ldc_w 1611
    //   5024: ldc_w 1613
    //   5027: sipush 630
    //   5030: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5033: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5036: putstatic 1615	com/neovisionaries/i18n/CountryCode:PR	Lcom/neovisionaries/i18n/CountryCode;
    //   5039: new 2	com/neovisionaries/i18n/CountryCode
    //   5042: dup
    //   5043: ldc_w 1616
    //   5046: sipush 186
    //   5049: ldc_w 1618
    //   5052: ldc_w 1620
    //   5055: sipush 275
    //   5058: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5061: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5064: putstatic 1622	com/neovisionaries/i18n/CountryCode:PS	Lcom/neovisionaries/i18n/CountryCode;
    //   5067: new 2	com/neovisionaries/i18n/CountryCode
    //   5070: dup
    //   5071: ldc_w 1623
    //   5074: sipush 187
    //   5077: ldc_w 1625
    //   5080: ldc_w 1627
    //   5083: sipush 620
    //   5086: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5089: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5092: putstatic 1629	com/neovisionaries/i18n/CountryCode:PT	Lcom/neovisionaries/i18n/CountryCode;
    //   5095: new 2	com/neovisionaries/i18n/CountryCode
    //   5098: dup
    //   5099: ldc_w 1630
    //   5102: sipush 188
    //   5105: ldc_w 1632
    //   5108: ldc_w 1634
    //   5111: sipush 585
    //   5114: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5117: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5120: putstatic 1636	com/neovisionaries/i18n/CountryCode:PW	Lcom/neovisionaries/i18n/CountryCode;
    //   5123: new 2	com/neovisionaries/i18n/CountryCode
    //   5126: dup
    //   5127: ldc_w 1637
    //   5130: sipush 189
    //   5133: ldc_w 1639
    //   5136: ldc_w 1641
    //   5139: sipush 600
    //   5142: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5145: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5148: putstatic 1643	com/neovisionaries/i18n/CountryCode:PY	Lcom/neovisionaries/i18n/CountryCode;
    //   5151: new 2	com/neovisionaries/i18n/CountryCode
    //   5154: dup
    //   5155: ldc_w 1644
    //   5158: sipush 190
    //   5161: ldc_w 1646
    //   5164: ldc_w 1648
    //   5167: sipush 634
    //   5170: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5173: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5176: putstatic 1650	com/neovisionaries/i18n/CountryCode:QA	Lcom/neovisionaries/i18n/CountryCode;
    //   5179: new 2	com/neovisionaries/i18n/CountryCode
    //   5182: dup
    //   5183: ldc_w 1651
    //   5186: sipush 191
    //   5189: ldc_w 1653
    //   5192: ldc_w 1655
    //   5195: sipush 638
    //   5198: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5201: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5204: putstatic 1657	com/neovisionaries/i18n/CountryCode:RE	Lcom/neovisionaries/i18n/CountryCode;
    //   5207: new 2	com/neovisionaries/i18n/CountryCode
    //   5210: dup
    //   5211: ldc_w 1658
    //   5214: sipush 192
    //   5217: ldc_w 1660
    //   5220: ldc_w 1662
    //   5223: sipush 642
    //   5226: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5229: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5232: putstatic 1664	com/neovisionaries/i18n/CountryCode:RO	Lcom/neovisionaries/i18n/CountryCode;
    //   5235: new 2	com/neovisionaries/i18n/CountryCode
    //   5238: dup
    //   5239: ldc_w 1665
    //   5242: sipush 193
    //   5245: ldc_w 1667
    //   5248: ldc_w 1669
    //   5251: sipush 688
    //   5254: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5257: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5260: putstatic 1671	com/neovisionaries/i18n/CountryCode:RS	Lcom/neovisionaries/i18n/CountryCode;
    //   5263: new 2	com/neovisionaries/i18n/CountryCode
    //   5266: dup
    //   5267: ldc_w 1672
    //   5270: sipush 194
    //   5273: ldc_w 1674
    //   5276: ldc_w 1676
    //   5279: sipush 643
    //   5282: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5285: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5288: putstatic 1678	com/neovisionaries/i18n/CountryCode:RU	Lcom/neovisionaries/i18n/CountryCode;
    //   5291: new 2	com/neovisionaries/i18n/CountryCode
    //   5294: dup
    //   5295: ldc_w 1679
    //   5298: sipush 195
    //   5301: ldc_w 1681
    //   5304: ldc_w 1683
    //   5307: sipush 646
    //   5310: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5313: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5316: putstatic 1685	com/neovisionaries/i18n/CountryCode:RW	Lcom/neovisionaries/i18n/CountryCode;
    //   5319: new 2	com/neovisionaries/i18n/CountryCode
    //   5322: dup
    //   5323: ldc_w 1686
    //   5326: sipush 196
    //   5329: ldc_w 1688
    //   5332: ldc_w 1690
    //   5335: sipush 682
    //   5338: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5341: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5344: putstatic 1692	com/neovisionaries/i18n/CountryCode:SA	Lcom/neovisionaries/i18n/CountryCode;
    //   5347: new 2	com/neovisionaries/i18n/CountryCode
    //   5350: dup
    //   5351: ldc_w 1693
    //   5354: sipush 197
    //   5357: ldc_w 1695
    //   5360: ldc_w 1697
    //   5363: bipush 90
    //   5365: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5368: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5371: putstatic 1699	com/neovisionaries/i18n/CountryCode:SB	Lcom/neovisionaries/i18n/CountryCode;
    //   5374: new 2	com/neovisionaries/i18n/CountryCode
    //   5377: dup
    //   5378: ldc_w 1700
    //   5381: sipush 198
    //   5384: ldc_w 1702
    //   5387: ldc_w 1704
    //   5390: sipush 690
    //   5393: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5396: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5399: putstatic 1706	com/neovisionaries/i18n/CountryCode:SC	Lcom/neovisionaries/i18n/CountryCode;
    //   5402: new 2	com/neovisionaries/i18n/CountryCode
    //   5405: dup
    //   5406: ldc_w 1707
    //   5409: sipush 199
    //   5412: ldc_w 1709
    //   5415: ldc_w 1711
    //   5418: sipush 729
    //   5421: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5424: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5427: putstatic 1713	com/neovisionaries/i18n/CountryCode:SD	Lcom/neovisionaries/i18n/CountryCode;
    //   5430: new 2	com/neovisionaries/i18n/CountryCode
    //   5433: dup
    //   5434: ldc_w 1714
    //   5437: sipush 200
    //   5440: ldc_w 1716
    //   5443: ldc_w 1718
    //   5446: sipush 752
    //   5449: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5452: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5455: putstatic 1720	com/neovisionaries/i18n/CountryCode:SE	Lcom/neovisionaries/i18n/CountryCode;
    //   5458: new 2	com/neovisionaries/i18n/CountryCode
    //   5461: dup
    //   5462: ldc_w 1721
    //   5465: sipush 201
    //   5468: ldc_w 807
    //   5471: ldc_w 809
    //   5474: sipush 246
    //   5477: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5480: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5483: putstatic 1723	com/neovisionaries/i18n/CountryCode:SF	Lcom/neovisionaries/i18n/CountryCode;
    //   5486: new 2	com/neovisionaries/i18n/CountryCode
    //   5489: dup
    //   5490: ldc_w 1724
    //   5493: sipush 202
    //   5496: ldc_w 1726
    //   5499: ldc_w 1728
    //   5502: sipush 702
    //   5505: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5508: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5511: putstatic 1730	com/neovisionaries/i18n/CountryCode:SG	Lcom/neovisionaries/i18n/CountryCode;
    //   5514: new 2	com/neovisionaries/i18n/CountryCode
    //   5517: dup
    //   5518: ldc_w 1731
    //   5521: sipush 203
    //   5524: ldc_w 1733
    //   5527: ldc_w 1735
    //   5530: sipush 654
    //   5533: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5536: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5539: putstatic 1737	com/neovisionaries/i18n/CountryCode:SH	Lcom/neovisionaries/i18n/CountryCode;
    //   5542: new 2	com/neovisionaries/i18n/CountryCode
    //   5545: dup
    //   5546: ldc_w 1738
    //   5549: sipush 204
    //   5552: ldc_w 1740
    //   5555: ldc_w 1742
    //   5558: sipush 705
    //   5561: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5564: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5567: putstatic 1744	com/neovisionaries/i18n/CountryCode:SI	Lcom/neovisionaries/i18n/CountryCode;
    //   5570: new 2	com/neovisionaries/i18n/CountryCode
    //   5573: dup
    //   5574: ldc_w 1745
    //   5577: sipush 205
    //   5580: ldc_w 1747
    //   5583: ldc_w 1749
    //   5586: sipush 744
    //   5589: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5592: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5595: putstatic 1751	com/neovisionaries/i18n/CountryCode:SJ	Lcom/neovisionaries/i18n/CountryCode;
    //   5598: new 2	com/neovisionaries/i18n/CountryCode
    //   5601: dup
    //   5602: ldc_w 1752
    //   5605: sipush 206
    //   5608: ldc_w 1754
    //   5611: ldc_w 1756
    //   5614: sipush 703
    //   5617: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5620: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5623: putstatic 1758	com/neovisionaries/i18n/CountryCode:SK	Lcom/neovisionaries/i18n/CountryCode;
    //   5626: new 2	com/neovisionaries/i18n/CountryCode
    //   5629: dup
    //   5630: ldc_w 1759
    //   5633: sipush 207
    //   5636: ldc_w 1761
    //   5639: ldc_w 1763
    //   5642: sipush 694
    //   5645: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5648: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5651: putstatic 1765	com/neovisionaries/i18n/CountryCode:SL	Lcom/neovisionaries/i18n/CountryCode;
    //   5654: new 2	com/neovisionaries/i18n/CountryCode
    //   5657: dup
    //   5658: ldc_w 1766
    //   5661: sipush 208
    //   5664: ldc_w 1768
    //   5667: ldc_w 1770
    //   5670: sipush 674
    //   5673: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5676: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5679: putstatic 1772	com/neovisionaries/i18n/CountryCode:SM	Lcom/neovisionaries/i18n/CountryCode;
    //   5682: new 2	com/neovisionaries/i18n/CountryCode
    //   5685: dup
    //   5686: ldc_w 1773
    //   5689: sipush 209
    //   5692: ldc_w 1775
    //   5695: ldc_w 1777
    //   5698: sipush 686
    //   5701: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5704: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5707: putstatic 1779	com/neovisionaries/i18n/CountryCode:SN	Lcom/neovisionaries/i18n/CountryCode;
    //   5710: new 2	com/neovisionaries/i18n/CountryCode
    //   5713: dup
    //   5714: ldc_w 1780
    //   5717: sipush 210
    //   5720: ldc_w 1782
    //   5723: ldc_w 1784
    //   5726: sipush 706
    //   5729: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5732: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5735: putstatic 1786	com/neovisionaries/i18n/CountryCode:SO	Lcom/neovisionaries/i18n/CountryCode;
    //   5738: new 2	com/neovisionaries/i18n/CountryCode
    //   5741: dup
    //   5742: ldc_w 1787
    //   5745: sipush 211
    //   5748: ldc_w 1789
    //   5751: ldc_w 1791
    //   5754: sipush 740
    //   5757: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5760: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5763: putstatic 1793	com/neovisionaries/i18n/CountryCode:SR	Lcom/neovisionaries/i18n/CountryCode;
    //   5766: new 2	com/neovisionaries/i18n/CountryCode
    //   5769: dup
    //   5770: ldc_w 1794
    //   5773: sipush 212
    //   5776: ldc_w 1796
    //   5779: ldc_w 1798
    //   5782: sipush 728
    //   5785: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5788: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5791: putstatic 1800	com/neovisionaries/i18n/CountryCode:SS	Lcom/neovisionaries/i18n/CountryCode;
    //   5794: new 2	com/neovisionaries/i18n/CountryCode
    //   5797: dup
    //   5798: ldc_w 1801
    //   5801: sipush 213
    //   5804: ldc_w 1803
    //   5807: ldc_w 1805
    //   5810: sipush 678
    //   5813: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5816: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5819: putstatic 1807	com/neovisionaries/i18n/CountryCode:ST	Lcom/neovisionaries/i18n/CountryCode;
    //   5822: new 2	com/neovisionaries/i18n/CountryCode
    //   5825: dup
    //   5826: ldc_w 1808
    //   5829: sipush 214
    //   5832: ldc_w 1810
    //   5835: ldc_w 1812
    //   5838: sipush 222
    //   5841: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5844: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5847: putstatic 1814	com/neovisionaries/i18n/CountryCode:SV	Lcom/neovisionaries/i18n/CountryCode;
    //   5850: new 2	com/neovisionaries/i18n/CountryCode
    //   5853: dup
    //   5854: ldc_w 1815
    //   5857: sipush 215
    //   5860: ldc_w 1817
    //   5863: ldc_w 1819
    //   5866: sipush 534
    //   5869: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5872: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5875: putstatic 1821	com/neovisionaries/i18n/CountryCode:SX	Lcom/neovisionaries/i18n/CountryCode;
    //   5878: new 2	com/neovisionaries/i18n/CountryCode
    //   5881: dup
    //   5882: ldc_w 1822
    //   5885: sipush 216
    //   5888: ldc_w 1824
    //   5891: ldc_w 1826
    //   5894: sipush 760
    //   5897: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5900: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5903: putstatic 1828	com/neovisionaries/i18n/CountryCode:SY	Lcom/neovisionaries/i18n/CountryCode;
    //   5906: new 2	com/neovisionaries/i18n/CountryCode
    //   5909: dup
    //   5910: ldc_w 1829
    //   5913: sipush 217
    //   5916: ldc_w 1831
    //   5919: ldc_w 1833
    //   5922: sipush 748
    //   5925: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5928: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5931: putstatic 1835	com/neovisionaries/i18n/CountryCode:SZ	Lcom/neovisionaries/i18n/CountryCode;
    //   5934: new 2	com/neovisionaries/i18n/CountryCode
    //   5937: dup
    //   5938: ldc_w 1836
    //   5941: sipush 218
    //   5944: ldc_w 1838
    //   5947: ldc_w 1840
    //   5950: sipush 796
    //   5953: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5956: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5959: putstatic 1842	com/neovisionaries/i18n/CountryCode:TC	Lcom/neovisionaries/i18n/CountryCode;
    //   5962: new 2	com/neovisionaries/i18n/CountryCode
    //   5965: dup
    //   5966: ldc_w 1843
    //   5969: sipush 219
    //   5972: ldc_w 1845
    //   5975: ldc_w 1847
    //   5978: sipush 148
    //   5981: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   5984: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   5987: putstatic 1849	com/neovisionaries/i18n/CountryCode:TD	Lcom/neovisionaries/i18n/CountryCode;
    //   5990: new 2	com/neovisionaries/i18n/CountryCode
    //   5993: dup
    //   5994: ldc_w 1850
    //   5997: sipush 220
    //   6000: ldc_w 1852
    //   6003: ldc_w 1854
    //   6006: sipush 260
    //   6009: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6012: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6015: putstatic 1856	com/neovisionaries/i18n/CountryCode:TF	Lcom/neovisionaries/i18n/CountryCode;
    //   6018: new 2	com/neovisionaries/i18n/CountryCode
    //   6021: dup
    //   6022: ldc_w 1857
    //   6025: sipush 221
    //   6028: ldc_w 1859
    //   6031: ldc_w 1861
    //   6034: sipush 768
    //   6037: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6040: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6043: putstatic 1863	com/neovisionaries/i18n/CountryCode:TG	Lcom/neovisionaries/i18n/CountryCode;
    //   6046: new 2	com/neovisionaries/i18n/CountryCode
    //   6049: dup
    //   6050: ldc_w 1864
    //   6053: sipush 222
    //   6056: ldc_w 1866
    //   6059: ldc_w 1868
    //   6062: sipush 764
    //   6065: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6068: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6071: putstatic 1870	com/neovisionaries/i18n/CountryCode:TH	Lcom/neovisionaries/i18n/CountryCode;
    //   6074: new 2	com/neovisionaries/i18n/CountryCode
    //   6077: dup
    //   6078: ldc_w 1871
    //   6081: sipush 223
    //   6084: ldc_w 1873
    //   6087: ldc_w 1875
    //   6090: sipush 762
    //   6093: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6096: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6099: putstatic 1877	com/neovisionaries/i18n/CountryCode:TJ	Lcom/neovisionaries/i18n/CountryCode;
    //   6102: new 2	com/neovisionaries/i18n/CountryCode
    //   6105: dup
    //   6106: ldc_w 1878
    //   6109: sipush 224
    //   6112: ldc_w 1880
    //   6115: ldc_w 1882
    //   6118: sipush 772
    //   6121: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6124: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6127: putstatic 1884	com/neovisionaries/i18n/CountryCode:TK	Lcom/neovisionaries/i18n/CountryCode;
    //   6130: new 2	com/neovisionaries/i18n/CountryCode
    //   6133: dup
    //   6134: ldc_w 1885
    //   6137: sipush 225
    //   6140: ldc_w 1887
    //   6143: ldc_w 1889
    //   6146: sipush 626
    //   6149: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6152: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6155: putstatic 1891	com/neovisionaries/i18n/CountryCode:TL	Lcom/neovisionaries/i18n/CountryCode;
    //   6158: new 2	com/neovisionaries/i18n/CountryCode
    //   6161: dup
    //   6162: ldc_w 1892
    //   6165: sipush 226
    //   6168: ldc_w 1894
    //   6171: ldc_w 1896
    //   6174: sipush 795
    //   6177: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6180: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6183: putstatic 1898	com/neovisionaries/i18n/CountryCode:TM	Lcom/neovisionaries/i18n/CountryCode;
    //   6186: new 2	com/neovisionaries/i18n/CountryCode
    //   6189: dup
    //   6190: ldc_w 1899
    //   6193: sipush 227
    //   6196: ldc_w 1901
    //   6199: ldc_w 1903
    //   6202: sipush 788
    //   6205: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6208: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6211: putstatic 1905	com/neovisionaries/i18n/CountryCode:TN	Lcom/neovisionaries/i18n/CountryCode;
    //   6214: new 2	com/neovisionaries/i18n/CountryCode
    //   6217: dup
    //   6218: ldc_w 1906
    //   6221: sipush 228
    //   6224: ldc_w 1908
    //   6227: ldc_w 1910
    //   6230: sipush 776
    //   6233: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6236: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6239: putstatic 1912	com/neovisionaries/i18n/CountryCode:TO	Lcom/neovisionaries/i18n/CountryCode;
    //   6242: new 2	com/neovisionaries/i18n/CountryCode
    //   6245: dup
    //   6246: ldc_w 1913
    //   6249: sipush 229
    //   6252: ldc_w 1915
    //   6255: ldc_w 1917
    //   6258: iconst_0
    //   6259: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6262: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6265: putstatic 1919	com/neovisionaries/i18n/CountryCode:TP	Lcom/neovisionaries/i18n/CountryCode;
    //   6268: new 2	com/neovisionaries/i18n/CountryCode
    //   6271: dup
    //   6272: ldc_w 1920
    //   6275: sipush 230
    //   6278: ldc_w 1922
    //   6281: ldc_w 1924
    //   6284: sipush 792
    //   6287: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6290: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6293: putstatic 1926	com/neovisionaries/i18n/CountryCode:TR	Lcom/neovisionaries/i18n/CountryCode;
    //   6296: new 2	com/neovisionaries/i18n/CountryCode
    //   6299: dup
    //   6300: ldc_w 1927
    //   6303: sipush 231
    //   6306: ldc_w 1929
    //   6309: ldc_w 1931
    //   6312: sipush 780
    //   6315: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6318: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6321: putstatic 1933	com/neovisionaries/i18n/CountryCode:TT	Lcom/neovisionaries/i18n/CountryCode;
    //   6324: new 2	com/neovisionaries/i18n/CountryCode
    //   6327: dup
    //   6328: ldc_w 1934
    //   6331: sipush 232
    //   6334: ldc_w 1936
    //   6337: ldc_w 1938
    //   6340: sipush 798
    //   6343: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6346: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6349: putstatic 1940	com/neovisionaries/i18n/CountryCode:TV	Lcom/neovisionaries/i18n/CountryCode;
    //   6352: new 1942	com/neovisionaries/i18n/CountryCode$9
    //   6355: dup
    //   6356: ldc_w 1943
    //   6359: sipush 233
    //   6362: ldc_w 1945
    //   6365: ldc_w 1947
    //   6368: sipush 158
    //   6371: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6374: invokespecial 1948	com/neovisionaries/i18n/CountryCode$9:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6377: putstatic 1950	com/neovisionaries/i18n/CountryCode:TW	Lcom/neovisionaries/i18n/CountryCode;
    //   6380: new 2	com/neovisionaries/i18n/CountryCode
    //   6383: dup
    //   6384: ldc_w 1951
    //   6387: sipush 234
    //   6390: ldc_w 1953
    //   6393: ldc_w 1955
    //   6396: sipush 834
    //   6399: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6402: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6405: putstatic 1957	com/neovisionaries/i18n/CountryCode:TZ	Lcom/neovisionaries/i18n/CountryCode;
    //   6408: new 2	com/neovisionaries/i18n/CountryCode
    //   6411: dup
    //   6412: ldc_w 1958
    //   6415: sipush 235
    //   6418: ldc_w 1960
    //   6421: ldc_w 1962
    //   6424: sipush 804
    //   6427: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6430: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6433: putstatic 1964	com/neovisionaries/i18n/CountryCode:UA	Lcom/neovisionaries/i18n/CountryCode;
    //   6436: new 2	com/neovisionaries/i18n/CountryCode
    //   6439: dup
    //   6440: ldc_w 1965
    //   6443: sipush 236
    //   6446: ldc_w 1967
    //   6449: ldc_w 1969
    //   6452: sipush 800
    //   6455: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6458: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6461: putstatic 1971	com/neovisionaries/i18n/CountryCode:UG	Lcom/neovisionaries/i18n/CountryCode;
    //   6464: new 2	com/neovisionaries/i18n/CountryCode
    //   6467: dup
    //   6468: ldc_w 1972
    //   6471: sipush 237
    //   6474: ldc_w 1974
    //   6477: ldc_w 1976
    //   6480: sipush 581
    //   6483: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6486: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6489: putstatic 1978	com/neovisionaries/i18n/CountryCode:UM	Lcom/neovisionaries/i18n/CountryCode;
    //   6492: new 1980	com/neovisionaries/i18n/CountryCode$10
    //   6495: dup
    //   6496: ldc_w 1981
    //   6499: sipush 238
    //   6502: ldc_w 1983
    //   6505: ldc_w 1985
    //   6508: sipush 840
    //   6511: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6514: invokespecial 1986	com/neovisionaries/i18n/CountryCode$10:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6517: putstatic 1988	com/neovisionaries/i18n/CountryCode:US	Lcom/neovisionaries/i18n/CountryCode;
    //   6520: new 2	com/neovisionaries/i18n/CountryCode
    //   6523: dup
    //   6524: ldc_w 1989
    //   6527: sipush 239
    //   6530: ldc_w 1991
    //   6533: ldc_w 1993
    //   6536: sipush 858
    //   6539: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6542: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6545: putstatic 1995	com/neovisionaries/i18n/CountryCode:UY	Lcom/neovisionaries/i18n/CountryCode;
    //   6548: new 2	com/neovisionaries/i18n/CountryCode
    //   6551: dup
    //   6552: ldc_w 1996
    //   6555: sipush 240
    //   6558: ldc_w 1998
    //   6561: ldc_w 2000
    //   6564: sipush 860
    //   6567: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6570: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6573: putstatic 2002	com/neovisionaries/i18n/CountryCode:UZ	Lcom/neovisionaries/i18n/CountryCode;
    //   6576: new 2	com/neovisionaries/i18n/CountryCode
    //   6579: dup
    //   6580: ldc_w 2003
    //   6583: sipush 241
    //   6586: ldc_w 2005
    //   6589: ldc_w 2007
    //   6592: sipush 336
    //   6595: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6598: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6601: putstatic 2009	com/neovisionaries/i18n/CountryCode:VA	Lcom/neovisionaries/i18n/CountryCode;
    //   6604: new 2	com/neovisionaries/i18n/CountryCode
    //   6607: dup
    //   6608: ldc_w 2010
    //   6611: sipush 242
    //   6614: ldc_w 2012
    //   6617: ldc_w 2014
    //   6620: sipush 670
    //   6623: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6626: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6629: putstatic 2016	com/neovisionaries/i18n/CountryCode:VC	Lcom/neovisionaries/i18n/CountryCode;
    //   6632: new 2	com/neovisionaries/i18n/CountryCode
    //   6635: dup
    //   6636: ldc_w 2017
    //   6639: sipush 243
    //   6642: ldc_w 2019
    //   6645: ldc_w 2021
    //   6648: sipush 862
    //   6651: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6654: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6657: putstatic 2023	com/neovisionaries/i18n/CountryCode:VE	Lcom/neovisionaries/i18n/CountryCode;
    //   6660: new 2	com/neovisionaries/i18n/CountryCode
    //   6663: dup
    //   6664: ldc_w 2024
    //   6667: sipush 244
    //   6670: ldc_w 2026
    //   6673: ldc_w 2028
    //   6676: bipush 92
    //   6678: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6681: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6684: putstatic 2030	com/neovisionaries/i18n/CountryCode:VG	Lcom/neovisionaries/i18n/CountryCode;
    //   6687: new 2	com/neovisionaries/i18n/CountryCode
    //   6690: dup
    //   6691: ldc_w 2031
    //   6694: sipush 245
    //   6697: ldc_w 2033
    //   6700: ldc_w 2035
    //   6703: sipush 850
    //   6706: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6709: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6712: putstatic 2037	com/neovisionaries/i18n/CountryCode:VI	Lcom/neovisionaries/i18n/CountryCode;
    //   6715: new 2	com/neovisionaries/i18n/CountryCode
    //   6718: dup
    //   6719: ldc_w 2038
    //   6722: sipush 246
    //   6725: ldc_w 2040
    //   6728: ldc_w 2042
    //   6731: sipush 704
    //   6734: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6737: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6740: putstatic 2044	com/neovisionaries/i18n/CountryCode:VN	Lcom/neovisionaries/i18n/CountryCode;
    //   6743: new 2	com/neovisionaries/i18n/CountryCode
    //   6746: dup
    //   6747: ldc_w 2045
    //   6750: sipush 247
    //   6753: ldc_w 2047
    //   6756: ldc_w 2049
    //   6759: sipush 548
    //   6762: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6765: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6768: putstatic 2051	com/neovisionaries/i18n/CountryCode:VU	Lcom/neovisionaries/i18n/CountryCode;
    //   6771: new 2	com/neovisionaries/i18n/CountryCode
    //   6774: dup
    //   6775: ldc_w 2052
    //   6778: sipush 248
    //   6781: ldc_w 2054
    //   6784: ldc_w 2056
    //   6787: sipush 876
    //   6790: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6793: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6796: putstatic 2058	com/neovisionaries/i18n/CountryCode:WF	Lcom/neovisionaries/i18n/CountryCode;
    //   6799: new 2	com/neovisionaries/i18n/CountryCode
    //   6802: dup
    //   6803: ldc_w 2059
    //   6806: sipush 249
    //   6809: ldc_w 2061
    //   6812: ldc_w 2063
    //   6815: sipush 882
    //   6818: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6821: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6824: putstatic 2065	com/neovisionaries/i18n/CountryCode:WS	Lcom/neovisionaries/i18n/CountryCode;
    //   6827: new 2	com/neovisionaries/i18n/CountryCode
    //   6830: dup
    //   6831: ldc_w 2066
    //   6834: sipush 250
    //   6837: ldc_w 2068
    //   6840: ldc_w 2070
    //   6843: sipush 887
    //   6846: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6849: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6852: putstatic 2072	com/neovisionaries/i18n/CountryCode:YE	Lcom/neovisionaries/i18n/CountryCode;
    //   6855: new 2	com/neovisionaries/i18n/CountryCode
    //   6858: dup
    //   6859: ldc_w 2073
    //   6862: sipush 251
    //   6865: ldc_w 2075
    //   6868: ldc_w 2077
    //   6871: sipush 175
    //   6874: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6877: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6880: putstatic 2079	com/neovisionaries/i18n/CountryCode:YT	Lcom/neovisionaries/i18n/CountryCode;
    //   6883: new 2	com/neovisionaries/i18n/CountryCode
    //   6886: dup
    //   6887: ldc_w 2080
    //   6890: sipush 252
    //   6893: ldc_w 2082
    //   6896: ldc_w 2084
    //   6899: sipush 890
    //   6902: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6905: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6908: putstatic 2086	com/neovisionaries/i18n/CountryCode:YU	Lcom/neovisionaries/i18n/CountryCode;
    //   6911: new 2	com/neovisionaries/i18n/CountryCode
    //   6914: dup
    //   6915: ldc_w 2087
    //   6918: sipush 253
    //   6921: ldc_w 2089
    //   6924: ldc_w 2091
    //   6927: sipush 710
    //   6930: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6933: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6936: putstatic 2093	com/neovisionaries/i18n/CountryCode:ZA	Lcom/neovisionaries/i18n/CountryCode;
    //   6939: new 2	com/neovisionaries/i18n/CountryCode
    //   6942: dup
    //   6943: ldc_w 2094
    //   6946: sipush 254
    //   6949: ldc_w 2096
    //   6952: ldc_w 2098
    //   6955: sipush 894
    //   6958: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6961: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6964: putstatic 2100	com/neovisionaries/i18n/CountryCode:ZM	Lcom/neovisionaries/i18n/CountryCode;
    //   6967: new 2	com/neovisionaries/i18n/CountryCode
    //   6970: dup
    //   6971: ldc_w 2101
    //   6974: sipush 255
    //   6977: ldc_w 2103
    //   6980: ldc_w 2105
    //   6983: iconst_0
    //   6984: getstatic 345	com/neovisionaries/i18n/CountryCode$Assignment:TRANSITIONALLY_RESERVED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   6987: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   6990: putstatic 2107	com/neovisionaries/i18n/CountryCode:ZR	Lcom/neovisionaries/i18n/CountryCode;
    //   6993: new 2	com/neovisionaries/i18n/CountryCode
    //   6996: dup
    //   6997: ldc_w 2108
    //   7000: sipush 256
    //   7003: ldc_w 2110
    //   7006: ldc_w 2112
    //   7009: sipush 716
    //   7012: getstatic 289	com/neovisionaries/i18n/CountryCode$Assignment:OFFICIALLY_ASSIGNED	Lcom/neovisionaries/i18n/CountryCode$Assignment;
    //   7015: invokespecial 293	com/neovisionaries/i18n/CountryCode:<init>	(Ljava/lang/String;ILjava/lang/String;Ljava/lang/String;ILcom/neovisionaries/i18n/CountryCode$Assignment;)V
    //   7018: putstatic 2114	com/neovisionaries/i18n/CountryCode:ZW	Lcom/neovisionaries/i18n/CountryCode;
    //   7021: sipush 257
    //   7024: anewarray 2	com/neovisionaries/i18n/CountryCode
    //   7027: astore_1
    //   7028: aload_1
    //   7029: iconst_0
    //   7030: getstatic 295	com/neovisionaries/i18n/CountryCode:AD	Lcom/neovisionaries/i18n/CountryCode;
    //   7033: aastore
    //   7034: aload_1
    //   7035: iconst_1
    //   7036: getstatic 302	com/neovisionaries/i18n/CountryCode:AE	Lcom/neovisionaries/i18n/CountryCode;
    //   7039: aastore
    //   7040: aload_1
    //   7041: iconst_2
    //   7042: getstatic 309	com/neovisionaries/i18n/CountryCode:AF	Lcom/neovisionaries/i18n/CountryCode;
    //   7045: aastore
    //   7046: aload_1
    //   7047: iconst_3
    //   7048: getstatic 316	com/neovisionaries/i18n/CountryCode:AG	Lcom/neovisionaries/i18n/CountryCode;
    //   7051: aastore
    //   7052: aload_1
    //   7053: iconst_4
    //   7054: getstatic 323	com/neovisionaries/i18n/CountryCode:AI	Lcom/neovisionaries/i18n/CountryCode;
    //   7057: aastore
    //   7058: aload_1
    //   7059: iconst_5
    //   7060: getstatic 330	com/neovisionaries/i18n/CountryCode:AL	Lcom/neovisionaries/i18n/CountryCode;
    //   7063: aastore
    //   7064: aload_1
    //   7065: bipush 6
    //   7067: getstatic 337	com/neovisionaries/i18n/CountryCode:AM	Lcom/neovisionaries/i18n/CountryCode;
    //   7070: aastore
    //   7071: aload_1
    //   7072: bipush 7
    //   7074: getstatic 347	com/neovisionaries/i18n/CountryCode:AN	Lcom/neovisionaries/i18n/CountryCode;
    //   7077: aastore
    //   7078: aload_1
    //   7079: bipush 8
    //   7081: getstatic 354	com/neovisionaries/i18n/CountryCode:AO	Lcom/neovisionaries/i18n/CountryCode;
    //   7084: aastore
    //   7085: aload_1
    //   7086: bipush 9
    //   7088: getstatic 361	com/neovisionaries/i18n/CountryCode:AQ	Lcom/neovisionaries/i18n/CountryCode;
    //   7091: aastore
    //   7092: aload_1
    //   7093: bipush 10
    //   7095: getstatic 368	com/neovisionaries/i18n/CountryCode:AR	Lcom/neovisionaries/i18n/CountryCode;
    //   7098: aastore
    //   7099: aload_1
    //   7100: bipush 11
    //   7102: getstatic 375	com/neovisionaries/i18n/CountryCode:AS	Lcom/neovisionaries/i18n/CountryCode;
    //   7105: aastore
    //   7106: aload_1
    //   7107: bipush 12
    //   7109: getstatic 382	com/neovisionaries/i18n/CountryCode:AT	Lcom/neovisionaries/i18n/CountryCode;
    //   7112: aastore
    //   7113: aload_1
    //   7114: bipush 13
    //   7116: getstatic 389	com/neovisionaries/i18n/CountryCode:AU	Lcom/neovisionaries/i18n/CountryCode;
    //   7119: aastore
    //   7120: aload_1
    //   7121: bipush 14
    //   7123: getstatic 396	com/neovisionaries/i18n/CountryCode:AW	Lcom/neovisionaries/i18n/CountryCode;
    //   7126: aastore
    //   7127: aload_1
    //   7128: bipush 15
    //   7130: getstatic 403	com/neovisionaries/i18n/CountryCode:AX	Lcom/neovisionaries/i18n/CountryCode;
    //   7133: aastore
    //   7134: aload_1
    //   7135: bipush 16
    //   7137: getstatic 410	com/neovisionaries/i18n/CountryCode:AZ	Lcom/neovisionaries/i18n/CountryCode;
    //   7140: aastore
    //   7141: aload_1
    //   7142: bipush 17
    //   7144: getstatic 417	com/neovisionaries/i18n/CountryCode:BA	Lcom/neovisionaries/i18n/CountryCode;
    //   7147: aastore
    //   7148: aload_1
    //   7149: bipush 18
    //   7151: getstatic 424	com/neovisionaries/i18n/CountryCode:BB	Lcom/neovisionaries/i18n/CountryCode;
    //   7154: aastore
    //   7155: aload_1
    //   7156: bipush 19
    //   7158: getstatic 431	com/neovisionaries/i18n/CountryCode:BD	Lcom/neovisionaries/i18n/CountryCode;
    //   7161: aastore
    //   7162: aload_1
    //   7163: bipush 20
    //   7165: getstatic 438	com/neovisionaries/i18n/CountryCode:BE	Lcom/neovisionaries/i18n/CountryCode;
    //   7168: aastore
    //   7169: aload_1
    //   7170: bipush 21
    //   7172: getstatic 445	com/neovisionaries/i18n/CountryCode:BF	Lcom/neovisionaries/i18n/CountryCode;
    //   7175: aastore
    //   7176: aload_1
    //   7177: bipush 22
    //   7179: getstatic 452	com/neovisionaries/i18n/CountryCode:BG	Lcom/neovisionaries/i18n/CountryCode;
    //   7182: aastore
    //   7183: aload_1
    //   7184: bipush 23
    //   7186: getstatic 459	com/neovisionaries/i18n/CountryCode:BH	Lcom/neovisionaries/i18n/CountryCode;
    //   7189: aastore
    //   7190: aload_1
    //   7191: bipush 24
    //   7193: getstatic 466	com/neovisionaries/i18n/CountryCode:BI	Lcom/neovisionaries/i18n/CountryCode;
    //   7196: aastore
    //   7197: aload_1
    //   7198: bipush 25
    //   7200: getstatic 473	com/neovisionaries/i18n/CountryCode:BJ	Lcom/neovisionaries/i18n/CountryCode;
    //   7203: aastore
    //   7204: aload_1
    //   7205: bipush 26
    //   7207: getstatic 480	com/neovisionaries/i18n/CountryCode:BL	Lcom/neovisionaries/i18n/CountryCode;
    //   7210: aastore
    //   7211: aload_1
    //   7212: bipush 27
    //   7214: getstatic 487	com/neovisionaries/i18n/CountryCode:BM	Lcom/neovisionaries/i18n/CountryCode;
    //   7217: aastore
    //   7218: aload_1
    //   7219: bipush 28
    //   7221: getstatic 494	com/neovisionaries/i18n/CountryCode:BN	Lcom/neovisionaries/i18n/CountryCode;
    //   7224: aastore
    //   7225: aload_1
    //   7226: bipush 29
    //   7228: getstatic 501	com/neovisionaries/i18n/CountryCode:BO	Lcom/neovisionaries/i18n/CountryCode;
    //   7231: aastore
    //   7232: aload_1
    //   7233: bipush 30
    //   7235: getstatic 508	com/neovisionaries/i18n/CountryCode:BQ	Lcom/neovisionaries/i18n/CountryCode;
    //   7238: aastore
    //   7239: aload_1
    //   7240: bipush 31
    //   7242: getstatic 515	com/neovisionaries/i18n/CountryCode:BR	Lcom/neovisionaries/i18n/CountryCode;
    //   7245: aastore
    //   7246: aload_1
    //   7247: bipush 32
    //   7249: getstatic 522	com/neovisionaries/i18n/CountryCode:BS	Lcom/neovisionaries/i18n/CountryCode;
    //   7252: aastore
    //   7253: aload_1
    //   7254: bipush 33
    //   7256: getstatic 529	com/neovisionaries/i18n/CountryCode:BT	Lcom/neovisionaries/i18n/CountryCode;
    //   7259: aastore
    //   7260: aload_1
    //   7261: bipush 34
    //   7263: getstatic 536	com/neovisionaries/i18n/CountryCode:BU	Lcom/neovisionaries/i18n/CountryCode;
    //   7266: aastore
    //   7267: aload_1
    //   7268: bipush 35
    //   7270: getstatic 543	com/neovisionaries/i18n/CountryCode:BV	Lcom/neovisionaries/i18n/CountryCode;
    //   7273: aastore
    //   7274: aload_1
    //   7275: bipush 36
    //   7277: getstatic 550	com/neovisionaries/i18n/CountryCode:BW	Lcom/neovisionaries/i18n/CountryCode;
    //   7280: aastore
    //   7281: aload_1
    //   7282: bipush 37
    //   7284: getstatic 557	com/neovisionaries/i18n/CountryCode:BY	Lcom/neovisionaries/i18n/CountryCode;
    //   7287: aastore
    //   7288: aload_1
    //   7289: bipush 38
    //   7291: getstatic 564	com/neovisionaries/i18n/CountryCode:BZ	Lcom/neovisionaries/i18n/CountryCode;
    //   7294: aastore
    //   7295: aload_1
    //   7296: bipush 39
    //   7298: getstatic 574	com/neovisionaries/i18n/CountryCode:CA	Lcom/neovisionaries/i18n/CountryCode;
    //   7301: aastore
    //   7302: aload_1
    //   7303: bipush 40
    //   7305: getstatic 581	com/neovisionaries/i18n/CountryCode:CC	Lcom/neovisionaries/i18n/CountryCode;
    //   7308: aastore
    //   7309: aload_1
    //   7310: bipush 41
    //   7312: getstatic 588	com/neovisionaries/i18n/CountryCode:CD	Lcom/neovisionaries/i18n/CountryCode;
    //   7315: aastore
    //   7316: aload_1
    //   7317: bipush 42
    //   7319: getstatic 595	com/neovisionaries/i18n/CountryCode:CF	Lcom/neovisionaries/i18n/CountryCode;
    //   7322: aastore
    //   7323: aload_1
    //   7324: bipush 43
    //   7326: getstatic 602	com/neovisionaries/i18n/CountryCode:CG	Lcom/neovisionaries/i18n/CountryCode;
    //   7329: aastore
    //   7330: aload_1
    //   7331: bipush 44
    //   7333: getstatic 609	com/neovisionaries/i18n/CountryCode:CH	Lcom/neovisionaries/i18n/CountryCode;
    //   7336: aastore
    //   7337: aload_1
    //   7338: bipush 45
    //   7340: getstatic 616	com/neovisionaries/i18n/CountryCode:CI	Lcom/neovisionaries/i18n/CountryCode;
    //   7343: aastore
    //   7344: aload_1
    //   7345: bipush 46
    //   7347: getstatic 623	com/neovisionaries/i18n/CountryCode:CK	Lcom/neovisionaries/i18n/CountryCode;
    //   7350: aastore
    //   7351: aload_1
    //   7352: bipush 47
    //   7354: getstatic 630	com/neovisionaries/i18n/CountryCode:CL	Lcom/neovisionaries/i18n/CountryCode;
    //   7357: aastore
    //   7358: aload_1
    //   7359: bipush 48
    //   7361: getstatic 637	com/neovisionaries/i18n/CountryCode:CM	Lcom/neovisionaries/i18n/CountryCode;
    //   7364: aastore
    //   7365: aload_1
    //   7366: bipush 49
    //   7368: getstatic 647	com/neovisionaries/i18n/CountryCode:CN	Lcom/neovisionaries/i18n/CountryCode;
    //   7371: aastore
    //   7372: aload_1
    //   7373: bipush 50
    //   7375: getstatic 654	com/neovisionaries/i18n/CountryCode:CO	Lcom/neovisionaries/i18n/CountryCode;
    //   7378: aastore
    //   7379: aload_1
    //   7380: bipush 51
    //   7382: getstatic 661	com/neovisionaries/i18n/CountryCode:CR	Lcom/neovisionaries/i18n/CountryCode;
    //   7385: aastore
    //   7386: aload_1
    //   7387: bipush 52
    //   7389: getstatic 668	com/neovisionaries/i18n/CountryCode:CS	Lcom/neovisionaries/i18n/CountryCode;
    //   7392: aastore
    //   7393: aload_1
    //   7394: bipush 53
    //   7396: getstatic 675	com/neovisionaries/i18n/CountryCode:CU	Lcom/neovisionaries/i18n/CountryCode;
    //   7399: aastore
    //   7400: aload_1
    //   7401: bipush 54
    //   7403: getstatic 682	com/neovisionaries/i18n/CountryCode:CV	Lcom/neovisionaries/i18n/CountryCode;
    //   7406: aastore
    //   7407: aload_1
    //   7408: bipush 55
    //   7410: getstatic 689	com/neovisionaries/i18n/CountryCode:CW	Lcom/neovisionaries/i18n/CountryCode;
    //   7413: aastore
    //   7414: aload_1
    //   7415: bipush 56
    //   7417: getstatic 696	com/neovisionaries/i18n/CountryCode:CX	Lcom/neovisionaries/i18n/CountryCode;
    //   7420: aastore
    //   7421: aload_1
    //   7422: bipush 57
    //   7424: getstatic 703	com/neovisionaries/i18n/CountryCode:CY	Lcom/neovisionaries/i18n/CountryCode;
    //   7427: aastore
    //   7428: aload_1
    //   7429: bipush 58
    //   7431: getstatic 710	com/neovisionaries/i18n/CountryCode:CZ	Lcom/neovisionaries/i18n/CountryCode;
    //   7434: aastore
    //   7435: aload_1
    //   7436: bipush 59
    //   7438: getstatic 720	com/neovisionaries/i18n/CountryCode:DE	Lcom/neovisionaries/i18n/CountryCode;
    //   7441: aastore
    //   7442: aload_1
    //   7443: bipush 60
    //   7445: getstatic 727	com/neovisionaries/i18n/CountryCode:DJ	Lcom/neovisionaries/i18n/CountryCode;
    //   7448: aastore
    //   7449: aload_1
    //   7450: bipush 61
    //   7452: getstatic 734	com/neovisionaries/i18n/CountryCode:DK	Lcom/neovisionaries/i18n/CountryCode;
    //   7455: aastore
    //   7456: aload_1
    //   7457: bipush 62
    //   7459: getstatic 741	com/neovisionaries/i18n/CountryCode:DM	Lcom/neovisionaries/i18n/CountryCode;
    //   7462: aastore
    //   7463: aload_1
    //   7464: bipush 63
    //   7466: getstatic 748	com/neovisionaries/i18n/CountryCode:DO	Lcom/neovisionaries/i18n/CountryCode;
    //   7469: aastore
    //   7470: aload_1
    //   7471: bipush 64
    //   7473: getstatic 755	com/neovisionaries/i18n/CountryCode:DZ	Lcom/neovisionaries/i18n/CountryCode;
    //   7476: aastore
    //   7477: aload_1
    //   7478: bipush 65
    //   7480: getstatic 762	com/neovisionaries/i18n/CountryCode:EC	Lcom/neovisionaries/i18n/CountryCode;
    //   7483: aastore
    //   7484: aload_1
    //   7485: bipush 66
    //   7487: getstatic 769	com/neovisionaries/i18n/CountryCode:EE	Lcom/neovisionaries/i18n/CountryCode;
    //   7490: aastore
    //   7491: aload_1
    //   7492: bipush 67
    //   7494: getstatic 776	com/neovisionaries/i18n/CountryCode:EG	Lcom/neovisionaries/i18n/CountryCode;
    //   7497: aastore
    //   7498: aload_1
    //   7499: bipush 68
    //   7501: getstatic 783	com/neovisionaries/i18n/CountryCode:EH	Lcom/neovisionaries/i18n/CountryCode;
    //   7504: aastore
    //   7505: aload_1
    //   7506: bipush 69
    //   7508: getstatic 790	com/neovisionaries/i18n/CountryCode:ER	Lcom/neovisionaries/i18n/CountryCode;
    //   7511: aastore
    //   7512: aload_1
    //   7513: bipush 70
    //   7515: getstatic 797	com/neovisionaries/i18n/CountryCode:ES	Lcom/neovisionaries/i18n/CountryCode;
    //   7518: aastore
    //   7519: aload_1
    //   7520: bipush 71
    //   7522: getstatic 804	com/neovisionaries/i18n/CountryCode:ET	Lcom/neovisionaries/i18n/CountryCode;
    //   7525: aastore
    //   7526: aload_1
    //   7527: bipush 72
    //   7529: getstatic 811	com/neovisionaries/i18n/CountryCode:FI	Lcom/neovisionaries/i18n/CountryCode;
    //   7532: aastore
    //   7533: aload_1
    //   7534: bipush 73
    //   7536: getstatic 818	com/neovisionaries/i18n/CountryCode:FJ	Lcom/neovisionaries/i18n/CountryCode;
    //   7539: aastore
    //   7540: aload_1
    //   7541: bipush 74
    //   7543: getstatic 825	com/neovisionaries/i18n/CountryCode:FK	Lcom/neovisionaries/i18n/CountryCode;
    //   7546: aastore
    //   7547: aload_1
    //   7548: bipush 75
    //   7550: getstatic 832	com/neovisionaries/i18n/CountryCode:FM	Lcom/neovisionaries/i18n/CountryCode;
    //   7553: aastore
    //   7554: aload_1
    //   7555: bipush 76
    //   7557: getstatic 839	com/neovisionaries/i18n/CountryCode:FO	Lcom/neovisionaries/i18n/CountryCode;
    //   7560: aastore
    //   7561: aload_1
    //   7562: bipush 77
    //   7564: getstatic 849	com/neovisionaries/i18n/CountryCode:FR	Lcom/neovisionaries/i18n/CountryCode;
    //   7567: aastore
    //   7568: aload_1
    //   7569: bipush 78
    //   7571: getstatic 856	com/neovisionaries/i18n/CountryCode:GA	Lcom/neovisionaries/i18n/CountryCode;
    //   7574: aastore
    //   7575: aload_1
    //   7576: bipush 79
    //   7578: getstatic 866	com/neovisionaries/i18n/CountryCode:GB	Lcom/neovisionaries/i18n/CountryCode;
    //   7581: aastore
    //   7582: aload_1
    //   7583: bipush 80
    //   7585: getstatic 873	com/neovisionaries/i18n/CountryCode:GD	Lcom/neovisionaries/i18n/CountryCode;
    //   7588: aastore
    //   7589: aload_1
    //   7590: bipush 81
    //   7592: getstatic 880	com/neovisionaries/i18n/CountryCode:GE	Lcom/neovisionaries/i18n/CountryCode;
    //   7595: aastore
    //   7596: aload_1
    //   7597: bipush 82
    //   7599: getstatic 887	com/neovisionaries/i18n/CountryCode:GF	Lcom/neovisionaries/i18n/CountryCode;
    //   7602: aastore
    //   7603: aload_1
    //   7604: bipush 83
    //   7606: getstatic 894	com/neovisionaries/i18n/CountryCode:GG	Lcom/neovisionaries/i18n/CountryCode;
    //   7609: aastore
    //   7610: aload_1
    //   7611: bipush 84
    //   7613: getstatic 901	com/neovisionaries/i18n/CountryCode:GH	Lcom/neovisionaries/i18n/CountryCode;
    //   7616: aastore
    //   7617: aload_1
    //   7618: bipush 85
    //   7620: getstatic 908	com/neovisionaries/i18n/CountryCode:GI	Lcom/neovisionaries/i18n/CountryCode;
    //   7623: aastore
    //   7624: aload_1
    //   7625: bipush 86
    //   7627: getstatic 915	com/neovisionaries/i18n/CountryCode:GL	Lcom/neovisionaries/i18n/CountryCode;
    //   7630: aastore
    //   7631: aload_1
    //   7632: bipush 87
    //   7634: getstatic 922	com/neovisionaries/i18n/CountryCode:GM	Lcom/neovisionaries/i18n/CountryCode;
    //   7637: aastore
    //   7638: aload_1
    //   7639: bipush 88
    //   7641: getstatic 929	com/neovisionaries/i18n/CountryCode:GN	Lcom/neovisionaries/i18n/CountryCode;
    //   7644: aastore
    //   7645: aload_1
    //   7646: bipush 89
    //   7648: getstatic 936	com/neovisionaries/i18n/CountryCode:GP	Lcom/neovisionaries/i18n/CountryCode;
    //   7651: aastore
    //   7652: aload_1
    //   7653: bipush 90
    //   7655: getstatic 943	com/neovisionaries/i18n/CountryCode:GQ	Lcom/neovisionaries/i18n/CountryCode;
    //   7658: aastore
    //   7659: aload_1
    //   7660: bipush 91
    //   7662: getstatic 950	com/neovisionaries/i18n/CountryCode:GR	Lcom/neovisionaries/i18n/CountryCode;
    //   7665: aastore
    //   7666: aload_1
    //   7667: bipush 92
    //   7669: getstatic 957	com/neovisionaries/i18n/CountryCode:GS	Lcom/neovisionaries/i18n/CountryCode;
    //   7672: aastore
    //   7673: aload_1
    //   7674: bipush 93
    //   7676: getstatic 964	com/neovisionaries/i18n/CountryCode:GT	Lcom/neovisionaries/i18n/CountryCode;
    //   7679: aastore
    //   7680: aload_1
    //   7681: bipush 94
    //   7683: getstatic 971	com/neovisionaries/i18n/CountryCode:GU	Lcom/neovisionaries/i18n/CountryCode;
    //   7686: aastore
    //   7687: aload_1
    //   7688: bipush 95
    //   7690: getstatic 978	com/neovisionaries/i18n/CountryCode:GW	Lcom/neovisionaries/i18n/CountryCode;
    //   7693: aastore
    //   7694: aload_1
    //   7695: bipush 96
    //   7697: getstatic 985	com/neovisionaries/i18n/CountryCode:GY	Lcom/neovisionaries/i18n/CountryCode;
    //   7700: aastore
    //   7701: aload_1
    //   7702: bipush 97
    //   7704: getstatic 992	com/neovisionaries/i18n/CountryCode:HK	Lcom/neovisionaries/i18n/CountryCode;
    //   7707: aastore
    //   7708: aload_1
    //   7709: bipush 98
    //   7711: getstatic 999	com/neovisionaries/i18n/CountryCode:HM	Lcom/neovisionaries/i18n/CountryCode;
    //   7714: aastore
    //   7715: aload_1
    //   7716: bipush 99
    //   7718: getstatic 1006	com/neovisionaries/i18n/CountryCode:HN	Lcom/neovisionaries/i18n/CountryCode;
    //   7721: aastore
    //   7722: aload_1
    //   7723: bipush 100
    //   7725: getstatic 1013	com/neovisionaries/i18n/CountryCode:HR	Lcom/neovisionaries/i18n/CountryCode;
    //   7728: aastore
    //   7729: aload_1
    //   7730: bipush 101
    //   7732: getstatic 1020	com/neovisionaries/i18n/CountryCode:HT	Lcom/neovisionaries/i18n/CountryCode;
    //   7735: aastore
    //   7736: aload_1
    //   7737: bipush 102
    //   7739: getstatic 1027	com/neovisionaries/i18n/CountryCode:HU	Lcom/neovisionaries/i18n/CountryCode;
    //   7742: aastore
    //   7743: aload_1
    //   7744: bipush 103
    //   7746: getstatic 1034	com/neovisionaries/i18n/CountryCode:ID	Lcom/neovisionaries/i18n/CountryCode;
    //   7749: aastore
    //   7750: aload_1
    //   7751: bipush 104
    //   7753: getstatic 1041	com/neovisionaries/i18n/CountryCode:IE	Lcom/neovisionaries/i18n/CountryCode;
    //   7756: aastore
    //   7757: aload_1
    //   7758: bipush 105
    //   7760: getstatic 1048	com/neovisionaries/i18n/CountryCode:IL	Lcom/neovisionaries/i18n/CountryCode;
    //   7763: aastore
    //   7764: aload_1
    //   7765: bipush 106
    //   7767: getstatic 1055	com/neovisionaries/i18n/CountryCode:IM	Lcom/neovisionaries/i18n/CountryCode;
    //   7770: aastore
    //   7771: aload_1
    //   7772: bipush 107
    //   7774: getstatic 1062	com/neovisionaries/i18n/CountryCode:IN	Lcom/neovisionaries/i18n/CountryCode;
    //   7777: aastore
    //   7778: aload_1
    //   7779: bipush 108
    //   7781: getstatic 1069	com/neovisionaries/i18n/CountryCode:IO	Lcom/neovisionaries/i18n/CountryCode;
    //   7784: aastore
    //   7785: aload_1
    //   7786: bipush 109
    //   7788: getstatic 1076	com/neovisionaries/i18n/CountryCode:IQ	Lcom/neovisionaries/i18n/CountryCode;
    //   7791: aastore
    //   7792: aload_1
    //   7793: bipush 110
    //   7795: getstatic 1083	com/neovisionaries/i18n/CountryCode:IR	Lcom/neovisionaries/i18n/CountryCode;
    //   7798: aastore
    //   7799: aload_1
    //   7800: bipush 111
    //   7802: getstatic 1090	com/neovisionaries/i18n/CountryCode:IS	Lcom/neovisionaries/i18n/CountryCode;
    //   7805: aastore
    //   7806: aload_1
    //   7807: bipush 112
    //   7809: getstatic 1100	com/neovisionaries/i18n/CountryCode:IT	Lcom/neovisionaries/i18n/CountryCode;
    //   7812: aastore
    //   7813: aload_1
    //   7814: bipush 113
    //   7816: getstatic 1107	com/neovisionaries/i18n/CountryCode:JE	Lcom/neovisionaries/i18n/CountryCode;
    //   7819: aastore
    //   7820: aload_1
    //   7821: bipush 114
    //   7823: getstatic 1114	com/neovisionaries/i18n/CountryCode:JM	Lcom/neovisionaries/i18n/CountryCode;
    //   7826: aastore
    //   7827: aload_1
    //   7828: bipush 115
    //   7830: getstatic 1121	com/neovisionaries/i18n/CountryCode:JO	Lcom/neovisionaries/i18n/CountryCode;
    //   7833: aastore
    //   7834: aload_1
    //   7835: bipush 116
    //   7837: getstatic 1131	com/neovisionaries/i18n/CountryCode:JP	Lcom/neovisionaries/i18n/CountryCode;
    //   7840: aastore
    //   7841: aload_1
    //   7842: bipush 117
    //   7844: getstatic 1138	com/neovisionaries/i18n/CountryCode:KE	Lcom/neovisionaries/i18n/CountryCode;
    //   7847: aastore
    //   7848: aload_1
    //   7849: bipush 118
    //   7851: getstatic 1145	com/neovisionaries/i18n/CountryCode:KG	Lcom/neovisionaries/i18n/CountryCode;
    //   7854: aastore
    //   7855: aload_1
    //   7856: bipush 119
    //   7858: getstatic 1152	com/neovisionaries/i18n/CountryCode:KH	Lcom/neovisionaries/i18n/CountryCode;
    //   7861: aastore
    //   7862: aload_1
    //   7863: bipush 120
    //   7865: getstatic 1159	com/neovisionaries/i18n/CountryCode:KI	Lcom/neovisionaries/i18n/CountryCode;
    //   7868: aastore
    //   7869: aload_1
    //   7870: bipush 121
    //   7872: getstatic 1166	com/neovisionaries/i18n/CountryCode:KM	Lcom/neovisionaries/i18n/CountryCode;
    //   7875: aastore
    //   7876: aload_1
    //   7877: bipush 122
    //   7879: getstatic 1173	com/neovisionaries/i18n/CountryCode:KN	Lcom/neovisionaries/i18n/CountryCode;
    //   7882: aastore
    //   7883: aload_1
    //   7884: bipush 123
    //   7886: getstatic 1180	com/neovisionaries/i18n/CountryCode:KP	Lcom/neovisionaries/i18n/CountryCode;
    //   7889: aastore
    //   7890: aload_1
    //   7891: bipush 124
    //   7893: getstatic 1190	com/neovisionaries/i18n/CountryCode:KR	Lcom/neovisionaries/i18n/CountryCode;
    //   7896: aastore
    //   7897: aload_1
    //   7898: bipush 125
    //   7900: getstatic 1197	com/neovisionaries/i18n/CountryCode:KW	Lcom/neovisionaries/i18n/CountryCode;
    //   7903: aastore
    //   7904: aload_1
    //   7905: bipush 126
    //   7907: getstatic 1204	com/neovisionaries/i18n/CountryCode:KY	Lcom/neovisionaries/i18n/CountryCode;
    //   7910: aastore
    //   7911: aload_1
    //   7912: bipush 127
    //   7914: getstatic 1211	com/neovisionaries/i18n/CountryCode:KZ	Lcom/neovisionaries/i18n/CountryCode;
    //   7917: aastore
    //   7918: aload_1
    //   7919: sipush 128
    //   7922: getstatic 1218	com/neovisionaries/i18n/CountryCode:LA	Lcom/neovisionaries/i18n/CountryCode;
    //   7925: aastore
    //   7926: aload_1
    //   7927: sipush 129
    //   7930: getstatic 1225	com/neovisionaries/i18n/CountryCode:LB	Lcom/neovisionaries/i18n/CountryCode;
    //   7933: aastore
    //   7934: aload_1
    //   7935: sipush 130
    //   7938: getstatic 1232	com/neovisionaries/i18n/CountryCode:LC	Lcom/neovisionaries/i18n/CountryCode;
    //   7941: aastore
    //   7942: aload_1
    //   7943: sipush 131
    //   7946: getstatic 1239	com/neovisionaries/i18n/CountryCode:LI	Lcom/neovisionaries/i18n/CountryCode;
    //   7949: aastore
    //   7950: aload_1
    //   7951: sipush 132
    //   7954: getstatic 1246	com/neovisionaries/i18n/CountryCode:LK	Lcom/neovisionaries/i18n/CountryCode;
    //   7957: aastore
    //   7958: aload_1
    //   7959: sipush 133
    //   7962: getstatic 1253	com/neovisionaries/i18n/CountryCode:LR	Lcom/neovisionaries/i18n/CountryCode;
    //   7965: aastore
    //   7966: aload_1
    //   7967: sipush 134
    //   7970: getstatic 1260	com/neovisionaries/i18n/CountryCode:LS	Lcom/neovisionaries/i18n/CountryCode;
    //   7973: aastore
    //   7974: aload_1
    //   7975: sipush 135
    //   7978: getstatic 1267	com/neovisionaries/i18n/CountryCode:LT	Lcom/neovisionaries/i18n/CountryCode;
    //   7981: aastore
    //   7982: aload_1
    //   7983: sipush 136
    //   7986: getstatic 1274	com/neovisionaries/i18n/CountryCode:LU	Lcom/neovisionaries/i18n/CountryCode;
    //   7989: aastore
    //   7990: aload_1
    //   7991: sipush 137
    //   7994: getstatic 1281	com/neovisionaries/i18n/CountryCode:LV	Lcom/neovisionaries/i18n/CountryCode;
    //   7997: aastore
    //   7998: aload_1
    //   7999: sipush 138
    //   8002: getstatic 1288	com/neovisionaries/i18n/CountryCode:LY	Lcom/neovisionaries/i18n/CountryCode;
    //   8005: aastore
    //   8006: aload_1
    //   8007: sipush 139
    //   8010: getstatic 1295	com/neovisionaries/i18n/CountryCode:MA	Lcom/neovisionaries/i18n/CountryCode;
    //   8013: aastore
    //   8014: aload_1
    //   8015: sipush 140
    //   8018: getstatic 1302	com/neovisionaries/i18n/CountryCode:MC	Lcom/neovisionaries/i18n/CountryCode;
    //   8021: aastore
    //   8022: aload_1
    //   8023: sipush 141
    //   8026: getstatic 1309	com/neovisionaries/i18n/CountryCode:MD	Lcom/neovisionaries/i18n/CountryCode;
    //   8029: aastore
    //   8030: aload_1
    //   8031: sipush 142
    //   8034: getstatic 1316	com/neovisionaries/i18n/CountryCode:ME	Lcom/neovisionaries/i18n/CountryCode;
    //   8037: aastore
    //   8038: aload_1
    //   8039: sipush 143
    //   8042: getstatic 1323	com/neovisionaries/i18n/CountryCode:MF	Lcom/neovisionaries/i18n/CountryCode;
    //   8045: aastore
    //   8046: aload_1
    //   8047: sipush 144
    //   8050: getstatic 1330	com/neovisionaries/i18n/CountryCode:MG	Lcom/neovisionaries/i18n/CountryCode;
    //   8053: aastore
    //   8054: aload_1
    //   8055: sipush 145
    //   8058: getstatic 1337	com/neovisionaries/i18n/CountryCode:MH	Lcom/neovisionaries/i18n/CountryCode;
    //   8061: aastore
    //   8062: aload_1
    //   8063: sipush 146
    //   8066: getstatic 1344	com/neovisionaries/i18n/CountryCode:MK	Lcom/neovisionaries/i18n/CountryCode;
    //   8069: aastore
    //   8070: aload_1
    //   8071: sipush 147
    //   8074: getstatic 1351	com/neovisionaries/i18n/CountryCode:ML	Lcom/neovisionaries/i18n/CountryCode;
    //   8077: aastore
    //   8078: aload_1
    //   8079: sipush 148
    //   8082: getstatic 1358	com/neovisionaries/i18n/CountryCode:MM	Lcom/neovisionaries/i18n/CountryCode;
    //   8085: aastore
    //   8086: aload_1
    //   8087: sipush 149
    //   8090: getstatic 1365	com/neovisionaries/i18n/CountryCode:MN	Lcom/neovisionaries/i18n/CountryCode;
    //   8093: aastore
    //   8094: aload_1
    //   8095: sipush 150
    //   8098: getstatic 1370	com/neovisionaries/i18n/CountryCode:MO	Lcom/neovisionaries/i18n/CountryCode;
    //   8101: aastore
    //   8102: aload_1
    //   8103: sipush 151
    //   8106: getstatic 1377	com/neovisionaries/i18n/CountryCode:MP	Lcom/neovisionaries/i18n/CountryCode;
    //   8109: aastore
    //   8110: aload_1
    //   8111: sipush 152
    //   8114: getstatic 1384	com/neovisionaries/i18n/CountryCode:MQ	Lcom/neovisionaries/i18n/CountryCode;
    //   8117: aastore
    //   8118: aload_1
    //   8119: sipush 153
    //   8122: getstatic 1391	com/neovisionaries/i18n/CountryCode:MR	Lcom/neovisionaries/i18n/CountryCode;
    //   8125: aastore
    //   8126: aload_1
    //   8127: sipush 154
    //   8130: getstatic 1398	com/neovisionaries/i18n/CountryCode:MS	Lcom/neovisionaries/i18n/CountryCode;
    //   8133: aastore
    //   8134: aload_1
    //   8135: sipush 155
    //   8138: getstatic 1405	com/neovisionaries/i18n/CountryCode:MT	Lcom/neovisionaries/i18n/CountryCode;
    //   8141: aastore
    //   8142: aload_1
    //   8143: sipush 156
    //   8146: getstatic 1412	com/neovisionaries/i18n/CountryCode:MU	Lcom/neovisionaries/i18n/CountryCode;
    //   8149: aastore
    //   8150: aload_1
    //   8151: sipush 157
    //   8154: getstatic 1419	com/neovisionaries/i18n/CountryCode:MV	Lcom/neovisionaries/i18n/CountryCode;
    //   8157: aastore
    //   8158: aload_1
    //   8159: sipush 158
    //   8162: getstatic 1426	com/neovisionaries/i18n/CountryCode:MW	Lcom/neovisionaries/i18n/CountryCode;
    //   8165: aastore
    //   8166: aload_1
    //   8167: sipush 159
    //   8170: getstatic 1433	com/neovisionaries/i18n/CountryCode:MX	Lcom/neovisionaries/i18n/CountryCode;
    //   8173: aastore
    //   8174: aload_1
    //   8175: sipush 160
    //   8178: getstatic 1440	com/neovisionaries/i18n/CountryCode:MY	Lcom/neovisionaries/i18n/CountryCode;
    //   8181: aastore
    //   8182: aload_1
    //   8183: sipush 161
    //   8186: getstatic 1447	com/neovisionaries/i18n/CountryCode:MZ	Lcom/neovisionaries/i18n/CountryCode;
    //   8189: aastore
    //   8190: aload_1
    //   8191: sipush 162
    //   8194: getstatic 1454	com/neovisionaries/i18n/CountryCode:NA	Lcom/neovisionaries/i18n/CountryCode;
    //   8197: aastore
    //   8198: aload_1
    //   8199: sipush 163
    //   8202: getstatic 1461	com/neovisionaries/i18n/CountryCode:NC	Lcom/neovisionaries/i18n/CountryCode;
    //   8205: aastore
    //   8206: aload_1
    //   8207: sipush 164
    //   8210: getstatic 1468	com/neovisionaries/i18n/CountryCode:NE	Lcom/neovisionaries/i18n/CountryCode;
    //   8213: aastore
    //   8214: aload_1
    //   8215: sipush 165
    //   8218: getstatic 1475	com/neovisionaries/i18n/CountryCode:NF	Lcom/neovisionaries/i18n/CountryCode;
    //   8221: aastore
    //   8222: aload_1
    //   8223: sipush 166
    //   8226: getstatic 1482	com/neovisionaries/i18n/CountryCode:NG	Lcom/neovisionaries/i18n/CountryCode;
    //   8229: aastore
    //   8230: aload_1
    //   8231: sipush 167
    //   8234: getstatic 1489	com/neovisionaries/i18n/CountryCode:NI	Lcom/neovisionaries/i18n/CountryCode;
    //   8237: aastore
    //   8238: aload_1
    //   8239: sipush 168
    //   8242: getstatic 1496	com/neovisionaries/i18n/CountryCode:NL	Lcom/neovisionaries/i18n/CountryCode;
    //   8245: aastore
    //   8246: aload_1
    //   8247: sipush 169
    //   8250: getstatic 1503	com/neovisionaries/i18n/CountryCode:NO	Lcom/neovisionaries/i18n/CountryCode;
    //   8253: aastore
    //   8254: aload_1
    //   8255: sipush 170
    //   8258: getstatic 1510	com/neovisionaries/i18n/CountryCode:NP	Lcom/neovisionaries/i18n/CountryCode;
    //   8261: aastore
    //   8262: aload_1
    //   8263: sipush 171
    //   8266: getstatic 1517	com/neovisionaries/i18n/CountryCode:NR	Lcom/neovisionaries/i18n/CountryCode;
    //   8269: aastore
    //   8270: aload_1
    //   8271: sipush 172
    //   8274: getstatic 1524	com/neovisionaries/i18n/CountryCode:NT	Lcom/neovisionaries/i18n/CountryCode;
    //   8277: aastore
    //   8278: aload_1
    //   8279: sipush 173
    //   8282: getstatic 1531	com/neovisionaries/i18n/CountryCode:NU	Lcom/neovisionaries/i18n/CountryCode;
    //   8285: aastore
    //   8286: aload_1
    //   8287: sipush 174
    //   8290: getstatic 1538	com/neovisionaries/i18n/CountryCode:NZ	Lcom/neovisionaries/i18n/CountryCode;
    //   8293: aastore
    //   8294: aload_1
    //   8295: sipush 175
    //   8298: getstatic 1545	com/neovisionaries/i18n/CountryCode:OM	Lcom/neovisionaries/i18n/CountryCode;
    //   8301: aastore
    //   8302: aload_1
    //   8303: sipush 176
    //   8306: getstatic 1552	com/neovisionaries/i18n/CountryCode:PA	Lcom/neovisionaries/i18n/CountryCode;
    //   8309: aastore
    //   8310: aload_1
    //   8311: sipush 177
    //   8314: getstatic 1559	com/neovisionaries/i18n/CountryCode:PE	Lcom/neovisionaries/i18n/CountryCode;
    //   8317: aastore
    //   8318: aload_1
    //   8319: sipush 178
    //   8322: getstatic 1566	com/neovisionaries/i18n/CountryCode:PF	Lcom/neovisionaries/i18n/CountryCode;
    //   8325: aastore
    //   8326: aload_1
    //   8327: sipush 179
    //   8330: getstatic 1573	com/neovisionaries/i18n/CountryCode:PG	Lcom/neovisionaries/i18n/CountryCode;
    //   8333: aastore
    //   8334: aload_1
    //   8335: sipush 180
    //   8338: getstatic 1580	com/neovisionaries/i18n/CountryCode:PH	Lcom/neovisionaries/i18n/CountryCode;
    //   8341: aastore
    //   8342: aload_1
    //   8343: sipush 181
    //   8346: getstatic 1587	com/neovisionaries/i18n/CountryCode:PK	Lcom/neovisionaries/i18n/CountryCode;
    //   8349: aastore
    //   8350: aload_1
    //   8351: sipush 182
    //   8354: getstatic 1594	com/neovisionaries/i18n/CountryCode:PL	Lcom/neovisionaries/i18n/CountryCode;
    //   8357: aastore
    //   8358: aload_1
    //   8359: sipush 183
    //   8362: getstatic 1601	com/neovisionaries/i18n/CountryCode:PM	Lcom/neovisionaries/i18n/CountryCode;
    //   8365: aastore
    //   8366: aload_1
    //   8367: sipush 184
    //   8370: getstatic 1608	com/neovisionaries/i18n/CountryCode:PN	Lcom/neovisionaries/i18n/CountryCode;
    //   8373: aastore
    //   8374: aload_1
    //   8375: sipush 185
    //   8378: getstatic 1615	com/neovisionaries/i18n/CountryCode:PR	Lcom/neovisionaries/i18n/CountryCode;
    //   8381: aastore
    //   8382: aload_1
    //   8383: sipush 186
    //   8386: getstatic 1622	com/neovisionaries/i18n/CountryCode:PS	Lcom/neovisionaries/i18n/CountryCode;
    //   8389: aastore
    //   8390: aload_1
    //   8391: sipush 187
    //   8394: getstatic 1629	com/neovisionaries/i18n/CountryCode:PT	Lcom/neovisionaries/i18n/CountryCode;
    //   8397: aastore
    //   8398: aload_1
    //   8399: sipush 188
    //   8402: getstatic 1636	com/neovisionaries/i18n/CountryCode:PW	Lcom/neovisionaries/i18n/CountryCode;
    //   8405: aastore
    //   8406: aload_1
    //   8407: sipush 189
    //   8410: getstatic 1643	com/neovisionaries/i18n/CountryCode:PY	Lcom/neovisionaries/i18n/CountryCode;
    //   8413: aastore
    //   8414: aload_1
    //   8415: sipush 190
    //   8418: getstatic 1650	com/neovisionaries/i18n/CountryCode:QA	Lcom/neovisionaries/i18n/CountryCode;
    //   8421: aastore
    //   8422: aload_1
    //   8423: sipush 191
    //   8426: getstatic 1657	com/neovisionaries/i18n/CountryCode:RE	Lcom/neovisionaries/i18n/CountryCode;
    //   8429: aastore
    //   8430: aload_1
    //   8431: sipush 192
    //   8434: getstatic 1664	com/neovisionaries/i18n/CountryCode:RO	Lcom/neovisionaries/i18n/CountryCode;
    //   8437: aastore
    //   8438: aload_1
    //   8439: sipush 193
    //   8442: getstatic 1671	com/neovisionaries/i18n/CountryCode:RS	Lcom/neovisionaries/i18n/CountryCode;
    //   8445: aastore
    //   8446: aload_1
    //   8447: sipush 194
    //   8450: getstatic 1678	com/neovisionaries/i18n/CountryCode:RU	Lcom/neovisionaries/i18n/CountryCode;
    //   8453: aastore
    //   8454: aload_1
    //   8455: sipush 195
    //   8458: getstatic 1685	com/neovisionaries/i18n/CountryCode:RW	Lcom/neovisionaries/i18n/CountryCode;
    //   8461: aastore
    //   8462: aload_1
    //   8463: sipush 196
    //   8466: getstatic 1692	com/neovisionaries/i18n/CountryCode:SA	Lcom/neovisionaries/i18n/CountryCode;
    //   8469: aastore
    //   8470: aload_1
    //   8471: sipush 197
    //   8474: getstatic 1699	com/neovisionaries/i18n/CountryCode:SB	Lcom/neovisionaries/i18n/CountryCode;
    //   8477: aastore
    //   8478: aload_1
    //   8479: sipush 198
    //   8482: getstatic 1706	com/neovisionaries/i18n/CountryCode:SC	Lcom/neovisionaries/i18n/CountryCode;
    //   8485: aastore
    //   8486: aload_1
    //   8487: sipush 199
    //   8490: getstatic 1713	com/neovisionaries/i18n/CountryCode:SD	Lcom/neovisionaries/i18n/CountryCode;
    //   8493: aastore
    //   8494: aload_1
    //   8495: sipush 200
    //   8498: getstatic 1720	com/neovisionaries/i18n/CountryCode:SE	Lcom/neovisionaries/i18n/CountryCode;
    //   8501: aastore
    //   8502: aload_1
    //   8503: sipush 201
    //   8506: getstatic 1723	com/neovisionaries/i18n/CountryCode:SF	Lcom/neovisionaries/i18n/CountryCode;
    //   8509: aastore
    //   8510: aload_1
    //   8511: sipush 202
    //   8514: getstatic 1730	com/neovisionaries/i18n/CountryCode:SG	Lcom/neovisionaries/i18n/CountryCode;
    //   8517: aastore
    //   8518: aload_1
    //   8519: sipush 203
    //   8522: getstatic 1737	com/neovisionaries/i18n/CountryCode:SH	Lcom/neovisionaries/i18n/CountryCode;
    //   8525: aastore
    //   8526: aload_1
    //   8527: sipush 204
    //   8530: getstatic 1744	com/neovisionaries/i18n/CountryCode:SI	Lcom/neovisionaries/i18n/CountryCode;
    //   8533: aastore
    //   8534: aload_1
    //   8535: sipush 205
    //   8538: getstatic 1751	com/neovisionaries/i18n/CountryCode:SJ	Lcom/neovisionaries/i18n/CountryCode;
    //   8541: aastore
    //   8542: aload_1
    //   8543: sipush 206
    //   8546: getstatic 1758	com/neovisionaries/i18n/CountryCode:SK	Lcom/neovisionaries/i18n/CountryCode;
    //   8549: aastore
    //   8550: aload_1
    //   8551: sipush 207
    //   8554: getstatic 1765	com/neovisionaries/i18n/CountryCode:SL	Lcom/neovisionaries/i18n/CountryCode;
    //   8557: aastore
    //   8558: aload_1
    //   8559: sipush 208
    //   8562: getstatic 1772	com/neovisionaries/i18n/CountryCode:SM	Lcom/neovisionaries/i18n/CountryCode;
    //   8565: aastore
    //   8566: aload_1
    //   8567: sipush 209
    //   8570: getstatic 1779	com/neovisionaries/i18n/CountryCode:SN	Lcom/neovisionaries/i18n/CountryCode;
    //   8573: aastore
    //   8574: aload_1
    //   8575: sipush 210
    //   8578: getstatic 1786	com/neovisionaries/i18n/CountryCode:SO	Lcom/neovisionaries/i18n/CountryCode;
    //   8581: aastore
    //   8582: aload_1
    //   8583: sipush 211
    //   8586: getstatic 1793	com/neovisionaries/i18n/CountryCode:SR	Lcom/neovisionaries/i18n/CountryCode;
    //   8589: aastore
    //   8590: aload_1
    //   8591: sipush 212
    //   8594: getstatic 1800	com/neovisionaries/i18n/CountryCode:SS	Lcom/neovisionaries/i18n/CountryCode;
    //   8597: aastore
    //   8598: aload_1
    //   8599: sipush 213
    //   8602: getstatic 1807	com/neovisionaries/i18n/CountryCode:ST	Lcom/neovisionaries/i18n/CountryCode;
    //   8605: aastore
    //   8606: aload_1
    //   8607: sipush 214
    //   8610: getstatic 1814	com/neovisionaries/i18n/CountryCode:SV	Lcom/neovisionaries/i18n/CountryCode;
    //   8613: aastore
    //   8614: aload_1
    //   8615: sipush 215
    //   8618: getstatic 1821	com/neovisionaries/i18n/CountryCode:SX	Lcom/neovisionaries/i18n/CountryCode;
    //   8621: aastore
    //   8622: aload_1
    //   8623: sipush 216
    //   8626: getstatic 1828	com/neovisionaries/i18n/CountryCode:SY	Lcom/neovisionaries/i18n/CountryCode;
    //   8629: aastore
    //   8630: aload_1
    //   8631: sipush 217
    //   8634: getstatic 1835	com/neovisionaries/i18n/CountryCode:SZ	Lcom/neovisionaries/i18n/CountryCode;
    //   8637: aastore
    //   8638: aload_1
    //   8639: sipush 218
    //   8642: getstatic 1842	com/neovisionaries/i18n/CountryCode:TC	Lcom/neovisionaries/i18n/CountryCode;
    //   8645: aastore
    //   8646: aload_1
    //   8647: sipush 219
    //   8650: getstatic 1849	com/neovisionaries/i18n/CountryCode:TD	Lcom/neovisionaries/i18n/CountryCode;
    //   8653: aastore
    //   8654: aload_1
    //   8655: sipush 220
    //   8658: getstatic 1856	com/neovisionaries/i18n/CountryCode:TF	Lcom/neovisionaries/i18n/CountryCode;
    //   8661: aastore
    //   8662: aload_1
    //   8663: sipush 221
    //   8666: getstatic 1863	com/neovisionaries/i18n/CountryCode:TG	Lcom/neovisionaries/i18n/CountryCode;
    //   8669: aastore
    //   8670: aload_1
    //   8671: sipush 222
    //   8674: getstatic 1870	com/neovisionaries/i18n/CountryCode:TH	Lcom/neovisionaries/i18n/CountryCode;
    //   8677: aastore
    //   8678: aload_1
    //   8679: sipush 223
    //   8682: getstatic 1877	com/neovisionaries/i18n/CountryCode:TJ	Lcom/neovisionaries/i18n/CountryCode;
    //   8685: aastore
    //   8686: aload_1
    //   8687: sipush 224
    //   8690: getstatic 1884	com/neovisionaries/i18n/CountryCode:TK	Lcom/neovisionaries/i18n/CountryCode;
    //   8693: aastore
    //   8694: aload_1
    //   8695: sipush 225
    //   8698: getstatic 1891	com/neovisionaries/i18n/CountryCode:TL	Lcom/neovisionaries/i18n/CountryCode;
    //   8701: aastore
    //   8702: aload_1
    //   8703: sipush 226
    //   8706: getstatic 1898	com/neovisionaries/i18n/CountryCode:TM	Lcom/neovisionaries/i18n/CountryCode;
    //   8709: aastore
    //   8710: aload_1
    //   8711: sipush 227
    //   8714: getstatic 1905	com/neovisionaries/i18n/CountryCode:TN	Lcom/neovisionaries/i18n/CountryCode;
    //   8717: aastore
    //   8718: aload_1
    //   8719: sipush 228
    //   8722: getstatic 1912	com/neovisionaries/i18n/CountryCode:TO	Lcom/neovisionaries/i18n/CountryCode;
    //   8725: aastore
    //   8726: aload_1
    //   8727: sipush 229
    //   8730: getstatic 1919	com/neovisionaries/i18n/CountryCode:TP	Lcom/neovisionaries/i18n/CountryCode;
    //   8733: aastore
    //   8734: aload_1
    //   8735: sipush 230
    //   8738: getstatic 1926	com/neovisionaries/i18n/CountryCode:TR	Lcom/neovisionaries/i18n/CountryCode;
    //   8741: aastore
    //   8742: aload_1
    //   8743: sipush 231
    //   8746: getstatic 1933	com/neovisionaries/i18n/CountryCode:TT	Lcom/neovisionaries/i18n/CountryCode;
    //   8749: aastore
    //   8750: aload_1
    //   8751: sipush 232
    //   8754: getstatic 1940	com/neovisionaries/i18n/CountryCode:TV	Lcom/neovisionaries/i18n/CountryCode;
    //   8757: aastore
    //   8758: aload_1
    //   8759: sipush 233
    //   8762: getstatic 1950	com/neovisionaries/i18n/CountryCode:TW	Lcom/neovisionaries/i18n/CountryCode;
    //   8765: aastore
    //   8766: aload_1
    //   8767: sipush 234
    //   8770: getstatic 1957	com/neovisionaries/i18n/CountryCode:TZ	Lcom/neovisionaries/i18n/CountryCode;
    //   8773: aastore
    //   8774: aload_1
    //   8775: sipush 235
    //   8778: getstatic 1964	com/neovisionaries/i18n/CountryCode:UA	Lcom/neovisionaries/i18n/CountryCode;
    //   8781: aastore
    //   8782: aload_1
    //   8783: sipush 236
    //   8786: getstatic 1971	com/neovisionaries/i18n/CountryCode:UG	Lcom/neovisionaries/i18n/CountryCode;
    //   8789: aastore
    //   8790: aload_1
    //   8791: sipush 237
    //   8794: getstatic 1978	com/neovisionaries/i18n/CountryCode:UM	Lcom/neovisionaries/i18n/CountryCode;
    //   8797: aastore
    //   8798: aload_1
    //   8799: sipush 238
    //   8802: getstatic 1988	com/neovisionaries/i18n/CountryCode:US	Lcom/neovisionaries/i18n/CountryCode;
    //   8805: aastore
    //   8806: aload_1
    //   8807: sipush 239
    //   8810: getstatic 1995	com/neovisionaries/i18n/CountryCode:UY	Lcom/neovisionaries/i18n/CountryCode;
    //   8813: aastore
    //   8814: aload_1
    //   8815: sipush 240
    //   8818: getstatic 2002	com/neovisionaries/i18n/CountryCode:UZ	Lcom/neovisionaries/i18n/CountryCode;
    //   8821: aastore
    //   8822: aload_1
    //   8823: sipush 241
    //   8826: getstatic 2009	com/neovisionaries/i18n/CountryCode:VA	Lcom/neovisionaries/i18n/CountryCode;
    //   8829: aastore
    //   8830: aload_1
    //   8831: sipush 242
    //   8834: getstatic 2016	com/neovisionaries/i18n/CountryCode:VC	Lcom/neovisionaries/i18n/CountryCode;
    //   8837: aastore
    //   8838: aload_1
    //   8839: sipush 243
    //   8842: getstatic 2023	com/neovisionaries/i18n/CountryCode:VE	Lcom/neovisionaries/i18n/CountryCode;
    //   8845: aastore
    //   8846: aload_1
    //   8847: sipush 244
    //   8850: getstatic 2030	com/neovisionaries/i18n/CountryCode:VG	Lcom/neovisionaries/i18n/CountryCode;
    //   8853: aastore
    //   8854: aload_1
    //   8855: sipush 245
    //   8858: getstatic 2037	com/neovisionaries/i18n/CountryCode:VI	Lcom/neovisionaries/i18n/CountryCode;
    //   8861: aastore
    //   8862: aload_1
    //   8863: sipush 246
    //   8866: getstatic 2044	com/neovisionaries/i18n/CountryCode:VN	Lcom/neovisionaries/i18n/CountryCode;
    //   8869: aastore
    //   8870: aload_1
    //   8871: sipush 247
    //   8874: getstatic 2051	com/neovisionaries/i18n/CountryCode:VU	Lcom/neovisionaries/i18n/CountryCode;
    //   8877: aastore
    //   8878: aload_1
    //   8879: sipush 248
    //   8882: getstatic 2058	com/neovisionaries/i18n/CountryCode:WF	Lcom/neovisionaries/i18n/CountryCode;
    //   8885: aastore
    //   8886: aload_1
    //   8887: sipush 249
    //   8890: getstatic 2065	com/neovisionaries/i18n/CountryCode:WS	Lcom/neovisionaries/i18n/CountryCode;
    //   8893: aastore
    //   8894: aload_1
    //   8895: sipush 250
    //   8898: getstatic 2072	com/neovisionaries/i18n/CountryCode:YE	Lcom/neovisionaries/i18n/CountryCode;
    //   8901: aastore
    //   8902: aload_1
    //   8903: sipush 251
    //   8906: getstatic 2079	com/neovisionaries/i18n/CountryCode:YT	Lcom/neovisionaries/i18n/CountryCode;
    //   8909: aastore
    //   8910: aload_1
    //   8911: sipush 252
    //   8914: getstatic 2086	com/neovisionaries/i18n/CountryCode:YU	Lcom/neovisionaries/i18n/CountryCode;
    //   8917: aastore
    //   8918: aload_1
    //   8919: sipush 253
    //   8922: getstatic 2093	com/neovisionaries/i18n/CountryCode:ZA	Lcom/neovisionaries/i18n/CountryCode;
    //   8925: aastore
    //   8926: aload_1
    //   8927: sipush 254
    //   8930: getstatic 2100	com/neovisionaries/i18n/CountryCode:ZM	Lcom/neovisionaries/i18n/CountryCode;
    //   8933: aastore
    //   8934: aload_1
    //   8935: sipush 255
    //   8938: getstatic 2107	com/neovisionaries/i18n/CountryCode:ZR	Lcom/neovisionaries/i18n/CountryCode;
    //   8941: aastore
    //   8942: aload_1
    //   8943: sipush 256
    //   8946: getstatic 2114	com/neovisionaries/i18n/CountryCode:ZW	Lcom/neovisionaries/i18n/CountryCode;
    //   8949: aastore
    //   8950: aload_1
    //   8951: putstatic 2116	com/neovisionaries/i18n/CountryCode:ENUM$VALUES	[Lcom/neovisionaries/i18n/CountryCode;
    //   8954: new 2118	java/util/HashMap
    //   8957: dup
    //   8958: invokespecial 2120	java/util/HashMap:<init>	()V
    //   8961: putstatic 2122	com/neovisionaries/i18n/CountryCode:alpha3Map	Ljava/util/Map;
    //   8964: new 2118	java/util/HashMap
    //   8967: dup
    //   8968: invokespecial 2120	java/util/HashMap:<init>	()V
    //   8971: putstatic 2124	com/neovisionaries/i18n/CountryCode:numericMap	Ljava/util/Map;
    //   8974: invokestatic 2128	com/neovisionaries/i18n/CountryCode:values	()[Lcom/neovisionaries/i18n/CountryCode;
    //   8977: astore_2
    //   8978: aload_2
    //   8979: arraylength
    //   8980: istore_3
    //   8981: iload_0
    //   8982: iload_3
    //   8983: if_icmplt +4 -> 8987
    //   8986: return
    //   8987: aload_2
    //   8988: iload_0
    //   8989: aaload
    //   8990: astore 4
    //   8992: getstatic 2122	com/neovisionaries/i18n/CountryCode:alpha3Map	Ljava/util/Map;
    //   8995: aload 4
    //   8997: invokevirtual 2132	com/neovisionaries/i18n/CountryCode:getAlpha3	()Ljava/lang/String;
    //   9000: aload 4
    //   9002: invokeinterface 2138 3 0
    //   9007: pop
    //   9008: getstatic 2124	com/neovisionaries/i18n/CountryCode:numericMap	Ljava/util/Map;
    //   9011: aload 4
    //   9013: invokevirtual 2142	com/neovisionaries/i18n/CountryCode:getNumeric	()I
    //   9016: invokestatic 2148	java/lang/Integer:valueOf	(I)Ljava/lang/Integer;
    //   9019: aload 4
    //   9021: invokeinterface 2138 3 0
    //   9026: pop
    //   9027: iinc 0 1
    //   9030: goto -49 -> 8981
  }

  private CountryCode(String paramInt, String paramAssignment, int arg5, Assignment arg6)
  {
    this.name = paramInt;
    this.alpha3 = paramAssignment;
    int i;
    this.numeric = i;
    Object localObject;
    this.assignment = localObject;
  }

  static String canonicalize(String paramString, boolean paramBoolean)
  {
    if ((paramString == null) || (paramString.length() == 0))
      paramString = null;
    while (paramBoolean)
      return paramString;
    return paramString.toUpperCase();
  }

  private static CountryCode getByAlpha2Code(String paramString)
  {
    try
    {
      CountryCode localCountryCode = (CountryCode)Enum.valueOf(CountryCode.class, paramString);
      return localCountryCode;
    }
    catch (IllegalArgumentException localIllegalArgumentException)
    {
    }
    return null;
  }

  private static CountryCode getByAlpha3Code(String paramString)
  {
    return (CountryCode)alpha3Map.get(paramString);
  }

  public static CountryCode getByCode(int paramInt)
  {
    return (CountryCode)numericMap.get(Integer.valueOf(paramInt));
  }

  public static CountryCode getByCode(String paramString)
  {
    return getByCode(paramString, false);
  }

  public static CountryCode getByCode(String paramString, boolean paramBoolean)
  {
    if (paramString == null)
      return null;
    switch (paramString.length())
    {
    default:
      return null;
    case 2:
      return getByAlpha2Code(canonicalize(paramString, paramBoolean));
    case 3:
    }
    return getByAlpha3Code(canonicalize(paramString, paramBoolean));
  }

  public static CountryCode getByLocale(Locale paramLocale)
  {
    if (paramLocale == null)
      return null;
    return getByCode(paramLocale.getCountry(), true);
  }

  public String getAlpha2()
  {
    return name();
  }

  public String getAlpha3()
  {
    return this.alpha3;
  }

  public Assignment getAssignment()
  {
    return this.assignment;
  }

  public Currency getCurrency()
  {
    try
    {
      Currency localCurrency = Currency.getInstance(toLocale());
      return localCurrency;
    }
    catch (IllegalArgumentException localIllegalArgumentException)
    {
    }
    return null;
  }

  public String getName()
  {
    return this.name;
  }

  public int getNumeric()
  {
    return this.numeric;
  }

  public Locale toLocale()
  {
    return new Locale("", name());
  }

  public static enum Assignment
  {
    static
    {
      EXCEPTIONALLY_RESERVED = new Assignment("EXCEPTIONALLY_RESERVED", 2);
      TRANSITIONALLY_RESERVED = new Assignment("TRANSITIONALLY_RESERVED", 3);
      INDETERMINATELY_RESERVED = new Assignment("INDETERMINATELY_RESERVED", 4);
      NOT_USED = new Assignment("NOT_USED", 5);
      Assignment[] arrayOfAssignment = new Assignment[6];
      arrayOfAssignment[0] = OFFICIALLY_ASSIGNED;
      arrayOfAssignment[1] = USER_ASSIGNED;
      arrayOfAssignment[2] = EXCEPTIONALLY_RESERVED;
      arrayOfAssignment[3] = TRANSITIONALLY_RESERVED;
      arrayOfAssignment[4] = INDETERMINATELY_RESERVED;
      arrayOfAssignment[5] = NOT_USED;
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     com.neovisionaries.i18n.CountryCode
 * JD-Core Version:    0.6.2
 */