package it.sephiroth.android.library.util;

import android.os.Build.VERSION;
import android.util.Log;
import android.view.View;
import it.sephiroth.android.library.util.v14.ViewHelper14;
import it.sephiroth.android.library.util.v16.ViewHelper16;

public class ViewHelperFactory
{
  private static final String LOG_TAG = "ViewHelper";

  public static final ViewHelper create(View paramView)
  {
    int i = Build.VERSION.SDK_INT;
    if (i >= 16)
      return new ViewHelper16(paramView);
    if (i >= 14)
      return new ViewHelper14(paramView);
    return new ViewHelperDefault(paramView);
  }

  public static abstract class ViewHelper
  {
    protected View view;

    protected ViewHelper(View paramView)
    {
      this.view = paramView;
      Log.i("ViewHelper", getClass().getSimpleName());
    }

    public abstract boolean isHardwareAccelerated();

    public abstract void postOnAnimation(Runnable paramRunnable);

    public abstract void setScrollX(int paramInt);
  }

  public static class ViewHelperDefault extends ViewHelperFactory.ViewHelper
  {
    public ViewHelperDefault(View paramView)
    {
      super();
    }

    public boolean isHardwareAccelerated()
    {
      return false;
    }

    public void postOnAnimation(Runnable paramRunnable)
    {
      this.view.post(paramRunnable);
    }

    public void setScrollX(int paramInt)
    {
      Log.d("ViewHelper", "setScrollX: " + paramInt);
      this.view.scrollTo(paramInt, this.view.getScrollY());
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     it.sephiroth.android.library.util.ViewHelperFactory
 * JD-Core Version:    0.6.2
 */