package it.sephiroth.android.library.widget;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.content.Context;
import android.database.DataSetObserver;
import android.os.Build.VERSION;
import android.os.Parcelable;
import android.os.SystemClock;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseArray;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewDebug.CapturedViewProperty;
import android.view.ViewDebug.ExportedProperty;
import android.view.ViewGroup;
import android.view.ViewGroup.LayoutParams;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityManager;
import android.view.accessibility.AccessibilityNodeInfo;
import android.widget.Adapter;

public abstract class AdapterView<T extends Adapter> extends ViewGroup
{
  public static final long INVALID_COL_ID = -9223372036854775808L;
  public static final int INVALID_POSITION = -1;
  public static final int ITEM_VIEW_TYPE_HEADER_OR_FOOTER = -2;
  public static final int ITEM_VIEW_TYPE_IGNORE = -1;
  static final int SYNC_FIRST_POSITION = 1;
  static final int SYNC_MAX_DURATION_MILLIS = 100;
  static final int SYNC_SELECTED_POSITION;
  AccessibilityManager mAccessibilityManager;
  protected boolean mBlockLayoutRequests = false;
  public boolean mDataChanged;
  private boolean mDesiredFocusableInTouchModeState;
  private boolean mDesiredFocusableState;
  private View mEmptyView;

  @ViewDebug.ExportedProperty(category="scrolling")
  protected int mFirstPosition = 0;
  protected boolean mInLayout = false;

  @ViewDebug.ExportedProperty(category="list")
  protected int mItemCount;
  private int mLayoutWidth;
  protected boolean mNeedSync = false;
  protected long mNextSelectedColId = -9223372036854775808L;

  @ViewDebug.ExportedProperty(category="list")
  protected int mNextSelectedPosition = -1;
  protected int mOldItemCount;
  protected long mOldSelectedColId = -9223372036854775808L;
  protected int mOldSelectedPosition = -1;
  OnItemClickListener mOnItemClickListener;
  OnItemLongClickListener mOnItemLongClickListener;
  OnItemSelectedListener mOnItemSelectedListener;
  protected long mSelectedColId = -9223372036854775808L;

  @ViewDebug.ExportedProperty(category="list")
  protected int mSelectedPosition = -1;
  private AdapterView<T>.SelectionNotifier mSelectionNotifier;
  protected int mSpecificLeft;
  protected long mSyncColId = -9223372036854775808L;
  int mSyncMode;
  protected int mSyncPosition;
  protected long mSyncWidth;

  public AdapterView(Context paramContext)
  {
    super(paramContext);
  }

  public AdapterView(Context paramContext, AttributeSet paramAttributeSet)
  {
    super(paramContext, paramAttributeSet);
  }

  public AdapterView(Context paramContext, AttributeSet paramAttributeSet, int paramInt)
  {
    super(paramContext, paramAttributeSet, paramInt);
    if ((Build.VERSION.SDK_INT >= 16) && (getImportantForAccessibility() == 0))
      setImportantForAccessibility(1);
    this.mAccessibilityManager = ((AccessibilityManager)getContext().getSystemService("accessibility"));
  }

  private void fireOnSelected()
  {
    if (this.mOnItemSelectedListener == null)
      return;
    int i = getSelectedItemPosition();
    if (i >= 0)
    {
      View localView = getSelectedView();
      this.mOnItemSelectedListener.onItemSelected(this, localView, i, getAdapter().getItemId(i));
      return;
    }
    this.mOnItemSelectedListener.onNothingSelected(this);
  }

  private boolean isScrollableForAccessibility()
  {
    Adapter localAdapter = getAdapter();
    boolean bool = false;
    if (localAdapter != null)
    {
      int i = localAdapter.getCount();
      bool = false;
      if (i > 0)
        if (getFirstVisiblePosition() <= 0)
        {
          int j = getLastVisiblePosition();
          int k = i - 1;
          bool = false;
          if (j >= k);
        }
        else
        {
          bool = true;
        }
    }
    return bool;
  }

  private void performAccessibilityActionsOnSelected()
  {
    if (!this.mAccessibilityManager.isEnabled());
    while (getSelectedItemPosition() < 0)
      return;
    sendAccessibilityEvent(4);
  }

  @SuppressLint({"WrongCall"})
  private void updateEmptyStatus(boolean paramBoolean)
  {
    if (isInFilterMode())
      paramBoolean = false;
    if (paramBoolean)
    {
      if (this.mEmptyView != null)
      {
        this.mEmptyView.setVisibility(0);
        setVisibility(8);
      }
      while (true)
      {
        if (this.mDataChanged)
          onLayout(false, getLeft(), getTop(), getRight(), getBottom());
        return;
        setVisibility(0);
      }
    }
    if (this.mEmptyView != null)
      this.mEmptyView.setVisibility(8);
    setVisibility(0);
  }

  public void addView(View paramView)
  {
    throw new UnsupportedOperationException("addView(View) is not supported in AdapterView");
  }

  public void addView(View paramView, int paramInt)
  {
    throw new UnsupportedOperationException("addView(View, int) is not supported in AdapterView");
  }

  public void addView(View paramView, int paramInt, ViewGroup.LayoutParams paramLayoutParams)
  {
    throw new UnsupportedOperationException("addView(View, int, LayoutParams) is not supported in AdapterView");
  }

  public void addView(View paramView, ViewGroup.LayoutParams paramLayoutParams)
  {
    throw new UnsupportedOperationException("addView(View, LayoutParams) is not supported in AdapterView");
  }

  protected boolean canAnimate()
  {
    return (super.canAnimate()) && (this.mItemCount > 0);
  }

  protected void checkFocus()
  {
    Adapter localAdapter = getAdapter();
    int i;
    int j;
    label33: boolean bool1;
    label47: boolean bool2;
    label67: boolean bool3;
    if ((localAdapter != null) && (localAdapter.getCount() != 0))
    {
      i = 0;
      if ((i == 0) || (isInFilterMode()))
        break label112;
      j = 0;
      if ((j == 0) || (!this.mDesiredFocusableInTouchModeState))
        break label117;
      bool1 = true;
      super.setFocusableInTouchMode(bool1);
      if ((j == 0) || (!this.mDesiredFocusableState))
        break label123;
      bool2 = true;
      super.setFocusable(bool2);
      if (this.mEmptyView != null)
      {
        if (localAdapter == null)
          break label129;
        boolean bool4 = localAdapter.isEmpty();
        bool3 = false;
        if (bool4)
          break label129;
      }
    }
    while (true)
    {
      updateEmptyStatus(bool3);
      return;
      i = 1;
      break;
      label112: j = 1;
      break label33;
      label117: bool1 = false;
      break label47;
      label123: bool2 = false;
      break label67;
      label129: bool3 = true;
    }
  }

  protected void checkSelectionChanged()
  {
    if ((this.mSelectedPosition != this.mOldSelectedPosition) || (this.mSelectedColId != this.mOldSelectedColId))
    {
      selectionChanged();
      this.mOldSelectedPosition = this.mSelectedPosition;
      this.mOldSelectedColId = this.mSelectedColId;
    }
  }

  public boolean dispatchPopulateAccessibilityEvent(AccessibilityEvent paramAccessibilityEvent)
  {
    View localView = getSelectedView();
    return (localView != null) && (localView.getVisibility() == 0) && (localView.dispatchPopulateAccessibilityEvent(paramAccessibilityEvent));
  }

  protected void dispatchRestoreInstanceState(SparseArray<Parcelable> paramSparseArray)
  {
    dispatchThawSelfOnly(paramSparseArray);
  }

  protected void dispatchSaveInstanceState(SparseArray<Parcelable> paramSparseArray)
  {
    dispatchFreezeSelfOnly(paramSparseArray);
  }

  int findSyncPosition()
  {
    int i = this.mItemCount;
    if (i == 0)
    {
      m = -1;
      return m;
    }
    long l1 = this.mSyncColId;
    int j = this.mSyncPosition;
    if (l1 == -9223372036854775808L)
      return -1;
    int k = Math.max(0, j);
    int m = Math.min(i - 1, k);
    long l2 = 100L + SystemClock.uptimeMillis();
    int n = m;
    int i1 = m;
    Adapter localAdapter = getAdapter();
    int i2 = 0;
    if (localAdapter == null)
      return -1;
    label138: label144: label207: 
    while (localAdapter.getItemId(m) != l1)
    {
      int i3;
      if (i1 == i - 1)
      {
        i3 = 1;
        if (n != 0)
          break label138;
      }
      for (int i4 = 1; ; i4 = 0)
      {
        if ((i3 == 0) || (i4 == 0))
          break label144;
        return -1;
        i3 = 0;
        break;
      }
      if ((i4 != 0) || ((i2 != 0) && (i3 == 0)))
      {
        i1++;
        m = i1;
      }
      for (i2 = 0; ; i2 = 1)
      {
        do
        {
          if (SystemClock.uptimeMillis() <= l2)
            break label207;
          break;
        }
        while ((i3 == 0) && ((i2 != 0) || (i4 != 0)));
        n--;
        m = n;
      }
    }
  }

  public abstract T getAdapter();

  @ViewDebug.CapturedViewProperty
  public int getCount()
  {
    return this.mItemCount;
  }

  public View getEmptyView()
  {
    return this.mEmptyView;
  }

  public int getFirstVisiblePosition()
  {
    return this.mFirstPosition;
  }

  public Object getItemAtPosition(int paramInt)
  {
    Adapter localAdapter = getAdapter();
    if ((localAdapter == null) || (paramInt < 0))
      return null;
    return localAdapter.getItem(paramInt);
  }

  public long getItemIdAtPosition(int paramInt)
  {
    Adapter localAdapter = getAdapter();
    if ((localAdapter == null) || (paramInt < 0))
      return -9223372036854775808L;
    return localAdapter.getItemId(paramInt);
  }

  public int getLastVisiblePosition()
  {
    return -1 + (this.mFirstPosition + getChildCount());
  }

  public final OnItemClickListener getOnItemClickListener()
  {
    return this.mOnItemClickListener;
  }

  public final OnItemLongClickListener getOnItemLongClickListener()
  {
    return this.mOnItemLongClickListener;
  }

  public final OnItemSelectedListener getOnItemSelectedListener()
  {
    return this.mOnItemSelectedListener;
  }

  public int getPositionForView(View paramView)
  {
    Object localObject = paramView;
    while (true)
    {
      int j;
      try
      {
        View localView = (View)((View)localObject).getParent();
        boolean bool = localView.equals(this);
        if (bool)
        {
          int i = getChildCount();
          j = 0;
          if (j >= i)
            return -1;
        }
        else
        {
          localObject = localView;
          continue;
        }
      }
      catch (ClassCastException localClassCastException)
      {
        return -1;
      }
      if (getChildAt(j).equals(localObject))
        return j + this.mFirstPosition;
      j++;
    }
  }

  public Object getSelectedItem()
  {
    Adapter localAdapter = getAdapter();
    int i = getSelectedItemPosition();
    if ((localAdapter != null) && (localAdapter.getCount() > 0) && (i >= 0))
      return localAdapter.getItem(i);
    return null;
  }

  @ViewDebug.CapturedViewProperty
  public long getSelectedItemId()
  {
    return this.mNextSelectedColId;
  }

  @ViewDebug.CapturedViewProperty
  public int getSelectedItemPosition()
  {
    return this.mNextSelectedPosition;
  }

  public abstract View getSelectedView();

  void handleDataChanged()
  {
    int i = this.mItemCount;
    int j = 0;
    if (i > 0)
    {
      boolean bool = this.mNeedSync;
      j = 0;
      if (bool)
      {
        this.mNeedSync = false;
        int n = findSyncPosition();
        j = 0;
        if (n >= 0)
        {
          int i1 = lookForSelectablePosition(n, true);
          j = 0;
          if (i1 == n)
          {
            setNextSelectedPositionInt(n);
            j = 1;
          }
        }
      }
      if (j == 0)
      {
        int k = getSelectedItemPosition();
        if (k >= i)
          k = i - 1;
        if (k < 0)
          k = 0;
        int m = lookForSelectablePosition(k, true);
        if (m < 0)
          m = lookForSelectablePosition(k, false);
        if (m >= 0)
        {
          setNextSelectedPositionInt(m);
          checkSelectionChanged();
          j = 1;
        }
      }
    }
    if (j == 0)
    {
      this.mSelectedPosition = -1;
      this.mSelectedColId = -9223372036854775808L;
      this.mNextSelectedPosition = -1;
      this.mNextSelectedColId = -9223372036854775808L;
      this.mNeedSync = false;
      checkSelectionChanged();
    }
  }

  boolean isInFilterMode()
  {
    return false;
  }

  protected int lookForSelectablePosition(int paramInt, boolean paramBoolean)
  {
    return paramInt;
  }

  protected void onDetachedFromWindow()
  {
    super.onDetachedFromWindow();
    removeCallbacks(this.mSelectionNotifier);
  }

  @TargetApi(14)
  public void onInitializeAccessibilityEvent(AccessibilityEvent paramAccessibilityEvent)
  {
    super.onInitializeAccessibilityEvent(paramAccessibilityEvent);
    paramAccessibilityEvent.setClassName(AdapterView.class.getName());
    paramAccessibilityEvent.setScrollable(isScrollableForAccessibility());
    View localView = getSelectedView();
    if (localView != null)
      paramAccessibilityEvent.setEnabled(localView.isEnabled());
    paramAccessibilityEvent.setCurrentItemIndex(getSelectedItemPosition());
    paramAccessibilityEvent.setFromIndex(getFirstVisiblePosition());
    paramAccessibilityEvent.setToIndex(getLastVisiblePosition());
    paramAccessibilityEvent.setItemCount(getCount());
  }

  @TargetApi(14)
  public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo paramAccessibilityNodeInfo)
  {
    super.onInitializeAccessibilityNodeInfo(paramAccessibilityNodeInfo);
    paramAccessibilityNodeInfo.setClassName(AdapterView.class.getName());
    paramAccessibilityNodeInfo.setScrollable(isScrollableForAccessibility());
    View localView = getSelectedView();
    if (localView != null)
      paramAccessibilityNodeInfo.setEnabled(localView.isEnabled());
  }

  protected void onLayout(boolean paramBoolean, int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    this.mLayoutWidth = getWidth();
  }

  @TargetApi(14)
  public boolean onRequestSendAccessibilityEvent(View paramView, AccessibilityEvent paramAccessibilityEvent)
  {
    if (super.onRequestSendAccessibilityEvent(paramView, paramAccessibilityEvent))
    {
      AccessibilityEvent localAccessibilityEvent = AccessibilityEvent.obtain();
      onInitializeAccessibilityEvent(localAccessibilityEvent);
      paramView.dispatchPopulateAccessibilityEvent(localAccessibilityEvent);
      paramAccessibilityEvent.appendRecord(localAccessibilityEvent);
      return true;
    }
    return false;
  }

  public boolean performItemClick(View paramView, int paramInt, long paramLong)
  {
    OnItemClickListener localOnItemClickListener = this.mOnItemClickListener;
    boolean bool = false;
    if (localOnItemClickListener != null)
    {
      playSoundEffect(0);
      if (paramView != null)
        paramView.sendAccessibilityEvent(1);
      this.mOnItemClickListener.onItemClick(this, paramView, paramInt, paramLong);
      bool = true;
    }
    return bool;
  }

  public void rememberSyncState()
  {
    if (getChildCount() > 0)
    {
      this.mNeedSync = true;
      this.mSyncWidth = this.mLayoutWidth;
      if (this.mSelectedPosition >= 0)
      {
        View localView2 = getChildAt(this.mSelectedPosition - this.mFirstPosition);
        this.mSyncColId = this.mNextSelectedColId;
        this.mSyncPosition = this.mNextSelectedPosition;
        if (localView2 != null)
          this.mSpecificLeft = localView2.getLeft();
        this.mSyncMode = 0;
      }
    }
    else
    {
      return;
    }
    View localView1 = getChildAt(0);
    Adapter localAdapter = getAdapter();
    if ((this.mFirstPosition >= 0) && (this.mFirstPosition < localAdapter.getCount()));
    for (this.mSyncColId = localAdapter.getItemId(this.mFirstPosition); ; this.mSyncColId = -1L)
    {
      this.mSyncPosition = this.mFirstPosition;
      if (localView1 != null)
        this.mSpecificLeft = localView1.getLeft();
      this.mSyncMode = 1;
      return;
    }
  }

  public void removeAllViews()
  {
    throw new UnsupportedOperationException("removeAllViews() is not supported in AdapterView");
  }

  public void removeView(View paramView)
  {
    throw new UnsupportedOperationException("removeView(View) is not supported in AdapterView");
  }

  public void removeViewAt(int paramInt)
  {
    throw new UnsupportedOperationException("removeViewAt(int) is not supported in AdapterView");
  }

  void selectionChanged()
  {
    if ((this.mOnItemSelectedListener != null) || (this.mAccessibilityManager.isEnabled()))
    {
      if ((this.mInLayout) || (this.mBlockLayoutRequests))
      {
        if (this.mSelectionNotifier == null)
          this.mSelectionNotifier = new SelectionNotifier(null);
        post(this.mSelectionNotifier);
      }
    }
    else
      return;
    fireOnSelected();
    performAccessibilityActionsOnSelected();
  }

  public abstract void setAdapter(T paramT);

  public void setEmptyView(View paramView)
  {
    int i = 1;
    this.mEmptyView = paramView;
    if ((Build.VERSION.SDK_INT >= 16) && (paramView != null) && (paramView.getImportantForAccessibility() == 0))
      paramView.setImportantForAccessibility(i);
    Adapter localAdapter = getAdapter();
    if ((localAdapter != null) && (!localAdapter.isEmpty()))
      i = 0;
    updateEmptyStatus(i);
  }

  public void setFocusable(boolean paramBoolean)
  {
    boolean bool = true;
    Adapter localAdapter = getAdapter();
    int i;
    if ((localAdapter != null) && (localAdapter.getCount() != 0))
    {
      i = 0;
      this.mDesiredFocusableState = paramBoolean;
      if (!paramBoolean)
        this.mDesiredFocusableInTouchModeState = false;
      if ((!paramBoolean) || ((i != 0) && (!isInFilterMode())))
        break label65;
    }
    while (true)
    {
      super.setFocusable(bool);
      return;
      i = bool;
      break;
      label65: bool = false;
    }
  }

  public void setFocusableInTouchMode(boolean paramBoolean)
  {
    boolean bool = true;
    Adapter localAdapter = getAdapter();
    int i;
    if ((localAdapter != null) && (localAdapter.getCount() != 0))
    {
      i = 0;
      this.mDesiredFocusableInTouchModeState = paramBoolean;
      if (paramBoolean)
        this.mDesiredFocusableState = bool;
      if ((!paramBoolean) || ((i != 0) && (!isInFilterMode())))
        break label65;
    }
    while (true)
    {
      super.setFocusableInTouchMode(bool);
      return;
      i = bool;
      break;
      label65: bool = false;
    }
  }

  protected void setNextSelectedPositionInt(int paramInt)
  {
    this.mNextSelectedPosition = paramInt;
    this.mNextSelectedColId = getItemIdAtPosition(paramInt);
    if ((this.mNeedSync) && (this.mSyncMode == 0) && (paramInt >= 0))
    {
      this.mSyncPosition = paramInt;
      this.mSyncColId = this.mNextSelectedColId;
    }
  }

  public void setOnClickListener(View.OnClickListener paramOnClickListener)
  {
    throw new RuntimeException("Don't call setOnClickListener for an AdapterView. You probably want setOnItemClickListener instead");
  }

  public void setOnItemClickListener(OnItemClickListener paramOnItemClickListener)
  {
    this.mOnItemClickListener = paramOnItemClickListener;
  }

  public void setOnItemLongClickListener(OnItemLongClickListener paramOnItemLongClickListener)
  {
    if (!isLongClickable())
      setLongClickable(true);
    this.mOnItemLongClickListener = paramOnItemLongClickListener;
  }

  public void setOnItemSelectedListener(OnItemSelectedListener paramOnItemSelectedListener)
  {
    this.mOnItemSelectedListener = paramOnItemSelectedListener;
  }

  protected void setSelectedPositionInt(int paramInt)
  {
    this.mSelectedPosition = paramInt;
    this.mSelectedColId = getItemIdAtPosition(paramInt);
  }

  public abstract void setSelection(int paramInt);

  public static class AdapterContextMenuInfo
    implements ContextMenu.ContextMenuInfo
  {
    public long id;
    public int position;
    public View targetView;

    public AdapterContextMenuInfo(View paramView, int paramInt, long paramLong)
    {
      this.targetView = paramView;
      this.position = paramInt;
      this.id = paramLong;
    }
  }

  class AdapterDataSetObserver extends DataSetObserver
  {
    private Parcelable mInstanceState = null;

    AdapterDataSetObserver()
    {
    }

    public void clearSavedState()
    {
      this.mInstanceState = null;
    }

    public void onChanged()
    {
      Log.i("View", "onChanged");
      AdapterView.this.mDataChanged = true;
      AdapterView.this.mOldItemCount = AdapterView.this.mItemCount;
      AdapterView.this.mItemCount = AdapterView.this.getAdapter().getCount();
      if ((AdapterView.this.getAdapter().hasStableIds()) && (this.mInstanceState != null) && (AdapterView.this.mOldItemCount == 0) && (AdapterView.this.mItemCount > 0))
      {
        Log.d("View", "calling onRestoreInstanceState");
        AdapterView.this.onRestoreInstanceState(this.mInstanceState);
        this.mInstanceState = null;
      }
      while (true)
      {
        AdapterView.this.checkFocus();
        AdapterView.this.requestLayout();
        return;
        Log.d("View", "else calling rememberSyncState");
        AdapterView.this.rememberSyncState();
      }
    }

    public void onInvalidated()
    {
      Log.i("View", "onInvalidated");
      AdapterView.this.mDataChanged = true;
      if (AdapterView.this.getAdapter().hasStableIds())
        this.mInstanceState = AdapterView.this.onSaveInstanceState();
      AdapterView.this.mOldItemCount = AdapterView.this.mItemCount;
      AdapterView.this.mItemCount = 0;
      AdapterView.this.mSelectedPosition = -1;
      AdapterView.this.mSelectedColId = -9223372036854775808L;
      AdapterView.this.mNextSelectedPosition = -1;
      AdapterView.this.mNextSelectedColId = -9223372036854775808L;
      AdapterView.this.mNeedSync = false;
      AdapterView.this.checkFocus();
      AdapterView.this.requestLayout();
    }
  }

  public static abstract interface OnItemClickListener
  {
    public abstract void onItemClick(AdapterView<?> paramAdapterView, View paramView, int paramInt, long paramLong);
  }

  public static abstract interface OnItemLongClickListener
  {
    public abstract boolean onItemLongClick(AdapterView<?> paramAdapterView, View paramView, int paramInt, long paramLong);
  }

  public static abstract interface OnItemSelectedListener
  {
    public abstract void onItemSelected(AdapterView<?> paramAdapterView, View paramView, int paramInt, long paramLong);

    public abstract void onNothingSelected(AdapterView<?> paramAdapterView);
  }

  private class SelectionNotifier
    implements Runnable
  {
    private SelectionNotifier()
    {
    }

    public void run()
    {
      if (AdapterView.this.mDataChanged)
      {
        if (AdapterView.this.getAdapter() != null)
          AdapterView.this.post(this);
        return;
      }
      AdapterView.this.fireOnSelected();
      AdapterView.this.performAccessibilityActionsOnSelected();
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     it.sephiroth.android.library.widget.AdapterView
 * JD-Core Version:    0.6.2
 */