package it.sephiroth.android.library.widget;

import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.os.Build.VERSION;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseBooleanArray;
import android.view.FocusFinder;
import android.view.KeyEvent;
import android.view.SoundEffectConstants;
import android.view.View;
import android.view.View.MeasureSpec;
import android.view.ViewDebug.ExportedProperty;
import android.view.ViewGroup;
import android.view.ViewGroup.LayoutParams;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityNodeInfo;
import android.widget.ArrayAdapter;
import android.widget.Checkable;
import android.widget.ListAdapter;
import android.widget.RemoteViews.RemoteView;
import java.util.ArrayList;

@RemoteViews.RemoteView
public class HListView extends AbsHListView
{
  private static final String LOG_TAG = "HListView";
  private static final float MAX_SCROLL_FACTOR = 0.33F;
  private static final int MIN_SCROLL_PREVIEW_PIXELS = 2;
  static final int NO_POSITION = -1;
  public static final String VERSION = "1.0.0";
  private boolean mAreAllItemsSelectable = true;
  private final ArrowScrollFocusResult mArrowScrollFocusResult = new ArrowScrollFocusResult(null);
  Drawable mDivider;
  private boolean mDividerIsOpaque;
  private Paint mDividerPaint;
  int mDividerWidth;
  private FocusSelector mFocusSelector;
  private boolean mFooterDividersEnabled;
  private ArrayList<FixedViewInfo> mFooterViewInfos = new ArrayList();
  private boolean mHeaderDividersEnabled;
  private ArrayList<FixedViewInfo> mHeaderViewInfos = new ArrayList();
  private boolean mIsCacheColorOpaque;
  private boolean mItemsCanFocus = false;
  int mMeasureWithChild;
  Drawable mOverScrollFooter;
  Drawable mOverScrollHeader;
  private final Rect mTempRect = new Rect();

  public HListView(Context paramContext)
  {
    this(paramContext, null);
  }

  public HListView(Context paramContext, AttributeSet paramAttributeSet)
  {
    this(paramContext, paramAttributeSet, paramContext.getResources().getIdentifier("sephiroth_listViewStyle", "attr", paramContext.getPackageName()));
  }

  public HListView(Context paramContext, AttributeSet paramAttributeSet, int paramInt)
  {
    super(paramContext, paramAttributeSet, paramInt);
    int[] arrayOfInt = (int[])getFieldFromStyleable(paramContext, "HListView");
    TypedArray localTypedArray = null;
    if (arrayOfInt != null)
      localTypedArray = paramContext.obtainStyledAttributes(paramAttributeSet, arrayOfInt, paramInt, 0);
    boolean bool1 = true;
    boolean bool2 = true;
    int i = -1;
    Drawable localDrawable1 = null;
    int j = 0;
    CharSequence[] arrayOfCharSequence = null;
    Drawable localDrawable2 = null;
    Drawable localDrawable3 = null;
    if (localTypedArray != null)
    {
      arrayOfCharSequence = localTypedArray.getTextArray(0);
      localDrawable1 = localTypedArray.getDrawable(1);
      localDrawable3 = localTypedArray.getDrawable(5);
      localDrawable2 = localTypedArray.getDrawable(6);
      j = localTypedArray.getDimensionPixelSize(2, 0);
      bool1 = localTypedArray.getBoolean(3, true);
      bool2 = localTypedArray.getBoolean(4, true);
      i = localTypedArray.getInteger(7, -1);
      localTypedArray.recycle();
    }
    if (arrayOfCharSequence != null)
      setAdapter(new ArrayAdapter(paramContext, 17367043, arrayOfCharSequence));
    if (localDrawable1 != null)
      setDivider(localDrawable1);
    if (localDrawable3 != null)
      setOverscrollHeader(localDrawable3);
    if (localDrawable2 != null)
      setOverscrollFooter(localDrawable2);
    if (j != 0)
      setDividerWidth(j);
    this.mHeaderDividersEnabled = bool1;
    this.mFooterDividersEnabled = bool2;
    this.mMeasureWithChild = i;
  }

  private View addViewAfter(View paramView, int paramInt)
  {
    int i = paramInt + 1;
    View localView = obtainView(i, this.mIsScrap);
    setupChild(localView, i, paramView.getRight() + this.mDividerWidth, true, this.mListPadding.top, false, this.mIsScrap[0]);
    return localView;
  }

  private View addViewBefore(View paramView, int paramInt)
  {
    int i = paramInt - 1;
    View localView = obtainView(i, this.mIsScrap);
    setupChild(localView, i, paramView.getLeft() - this.mDividerWidth, false, this.mListPadding.top, false, this.mIsScrap[0]);
    return localView;
  }

  private void adjustViewsLeftOrRight()
  {
    int i = getChildCount();
    int j;
    if (i > 0)
    {
      if (this.mStackFromRight)
        break label64;
      j = getChildAt(0).getLeft() - this.mListPadding.left;
      if (this.mFirstPosition != 0)
        j -= this.mDividerWidth;
      if (j < 0)
        j = 0;
    }
    while (true)
    {
      if (j != 0)
        offsetChildrenLeftAndRight(-j);
      return;
      label64: j = getChildAt(i - 1).getRight() - (getWidth() - this.mListPadding.right);
      if (i + this.mFirstPosition < this.mItemCount)
        j += this.mDividerWidth;
      if (j > 0)
        j = 0;
    }
  }

  private int amountToScroll(int paramInt1, int paramInt2)
  {
    int i = getWidth() - this.mListPadding.right;
    int j = this.mListPadding.left;
    int k = getChildCount();
    if (paramInt1 == 130)
    {
      int i3 = k - 1;
      if (paramInt2 != -1)
        i3 = paramInt2 - this.mFirstPosition;
      int i4 = i3 + this.mFirstPosition;
      View localView2 = getChildAt(i3);
      int i5 = i;
      if (i4 < -1 + this.mItemCount)
        i5 -= getArrowScrollPreviewLength();
      if (localView2.getRight() <= i5)
        return 0;
      if ((paramInt2 != -1) && (i5 - localView2.getLeft() >= getMaxScrollAmount()))
        return 0;
      int i6 = localView2.getRight() - i5;
      if (k + this.mFirstPosition == this.mItemCount)
        i6 = Math.min(i6, getChildAt(k - 1).getRight() - i);
      return Math.min(i6, getMaxScrollAmount());
    }
    int m = 0;
    if (paramInt2 != -1)
      m = paramInt2 - this.mFirstPosition;
    int n = m + this.mFirstPosition;
    View localView1 = getChildAt(m);
    int i1 = j;
    if (n > 0)
      i1 += getArrowScrollPreviewLength();
    if (localView1.getLeft() >= i1)
      return 0;
    if ((paramInt2 != -1) && (localView1.getRight() - i1 >= getMaxScrollAmount()))
      return 0;
    int i2 = i1 - localView1.getLeft();
    if (this.mFirstPosition == 0)
      i2 = Math.min(i2, j - getChildAt(0).getLeft());
    return Math.min(i2, getMaxScrollAmount());
  }

  private int amountToScrollToNewFocus(int paramInt1, View paramView, int paramInt2)
  {
    paramView.getDrawingRect(this.mTempRect);
    offsetDescendantRectToMyCoords(paramView, this.mTempRect);
    int k;
    if (paramInt1 == 33)
    {
      int m = this.mTempRect.left;
      int n = this.mListPadding.left;
      k = 0;
      if (m < n)
      {
        k = this.mListPadding.left - this.mTempRect.left;
        if (paramInt2 > 0)
          k += getArrowScrollPreviewLength();
      }
    }
    do
    {
      int i;
      int j;
      do
      {
        return k;
        i = getWidth() - this.mListPadding.right;
        j = this.mTempRect.bottom;
        k = 0;
      }
      while (j <= i);
      k = this.mTempRect.right - i;
    }
    while (paramInt2 >= -1 + this.mItemCount);
    return k + getArrowScrollPreviewLength();
  }

  private ArrowScrollFocusResult arrowScrollFocused(int paramInt)
  {
    View localView1 = getSelectedView();
    View localView2;
    int i1;
    if ((localView1 != null) && (localView1.hasFocus()))
    {
      View localView3 = localView1.findFocus();
      localView2 = FocusFinder.getInstance().findNextFocus(this, localView3, paramInt);
      if (localView2 == null)
        break label403;
      i1 = positionOfNewFocus(localView2);
      if ((this.mSelectedPosition != -1) && (i1 != this.mSelectedPosition))
      {
        int i4 = lookForSelectablePositionOnScreen(paramInt);
        if ((i4 != -1) && (((paramInt == 130) && (i4 < i1)) || ((paramInt == 33) && (i4 > i1))))
          return null;
      }
    }
    else
    {
      if (paramInt == 130)
      {
        int i5;
        label123: int i7;
        label143: int i8;
        if (this.mFirstPosition > 0)
        {
          i5 = 1;
          int i6 = this.mListPadding.left;
          if (i5 == 0)
            break label205;
          i7 = getArrowScrollPreviewLength();
          i8 = i6 + i7;
          if ((localView1 == null) || (localView1.getLeft() <= i8))
            break label211;
        }
        label205: label211: for (int i9 = localView1.getLeft(); ; i9 = i8)
        {
          this.mTempRect.set(i9, 0, i9, 0);
          localView2 = FocusFinder.getInstance().findNextFocusFromRect(this, this.mTempRect, paramInt);
          break;
          i5 = 0;
          break label123;
          i7 = 0;
          break label143;
        }
      }
      int i;
      label238: int k;
      label262: int m;
      if (-1 + (this.mFirstPosition + getChildCount()) < this.mItemCount)
      {
        i = 1;
        int j = getWidth() - this.mListPadding.right;
        if (i == 0)
          break label309;
        k = getArrowScrollPreviewLength();
        m = j - k;
        if ((localView1 == null) || (localView1.getRight() >= m))
          break label315;
      }
      label309: label315: for (int n = localView1.getRight(); ; n = m)
      {
        this.mTempRect.set(n, 0, n, 0);
        break;
        i = 0;
        break label238;
        k = 0;
        break label262;
      }
    }
    int i2 = amountToScrollToNewFocus(paramInt, localView2, i1);
    int i3 = getMaxScrollAmount();
    if (i2 < i3)
    {
      localView2.requestFocus(paramInt);
      this.mArrowScrollFocusResult.populate(i1, i2);
      return this.mArrowScrollFocusResult;
    }
    if (distanceToView(localView2) < i3)
    {
      localView2.requestFocus(paramInt);
      this.mArrowScrollFocusResult.populate(i1, i3);
      return this.mArrowScrollFocusResult;
    }
    label403: return null;
  }

  private boolean arrowScrollImpl(int paramInt)
  {
    if (getChildCount() <= 0)
      return false;
    View localView1 = getSelectedView();
    int i = this.mSelectedPosition;
    int j = lookForSelectablePositionOnScreen(paramInt);
    int k = amountToScroll(paramInt, j);
    ArrowScrollFocusResult localArrowScrollFocusResult;
    label49: int m;
    label76: boolean bool;
    if (this.mItemsCanFocus)
    {
      localArrowScrollFocusResult = arrowScrollFocused(paramInt);
      if (localArrowScrollFocusResult != null)
      {
        j = localArrowScrollFocusResult.getSelectedPosition();
        k = localArrowScrollFocusResult.getAmountToScroll();
      }
      if (localArrowScrollFocusResult == null)
        break label304;
      m = 1;
      if (j != -1)
      {
        if (localArrowScrollFocusResult == null)
          break label310;
        bool = true;
        label90: handleNewSelectionChange(localView1, paramInt, j, bool);
        setSelectedPositionInt(j);
        setNextSelectedPositionInt(j);
        localView1 = getSelectedView();
        i = j;
        if ((this.mItemsCanFocus) && (localArrowScrollFocusResult == null))
        {
          View localView3 = getFocusedChild();
          if (localView3 != null)
            localView3.clearFocus();
        }
        m = 1;
        checkSelectionChanged();
      }
      if (k > 0)
        if (paramInt != 33)
          break label316;
    }
    while (true)
    {
      scrollListItemsBy(k);
      m = 1;
      if ((this.mItemsCanFocus) && (localArrowScrollFocusResult == null) && (localView1 != null) && (localView1.hasFocus()))
      {
        View localView2 = localView1.findFocus();
        if ((!isViewAncestorOf(localView2, this)) || (distanceToView(localView2) > 0))
          localView2.clearFocus();
      }
      if ((j == -1) && (localView1 != null) && (!isViewAncestorOf(localView1, this)))
      {
        localView1 = null;
        hideSelector();
        this.mResurrectToPosition = -1;
      }
      if (m == 0)
        break;
      if (localView1 != null)
      {
        positionSelector(i, localView1);
        this.mSelectedLeft = localView1.getLeft();
      }
      if (!awakenScrollBars())
        invalidate();
      invokeOnItemScrollListener();
      return true;
      localArrowScrollFocusResult = null;
      break label49;
      label304: m = 0;
      break label76;
      label310: bool = false;
      break label90;
      label316: k = -k;
    }
  }

  private void clearRecycledState(ArrayList<FixedViewInfo> paramArrayList)
  {
    int i;
    if (paramArrayList != null)
      i = paramArrayList.size();
    for (int j = 0; ; j++)
    {
      if (j >= i)
        return;
      AbsHListView.LayoutParams localLayoutParams = (AbsHListView.LayoutParams)((FixedViewInfo)paramArrayList.get(j)).view.getLayoutParams();
      if (localLayoutParams != null)
        localLayoutParams.recycledHeaderFooter = false;
    }
  }

  @TargetApi(11)
  private boolean commonKey(int paramInt1, int paramInt2, KeyEvent paramKeyEvent)
  {
    if ((this.mAdapter == null) || (!this.mIsAttached));
    do
    {
      return false;
      if (this.mDataChanged)
        layoutChildren();
    }
    while (Build.VERSION.SDK_INT < 11);
    int i = paramKeyEvent.getAction();
    boolean bool1 = false;
    if (i != 1)
    {
      bool1 = false;
      switch (paramInt1)
      {
      default:
      case 19:
      case 20:
      case 21:
      case 22:
      case 23:
      case 66:
      case 62:
      case 92:
      case 93:
      case 122:
      case 123:
      }
    }
    while (bool1)
    {
      return true;
      if (paramKeyEvent.hasNoModifiers())
      {
        bool1 = resurrectSelectionIfNeeded();
        if (!bool1)
          for (int k = paramInt2; ; k = paramInt2)
          {
            paramInt2 = k - 1;
            if ((k <= 0) || (!arrowScroll(33)))
              break;
            bool1 = true;
          }
      }
      else
      {
        boolean bool10 = paramKeyEvent.hasModifiers(2);
        bool1 = false;
        if (bool10)
        {
          if ((!resurrectSelectionIfNeeded()) && (!fullScroll(33)));
          for (bool1 = false; ; bool1 = true)
            break;
          if (paramKeyEvent.hasNoModifiers())
          {
            bool1 = resurrectSelectionIfNeeded();
            if (!bool1)
              for (int j = paramInt2; ; j = paramInt2)
              {
                paramInt2 = j - 1;
                if ((j <= 0) || (!arrowScroll(130)))
                  break;
                bool1 = true;
              }
          }
          else
          {
            boolean bool9 = paramKeyEvent.hasModifiers(2);
            bool1 = false;
            if (bool9)
            {
              if ((!resurrectSelectionIfNeeded()) && (!fullScroll(130)));
              for (bool1 = false; ; bool1 = true)
                break;
              boolean bool8 = paramKeyEvent.hasNoModifiers();
              bool1 = false;
              if (bool8)
              {
                bool1 = handleHorizontalFocusWithinListItem(17);
                continue;
                boolean bool7 = paramKeyEvent.hasNoModifiers();
                bool1 = false;
                if (bool7)
                {
                  bool1 = handleHorizontalFocusWithinListItem(66);
                  continue;
                  boolean bool6 = paramKeyEvent.hasNoModifiers();
                  bool1 = false;
                  if (bool6)
                  {
                    bool1 = resurrectSelectionIfNeeded();
                    if ((!bool1) && (paramKeyEvent.getRepeatCount() == 0) && (getChildCount() > 0))
                    {
                      keyPressed();
                      bool1 = true;
                      continue;
                      if (paramKeyEvent.hasNoModifiers())
                        if ((resurrectSelectionIfNeeded()) || (pageScroll(130)));
                      while ((!paramKeyEvent.hasModifiers(1)) || ((!resurrectSelectionIfNeeded()) && (!pageScroll(33))))
                        while (true)
                        {
                          bool1 = true;
                          break;
                        }
                      while (true);
                      if (paramKeyEvent.hasNoModifiers())
                      {
                        if ((!resurrectSelectionIfNeeded()) && (!pageScroll(33)));
                        for (bool1 = false; ; bool1 = true)
                          break;
                      }
                      boolean bool5 = paramKeyEvent.hasModifiers(2);
                      bool1 = false;
                      if (bool5)
                      {
                        if ((!resurrectSelectionIfNeeded()) && (!fullScroll(33)));
                        for (bool1 = false; ; bool1 = true)
                          break;
                        if (paramKeyEvent.hasNoModifiers())
                        {
                          if ((!resurrectSelectionIfNeeded()) && (!pageScroll(130)));
                          for (bool1 = false; ; bool1 = true)
                            break;
                        }
                        boolean bool4 = paramKeyEvent.hasModifiers(2);
                        bool1 = false;
                        if (bool4)
                        {
                          if ((!resurrectSelectionIfNeeded()) && (!fullScroll(130)));
                          for (bool1 = false; ; bool1 = true)
                            break;
                          boolean bool3 = paramKeyEvent.hasNoModifiers();
                          bool1 = false;
                          if (bool3)
                          {
                            if ((!resurrectSelectionIfNeeded()) && (!fullScroll(33)));
                            for (bool1 = false; ; bool1 = true)
                              break;
                            boolean bool2 = paramKeyEvent.hasNoModifiers();
                            bool1 = false;
                            if (bool2)
                            {
                              if ((!resurrectSelectionIfNeeded()) && (!fullScroll(130)));
                              for (bool1 = false; ; bool1 = true)
                                break;
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    switch (i)
    {
    default:
      return false;
    case 0:
      return super.onKeyDown(paramInt1, paramKeyEvent);
    case 1:
      return super.onKeyUp(paramInt1, paramKeyEvent);
    case 2:
    }
    return super.onKeyMultiple(paramInt1, paramInt2, paramKeyEvent);
  }

  private void correctTooSmall(int paramInt)
  {
    int i1;
    if ((this.mFirstPosition == 0) && (paramInt > 0))
    {
      int i = getChildAt(0).getLeft();
      int j = this.mListPadding.left;
      int k = getRight() - getLeft() - this.mListPadding.right;
      int m = i - j;
      View localView = getChildAt(paramInt - 1);
      int n = localView.getRight();
      i1 = -1 + (paramInt + this.mFirstPosition);
      if (m > 0)
      {
        if ((i1 >= -1 + this.mItemCount) && (n <= k))
          break label166;
        if (i1 == -1 + this.mItemCount)
          m = Math.min(m, n - k);
        offsetChildrenLeftAndRight(-m);
        if (i1 < -1 + this.mItemCount)
        {
          fillRight(i1 + 1, localView.getRight() + this.mDividerWidth);
          adjustViewsLeftOrRight();
        }
      }
    }
    label166: 
    while (i1 != -1 + this.mItemCount)
      return;
    adjustViewsLeftOrRight();
  }

  private void correctTooWide(int paramInt)
  {
    if ((-1 + (paramInt + this.mFirstPosition) == -1 + this.mItemCount) && (paramInt > 0))
    {
      int i = getChildAt(paramInt - 1).getRight();
      int j = getRight() - getLeft() - this.mListPadding.right - i;
      View localView = getChildAt(0);
      int k = localView.getLeft();
      if ((j > 0) && ((this.mFirstPosition > 0) || (k < this.mListPadding.top)))
      {
        if (this.mFirstPosition == 0)
          j = Math.min(j, this.mListPadding.top - k);
        offsetChildrenLeftAndRight(j);
        if (this.mFirstPosition > 0)
        {
          fillLeft(-1 + this.mFirstPosition, localView.getLeft() - this.mDividerWidth);
          adjustViewsLeftOrRight();
        }
      }
    }
  }

  private int distanceToView(View paramView)
  {
    paramView.getDrawingRect(this.mTempRect);
    offsetDescendantRectToMyCoords(paramView, this.mTempRect);
    int i = getRight() - getLeft() - this.mListPadding.right;
    int k;
    if (this.mTempRect.right < this.mListPadding.left)
      k = this.mListPadding.left - this.mTempRect.right;
    int j;
    do
    {
      return k;
      j = this.mTempRect.left;
      k = 0;
    }
    while (j <= i);
    return this.mTempRect.left - i;
  }

  private void fillBeforeAndAfter(View paramView, int paramInt)
  {
    int i = this.mDividerWidth;
    if (!this.mStackFromRight)
    {
      fillLeft(paramInt - 1, paramView.getLeft() - i);
      adjustViewsLeftOrRight();
      fillRight(paramInt + 1, i + paramView.getRight());
      return;
    }
    fillRight(paramInt + 1, i + paramView.getRight());
    adjustViewsLeftOrRight();
    fillLeft(paramInt - 1, paramView.getLeft() - i);
  }

  private View fillFromLeft(int paramInt)
  {
    this.mFirstPosition = Math.min(this.mFirstPosition, this.mSelectedPosition);
    this.mFirstPosition = Math.min(this.mFirstPosition, -1 + this.mItemCount);
    if (this.mFirstPosition < 0)
      this.mFirstPosition = 0;
    return fillRight(this.mFirstPosition, paramInt);
  }

  private View fillFromMiddle(int paramInt1, int paramInt2)
  {
    int i = paramInt2 - paramInt1;
    int j = reconcileSelectedPosition();
    View localView = makeAndAddView(j, paramInt1, true, this.mListPadding.top, true);
    this.mFirstPosition = j;
    int k = localView.getMeasuredWidth();
    if (k <= i)
      localView.offsetLeftAndRight((i - k) / 2);
    fillBeforeAndAfter(localView, j);
    if (!this.mStackFromRight)
    {
      correctTooWide(getChildCount());
      return localView;
    }
    correctTooSmall(getChildCount());
    return localView;
  }

  private View fillFromSelection(int paramInt1, int paramInt2, int paramInt3)
  {
    int i = getHorizontalFadingEdgeLength();
    int j = this.mSelectedPosition;
    int k = getLeftSelectionPixel(paramInt2, i, j);
    int m = getRightSelectionPixel(paramInt3, i, j);
    View localView = makeAndAddView(j, paramInt1, true, this.mListPadding.top, true);
    if (localView.getRight() > m)
      localView.offsetLeftAndRight(-Math.min(localView.getLeft() - k, localView.getRight() - m));
    while (true)
    {
      fillBeforeAndAfter(localView, j);
      if (this.mStackFromRight)
        break;
      correctTooWide(getChildCount());
      return localView;
      if (localView.getLeft() < k)
        localView.offsetLeftAndRight(Math.min(k - localView.getLeft(), m - localView.getRight()));
    }
    correctTooSmall(getChildCount());
    return localView;
  }

  private View fillLeft(int paramInt1, int paramInt2)
  {
    Object localObject = null;
    if ((paramInt2 <= 0) || (paramInt1 < 0))
    {
      this.mFirstPosition = (paramInt1 + 1);
      setVisibleRangeHint(this.mFirstPosition, -1 + (this.mFirstPosition + getChildCount()));
      return localObject;
    }
    if (paramInt1 == this.mSelectedPosition);
    for (boolean bool = true; ; bool = false)
    {
      int i = this.mListPadding.top;
      View localView = makeAndAddView(paramInt1, paramInt2, false, i, bool);
      paramInt2 = localView.getLeft() - this.mDividerWidth;
      if (bool)
        localObject = localView;
      paramInt1--;
      break;
    }
  }

  private View fillRight(int paramInt1, int paramInt2)
  {
    Object localObject = null;
    int i = getRight() - getLeft();
    if ((paramInt2 >= i) || (paramInt1 >= this.mItemCount))
    {
      setVisibleRangeHint(this.mFirstPosition, -1 + (this.mFirstPosition + getChildCount()));
      return localObject;
    }
    if (paramInt1 == this.mSelectedPosition);
    for (boolean bool = true; ; bool = false)
    {
      int j = this.mListPadding.top;
      View localView = makeAndAddView(paramInt1, paramInt2, true, j, bool);
      paramInt2 = localView.getRight() + this.mDividerWidth;
      if (bool)
        localObject = localView;
      paramInt1++;
      break;
    }
  }

  private View fillSpecific(int paramInt1, int paramInt2)
  {
    boolean bool;
    View localView1;
    int i;
    View localView3;
    View localView2;
    if (paramInt1 == this.mSelectedPosition)
    {
      bool = true;
      localView1 = makeAndAddView(paramInt1, paramInt2, true, this.mListPadding.top, bool);
      this.mFirstPosition = paramInt1;
      i = this.mDividerWidth;
      if (this.mStackFromRight)
        break label112;
      localView3 = fillLeft(paramInt1 - 1, localView1.getLeft() - i);
      adjustViewsLeftOrRight();
      localView2 = fillRight(paramInt1 + 1, i + localView1.getRight());
      int k = getChildCount();
      if (k > 0)
        correctTooWide(k);
    }
    while (true)
    {
      if (!bool)
        break label170;
      return localView1;
      bool = false;
      break;
      label112: localView2 = fillRight(paramInt1 + 1, i + localView1.getRight());
      adjustViewsLeftOrRight();
      localView3 = fillLeft(paramInt1 - 1, localView1.getLeft() - i);
      int j = getChildCount();
      if (j > 0)
        correctTooSmall(j);
    }
    label170: if (localView3 != null)
      return localView3;
    return localView2;
  }

  private View findAccessibilityFocusedChild(View paramView)
  {
    for (ViewParent localViewParent = paramView.getParent(); ; localViewParent = localViewParent.getParent())
    {
      if ((!(localViewParent instanceof View)) || (localViewParent == this))
      {
        if (!(localViewParent instanceof View))
          paramView = null;
        return paramView;
      }
      paramView = (View)localViewParent;
    }
  }

  private int getArrowScrollPreviewLength()
  {
    return Math.max(2, getHorizontalFadingEdgeLength());
  }

  private int getLeftSelectionPixel(int paramInt1, int paramInt2, int paramInt3)
  {
    int i = paramInt1;
    if (paramInt3 > 0)
      i += paramInt2;
    return i;
  }

  private int getRightSelectionPixel(int paramInt1, int paramInt2, int paramInt3)
  {
    int i = paramInt1;
    if (paramInt3 != -1 + this.mItemCount)
      i -= paramInt2;
    return i;
  }

  private boolean handleHorizontalFocusWithinListItem(int paramInt)
  {
    if ((paramInt != 17) && (paramInt != 66))
      throw new IllegalArgumentException("direction must be one of {View.FOCUS_LEFT, View.FOCUS_RIGHT}");
    int i = getChildCount();
    if ((this.mItemsCanFocus) && (i > 0) && (this.mSelectedPosition != -1))
    {
      View localView1 = getSelectedView();
      if ((localView1 != null) && (localView1.hasFocus()) && ((localView1 instanceof ViewGroup)))
      {
        View localView2 = localView1.findFocus();
        View localView3 = FocusFinder.getInstance().findNextFocus((ViewGroup)localView1, localView2, paramInt);
        if (localView3 != null)
        {
          localView2.getFocusedRect(this.mTempRect);
          offsetDescendantRectToMyCoords(localView2, this.mTempRect);
          offsetRectIntoDescendantCoords(localView3, this.mTempRect);
          if (localView3.requestFocus(paramInt, this.mTempRect))
            return true;
        }
        View localView4 = FocusFinder.getInstance().findNextFocus((ViewGroup)getRootView(), localView2, paramInt);
        if (localView4 != null)
          return isViewAncestorOf(localView4, this);
      }
    }
    return false;
  }

  private void handleNewSelectionChange(View paramView, int paramInt1, int paramInt2, boolean paramBoolean)
  {
    if (paramInt2 == -1)
      throw new IllegalArgumentException("newSelectedPosition needs to be valid");
    int i = this.mSelectedPosition - this.mFirstPosition;
    int j = paramInt2 - this.mFirstPosition;
    int k;
    int m;
    View localView1;
    View localView2;
    int n;
    int i1;
    boolean bool2;
    if (paramInt1 == 33)
    {
      k = j;
      m = i;
      localView1 = getChildAt(k);
      localView2 = paramView;
      n = 1;
      i1 = getChildCount();
      if (localView1 != null)
      {
        if ((paramBoolean) || (n == 0))
          break label165;
        bool2 = true;
        label87: localView1.setSelected(bool2);
        measureAndAdjustRight(localView1, k, i1);
      }
      if (localView2 != null)
        if ((paramBoolean) || (n != 0))
          break label171;
    }
    label165: label171: for (boolean bool1 = true; ; bool1 = false)
    {
      localView2.setSelected(bool1);
      measureAndAdjustRight(localView2, m, i1);
      return;
      k = i;
      m = j;
      localView1 = paramView;
      localView2 = getChildAt(m);
      n = 0;
      break;
      bool2 = false;
      break label87;
    }
  }

  private boolean isDirectChildHeaderOrFooter(View paramView)
  {
    ArrayList localArrayList1 = this.mHeaderViewInfos;
    int i = localArrayList1.size();
    int j = 0;
    ArrayList localArrayList2;
    int k;
    if (j >= i)
    {
      localArrayList2 = this.mFooterViewInfos;
      k = localArrayList2.size();
    }
    for (int m = 0; ; m++)
    {
      if (m >= k)
      {
        return false;
        if (paramView == ((FixedViewInfo)localArrayList1.get(j)).view)
          return true;
        j++;
        break;
      }
      if (paramView == ((FixedViewInfo)localArrayList2.get(m)).view)
        return true;
    }
  }

  private boolean isViewAncestorOf(View paramView1, View paramView2)
  {
    if (paramView1 == paramView2);
    ViewParent localViewParent;
    do
    {
      return true;
      localViewParent = paramView1.getParent();
    }
    while (((localViewParent instanceof ViewGroup)) && (isViewAncestorOf((View)localViewParent, paramView2)));
    return false;
  }

  private int lookForSelectablePositionOnScreen(int paramInt)
  {
    int i = this.mFirstPosition;
    int m;
    ListAdapter localListAdapter2;
    if (paramInt == 130)
    {
      if (this.mSelectedPosition != -1);
      for (int n = 1 + this.mSelectedPosition; n >= this.mAdapter.getCount(); n = i)
      {
        m = -1;
        return m;
      }
      if (n < i)
        n = i;
      int i1 = getLastVisiblePosition();
      localListAdapter2 = getAdapter();
      m = n;
      label79: if (m <= i1);
    }
    label234: 
    while (true)
    {
      return -1;
      if ((localListAdapter2.isEnabled(m)) && (getChildAt(m - i).getVisibility() == 0))
        break;
      m++;
      break label79;
      int j = -1 + (i + getChildCount());
      if (this.mSelectedPosition != -1);
      for (int k = -1 + this.mSelectedPosition; (k < 0) || (k >= this.mAdapter.getCount()); k = -1 + (i + getChildCount()))
        return -1;
      if (k > j)
        k = j;
      ListAdapter localListAdapter1 = getAdapter();
      for (m = k; ; m--)
      {
        if (m < i)
          break label234;
        if ((localListAdapter1.isEnabled(m)) && (getChildAt(m - i).getVisibility() == 0))
          break;
      }
    }
  }

  private View makeAndAddView(int paramInt1, int paramInt2, boolean paramBoolean1, int paramInt3, boolean paramBoolean2)
  {
    if (!this.mDataChanged)
    {
      View localView2 = this.mRecycler.getActiveView(paramInt1);
      if (localView2 != null)
      {
        setupChild(localView2, paramInt1, paramInt2, paramBoolean1, paramInt3, paramBoolean2, true);
        return localView2;
      }
    }
    View localView1 = obtainView(paramInt1, this.mIsScrap);
    setupChild(localView1, paramInt1, paramInt2, paramBoolean1, paramInt3, paramBoolean2, this.mIsScrap[0]);
    return localView1;
  }

  private void measureAndAdjustRight(View paramView, int paramInt1, int paramInt2)
  {
    int i = paramView.getWidth();
    measureItem(paramView);
    int j;
    if (paramView.getMeasuredWidth() != i)
    {
      relayoutMeasuredItem(paramView);
      j = paramView.getMeasuredWidth() - i;
    }
    for (int k = paramInt1 + 1; ; k++)
    {
      if (k >= paramInt2)
        return;
      getChildAt(k).offsetLeftAndRight(j);
    }
  }

  private void measureItem(View paramView)
  {
    ViewGroup.LayoutParams localLayoutParams = paramView.getLayoutParams();
    if (localLayoutParams == null)
      localLayoutParams = new ViewGroup.LayoutParams(-2, -1);
    int i = ViewGroup.getChildMeasureSpec(this.mHeightMeasureSpec, this.mListPadding.top + this.mListPadding.bottom, localLayoutParams.height);
    int j = localLayoutParams.width;
    if (j > 0);
    for (int k = View.MeasureSpec.makeMeasureSpec(j, 1073741824); ; k = View.MeasureSpec.makeMeasureSpec(0, 0))
    {
      paramView.measure(k, i);
      return;
    }
  }

  private void measureScrapChildWidth(View paramView, int paramInt1, int paramInt2)
  {
    AbsHListView.LayoutParams localLayoutParams = (AbsHListView.LayoutParams)paramView.getLayoutParams();
    if (localLayoutParams == null)
    {
      localLayoutParams = (AbsHListView.LayoutParams)generateDefaultLayoutParams();
      paramView.setLayoutParams(localLayoutParams);
    }
    localLayoutParams.viewType = this.mAdapter.getItemViewType(paramInt1);
    localLayoutParams.forceAdd = true;
    int i = ViewGroup.getChildMeasureSpec(paramInt2, this.mListPadding.top + this.mListPadding.bottom, localLayoutParams.height);
    int j = localLayoutParams.width;
    if (j > 0);
    for (int k = View.MeasureSpec.makeMeasureSpec(j, 1073741824); ; k = View.MeasureSpec.makeMeasureSpec(0, 0))
    {
      paramView.measure(k, i);
      return;
    }
  }

  private View moveSelection(View paramView1, View paramView2, int paramInt1, int paramInt2, int paramInt3)
  {
    int i = getHorizontalFadingEdgeLength();
    int j = this.mSelectedPosition;
    int k = getLeftSelectionPixel(paramInt2, i, j);
    int m = getRightSelectionPixel(paramInt2, i, j);
    if (paramInt1 > 0)
    {
      View localView3 = makeAndAddView(j - 1, paramView1.getLeft(), true, this.mListPadding.top, false);
      int i5 = this.mDividerWidth;
      View localView4 = makeAndAddView(j, i5 + localView3.getRight(), true, this.mListPadding.top, true);
      if (localView4.getRight() > m)
      {
        int i6 = localView4.getLeft() - k;
        int i7 = localView4.getRight() - m;
        int i8 = (paramInt3 - paramInt2) / 2;
        int i9 = Math.min(Math.min(i6, i7), i8);
        localView3.offsetLeftAndRight(-i9);
        localView4.offsetLeftAndRight(-i9);
      }
      if (!this.mStackFromRight)
      {
        fillLeft(-2 + this.mSelectedPosition, localView4.getLeft() - i5);
        adjustViewsLeftOrRight();
        fillRight(1 + this.mSelectedPosition, i5 + localView4.getRight());
        return localView4;
      }
      fillRight(1 + this.mSelectedPosition, i5 + localView4.getRight());
      adjustViewsLeftOrRight();
      fillLeft(-2 + this.mSelectedPosition, localView4.getLeft() - i5);
      return localView4;
    }
    if (paramInt1 < 0)
    {
      if (paramView2 != null);
      for (View localView2 = makeAndAddView(j, paramView2.getLeft(), true, this.mListPadding.top, true); ; localView2 = makeAndAddView(j, paramView1.getLeft(), false, this.mListPadding.top, true))
      {
        if (localView2.getLeft() < k)
        {
          int i1 = k - localView2.getLeft();
          int i2 = m - localView2.getRight();
          int i3 = (paramInt3 - paramInt2) / 2;
          int i4 = Math.min(Math.min(i1, i2), i3);
          localView2.offsetLeftAndRight(i4);
        }
        fillBeforeAndAfter(localView2, j);
        return localView2;
      }
    }
    int n = paramView1.getLeft();
    View localView1 = makeAndAddView(j, n, true, this.mListPadding.top, true);
    if ((n < paramInt2) && (localView1.getRight() < paramInt2 + 20))
      localView1.offsetLeftAndRight(paramInt2 - localView1.getLeft());
    fillBeforeAndAfter(localView1, j);
    return localView1;
  }

  private int positionOfNewFocus(View paramView)
  {
    int i = getChildCount();
    for (int j = 0; ; j++)
    {
      if (j >= i)
        throw new IllegalArgumentException("newFocus is not a child of any of the children of the list!");
      if (isViewAncestorOf(paramView, getChildAt(j)))
        return j + this.mFirstPosition;
    }
  }

  private void relayoutMeasuredItem(View paramView)
  {
    int i = paramView.getMeasuredWidth();
    int j = paramView.getMeasuredHeight();
    int k = this.mListPadding.top;
    int m = k + j;
    int n = paramView.getLeft();
    paramView.layout(n, k, n + i, m);
  }

  private void removeFixedViewInfo(View paramView, ArrayList<FixedViewInfo> paramArrayList)
  {
    int i = paramArrayList.size();
    for (int j = 0; ; j++)
    {
      if (j >= i)
        return;
      if (((FixedViewInfo)paramArrayList.get(j)).view == paramView)
      {
        paramArrayList.remove(j);
        return;
      }
    }
  }

  private void scrollListItemsBy(int paramInt)
  {
    offsetChildrenLeftAndRight(paramInt);
    int i = getWidth() - this.mListPadding.right;
    int j = this.mListPadding.left;
    AbsHListView.RecycleBin localRecycleBin = this.mRecycler;
    if (paramInt < 0)
    {
      int m = getChildCount();
      View localView3 = getChildAt(m - 1);
      View localView4;
      while (true)
      {
        if (localView3.getRight() >= i);
        int n;
        do
        {
          if (localView3.getBottom() < i)
            offsetChildrenLeftAndRight(i - localView3.getRight());
          localView4 = getChildAt(0);
          if (localView4.getRight() < j)
            break;
          return;
          n = -1 + (m + this.mFirstPosition);
        }
        while (n >= -1 + this.mItemCount);
        localView3 = addViewAfter(localView3, n);
        m++;
      }
      if (localRecycleBin.shouldRecycleViewType(((AbsHListView.LayoutParams)localView4.getLayoutParams()).viewType))
      {
        detachViewFromParent(localView4);
        localRecycleBin.addScrapView(localView4, this.mFirstPosition);
      }
      while (true)
      {
        localView4 = getChildAt(0);
        this.mFirstPosition = (1 + this.mFirstPosition);
        break;
        removeViewInLayout(localView4);
      }
    }
    View localView1 = getChildAt(0);
    label208: int k;
    View localView2;
    if ((localView1.getLeft() <= j) || (this.mFirstPosition <= 0))
    {
      if (localView1.getLeft() > j)
        offsetChildrenLeftAndRight(j - localView1.getLeft());
      k = -1 + getChildCount();
      localView2 = getChildAt(k);
      label260: if (localView2.getLeft() > i)
      {
        if (!localRecycleBin.shouldRecycleViewType(((AbsHListView.LayoutParams)localView2.getLayoutParams()).viewType))
          break label347;
        detachViewFromParent(localView2);
        localRecycleBin.addScrapView(localView2, k + this.mFirstPosition);
      }
    }
    while (true)
    {
      k--;
      localView2 = getChildAt(k);
      break label260;
      break;
      localView1 = addViewBefore(localView1, this.mFirstPosition);
      this.mFirstPosition = (-1 + this.mFirstPosition);
      break label208;
      label347: removeViewInLayout(localView2);
    }
  }

  @TargetApi(11)
  private void setupChild(View paramView, int paramInt1, int paramInt2, boolean paramBoolean1, int paramInt3, boolean paramBoolean2, boolean paramBoolean3)
  {
    boolean bool1;
    boolean bool3;
    label52: int j;
    label81: AbsHListView.LayoutParams localLayoutParams;
    int i6;
    label158: label227: int i5;
    label283: label291: int m;
    int i1;
    if ((paramBoolean2) && (shouldShowSelector()))
    {
      bool1 = true;
      boolean bool2 = bool1 ^ paramView.isSelected();
      int i = this.mTouchMode;
      if ((i <= 0) || (i >= 3) || (this.mMotionPosition != paramInt1))
        break label395;
      bool3 = true;
      boolean bool4 = bool3 ^ paramView.isPressed();
      if ((!paramBoolean3) || (bool2) || (paramView.isLayoutRequested()))
        break label401;
      j = 0;
      localLayoutParams = (AbsHListView.LayoutParams)paramView.getLayoutParams();
      if (localLayoutParams == null)
        localLayoutParams = (AbsHListView.LayoutParams)generateDefaultLayoutParams();
      localLayoutParams.viewType = this.mAdapter.getItemViewType(paramInt1);
      if (((!paramBoolean3) || (localLayoutParams.forceAdd)) && ((!localLayoutParams.recycledHeaderFooter) || (localLayoutParams.viewType != -2)))
        break label413;
      if (!paramBoolean1)
        break label407;
      i6 = -1;
      attachViewToParent(paramView, i6, localLayoutParams);
      if (bool2)
        paramView.setSelected(bool1);
      if (bool4)
        paramView.setPressed(bool3);
      if ((this.mChoiceMode != 0) && (this.mCheckStates != null))
      {
        if (!(paramView instanceof Checkable))
          break label463;
        ((Checkable)paramView).setChecked(this.mCheckStates.get(paramInt1));
      }
      if (j == 0)
        break label496;
      int i3 = ViewGroup.getChildMeasureSpec(this.mHeightMeasureSpec, this.mListPadding.top + this.mListPadding.bottom, localLayoutParams.height);
      int i4 = localLayoutParams.width;
      if (i4 <= 0)
        break label486;
      i5 = View.MeasureSpec.makeMeasureSpec(i4, 1073741824);
      paramView.measure(i5, i3);
      m = paramView.getMeasuredWidth();
      int n = paramView.getMeasuredHeight();
      if (!paramBoolean1)
        break label504;
      i1 = paramInt2;
      label311: if (j == 0)
        break label513;
      int i2 = paramInt3 + n;
      paramView.layout(i1, paramInt3, i1 + m, i2);
    }
    while (true)
    {
      if ((this.mCachingStarted) && (!paramView.isDrawingCacheEnabled()))
        paramView.setDrawingCacheEnabled(true);
      if ((Build.VERSION.SDK_INT >= 11) && (paramBoolean3) && (((AbsHListView.LayoutParams)paramView.getLayoutParams()).scrappedFromPosition != paramInt1))
        paramView.jumpDrawablesToCurrentState();
      return;
      bool1 = false;
      break;
      label395: bool3 = false;
      break label52;
      label401: j = 1;
      break label81;
      label407: i6 = 0;
      break label158;
      label413: localLayoutParams.forceAdd = false;
      if (localLayoutParams.viewType == -2)
        localLayoutParams.recycledHeaderFooter = true;
      if (paramBoolean1);
      for (int k = -1; ; k = 0)
      {
        addViewInLayout(paramView, k, localLayoutParams, true);
        break;
      }
      label463: if (Build.VERSION.SDK_INT < 11)
        break label227;
      paramView.setActivated(this.mCheckStates.get(paramInt1));
      break label227;
      label486: i5 = View.MeasureSpec.makeMeasureSpec(0, 0);
      break label283;
      label496: cleanupLayoutState(paramView);
      break label291;
      label504: i1 = paramInt2 - m;
      break label311;
      label513: paramView.offsetLeftAndRight(i1 - paramView.getLeft());
      paramView.offsetTopAndBottom(paramInt3 - paramView.getTop());
    }
  }

  private boolean showingLeftFadingEdge()
  {
    int i = getScrollX() + this.mListPadding.left;
    return (this.mFirstPosition > 0) || (getChildAt(0).getLeft() > i);
  }

  private boolean showingRightFadingEdge()
  {
    int i = getChildCount();
    int j = getChildAt(i - 1).getRight();
    int k = -1 + (i + this.mFirstPosition);
    int m = getScrollX() + getWidth() - this.mListPadding.right;
    return (k < -1 + this.mItemCount) || (j < m);
  }

  public void addFooterView(View paramView)
  {
    addFooterView(paramView, null, true);
  }

  public void addFooterView(View paramView, Object paramObject, boolean paramBoolean)
  {
    FixedViewInfo localFixedViewInfo = new FixedViewInfo();
    localFixedViewInfo.view = paramView;
    localFixedViewInfo.data = paramObject;
    localFixedViewInfo.isSelectable = paramBoolean;
    this.mFooterViewInfos.add(localFixedViewInfo);
    if ((this.mAdapter != null) && (this.mDataSetObserver != null))
      this.mDataSetObserver.onChanged();
  }

  public void addHeaderView(View paramView)
  {
    addHeaderView(paramView, null, true);
  }

  public void addHeaderView(View paramView, Object paramObject, boolean paramBoolean)
  {
    if ((this.mAdapter != null) && (!(this.mAdapter instanceof HeaderViewListAdapter)))
      throw new IllegalStateException("Cannot add header view to list -- setAdapter has already been called.");
    FixedViewInfo localFixedViewInfo = new FixedViewInfo();
    localFixedViewInfo.view = paramView;
    localFixedViewInfo.data = paramObject;
    localFixedViewInfo.isSelectable = paramBoolean;
    this.mHeaderViewInfos.add(localFixedViewInfo);
    if ((this.mAdapter != null) && (this.mDataSetObserver != null))
      this.mDataSetObserver.onChanged();
  }

  boolean arrowScroll(int paramInt)
  {
    try
    {
      this.mInLayout = true;
      boolean bool = arrowScrollImpl(paramInt);
      if (bool)
        playSoundEffect(SoundEffectConstants.getContantForFocusDirection(paramInt));
      return bool;
    }
    finally
    {
      this.mInLayout = false;
    }
  }

  protected boolean canAnimate()
  {
    return (super.canAnimate()) && (this.mItemCount > 0);
  }

  protected void dispatchDraw(Canvas paramCanvas)
  {
    if (this.mCachingStarted)
      this.mCachingActive = true;
    int i = this.mDividerWidth;
    Drawable localDrawable1 = this.mOverScrollHeader;
    Drawable localDrawable2 = this.mOverScrollFooter;
    int j;
    int k;
    label43: int m;
    label57: Rect localRect;
    int n;
    int i1;
    int i3;
    boolean bool1;
    boolean bool2;
    int i4;
    boolean bool3;
    ListAdapter localListAdapter;
    int i5;
    label188: Paint localPaint;
    int i6;
    int i13;
    label305: int i15;
    if (localDrawable1 != null)
    {
      j = 1;
      if (localDrawable2 == null)
        break label383;
      k = 1;
      if ((i <= 0) || (this.mDivider == null))
        break label389;
      m = 1;
      if ((m != 0) || (j != 0) || (k != 0))
      {
        localRect = this.mTempRect;
        localRect.top = getPaddingTop();
        localRect.bottom = (getBottom() - getTop() - getPaddingBottom());
        n = getChildCount();
        i1 = this.mHeaderViewInfos.size();
        int i2 = this.mItemCount;
        i3 = -1 + (i2 - this.mFooterViewInfos.size());
        bool1 = this.mHeaderDividersEnabled;
        bool2 = this.mFooterDividersEnabled;
        i4 = this.mFirstPosition;
        bool3 = this.mAreAllItemsSelectable;
        localListAdapter = this.mAdapter;
        if ((!isOpaque()) || (super.isOpaque()))
          break label395;
        i5 = 1;
        if ((i5 != 0) && (this.mDividerPaint == null) && (this.mIsCacheColorOpaque))
        {
          this.mDividerPaint = new Paint();
          this.mDividerPaint.setColor(getCacheColorHint());
        }
        localPaint = this.mDividerPaint;
        i6 = getRight() - getLeft() - 0 + getScrollX();
        if (this.mStackFromRight)
          break label614;
        i13 = 0;
        int i14 = getScrollX();
        if ((n > 0) && (i14 < 0))
        {
          if (j == 0)
            break label401;
          localRect.right = 0;
          localRect.left = i14;
          drawOverscrollHeader(paramCanvas, localDrawable1, localRect);
        }
        i15 = 0;
        if (i15 < n)
          break label430;
        int i18 = getRight() + getScrollX();
        if ((k != 0) && (i4 + n == i2) && (i18 > i13))
        {
          localRect.left = i13;
          localRect.right = i18;
          drawOverscrollFooter(paramCanvas, localDrawable2, localRect);
        }
      }
    }
    while (true)
    {
      super.dispatchDraw(paramCanvas);
      return;
      j = 0;
      break;
      label383: k = 0;
      break label43;
      label389: m = 0;
      break label57;
      label395: i5 = 0;
      break label188;
      label401: if (m == 0)
        break label305;
      localRect.right = 0;
      localRect.left = (-i);
      drawDivider(paramCanvas, localRect, -1);
      break label305;
      label430: if (((bool1) || (i4 + i15 >= i1)) && ((bool2) || (i4 + i15 < i3)))
      {
        i13 = getChildAt(i15).getRight();
        if ((m != 0) && (i13 < i6))
          if (k != 0)
          {
            int i17 = n - 1;
            if (i15 == i17);
          }
          else
          {
            if (!bool3)
            {
              if (!localListAdapter.isEnabled(i4 + i15))
                break label582;
              int i16 = n - 1;
              if ((i15 != i16) && (!localListAdapter.isEnabled(1 + (i4 + i15))))
                break label582;
            }
            localRect.left = i13;
            localRect.right = (i13 + i);
            drawDivider(paramCanvas, localRect, i15);
          }
      }
      while (true)
      {
        i15++;
        break;
        label582: if (i5 != 0)
        {
          localRect.left = i13;
          localRect.right = (i13 + i);
          paramCanvas.drawRect(localRect, localPaint);
        }
      }
      label614: int i7 = getScrollX();
      if ((n > 0) && (j != 0))
      {
        localRect.left = i7;
        localRect.right = getChildAt(0).getLeft();
        drawOverscrollHeader(paramCanvas, localDrawable1, localRect);
      }
      if (j != 0);
      int i9;
      for (int i8 = 1; ; i8 = 0)
      {
        i9 = i8;
        if (i9 < n)
          break label733;
        if ((n <= 0) || (i7 <= 0))
          break;
        if (k == 0)
          break label894;
        int i12 = getRight();
        localRect.left = i12;
        localRect.right = (i12 + i7);
        drawOverscrollFooter(paramCanvas, localDrawable2, localRect);
        break;
      }
      label733: int i10;
      if (((bool1) || (i4 + i9 >= i1)) && ((bool2) || (i4 + i9 < i3)))
      {
        i10 = getChildAt(i9).getLeft();
        if (i10 > 0)
        {
          if (!bool3)
          {
            if (!localListAdapter.isEnabled(i4 + i9))
              break label862;
            int i11 = n - 1;
            if ((i9 != i11) && (!localListAdapter.isEnabled(1 + (i4 + i9))))
              break label862;
          }
          localRect.left = (i10 - i);
          localRect.right = i10;
          drawDivider(paramCanvas, localRect, i9 - 1);
        }
      }
      while (true)
      {
        i9++;
        break;
        label862: if (i5 != 0)
        {
          localRect.left = (i10 - i);
          localRect.right = i10;
          paramCanvas.drawRect(localRect, localPaint);
        }
      }
      label894: if (m != 0)
      {
        localRect.left = i6;
        localRect.right = (i6 + i);
        drawDivider(paramCanvas, localRect, -1);
      }
    }
  }

  public boolean dispatchKeyEvent(KeyEvent paramKeyEvent)
  {
    boolean bool = super.dispatchKeyEvent(paramKeyEvent);
    if ((!bool) && (getFocusedChild() != null) && (paramKeyEvent.getAction() == 0))
      bool = onKeyDown(paramKeyEvent.getKeyCode(), paramKeyEvent);
    return bool;
  }

  protected boolean drawChild(Canvas paramCanvas, View paramView, long paramLong)
  {
    boolean bool = super.drawChild(paramCanvas, paramView, paramLong);
    if (this.mCachingActive)
      this.mCachingActive = false;
    return bool;
  }

  void drawDivider(Canvas paramCanvas, Rect paramRect, int paramInt)
  {
    Drawable localDrawable = this.mDivider;
    localDrawable.setBounds(paramRect);
    localDrawable.draw(paramCanvas);
  }

  void drawOverscrollFooter(Canvas paramCanvas, Drawable paramDrawable, Rect paramRect)
  {
    int i = paramDrawable.getMinimumWidth();
    paramCanvas.save();
    paramCanvas.clipRect(paramRect);
    if (paramRect.right - paramRect.left < i)
      paramRect.right = (i + paramRect.left);
    paramDrawable.setBounds(paramRect);
    paramDrawable.draw(paramCanvas);
    paramCanvas.restore();
  }

  void drawOverscrollHeader(Canvas paramCanvas, Drawable paramDrawable, Rect paramRect)
  {
    int i = paramDrawable.getMinimumWidth();
    paramCanvas.save();
    paramCanvas.clipRect(paramRect);
    if (paramRect.right - paramRect.left < i)
      paramRect.left = (paramRect.right - i);
    paramDrawable.setBounds(paramRect);
    paramDrawable.draw(paramCanvas);
    paramCanvas.restore();
  }

  protected void fillGap(boolean paramBoolean)
  {
    int i = getChildCount();
    if (paramBoolean)
    {
      if (i > 0);
      for (int k = getChildAt(i - 1).getRight() + this.mDividerWidth; ; k = 0)
      {
        fillRight(i + this.mFirstPosition, k);
        correctTooWide(getChildCount());
        return;
      }
    }
    if (i > 0);
    for (int j = getChildAt(0).getLeft() - this.mDividerWidth; ; j = getWidth() - 0)
    {
      fillLeft(-1 + this.mFirstPosition, j);
      correctTooSmall(getChildCount());
      return;
    }
  }

  protected int findMotionCol(int paramInt)
  {
    int i = getChildCount();
    int k;
    if (i > 0)
    {
      if (this.mStackFromRight)
        break label54;
      k = 0;
      if (k < i)
        break label27;
    }
    while (true)
    {
      return -1;
      label27: if (paramInt <= getChildAt(k).getRight())
        return k + this.mFirstPosition;
      k++;
      break;
      label54: for (int j = i - 1; j >= 0; j--)
        if (paramInt >= getChildAt(j).getLeft())
          return j + this.mFirstPosition;
    }
  }

  boolean fullScroll(int paramInt)
  {
    boolean bool;
    if (paramInt == 33)
    {
      int m = this.mSelectedPosition;
      bool = false;
      if (m != 0)
      {
        int n = lookForSelectablePosition(0, true);
        if (n >= 0)
        {
          this.mLayoutMode = 1;
          setSelectionInt(n);
          invokeOnItemScrollListener();
        }
        bool = true;
      }
    }
    while (true)
    {
      if ((bool) && (!awakenScrollBars()))
      {
        awakenScrollBars();
        invalidate();
      }
      return bool;
      bool = false;
      if (paramInt == 130)
      {
        int i = this.mSelectedPosition;
        int j = -1 + this.mItemCount;
        bool = false;
        if (i < j)
        {
          int k = lookForSelectablePosition(-1 + this.mItemCount, true);
          if (k >= 0)
          {
            this.mLayoutMode = 3;
            setSelectionInt(k);
            invokeOnItemScrollListener();
          }
          bool = true;
        }
      }
    }
  }

  public ListAdapter getAdapter()
  {
    return this.mAdapter;
  }

  @Deprecated
  public long[] getCheckItemIds()
  {
    long[] arrayOfLong1;
    if ((this.mAdapter != null) && (this.mAdapter.hasStableIds()))
      arrayOfLong1 = getCheckedItemIds();
    SparseBooleanArray localSparseBooleanArray;
    int i;
    ListAdapter localListAdapter;
    int j;
    int k;
    do
    {
      return arrayOfLong1;
      if ((this.mChoiceMode == 0) || (this.mCheckStates == null) || (this.mAdapter == null))
        break label146;
      localSparseBooleanArray = this.mCheckStates;
      i = localSparseBooleanArray.size();
      arrayOfLong1 = new long[i];
      localListAdapter = this.mAdapter;
      j = 0;
      k = 0;
      if (j < i)
        break;
    }
    while (k == i);
    long[] arrayOfLong2 = new long[k];
    System.arraycopy(arrayOfLong1, 0, arrayOfLong2, 0, k);
    return arrayOfLong2;
    int m;
    if (localSparseBooleanArray.valueAt(j))
    {
      m = k + 1;
      arrayOfLong1[k] = localListAdapter.getItemId(localSparseBooleanArray.keyAt(j));
    }
    while (true)
    {
      j++;
      k = m;
      break;
      label146: return new long[0];
      m = k;
    }
  }

  public Drawable getDivider()
  {
    return this.mDivider;
  }

  public int getDividerWidth()
  {
    return this.mDividerWidth;
  }

  public int getFooterViewsCount()
  {
    return this.mFooterViewInfos.size();
  }

  public int getHeaderViewsCount()
  {
    return this.mHeaderViewInfos.size();
  }

  public boolean getItemsCanFocus()
  {
    return this.mItemsCanFocus;
  }

  public int getMaxScrollAmount()
  {
    return (int)(0.33F * (getRight() - getLeft()));
  }

  public Drawable getOverscrollFooter()
  {
    return this.mOverScrollFooter;
  }

  public Drawable getOverscrollHeader()
  {
    return this.mOverScrollHeader;
  }

  public boolean isOpaque()
  {
    boolean bool;
    if (((!this.mCachingActive) || (!this.mIsCacheColorOpaque) || (!this.mDividerIsOpaque)) && (!super.isOpaque()))
    {
      bool = false;
      if (bool)
        if (this.mListPadding == null)
          break label76;
    }
    label76: for (int i = this.mListPadding.left; ; i = getPaddingLeft())
    {
      View localView1 = getChildAt(0);
      if ((localView1 != null) && (localView1.getLeft() <= i))
        break label84;
      bool = false;
      return bool;
      bool = true;
      break;
    }
    label84: int j = getWidth();
    if (this.mListPadding != null);
    for (int k = this.mListPadding.right; ; k = getPaddingRight())
    {
      int m = j - k;
      View localView2 = getChildAt(-1 + getChildCount());
      if ((localView2 != null) && (localView2.getRight() >= m))
        break;
      return false;
    }
  }

  protected void layoutChildren()
  {
    boolean bool1 = this.mBlockLayoutRequests;
    if (!bool1)
      this.mBlockLayoutRequests = true;
    int i;
    int j;
    int k;
    View localView1;
    View localView2;
    int n;
    View localView3;
    boolean bool2;
    try
    {
      super.layoutChildren();
      invalidate();
      if (this.mAdapter == null)
      {
        resetList();
        invokeOnItemScrollListener();
        return;
      }
      i = this.mListPadding.left;
      j = getRight() - getLeft() - this.mListPadding.right;
      k = getChildCount();
      int m = this.mLayoutMode;
      localView1 = null;
      localView2 = null;
      n = 0;
      localView3 = null;
      switch (m)
      {
      default:
        int i7 = this.mSelectedPosition - this.mFirstPosition;
        localView1 = null;
        if (i7 >= 0)
        {
          localView1 = null;
          if (i7 < k)
            localView1 = getChildAt(i7);
        }
        localView3 = getChildAt(0);
        int i8 = this.mNextSelectedPosition;
        n = 0;
        if (i8 >= 0)
          n = this.mNextSelectedPosition - this.mSelectedPosition;
        localView2 = getChildAt(i7 + n);
      case 1:
      case 3:
      case 4:
      case 5:
      case 2:
      }
      while (true)
      {
        bool2 = this.mDataChanged;
        if (bool2)
          handleDataChanged();
        if (this.mItemCount != 0)
          break;
        resetList();
        invokeOnItemScrollListener();
        return;
        int i1 = this.mNextSelectedPosition - this.mFirstPosition;
        localView1 = null;
        localView2 = null;
        n = 0;
        localView3 = null;
        if (i1 >= 0)
        {
          localView1 = null;
          localView2 = null;
          n = 0;
          localView3 = null;
          if (i1 < k)
          {
            localView2 = getChildAt(i1);
            localView1 = null;
            n = 0;
            localView3 = null;
          }
        }
      }
      if (this.mItemCount != this.mAdapter.getCount())
        throw new IllegalStateException("The content of the adapter has changed but ListView did not receive a notification. Make sure the content of your adapter is not modified from a background thread, but only from the UI thread. [in ListView(" + getId() + ", " + getClass() + ") with Adapter(" + this.mAdapter.getClass() + ")]");
    }
    finally
    {
      if (!bool1)
        this.mBlockLayoutRequests = false;
    }
    setSelectedPositionInt(this.mNextSelectedPosition);
    int i2 = this.mFirstPosition;
    AbsHListView.RecycleBin localRecycleBin = this.mRecycler;
    int i3;
    label445: View localView6;
    View localView7;
    if (bool2)
    {
      i3 = 0;
      break label1187;
      View localView4 = getFocusedChild();
      View localView5 = null;
      localView6 = null;
      if (localView4 != null)
      {
        if (bool2)
        {
          boolean bool3 = isDirectChildHeaderOrFooter(localView4);
          localView5 = null;
          localView6 = null;
          if (!bool3);
        }
        else
        {
          localView5 = localView4;
          localView6 = findFocus();
          if (localView6 != null)
            localView6.onStartTemporaryDetach();
        }
        requestFocus();
      }
      detachAllViewsFromParent();
      localRecycleBin.removeSkippedScrap();
      switch (this.mLayoutMode)
      {
      default:
        if (k == 0)
          if (!this.mStackFromRight)
          {
            setSelectedPositionInt(lookForSelectablePosition(0, true));
            localView7 = fillFromLeft(i);
            label593: localRecycleBin.scrapActiveViews();
            if (localView7 == null)
              break label1106;
            if ((!this.mItemsCanFocus) || (!hasFocus()) || (localView7.hasFocus()))
              break label1096;
            if (((localView7 == localView5) && (localView6 != null) && (localView6.requestFocus())) || (localView7.requestFocus()))
              break label1197;
          }
        break;
      case 2:
      case 5:
      case 3:
      case 1:
      case 4:
      case 6:
      }
    }
    label684: label1197: for (int i4 = 0; ; i4 = 1)
    {
      if (i4 == 0)
      {
        View localView8 = getFocusedChild();
        if (localView8 != null)
          localView8.clearFocus();
        positionSelector(-1, localView7);
        this.mSelectedLeft = localView7.getLeft();
        label693: if ((localView6 != null) && (localView6.getWindowToken() != null))
          localView6.onFinishTemporaryDetach();
        this.mLayoutMode = 0;
        this.mDataChanged = false;
        if (this.mPositionScrollAfterLayout != null)
        {
          post(this.mPositionScrollAfterLayout);
          this.mPositionScrollAfterLayout = null;
        }
        this.mNeedSync = false;
        setNextSelectedPositionInt(this.mSelectedPosition);
        updateScrollIndicators();
        if (this.mItemCount > 0)
          checkSelectionChanged();
        invokeOnItemScrollListener();
        if (bool1)
          break;
        this.mBlockLayoutRequests = false;
        return;
      }
      label1096: label1106: 
      do
      {
        localRecycleBin.addScrapView(getChildAt(i3), i2 + i3);
        i3++;
        continue;
        localRecycleBin.fillActiveViews(k, i2);
        break;
        if (localView2 != null)
        {
          localView7 = fillFromSelection(localView2.getLeft(), i, j);
          break label593;
        }
        localView7 = fillFromMiddle(i, j);
        break label593;
        localView7 = fillSpecific(this.mSyncPosition, this.mSpecificLeft);
        break label593;
        localView7 = fillLeft(-1 + this.mItemCount, j);
        adjustViewsLeftOrRight();
        break label593;
        this.mFirstPosition = 0;
        localView7 = fillFromLeft(i);
        adjustViewsLeftOrRight();
        break label593;
        localView7 = fillSpecific(reconcileSelectedPosition(), this.mSpecificLeft);
        break label593;
        localView7 = moveSelection(localView1, localView2, n, i, j);
        break label593;
        setSelectedPositionInt(lookForSelectablePosition(-1 + this.mItemCount, false));
        localView7 = fillLeft(-1 + this.mItemCount, j);
        break label593;
        if ((this.mSelectedPosition >= 0) && (this.mSelectedPosition < this.mItemCount))
        {
          int i6 = this.mSelectedPosition;
          if (localView1 == null);
          while (true)
          {
            localView7 = fillSpecific(i6, i);
            break;
            i = localView1.getLeft();
          }
        }
        if (this.mFirstPosition < this.mItemCount)
        {
          int i5 = this.mFirstPosition;
          if (localView3 == null);
          while (true)
          {
            localView7 = fillSpecific(i5, i);
            break;
            i = localView3.getLeft();
          }
        }
        localView7 = fillSpecific(0, i);
        break label593;
        localView7.setSelected(false);
        this.mSelectorRect.setEmpty();
        break label684;
        positionSelector(-1, localView7);
        break label684;
        if ((this.mTouchMode > 0) && (this.mTouchMode < 3))
        {
          View localView9 = getChildAt(this.mMotionPosition - this.mFirstPosition);
          if (localView9 != null)
            positionSelector(this.mMotionPosition, localView9);
        }
        while (true)
        {
          if ((!hasFocus()) || (localView6 == null))
            break label1185;
          localView6.requestFocus();
          break;
          this.mSelectedLeft = 0;
          this.mSelectorRect.setEmpty();
        }
        break label693;
      }
      while (i3 < k);
      break label445;
    }
  }

  protected int lookForSelectablePosition(int paramInt, boolean paramBoolean)
  {
    ListAdapter localListAdapter = this.mAdapter;
    if ((localListAdapter == null) || (isInTouchMode()));
    int i;
    label44: 
    do
    {
      return -1;
      i = localListAdapter.getCount();
      if (!this.mAreAllItemsSelectable)
      {
        int j;
        if (paramBoolean)
        {
          j = Math.max(0, paramInt);
          if ((j < i) && (!localListAdapter.isEnabled(j)));
        }
        while ((j >= 0) && (j < i))
        {
          return j;
          j++;
          break label44;
          for (j = Math.min(paramInt, i - 1); (j >= 0) && (!localListAdapter.isEnabled(j)); j--);
        }
      }
    }
    while ((paramInt < 0) || (paramInt >= i));
    return paramInt;
  }

  public int[] measureChild(View paramView)
  {
    measureItem(paramView);
    return new int[] { paramView.getMeasuredWidth(), paramView.getMeasuredHeight() };
  }

  final int measureWidthOfChildren(int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5)
  {
    Log.i("HListView", "measureWidthOfChildren, from " + paramInt2 + " to " + paramInt3);
    ListAdapter localListAdapter = this.mAdapter;
    int k;
    if (localListAdapter == null)
    {
      k = this.mListPadding.left + this.mListPadding.right;
      return k;
    }
    int i = this.mListPadding.left + this.mListPadding.right;
    int j;
    label101: AbsHListView.RecycleBin localRecycleBin;
    boolean bool;
    boolean[] arrayOfBoolean;
    if ((this.mDividerWidth > 0) && (this.mDivider != null))
    {
      j = this.mDividerWidth;
      k = 0;
      if (paramInt3 == -1)
        paramInt3 = -1 + localListAdapter.getCount();
      localRecycleBin = this.mRecycler;
      bool = recycleOnMeasure();
      arrayOfBoolean = this.mIsScrap;
    }
    for (int m = paramInt2; ; m++)
    {
      if (m > paramInt3)
      {
        return i;
        j = 0;
        break label101;
      }
      View localView = obtainView(m, arrayOfBoolean);
      measureScrapChildWidth(localView, m, paramInt1);
      if (m > 0)
        i += j;
      if ((bool) && (localRecycleBin.shouldRecycleViewType(((AbsHListView.LayoutParams)localView.getLayoutParams()).viewType)))
        localRecycleBin.addScrapView(localView, -1);
      i += localView.getMeasuredWidth();
      if (i >= paramInt4)
      {
        if ((paramInt5 >= 0) && (m > paramInt5) && (k > 0) && (i != paramInt4))
          break;
        return paramInt4;
      }
      if ((paramInt5 >= 0) && (m >= paramInt5))
        k = i;
    }
  }

  final int[] measureWithLargeChildren(int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5, int paramInt6)
  {
    Log.i("HListView", "measureWithLargeChildren, from " + paramInt2 + " to " + paramInt3);
    ListAdapter localListAdapter = this.mAdapter;
    if (localListAdapter == null)
    {
      int[] arrayOfInt2 = new int[2];
      arrayOfInt2[0] = (this.mListPadding.left + this.mListPadding.right);
      arrayOfInt2[1] = (this.mListPadding.top + this.mListPadding.bottom);
      return arrayOfInt2;
    }
    int i = this.mListPadding.left + this.mListPadding.right;
    int j = this.mListPadding.top + this.mListPadding.bottom;
    int k;
    int m;
    int n;
    AbsHListView.RecycleBin localRecycleBin;
    boolean bool;
    boolean[] arrayOfBoolean;
    if ((this.mDividerWidth > 0) && (this.mDivider != null))
    {
      k = this.mDividerWidth;
      m = 0;
      n = 0;
      if (paramInt3 == -1)
        paramInt3 = -1 + localListAdapter.getCount();
      localRecycleBin = this.mRecycler;
      bool = recycleOnMeasure();
      arrayOfBoolean = this.mIsScrap;
    }
    for (int i1 = paramInt2; ; i1++)
    {
      if (i1 > paramInt3)
      {
        int i2 = i + m;
        int i3 = j + n;
        int[] arrayOfInt1 = new int[2];
        arrayOfInt1[0] = Math.min(i2, paramInt4);
        arrayOfInt1[1] = Math.min(i3, paramInt5);
        return arrayOfInt1;
        k = 0;
        break;
      }
      View localView = obtainView(i1, arrayOfBoolean);
      measureScrapChildWidth(localView, i1, paramInt1);
      if ((bool) && (localRecycleBin.shouldRecycleViewType(((AbsHListView.LayoutParams)localView.getLayoutParams()).viewType)))
        localRecycleBin.addScrapView(localView, -1);
      m = Math.max(m, k + localView.getMeasuredWidth());
      n = Math.max(n, localView.getMeasuredHeight());
    }
  }

  protected void onFinishInflate()
  {
    super.onFinishInflate();
    int i = getChildCount();
    if (i > 0);
    for (int j = 0; ; j++)
    {
      if (j >= i)
      {
        removeAllViews();
        return;
      }
      addHeaderView(getChildAt(j));
    }
  }

  protected void onFocusChanged(boolean paramBoolean, int paramInt, Rect paramRect)
  {
    super.onFocusChanged(paramBoolean, paramInt, paramRect);
    ListAdapter localListAdapter = this.mAdapter;
    int i = -1;
    int j = 0;
    Rect localRect;
    int k;
    int n;
    int i1;
    if (localListAdapter != null)
    {
      j = 0;
      if (paramBoolean)
      {
        j = 0;
        if (paramRect != null)
        {
          paramRect.offset(getScrollX(), getScrollY());
          if (localListAdapter.getCount() < getChildCount() + this.mFirstPosition)
          {
            this.mLayoutMode = 0;
            layoutChildren();
          }
          localRect = this.mTempRect;
          k = 2147483647;
          int m = getChildCount();
          n = this.mFirstPosition;
          i1 = 0;
          if (i1 < m)
            break label130;
        }
      }
    }
    if (i >= 0)
    {
      setSelectionFromLeft(i + this.mFirstPosition, j);
      return;
      label130: if (!localListAdapter.isEnabled(n + i1));
      while (true)
      {
        i1++;
        break;
        View localView = getChildAt(i1);
        localView.getDrawingRect(localRect);
        offsetDescendantRectToMyCoords(localView, localRect);
        int i2 = getDistance(paramRect, localRect, paramInt);
        if (i2 < k)
        {
          k = i2;
          i = i1;
          j = localView.getLeft();
        }
      }
    }
    requestLayout();
  }

  public void onGlobalLayout()
  {
  }

  public void onInitializeAccessibilityEvent(AccessibilityEvent paramAccessibilityEvent)
  {
    super.onInitializeAccessibilityEvent(paramAccessibilityEvent);
    paramAccessibilityEvent.setClassName(HListView.class.getName());
  }

  @TargetApi(14)
  public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo paramAccessibilityNodeInfo)
  {
    super.onInitializeAccessibilityNodeInfo(paramAccessibilityNodeInfo);
    paramAccessibilityNodeInfo.setClassName(HListView.class.getName());
  }

  public boolean onKeyDown(int paramInt, KeyEvent paramKeyEvent)
  {
    return commonKey(paramInt, 1, paramKeyEvent);
  }

  public boolean onKeyMultiple(int paramInt1, int paramInt2, KeyEvent paramKeyEvent)
  {
    return commonKey(paramInt1, paramInt2, paramKeyEvent);
  }

  public boolean onKeyUp(int paramInt, KeyEvent paramKeyEvent)
  {
    return commonKey(paramInt, 1, paramKeyEvent);
  }

  @TargetApi(11)
  protected void onMeasure(int paramInt1, int paramInt2)
  {
    super.onMeasure(paramInt1, paramInt2);
    int i = View.MeasureSpec.getMode(paramInt1);
    int j = View.MeasureSpec.getMode(paramInt2);
    int k = View.MeasureSpec.getSize(paramInt1);
    int m = View.MeasureSpec.getSize(paramInt2);
    int n;
    int i3;
    int i4;
    if (this.mAdapter == null)
    {
      n = 0;
      this.mItemCount = n;
      int i1 = this.mItemCount;
      int i2 = 0;
      i3 = 0;
      i4 = 0;
      if (i1 > 0)
        if (i != 0)
        {
          i2 = 0;
          i3 = 0;
          i4 = 0;
          if (j != 0);
        }
        else
        {
          Log.d("HListView", "let's measure a scrap child");
          View localView = obtainView(0, this.mIsScrap);
          measureScrapChildWidth(localView, 0, paramInt2);
          i4 = localView.getMeasuredWidth();
          i2 = localView.getMeasuredHeight();
          int i5 = Build.VERSION.SDK_INT;
          i3 = 0;
          if (i5 >= 11)
            i3 = combineMeasuredStates(0, localView.getMeasuredState());
          if ((recycleOnMeasure()) && (this.mRecycler.shouldRecycleViewType(((AbsHListView.LayoutParams)localView.getLayoutParams()).viewType)))
            this.mRecycler.addScrapView(localView, -1);
        }
      if (j != 0)
        break label297;
      m = i2 + (this.mListPadding.top + this.mListPadding.bottom) + getHorizontalScrollbarHeight();
    }
    while (true)
    {
      if (i == 0)
        k = i4 + (this.mListPadding.left + this.mListPadding.right) + 2 * getHorizontalFadingEdgeLength();
      if (i == -2147483648)
        k = measureWidthOfChildren(paramInt2, 0, -1, k, -1);
      setMeasuredDimension(k, m);
      this.mHeightMeasureSpec = paramInt2;
      return;
      n = this.mAdapter.getCount();
      break;
      label297: if ((j == -2147483648) && (this.mItemCount > 0) && (this.mMeasureWithChild > -1))
        m = measureWithLargeChildren(paramInt2, this.mMeasureWithChild, this.mMeasureWithChild, k, m, -1)[1];
      else if (Build.VERSION.SDK_INT >= 11)
        m |= 0xFF000000 & i3;
    }
  }

  protected void onSizeChanged(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    if (getChildCount() > 0)
    {
      View localView = getFocusedChild();
      if (localView != null)
      {
        int i = this.mFirstPosition + indexOfChild(localView);
        int j = Math.max(0, localView.getRight() - (paramInt1 - getPaddingLeft()));
        int k = localView.getLeft() - j;
        if (this.mFocusSelector == null)
          this.mFocusSelector = new FocusSelector(null);
        post(this.mFocusSelector.setup(i, k));
      }
    }
    super.onSizeChanged(paramInt1, paramInt2, paramInt3, paramInt4);
  }

  boolean pageScroll(int paramInt)
  {
    int i = -1;
    boolean bool = false;
    if (paramInt == 33)
      i = Math.max(0, -1 + (this.mSelectedPosition - getChildCount()));
    while (i >= 0)
    {
      int j = lookForSelectablePosition(i, bool);
      if (j < 0)
        break;
      this.mLayoutMode = 4;
      this.mSpecificLeft = (getPaddingLeft() + getHorizontalFadingEdgeLength());
      if ((bool) && (j > this.mItemCount - getChildCount()))
        this.mLayoutMode = 3;
      if ((!bool) && (j < getChildCount()))
        this.mLayoutMode = 1;
      setSelectionInt(j);
      invokeOnItemScrollListener();
      if (!awakenScrollBars())
        invalidate();
      return true;
      bool = false;
      if (paramInt == 130)
      {
        i = Math.min(-1 + this.mItemCount, -1 + (this.mSelectedPosition + getChildCount()));
        bool = true;
      }
    }
    return false;
  }

  @ViewDebug.ExportedProperty(category="list")
  protected boolean recycleOnMeasure()
  {
    return true;
  }

  public boolean removeFooterView(View paramView)
  {
    if (this.mFooterViewInfos.size() > 0)
    {
      ListAdapter localListAdapter = this.mAdapter;
      boolean bool1 = false;
      if (localListAdapter != null)
      {
        boolean bool2 = ((HeaderViewListAdapter)this.mAdapter).removeFooter(paramView);
        bool1 = false;
        if (bool2)
        {
          if (this.mDataSetObserver != null)
            this.mDataSetObserver.onChanged();
          bool1 = true;
        }
      }
      removeFixedViewInfo(paramView, this.mFooterViewInfos);
      return bool1;
    }
    return false;
  }

  public boolean removeHeaderView(View paramView)
  {
    if (this.mHeaderViewInfos.size() > 0)
    {
      ListAdapter localListAdapter = this.mAdapter;
      boolean bool1 = false;
      if (localListAdapter != null)
      {
        boolean bool2 = ((HeaderViewListAdapter)this.mAdapter).removeHeader(paramView);
        bool1 = false;
        if (bool2)
        {
          if (this.mDataSetObserver != null)
            this.mDataSetObserver.onChanged();
          bool1 = true;
        }
      }
      removeFixedViewInfo(paramView, this.mHeaderViewInfos);
      return bool1;
    }
    return false;
  }

  public boolean requestChildRectangleOnScreen(View paramView, Rect paramRect, boolean paramBoolean)
  {
    int i = paramRect.left;
    paramRect.offset(paramView.getLeft(), paramView.getTop());
    paramRect.offset(-paramView.getScrollX(), -paramView.getScrollY());
    int j = getWidth();
    int k = getScrollX();
    int m = k + j;
    int n = getHorizontalFadingEdgeLength();
    if ((showingLeftFadingEdge()) && ((this.mSelectedPosition > 0) || (i > n)))
      k += n;
    int i1 = getChildAt(-1 + getChildCount()).getRight();
    if ((showingRightFadingEdge()) && ((this.mSelectedPosition < -1 + this.mItemCount) || (paramRect.right < i1 - n)))
      m -= n;
    int i6;
    int i3;
    if ((paramRect.right > m) && (paramRect.left > k))
      if (paramRect.width() > j)
      {
        i6 = 0 + (paramRect.left - k);
        i3 = Math.min(i6, i1 - m);
        label189: if (i3 == 0)
          break label331;
      }
    label331: for (boolean bool = true; ; bool = false)
    {
      if (bool)
      {
        scrollListItemsBy(-i3);
        positionSelector(-1, paramView);
        this.mSelectedLeft = paramView.getTop();
        invalidate();
      }
      return bool;
      i6 = 0 + (paramRect.right - m);
      break;
      int i2 = paramRect.left;
      i3 = 0;
      if (i2 >= k)
        break label189;
      int i4 = paramRect.right;
      i3 = 0;
      if (i4 >= m)
        break label189;
      if (paramRect.width() > j);
      for (int i5 = 0 - (m - paramRect.right); ; i5 = 0 - (k - paramRect.left))
      {
        i3 = Math.max(i5, getChildAt(0).getLeft() - k);
        break;
      }
    }
  }

  protected void resetList()
  {
    clearRecycledState(this.mHeaderViewInfos);
    clearRecycledState(this.mFooterViewInfos);
    super.resetList();
    this.mLayoutMode = 0;
  }

  public void setAdapter(ListAdapter paramListAdapter)
  {
    if ((this.mAdapter != null) && (this.mDataSetObserver != null))
      this.mAdapter.unregisterDataSetObserver(this.mDataSetObserver);
    resetList();
    this.mRecycler.clear();
    int i;
    if ((this.mHeaderViewInfos.size() > 0) || (this.mFooterViewInfos.size() > 0))
    {
      this.mAdapter = new HeaderViewListAdapter(this.mHeaderViewInfos, this.mFooterViewInfos, paramListAdapter);
      this.mOldSelectedPosition = -1;
      this.mOldSelectedColId = -9223372036854775808L;
      super.setAdapter(paramListAdapter);
      if (this.mAdapter == null)
        break label244;
      this.mAreAllItemsSelectable = this.mAdapter.areAllItemsEnabled();
      this.mOldItemCount = this.mItemCount;
      this.mItemCount = this.mAdapter.getCount();
      checkFocus();
      this.mDataSetObserver = new AbsHListView.AdapterDataSetObserver(this);
      this.mAdapter.registerDataSetObserver(this.mDataSetObserver);
      this.mRecycler.setViewTypeCount(this.mAdapter.getViewTypeCount());
      if (!this.mStackFromRight)
        break label234;
      i = lookForSelectablePosition(-1 + this.mItemCount, false);
      label200: setSelectedPositionInt(i);
      setNextSelectedPositionInt(i);
      if (this.mItemCount == 0)
        checkSelectionChanged();
    }
    while (true)
    {
      requestLayout();
      return;
      this.mAdapter = paramListAdapter;
      break;
      label234: i = lookForSelectablePosition(0, true);
      break label200;
      label244: this.mAreAllItemsSelectable = true;
      checkFocus();
      checkSelectionChanged();
    }
  }

  public void setCacheColorHint(int paramInt)
  {
    if (paramInt >>> 24 == 255);
    for (boolean bool = true; ; bool = false)
    {
      this.mIsCacheColorOpaque = bool;
      if (bool)
      {
        if (this.mDividerPaint == null)
          this.mDividerPaint = new Paint();
        this.mDividerPaint.setColor(paramInt);
      }
      super.setCacheColorHint(paramInt);
      return;
    }
  }

  public void setDivider(Drawable paramDrawable)
  {
    Log.i("HListView", "setDivider: " + paramDrawable);
    boolean bool;
    if (paramDrawable != null)
    {
      this.mDividerWidth = paramDrawable.getIntrinsicWidth();
      this.mDivider = paramDrawable;
      if (paramDrawable == null)
        break label80;
      int i = paramDrawable.getOpacity();
      bool = false;
      if (i == -1)
        break label80;
    }
    while (true)
    {
      this.mDividerIsOpaque = bool;
      requestLayout();
      invalidate();
      return;
      this.mDividerWidth = 0;
      break;
      label80: bool = true;
    }
  }

  public void setDividerWidth(int paramInt)
  {
    Log.i("HListView", "setDividerWidth: " + paramInt);
    this.mDividerWidth = paramInt;
    requestLayout();
    invalidate();
  }

  public void setFooterDividersEnabled(boolean paramBoolean)
  {
    this.mFooterDividersEnabled = paramBoolean;
    invalidate();
  }

  public void setHeaderDividersEnabled(boolean paramBoolean)
  {
    this.mHeaderDividersEnabled = paramBoolean;
    invalidate();
  }

  public void setItemsCanFocus(boolean paramBoolean)
  {
    this.mItemsCanFocus = paramBoolean;
    if (!paramBoolean)
      setDescendantFocusability(393216);
  }

  public void setOverscrollFooter(Drawable paramDrawable)
  {
    this.mOverScrollFooter = paramDrawable;
    invalidate();
  }

  public void setOverscrollHeader(Drawable paramDrawable)
  {
    this.mOverScrollHeader = paramDrawable;
    if (getScrollX() < 0)
      invalidate();
  }

  public void setSelection(int paramInt)
  {
    setSelectionFromLeft(paramInt, 0);
  }

  public void setSelectionAfterHeaderView()
  {
    int i = this.mHeaderViewInfos.size();
    if (i > 0)
    {
      this.mNextSelectedPosition = 0;
      return;
    }
    if (this.mAdapter != null)
    {
      setSelection(i);
      return;
    }
    this.mNextSelectedPosition = i;
    this.mLayoutMode = 2;
  }

  public void setSelectionFromLeft(int paramInt1, int paramInt2)
  {
    if (this.mAdapter == null);
    while (true)
    {
      return;
      if (!isInTouchMode())
      {
        paramInt1 = lookForSelectablePosition(paramInt1, true);
        if (paramInt1 >= 0)
          setNextSelectedPositionInt(paramInt1);
      }
      while (paramInt1 >= 0)
      {
        this.mLayoutMode = 4;
        this.mSpecificLeft = (paramInt2 + this.mListPadding.left);
        if (this.mNeedSync)
        {
          this.mSyncPosition = paramInt1;
          this.mSyncColId = this.mAdapter.getItemId(paramInt1);
        }
        if (this.mPositionScroller != null)
          this.mPositionScroller.stop();
        requestLayout();
        return;
        this.mResurrectToPosition = paramInt1;
      }
    }
  }

  public void setSelectionInt(int paramInt)
  {
    setNextSelectedPositionInt(paramInt);
    int i = this.mSelectedPosition;
    int j = 0;
    if (i >= 0)
    {
      if (paramInt != i - 1)
        break label53;
      j = 1;
    }
    while (true)
    {
      if (this.mPositionScroller != null)
        this.mPositionScroller.stop();
      layoutChildren();
      if (j != 0)
        awakenScrollBars();
      return;
      label53: int k = i + 1;
      j = 0;
      if (paramInt == k)
        j = 1;
    }
  }

  public void smoothScrollByOffset(int paramInt)
  {
    super.smoothScrollByOffset(paramInt);
  }

  public void smoothScrollToPosition(int paramInt)
  {
    super.smoothScrollToPosition(paramInt);
  }

  private static class ArrowScrollFocusResult
  {
    private int mAmountToScroll;
    private int mSelectedPosition;

    public int getAmountToScroll()
    {
      return this.mAmountToScroll;
    }

    public int getSelectedPosition()
    {
      return this.mSelectedPosition;
    }

    void populate(int paramInt1, int paramInt2)
    {
      this.mSelectedPosition = paramInt1;
      this.mAmountToScroll = paramInt2;
    }
  }

  public static class FixedViewInfo
  {
    public Object data;
    public boolean isSelectable;
    public View view;
  }

  private class FocusSelector
    implements Runnable
  {
    private int mPosition;
    private int mPositionLeft;

    private FocusSelector()
    {
    }

    public void run()
    {
      HListView.this.setSelectionFromLeft(this.mPosition, this.mPositionLeft);
    }

    public FocusSelector setup(int paramInt1, int paramInt2)
    {
      this.mPosition = paramInt1;
      this.mPositionLeft = paramInt2;
      return this;
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     it.sephiroth.android.library.widget.HListView
 * JD-Core Version:    0.6.2
 */