package net.sqlcipher;

import android.content.ContentValues;
import android.content.OperationApplicationException;
import android.os.Parcel;
import android.text.TextUtils;
import android.util.Log;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.text.CollationKey;
import java.text.Collator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map.Entry;
import java.util.Set;
import net.sqlcipher.database.SQLiteAbortException;
import net.sqlcipher.database.SQLiteConstraintException;
import net.sqlcipher.database.SQLiteDatabase;
import net.sqlcipher.database.SQLiteDatabaseCorruptException;
import net.sqlcipher.database.SQLiteDiskIOException;
import net.sqlcipher.database.SQLiteException;
import net.sqlcipher.database.SQLiteFullException;
import net.sqlcipher.database.SQLiteProgram;
import net.sqlcipher.database.SQLiteStatement;
import org.apache.commons.codec.binary.Hex;

public class DatabaseUtils
{
  private static final boolean DEBUG = false;
  private static final boolean LOCAL_LOGV = false;
  private static final String TAG = "DatabaseUtils";
  private static final String[] countProjection = { "count(*)" };
  private static Collator mColl = null;

  public static void appendEscapedSQLString(StringBuilder paramStringBuilder, String paramString)
  {
    paramStringBuilder.append('\'');
    if (paramString.indexOf('\'') != -1)
    {
      int i = paramString.length();
      for (int j = 0; j < i; j++)
      {
        char c = paramString.charAt(j);
        if (c == '\'')
          paramStringBuilder.append('\'');
        paramStringBuilder.append(c);
      }
    }
    paramStringBuilder.append(paramString);
    paramStringBuilder.append('\'');
  }

  public static final void appendValueToSql(StringBuilder paramStringBuilder, Object paramObject)
  {
    if (paramObject == null)
    {
      paramStringBuilder.append("NULL");
      return;
    }
    if ((paramObject instanceof Boolean))
    {
      if (((Boolean)paramObject).booleanValue())
      {
        paramStringBuilder.append('1');
        return;
      }
      paramStringBuilder.append('0');
      return;
    }
    appendEscapedSQLString(paramStringBuilder, paramObject.toString());
  }

  public static void bindObjectToProgram(SQLiteProgram paramSQLiteProgram, int paramInt, Object paramObject)
  {
    if (paramObject == null)
    {
      paramSQLiteProgram.bindNull(paramInt);
      return;
    }
    if (((paramObject instanceof Double)) || ((paramObject instanceof Float)))
    {
      paramSQLiteProgram.bindDouble(paramInt, ((Number)paramObject).doubleValue());
      return;
    }
    if ((paramObject instanceof Number))
    {
      paramSQLiteProgram.bindLong(paramInt, ((Number)paramObject).longValue());
      return;
    }
    if ((paramObject instanceof Boolean))
    {
      if (((Boolean)paramObject).booleanValue())
      {
        paramSQLiteProgram.bindLong(paramInt, 1L);
        return;
      }
      paramSQLiteProgram.bindLong(paramInt, 0L);
      return;
    }
    if ((paramObject instanceof byte[]))
    {
      paramSQLiteProgram.bindBlob(paramInt, (byte[])paramObject);
      return;
    }
    paramSQLiteProgram.bindString(paramInt, paramObject.toString());
  }

  public static String concatenateWhere(String paramString1, String paramString2)
  {
    if (TextUtils.isEmpty(paramString1))
      return paramString2;
    if (TextUtils.isEmpty(paramString2))
      return paramString1;
    return "(" + paramString1 + ") AND (" + paramString2 + ")";
  }

  public static void cursorDoubleToContentValues(android.database.Cursor paramCursor, String paramString1, ContentValues paramContentValues, String paramString2)
  {
    int i = paramCursor.getColumnIndex(paramString1);
    if (!paramCursor.isNull(i))
    {
      paramContentValues.put(paramString2, Double.valueOf(paramCursor.getDouble(i)));
      return;
    }
    paramContentValues.put(paramString2, (Double)null);
  }

  public static void cursorDoubleToContentValuesIfPresent(android.database.Cursor paramCursor, ContentValues paramContentValues, String paramString)
  {
    int i = paramCursor.getColumnIndexOrThrow(paramString);
    if (!paramCursor.isNull(i))
      paramContentValues.put(paramString, Double.valueOf(paramCursor.getDouble(i)));
  }

  public static void cursorDoubleToCursorValues(android.database.Cursor paramCursor, String paramString, ContentValues paramContentValues)
  {
    cursorDoubleToContentValues(paramCursor, paramString, paramContentValues, paramString);
  }

  public static void cursorFloatToContentValuesIfPresent(android.database.Cursor paramCursor, ContentValues paramContentValues, String paramString)
  {
    int i = paramCursor.getColumnIndexOrThrow(paramString);
    if (!paramCursor.isNull(i))
      paramContentValues.put(paramString, Float.valueOf(paramCursor.getFloat(i)));
  }

  public static void cursorIntToContentValues(android.database.Cursor paramCursor, String paramString, ContentValues paramContentValues)
  {
    cursorIntToContentValues(paramCursor, paramString, paramContentValues, paramString);
  }

  public static void cursorIntToContentValues(android.database.Cursor paramCursor, String paramString1, ContentValues paramContentValues, String paramString2)
  {
    int i = paramCursor.getColumnIndex(paramString1);
    if (!paramCursor.isNull(i))
    {
      paramContentValues.put(paramString2, Integer.valueOf(paramCursor.getInt(i)));
      return;
    }
    paramContentValues.put(paramString2, (Integer)null);
  }

  public static void cursorIntToContentValuesIfPresent(android.database.Cursor paramCursor, ContentValues paramContentValues, String paramString)
  {
    int i = paramCursor.getColumnIndexOrThrow(paramString);
    if (!paramCursor.isNull(i))
      paramContentValues.put(paramString, Integer.valueOf(paramCursor.getInt(i)));
  }

  public static void cursorLongToContentValues(android.database.Cursor paramCursor, String paramString, ContentValues paramContentValues)
  {
    cursorLongToContentValues(paramCursor, paramString, paramContentValues, paramString);
  }

  public static void cursorLongToContentValues(android.database.Cursor paramCursor, String paramString1, ContentValues paramContentValues, String paramString2)
  {
    int i = paramCursor.getColumnIndex(paramString1);
    if (!paramCursor.isNull(i))
    {
      paramContentValues.put(paramString2, Long.valueOf(paramCursor.getLong(i)));
      return;
    }
    paramContentValues.put(paramString2, (Long)null);
  }

  public static void cursorLongToContentValuesIfPresent(android.database.Cursor paramCursor, ContentValues paramContentValues, String paramString)
  {
    int i = paramCursor.getColumnIndexOrThrow(paramString);
    if (!paramCursor.isNull(i))
      paramContentValues.put(paramString, Long.valueOf(paramCursor.getLong(i)));
  }

  public static void cursorRowToContentValues(android.database.Cursor paramCursor, ContentValues paramContentValues)
  {
    AbstractWindowedCursor localAbstractWindowedCursor;
    String[] arrayOfString;
    int j;
    if ((paramCursor instanceof AbstractWindowedCursor))
    {
      localAbstractWindowedCursor = (AbstractWindowedCursor)paramCursor;
      arrayOfString = paramCursor.getColumnNames();
      int i = arrayOfString.length;
      j = 0;
      label26: if (j >= i)
        return;
      if ((localAbstractWindowedCursor == null) || (!localAbstractWindowedCursor.isBlob(j)))
        break label73;
      paramContentValues.put(arrayOfString[j], paramCursor.getBlob(j));
    }
    while (true)
    {
      j++;
      break label26;
      localAbstractWindowedCursor = null;
      break;
      label73: paramContentValues.put(arrayOfString[j], paramCursor.getString(j));
    }
  }

  public static void cursorShortToContentValuesIfPresent(android.database.Cursor paramCursor, ContentValues paramContentValues, String paramString)
  {
    int i = paramCursor.getColumnIndexOrThrow(paramString);
    if (!paramCursor.isNull(i))
      paramContentValues.put(paramString, Short.valueOf(paramCursor.getShort(i)));
  }

  public static void cursorStringToContentValues(android.database.Cursor paramCursor, String paramString, ContentValues paramContentValues)
  {
    cursorStringToContentValues(paramCursor, paramString, paramContentValues, paramString);
  }

  public static void cursorStringToContentValues(android.database.Cursor paramCursor, String paramString1, ContentValues paramContentValues, String paramString2)
  {
    paramContentValues.put(paramString2, paramCursor.getString(paramCursor.getColumnIndexOrThrow(paramString1)));
  }

  public static void cursorStringToContentValuesIfPresent(android.database.Cursor paramCursor, ContentValues paramContentValues, String paramString)
  {
    int i = paramCursor.getColumnIndexOrThrow(paramString);
    if (!paramCursor.isNull(i))
      paramContentValues.put(paramString, paramCursor.getString(i));
  }

  public static void cursorStringToInsertHelper(android.database.Cursor paramCursor, String paramString, InsertHelper paramInsertHelper, int paramInt)
  {
    paramInsertHelper.bind(paramInt, paramCursor.getString(paramCursor.getColumnIndexOrThrow(paramString)));
  }

  public static void dumpCurrentRow(android.database.Cursor paramCursor)
  {
    dumpCurrentRow(paramCursor, System.out);
  }

  public static void dumpCurrentRow(android.database.Cursor paramCursor, PrintStream paramPrintStream)
  {
    String[] arrayOfString = paramCursor.getColumnNames();
    paramPrintStream.println("" + paramCursor.getPosition() + " {");
    int i = arrayOfString.length;
    int j = 0;
    while (true)
      if (j < i)
        try
        {
          String str2 = paramCursor.getString(j);
          str1 = str2;
          paramPrintStream.println("   " + arrayOfString[j] + '=' + str1);
          j++;
        }
        catch (SQLiteException localSQLiteException)
        {
          while (true)
            String str1 = "<unprintable>";
        }
    paramPrintStream.println("}");
  }

  public static void dumpCurrentRow(android.database.Cursor paramCursor, StringBuilder paramStringBuilder)
  {
    String[] arrayOfString = paramCursor.getColumnNames();
    paramStringBuilder.append("" + paramCursor.getPosition() + " {\n");
    int i = arrayOfString.length;
    int j = 0;
    while (true)
      if (j < i)
        try
        {
          String str2 = paramCursor.getString(j);
          str1 = str2;
          paramStringBuilder.append("   " + arrayOfString[j] + '=' + str1 + "\n");
          j++;
        }
        catch (SQLiteException localSQLiteException)
        {
          while (true)
            String str1 = "<unprintable>";
        }
    paramStringBuilder.append("}\n");
  }

  public static String dumpCurrentRowToString(android.database.Cursor paramCursor)
  {
    StringBuilder localStringBuilder = new StringBuilder();
    dumpCurrentRow(paramCursor, localStringBuilder);
    return localStringBuilder.toString();
  }

  public static void dumpCursor(android.database.Cursor paramCursor)
  {
    dumpCursor(paramCursor, System.out);
  }

  public static void dumpCursor(android.database.Cursor paramCursor, PrintStream paramPrintStream)
  {
    paramPrintStream.println(">>>>> Dumping cursor " + paramCursor);
    if (paramCursor != null)
    {
      int i = paramCursor.getPosition();
      paramCursor.moveToPosition(-1);
      while (paramCursor.moveToNext())
        dumpCurrentRow(paramCursor, paramPrintStream);
      paramCursor.moveToPosition(i);
    }
    paramPrintStream.println("<<<<<");
  }

  public static void dumpCursor(android.database.Cursor paramCursor, StringBuilder paramStringBuilder)
  {
    paramStringBuilder.append(">>>>> Dumping cursor " + paramCursor + "\n");
    if (paramCursor != null)
    {
      int i = paramCursor.getPosition();
      paramCursor.moveToPosition(-1);
      while (paramCursor.moveToNext())
        dumpCurrentRow(paramCursor, paramStringBuilder);
      paramCursor.moveToPosition(i);
    }
    paramStringBuilder.append("<<<<<\n");
  }

  public static String dumpCursorToString(android.database.Cursor paramCursor)
  {
    StringBuilder localStringBuilder = new StringBuilder();
    dumpCursor(paramCursor, localStringBuilder);
    return localStringBuilder.toString();
  }

  public static String getCollationKey(String paramString)
  {
    byte[] arrayOfByte = getCollationKeyInBytes(paramString);
    try
    {
      String str = new String(arrayOfByte, 0, getKeyLen(arrayOfByte), "ISO8859_1");
      return str;
    }
    catch (Exception localException)
    {
    }
    return "";
  }

  private static byte[] getCollationKeyInBytes(String paramString)
  {
    if (mColl == null)
    {
      mColl = Collator.getInstance();
      mColl.setStrength(0);
    }
    return mColl.getCollationKey(paramString).toByteArray();
  }

  public static String getHexCollationKey(String paramString)
  {
    byte[] arrayOfByte = getCollationKeyInBytes(paramString);
    return new String(Hex.encodeHex(arrayOfByte), 0, 2 * getKeyLen(arrayOfByte));
  }

  private static int getKeyLen(byte[] paramArrayOfByte)
  {
    if (paramArrayOfByte[(-1 + paramArrayOfByte.length)] != 0)
      return paramArrayOfByte.length;
    return -1 + paramArrayOfByte.length;
  }

  public static int getTypeOfObject(Object paramObject)
  {
    if (paramObject == null)
      return 0;
    if ((paramObject instanceof byte[]))
      return 4;
    if (((paramObject instanceof Float)) || ((paramObject instanceof Double)))
      return 2;
    if (((paramObject instanceof Long)) || ((paramObject instanceof Integer)))
      return 1;
    return 3;
  }

  public static long longForQuery(SQLiteDatabase paramSQLiteDatabase, String paramString, String[] paramArrayOfString)
  {
    SQLiteStatement localSQLiteStatement = paramSQLiteDatabase.compileStatement(paramString);
    try
    {
      long l = longForQuery(localSQLiteStatement, paramArrayOfString);
      return l;
    }
    finally
    {
      localSQLiteStatement.close();
    }
  }

  public static long longForQuery(SQLiteStatement paramSQLiteStatement, String[] paramArrayOfString)
  {
    if (paramArrayOfString != null)
    {
      int i = paramArrayOfString.length;
      for (int j = 0; j < i; j++)
        bindObjectToProgram(paramSQLiteStatement, j + 1, paramArrayOfString[j]);
    }
    return paramSQLiteStatement.simpleQueryForLong();
  }

  public static long queryNumEntries(SQLiteDatabase paramSQLiteDatabase, String paramString)
  {
    Cursor localCursor = paramSQLiteDatabase.query(paramString, countProjection, null, null, null, null, null);
    try
    {
      localCursor.moveToFirst();
      long l = localCursor.getLong(0);
      return l;
    }
    finally
    {
      localCursor.close();
    }
  }

  public static final void readExceptionFromParcel(Parcel paramParcel)
  {
    int i = paramParcel.readInt();
    if (i == 0)
      return;
    readExceptionFromParcel(paramParcel, paramParcel.readString(), i);
  }

  private static final void readExceptionFromParcel(Parcel paramParcel, String paramString, int paramInt)
  {
    switch (paramInt)
    {
    default:
      paramParcel.readException(paramInt, paramString);
      return;
    case 2:
      throw new IllegalArgumentException(paramString);
    case 3:
      throw new UnsupportedOperationException(paramString);
    case 4:
      throw new SQLiteAbortException(paramString);
    case 5:
      throw new SQLiteConstraintException(paramString);
    case 6:
      throw new SQLiteDatabaseCorruptException(paramString);
    case 7:
      throw new SQLiteFullException(paramString);
    case 8:
      throw new SQLiteDiskIOException(paramString);
    case 9:
    }
    throw new SQLiteException(paramString);
  }

  public static void readExceptionWithFileNotFoundExceptionFromParcel(Parcel paramParcel)
    throws FileNotFoundException
  {
    int i = paramParcel.readInt();
    if (i == 0)
      return;
    String str = paramParcel.readString();
    if (i == 1)
      throw new FileNotFoundException(str);
    readExceptionFromParcel(paramParcel, str, i);
  }

  public static void readExceptionWithOperationApplicationExceptionFromParcel(Parcel paramParcel)
    throws OperationApplicationException
  {
    int i = paramParcel.readInt();
    if (i == 0)
      return;
    String str = paramParcel.readString();
    if (i == 10)
      throw new OperationApplicationException(str);
    readExceptionFromParcel(paramParcel, str, i);
  }

  public static String sqlEscapeString(String paramString)
  {
    StringBuilder localStringBuilder = new StringBuilder();
    appendEscapedSQLString(localStringBuilder, paramString);
    return localStringBuilder.toString();
  }

  public static String stringForQuery(SQLiteDatabase paramSQLiteDatabase, String paramString, String[] paramArrayOfString)
  {
    SQLiteStatement localSQLiteStatement = paramSQLiteDatabase.compileStatement(paramString);
    try
    {
      String str = stringForQuery(localSQLiteStatement, paramArrayOfString);
      return str;
    }
    finally
    {
      localSQLiteStatement.close();
    }
  }

  public static String stringForQuery(SQLiteStatement paramSQLiteStatement, String[] paramArrayOfString)
  {
    if (paramArrayOfString != null)
    {
      int i = paramArrayOfString.length;
      for (int j = 0; j < i; j++)
        bindObjectToProgram(paramSQLiteStatement, j + 1, paramArrayOfString[j]);
    }
    return paramSQLiteStatement.simpleQueryForString();
  }

  public static final void writeExceptionToParcel(Parcel paramParcel, Exception paramException)
  {
    int i = 1;
    int j;
    if ((paramException instanceof FileNotFoundException))
    {
      j = 1;
      i = 0;
    }
    while (true)
    {
      paramParcel.writeInt(j);
      paramParcel.writeString(paramException.getMessage());
      if (i != 0)
        Log.e("DatabaseUtils", "Writing exception to parcel", paramException);
      return;
      if ((paramException instanceof IllegalArgumentException))
      {
        j = 2;
      }
      else if ((paramException instanceof UnsupportedOperationException))
      {
        j = 3;
      }
      else if ((paramException instanceof SQLiteAbortException))
      {
        j = 4;
      }
      else if ((paramException instanceof SQLiteConstraintException))
      {
        j = 5;
      }
      else if ((paramException instanceof SQLiteDatabaseCorruptException))
      {
        j = 6;
      }
      else if ((paramException instanceof SQLiteFullException))
      {
        j = 7;
      }
      else if ((paramException instanceof SQLiteDiskIOException))
      {
        j = 8;
      }
      else if ((paramException instanceof SQLiteException))
      {
        j = 9;
      }
      else
      {
        if (!(paramException instanceof OperationApplicationException))
          break;
        j = 10;
      }
    }
    paramParcel.writeException(paramException);
    Log.e("DatabaseUtils", "Writing exception to parcel", paramException);
  }

  public static class InsertHelper
  {
    public static final int TABLE_INFO_PRAGMA_COLUMNNAME_INDEX = 1;
    public static final int TABLE_INFO_PRAGMA_DEFAULT_INDEX = 4;
    private HashMap<String, Integer> mColumns;
    private final SQLiteDatabase mDb;
    private String mInsertSQL = null;
    private SQLiteStatement mInsertStatement = null;
    private SQLiteStatement mPreparedStatement = null;
    private SQLiteStatement mReplaceStatement = null;
    private final String mTableName;

    public InsertHelper(SQLiteDatabase paramSQLiteDatabase, String paramString)
    {
      this.mDb = paramSQLiteDatabase;
      this.mTableName = paramString;
    }

    private void buildSQL()
      throws SQLException
    {
      StringBuilder localStringBuilder1 = new StringBuilder(128);
      localStringBuilder1.append("INSERT INTO ");
      localStringBuilder1.append(this.mTableName);
      localStringBuilder1.append(" (");
      StringBuilder localStringBuilder2 = new StringBuilder(128);
      localStringBuilder2.append("VALUES (");
      int i = 1;
      Cursor localCursor = null;
      while (true)
      {
        try
        {
          localCursor = this.mDb.rawQuery("PRAGMA table_info(" + this.mTableName + ")", null);
          this.mColumns = new HashMap(localCursor.getCount());
          if (!localCursor.moveToNext())
            break;
          String str1 = localCursor.getString(1);
          String str2 = localCursor.getString(4);
          this.mColumns.put(str1, Integer.valueOf(i));
          localStringBuilder1.append("'");
          localStringBuilder1.append(str1);
          localStringBuilder1.append("'");
          if (str2 == null)
          {
            localStringBuilder2.append("?");
            if (i != localCursor.getCount())
              break label291;
            str3 = ") ";
            localStringBuilder1.append(str3);
            if (i != localCursor.getCount())
              break label298;
            str4 = ");";
            localStringBuilder2.append(str4);
            i++;
            continue;
          }
          localStringBuilder2.append("COALESCE(?, ");
          localStringBuilder2.append(str2);
          localStringBuilder2.append(")");
          continue;
        }
        finally
        {
          if (localCursor != null)
            localCursor.close();
        }
        label291: String str3 = ", ";
        continue;
        label298: String str4 = ", ";
      }
      if (localCursor != null)
        localCursor.close();
      localStringBuilder1.append(localStringBuilder2);
      this.mInsertSQL = localStringBuilder1.toString();
    }

    private SQLiteStatement getStatement(boolean paramBoolean)
      throws SQLException
    {
      if (paramBoolean)
      {
        if (this.mReplaceStatement == null)
        {
          if (this.mInsertSQL == null)
            buildSQL();
          String str = "INSERT OR REPLACE" + this.mInsertSQL.substring(6);
          this.mReplaceStatement = this.mDb.compileStatement(str);
        }
        return this.mReplaceStatement;
      }
      if (this.mInsertStatement == null)
      {
        if (this.mInsertSQL == null)
          buildSQL();
        this.mInsertStatement = this.mDb.compileStatement(this.mInsertSQL);
      }
      return this.mInsertStatement;
    }

    private long insertInternal(ContentValues paramContentValues, boolean paramBoolean)
    {
      try
      {
        localSQLiteStatement = getStatement(paramBoolean);
        localSQLiteStatement.clearBindings();
        Iterator localIterator = paramContentValues.valueSet().iterator();
        while (localIterator.hasNext())
        {
          Map.Entry localEntry = (Map.Entry)localIterator.next();
          DatabaseUtils.bindObjectToProgram(localSQLiteStatement, getColumnIndex((String)localEntry.getKey()), localEntry.getValue());
        }
      }
      catch (SQLException localSQLException)
      {
        SQLiteStatement localSQLiteStatement;
        Log.e("DatabaseUtils", "Error inserting " + paramContentValues + " into table  " + this.mTableName, localSQLException);
        long l2;
        for (long l1 = -1L; ; l1 = l2)
        {
          return l1;
          l2 = localSQLiteStatement.executeInsert();
        }
      }
      finally
      {
      }
    }

    public void bind(int paramInt, double paramDouble)
    {
      this.mPreparedStatement.bindDouble(paramInt, paramDouble);
    }

    public void bind(int paramInt, float paramFloat)
    {
      this.mPreparedStatement.bindDouble(paramInt, paramFloat);
    }

    public void bind(int paramInt1, int paramInt2)
    {
      this.mPreparedStatement.bindLong(paramInt1, paramInt2);
    }

    public void bind(int paramInt, long paramLong)
    {
      this.mPreparedStatement.bindLong(paramInt, paramLong);
    }

    public void bind(int paramInt, String paramString)
    {
      if (paramString == null)
      {
        this.mPreparedStatement.bindNull(paramInt);
        return;
      }
      this.mPreparedStatement.bindString(paramInt, paramString);
    }

    public void bind(int paramInt, boolean paramBoolean)
    {
      SQLiteStatement localSQLiteStatement = this.mPreparedStatement;
      if (paramBoolean);
      for (long l = 1L; ; l = 0L)
      {
        localSQLiteStatement.bindLong(paramInt, l);
        return;
      }
    }

    public void bind(int paramInt, byte[] paramArrayOfByte)
    {
      if (paramArrayOfByte == null)
      {
        this.mPreparedStatement.bindNull(paramInt);
        return;
      }
      this.mPreparedStatement.bindBlob(paramInt, paramArrayOfByte);
    }

    public void bindNull(int paramInt)
    {
      this.mPreparedStatement.bindNull(paramInt);
    }

    public void close()
    {
      if (this.mInsertStatement != null)
      {
        this.mInsertStatement.close();
        this.mInsertStatement = null;
      }
      if (this.mReplaceStatement != null)
      {
        this.mReplaceStatement.close();
        this.mReplaceStatement = null;
      }
      this.mInsertSQL = null;
      this.mColumns = null;
    }

    public long execute()
    {
      if (this.mPreparedStatement == null)
        throw new IllegalStateException("you must prepare this inserter before calling execute");
      try
      {
        long l = this.mPreparedStatement.executeInsert();
        return l;
      }
      catch (SQLException localSQLException)
      {
        Log.e("DatabaseUtils", "Error executing InsertHelper with table " + this.mTableName, localSQLException);
        return -1L;
      }
      finally
      {
        this.mPreparedStatement = null;
      }
    }

    public int getColumnIndex(String paramString)
    {
      getStatement(false);
      Integer localInteger = (Integer)this.mColumns.get(paramString);
      if (localInteger == null)
        throw new IllegalArgumentException("column '" + paramString + "' is invalid");
      return localInteger.intValue();
    }

    public long insert(ContentValues paramContentValues)
    {
      return insertInternal(paramContentValues, false);
    }

    public void prepareForInsert()
    {
      this.mPreparedStatement = getStatement(false);
      this.mPreparedStatement.clearBindings();
    }

    public void prepareForReplace()
    {
      this.mPreparedStatement = getStatement(true);
      this.mPreparedStatement.clearBindings();
    }

    public long replace(ContentValues paramContentValues)
    {
      return insertInternal(paramContentValues, true);
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     net.sqlcipher.DatabaseUtils
 * JD-Core Version:    0.6.2
 */