package net.sqlcipher.database;

import android.util.Log;

class SQLiteCompiledSql
{
  private static final String TAG = "SQLiteCompiledSql";
  SQLiteDatabase mDatabase;
  private boolean mInUse = false;
  private String mSqlStmt = null;
  private Throwable mStackTrace = null;
  int nHandle = 0;
  int nStatement = 0;

  SQLiteCompiledSql(SQLiteDatabase paramSQLiteDatabase, String paramString)
  {
    if (!paramSQLiteDatabase.isOpen())
      throw new IllegalStateException("database " + paramSQLiteDatabase.getPath() + " already closed");
    this.mDatabase = paramSQLiteDatabase;
    this.mSqlStmt = paramString;
    this.mStackTrace = new DatabaseObjectNotClosedException().fillInStackTrace();
    this.nHandle = paramSQLiteDatabase.mNativeHandle;
    compile(paramString, true);
  }

  private void compile(String paramString, boolean paramBoolean)
  {
    if (!this.mDatabase.isOpen())
      throw new IllegalStateException("database " + this.mDatabase.getPath() + " already closed");
    if (paramBoolean)
      this.mDatabase.lock();
    try
    {
      native_compile(paramString);
      return;
    }
    finally
    {
      this.mDatabase.unlock();
    }
  }

  private final native void native_compile(String paramString);

  private final native void native_finalize();

  boolean acquire()
  {
    boolean bool1 = true;
    try
    {
      boolean bool2 = this.mInUse;
      if (bool2)
        bool1 = false;
      while (true)
      {
        return bool1;
        this.mInUse = true;
        if (SQLiteDebug.DEBUG_ACTIVE_CURSOR_FINALIZATION)
          Log.v("SQLiteCompiledSql", "Acquired DbObj (id#" + this.nStatement + ") from DB cache");
      }
    }
    finally
    {
    }
  }

  protected void finalize()
    throws Throwable
  {
    try
    {
      int i = this.nStatement;
      if (i == 0)
        return;
      if (SQLiteDebug.DEBUG_ACTIVE_CURSOR_FINALIZATION)
        Log.v("SQLiteCompiledSql", "** warning ** Finalized DbObj (id#" + this.nStatement + ")");
      int j = this.mSqlStmt.length();
      StringBuilder localStringBuilder = new StringBuilder().append("Releasing statement in a finalizer. Please ensure that you explicitly call close() on your cursor: ");
      String str = this.mSqlStmt;
      if (j > 100)
        j = 100;
      Log.w("SQLiteCompiledSql", str.substring(0, j), this.mStackTrace);
      releaseSqlStatement();
      return;
    }
    finally
    {
      super.finalize();
    }
  }

  void release()
  {
    try
    {
      if (SQLiteDebug.DEBUG_ACTIVE_CURSOR_FINALIZATION)
        Log.v("SQLiteCompiledSql", "Released DbObj (id#" + this.nStatement + ") back to DB cache");
      this.mInUse = false;
      return;
    }
    finally
    {
    }
  }

  void releaseSqlStatement()
  {
    if (this.nStatement != 0)
      if (SQLiteDebug.DEBUG_ACTIVE_CURSOR_FINALIZATION)
        Log.v("SQLiteCompiledSql", "closed and deallocated DbObj (id#" + this.nStatement + ")");
    try
    {
      this.mDatabase.lock();
      native_finalize();
      this.nStatement = 0;
      return;
    }
    finally
    {
      this.mDatabase.unlock();
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     net.sqlcipher.database.SQLiteCompiledSql
 * JD-Core Version:    0.6.2
 */