package net.sqlcipher.database;

import android.database.DataSetObserver;
import android.os.Handler;
import android.os.Message;
import android.os.Process;
import android.text.TextUtils;
import android.util.Log;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;
import java.util.concurrent.locks.ReentrantLock;
import net.sqlcipher.AbstractWindowedCursor;
import net.sqlcipher.SQLException;

public class SQLiteCursor extends AbstractWindowedCursor
{
  static final int NO_COUNT = -1;
  static final String TAG = "Cursor";
  private Map<String, Integer> mColumnNameMap;
  private String[] mColumns;
  private int mCount = -1;
  private int mCursorState = 0;
  private SQLiteDatabase mDatabase;
  private SQLiteCursorDriver mDriver;
  private String mEditTable;
  private int mInitialRead = 2147483647;
  private ReentrantLock mLock = null;
  private int mMaxRead = 2147483647;
  protected MainThreadNotificationHandler mNotificationHandler;
  private boolean mPendingData = false;
  private SQLiteQuery mQuery;
  private Throwable mStackTrace = new DatabaseObjectNotClosedException().fillInStackTrace();

  public SQLiteCursor(SQLiteDatabase paramSQLiteDatabase, SQLiteCursorDriver paramSQLiteCursorDriver, String paramString, SQLiteQuery paramSQLiteQuery)
  {
    this.mDatabase = paramSQLiteDatabase;
    this.mDriver = paramSQLiteCursorDriver;
    this.mEditTable = paramString;
    this.mColumnNameMap = null;
    this.mQuery = paramSQLiteQuery;
    try
    {
      paramSQLiteDatabase.lock();
      int i = this.mQuery.columnCountLocked();
      this.mColumns = new String[i];
      for (int j = 0; j < i; j++)
      {
        String str = this.mQuery.columnNameLocked(j);
        this.mColumns[j] = str;
        if ("_id".equals(str))
          this.mRowIdColumnIndex = j;
      }
      return;
    }
    finally
    {
      paramSQLiteDatabase.unlock();
    }
  }

  private void deactivateCommon()
  {
    this.mCursorState = 0;
    if (this.mWindow != null)
    {
      this.mWindow.close();
      this.mWindow = null;
    }
  }

  private void fillWindow(int paramInt)
  {
    if (this.mWindow == null)
      this.mWindow = new net.sqlcipher.CursorWindow(true);
    while (true)
    {
      this.mWindow.setStartPosition(paramInt);
      this.mCount = this.mQuery.fillWindow(this.mWindow, this.mInitialRead, 0);
      if (this.mCount == -1)
      {
        this.mCount = (paramInt + this.mInitialRead);
        new Thread(new QueryThread(this.mCursorState), "query thread").start();
      }
      return;
      this.mCursorState = (1 + this.mCursorState);
      queryThreadLock();
      try
      {
        this.mWindow.clear();
        queryThreadUnlock();
      }
      finally
      {
        queryThreadUnlock();
      }
    }
  }

  private void queryThreadLock()
  {
    if (this.mLock != null)
      this.mLock.lock();
  }

  private void queryThreadUnlock()
  {
    if (this.mLock != null)
      this.mLock.unlock();
  }

  public void close()
  {
    super.close();
    deactivateCommon();
    this.mQuery.close();
    this.mDriver.cursorClosed();
  }

  public boolean commitUpdates(Map<? extends Long, ? extends Map<String, Object>> paramMap)
  {
    if (!supportsUpdates())
    {
      Log.e("Cursor", "commitUpdates not supported on this cursor, did you include the _id column?");
      return false;
    }
    HashMap localHashMap = this.mUpdatedRows;
    if (paramMap != null);
    try
    {
      this.mUpdatedRows.putAll(paramMap);
      if (this.mUpdatedRows.size() == 0)
        return true;
    }
    finally
    {
    }
    this.mDatabase.beginTransaction();
    StringBuilder localStringBuilder;
    long l;
    Iterator localIterator2;
    Object[] arrayOfObject;
    while (true)
    {
      Map localMap;
      Long localLong;
      try
      {
        localStringBuilder = new StringBuilder(128);
        Iterator localIterator1 = this.mUpdatedRows.entrySet().iterator();
        if (!localIterator1.hasNext())
          break;
        Map.Entry localEntry1 = (Map.Entry)localIterator1.next();
        localMap = (Map)localEntry1.getValue();
        localLong = (Long)localEntry1.getKey();
        if ((localLong == null) || (localMap == null))
          throw new IllegalStateException("null rowId or values found! rowId = " + localLong + ", values = " + localMap);
      }
      finally
      {
        this.mDatabase.endTransaction();
      }
      if (localMap.size() != 0)
      {
        l = localLong.longValue();
        localIterator2 = localMap.entrySet().iterator();
        localStringBuilder.setLength(0);
        localStringBuilder.append("UPDATE " + this.mEditTable + " SET ");
        arrayOfObject = new Object[localMap.size()];
      }
    }
    for (int i = 0; ; i++)
      if (localIterator2.hasNext())
      {
        Map.Entry localEntry2 = (Map.Entry)localIterator2.next();
        localStringBuilder.append((String)localEntry2.getKey());
        localStringBuilder.append("=?");
        arrayOfObject[i] = localEntry2.getValue();
        if (localIterator2.hasNext())
          localStringBuilder.append(", ");
      }
      else
      {
        localStringBuilder.append(" WHERE " + this.mColumns[this.mRowIdColumnIndex] + '=' + l);
        localStringBuilder.append(';');
        this.mDatabase.execSQL(localStringBuilder.toString(), arrayOfObject);
        this.mDatabase.rowUpdated(this.mEditTable, l);
        break;
        this.mDatabase.setTransactionSuccessful();
        this.mDatabase.endTransaction();
        this.mUpdatedRows.clear();
        onChange(true);
        return true;
      }
  }

  public void deactivate()
  {
    super.deactivate();
    deactivateCommon();
    this.mDriver.cursorDeactivated();
  }

  public boolean deleteRow()
  {
    checkPosition();
    if ((this.mRowIdColumnIndex == -1) || (this.mCurrentRowID == null))
    {
      Log.e("Cursor", "Could not delete row because either the row ID column is not available or ithas not been read.");
      return false;
    }
    this.mDatabase.lock();
    try
    {
      SQLiteDatabase localSQLiteDatabase = this.mDatabase;
      String str1 = this.mEditTable;
      String str2 = this.mColumns[this.mRowIdColumnIndex] + "=?";
      String[] arrayOfString = new String[1];
      arrayOfString[0] = this.mCurrentRowID.toString();
      localSQLiteDatabase.delete(str1, str2, arrayOfString);
      i = 1;
      int j = this.mPos;
      requery();
      moveToPosition(j);
      this.mDatabase.unlock();
      if (i != 0)
      {
        onChange(true);
        return true;
      }
    }
    catch (SQLException localSQLException)
    {
      while (true)
        int i = 0;
    }
    finally
    {
      this.mDatabase.unlock();
    }
    return false;
  }

  public void fillWindow(int paramInt, android.database.CursorWindow paramCursorWindow)
  {
    if (this.mWindow == null)
      this.mWindow = new net.sqlcipher.CursorWindow(true);
    while (true)
    {
      this.mWindow.setStartPosition(paramInt);
      this.mCount = this.mQuery.fillWindow(this.mWindow, this.mInitialRead, 0);
      if (this.mCount == -1)
      {
        this.mCount = (paramInt + this.mInitialRead);
        new Thread(new QueryThread(this.mCursorState), "query thread").start();
      }
      return;
      this.mCursorState = (1 + this.mCursorState);
      queryThreadLock();
      try
      {
        this.mWindow.clear();
        queryThreadUnlock();
      }
      finally
      {
        queryThreadUnlock();
      }
    }
  }

  protected void finalize()
  {
    try
    {
      if (this.mWindow != null)
      {
        int i = this.mQuery.mSql.length();
        StringBuilder localStringBuilder = new StringBuilder().append("Finalizing a Cursor that has not been deactivated or closed. database = ").append(this.mDatabase.getPath()).append(", table = ").append(this.mEditTable).append(", query = ");
        String str = this.mQuery.mSql;
        if (i > 100)
          i = 100;
        Log.e("Cursor", str.substring(0, i), this.mStackTrace);
        close();
        SQLiteDebug.notifyActiveCursorFinalized();
      }
      return;
    }
    finally
    {
      super.finalize();
    }
  }

  public int getColumnIndex(String paramString)
  {
    int i = -1;
    if (this.mColumnNameMap == null)
    {
      String[] arrayOfString = this.mColumns;
      int k = arrayOfString.length;
      HashMap localHashMap = new HashMap(k, 1.0F);
      for (int m = 0; m < k; m++)
        localHashMap.put(arrayOfString[m], Integer.valueOf(m));
      this.mColumnNameMap = localHashMap;
    }
    int j = paramString.lastIndexOf('.');
    if (j != i)
    {
      Exception localException = new Exception();
      Log.e("Cursor", "requesting column name with table name -- " + paramString, localException);
      paramString = paramString.substring(j + 1);
    }
    Integer localInteger = (Integer)this.mColumnNameMap.get(paramString);
    if (localInteger != null)
      i = localInteger.intValue();
    return i;
  }

  public String[] getColumnNames()
  {
    return this.mColumns;
  }

  public int getCount()
  {
    if (this.mCount == -1)
      fillWindow(0);
    return this.mCount;
  }

  public SQLiteDatabase getDatabase()
  {
    return this.mDatabase;
  }

  public boolean onMove(int paramInt1, int paramInt2)
  {
    if ((this.mWindow == null) || (paramInt2 < this.mWindow.getStartPosition()) || (paramInt2 >= this.mWindow.getStartPosition() + this.mWindow.getNumRows()))
      fillWindow(paramInt2);
    return true;
  }

  public void registerDataSetObserver(DataSetObserver paramDataSetObserver)
  {
    super.registerDataSetObserver(paramDataSetObserver);
    if (((2147483647 != this.mMaxRead) || (2147483647 != this.mInitialRead)) && (this.mNotificationHandler == null))
      queryThreadLock();
    try
    {
      this.mNotificationHandler = new MainThreadNotificationHandler();
      if (this.mPendingData)
      {
        notifyDataSetChange();
        this.mPendingData = false;
      }
      return;
    }
    finally
    {
      queryThreadUnlock();
    }
  }

  public boolean requery()
  {
    if (isClosed())
      return false;
    this.mDatabase.lock();
    try
    {
      if (this.mWindow != null)
        this.mWindow.clear();
      this.mPos = -1;
      this.mDriver.cursorRequeried(this);
      this.mCount = -1;
      this.mCursorState = (1 + this.mCursorState);
      queryThreadLock();
      try
      {
        this.mQuery.requery();
        queryThreadUnlock();
        return super.requery();
      }
      finally
      {
        queryThreadUnlock();
      }
    }
    finally
    {
      this.mDatabase.unlock();
    }
  }

  public void setLoadStyle(int paramInt1, int paramInt2)
  {
    this.mMaxRead = paramInt2;
    this.mInitialRead = paramInt1;
    this.mLock = new ReentrantLock(true);
  }

  public void setSelectionArguments(String[] paramArrayOfString)
  {
    this.mDriver.setBindArguments(paramArrayOfString);
  }

  public void setWindow(net.sqlcipher.CursorWindow paramCursorWindow)
  {
    if (this.mWindow != null)
    {
      this.mCursorState = (1 + this.mCursorState);
      queryThreadLock();
    }
    try
    {
      this.mWindow.close();
      queryThreadUnlock();
      this.mCount = -1;
      this.mWindow = paramCursorWindow;
      return;
    }
    finally
    {
      queryThreadUnlock();
    }
  }

  public boolean supportsUpdates()
  {
    return !TextUtils.isEmpty(this.mEditTable);
  }

  protected class MainThreadNotificationHandler extends Handler
  {
    protected MainThreadNotificationHandler()
    {
    }

    public void handleMessage(Message paramMessage)
    {
      SQLiteCursor.this.notifyDataSetChange();
    }
  }

  private final class QueryThread
    implements Runnable
  {
    private final int mThreadState;

    QueryThread(int arg2)
    {
      int i;
      this.mThreadState = i;
    }

    private void sendMessage()
    {
      if (SQLiteCursor.this.mNotificationHandler != null)
      {
        SQLiteCursor.this.mNotificationHandler.sendEmptyMessage(1);
        SQLiteCursor.access$002(SQLiteCursor.this, false);
        return;
      }
      SQLiteCursor.access$002(SQLiteCursor.this, true);
    }

    public void run()
    {
      net.sqlcipher.CursorWindow localCursorWindow = SQLiteCursor.this.mWindow;
      Process.setThreadPriority(Process.myTid(), 10);
      while (true)
      {
        SQLiteCursor.this.mLock.lock();
        if (SQLiteCursor.this.mCursorState != this.mThreadState)
        {
          SQLiteCursor.this.mLock.unlock();
          return;
        }
        try
        {
          int i = SQLiteCursor.this.mQuery.fillWindow(localCursorWindow, SQLiteCursor.this.mMaxRead, SQLiteCursor.this.mCount);
          if (i != 0)
          {
            if (i == -1)
            {
              SQLiteCursor.access$512(SQLiteCursor.this, SQLiteCursor.this.mMaxRead);
              sendMessage();
              SQLiteCursor.this.mLock.unlock();
              continue;
            }
            SQLiteCursor.access$502(SQLiteCursor.this, i);
            sendMessage();
            return;
          }
          return;
        }
        catch (Exception localException)
        {
        }
        finally
        {
          SQLiteCursor.this.mLock.unlock();
        }
      }
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     net.sqlcipher.database.SQLiteCursor
 * JD-Core Version:    0.6.2
 */