package net.sqlcipher.database;

import android.content.Context;
import android.util.Log;
import java.io.File;

public abstract class SQLiteOpenHelper
{
  private static final String TAG = SQLiteOpenHelper.class.getSimpleName();
  private final Context mContext;
  private SQLiteDatabase mDatabase = null;
  private final SQLiteDatabase.CursorFactory mFactory;
  private boolean mIsInitializing = false;
  private final String mName;
  private final int mNewVersion;

  public SQLiteOpenHelper(Context paramContext, String paramString, SQLiteDatabase.CursorFactory paramCursorFactory, int paramInt)
  {
    if (paramInt < 1)
      throw new IllegalArgumentException("Version must be >= 1, was " + paramInt);
    this.mContext = paramContext;
    this.mName = paramString;
    this.mFactory = paramCursorFactory;
    this.mNewVersion = paramInt;
  }

  public void close()
  {
    try
    {
      if (this.mIsInitializing)
        throw new IllegalStateException("Closed during initialization");
    }
    finally
    {
    }
    if ((this.mDatabase != null) && (this.mDatabase.isOpen()))
    {
      this.mDatabase.close();
      this.mDatabase = null;
    }
  }

  public SQLiteDatabase getReadableDatabase(String paramString)
  {
    while (true)
    {
      Object localObject3;
      try
      {
        if ((this.mDatabase != null) && (this.mDatabase.isOpen()))
        {
          localObject3 = this.mDatabase;
          return localObject3;
        }
        if (this.mIsInitializing)
          throw new IllegalStateException("getReadableDatabase called recursively");
      }
      finally
      {
      }
      SQLiteDatabase localSQLiteDatabase1;
      try
      {
        SQLiteDatabase localSQLiteDatabase2 = getWritableDatabase(paramString);
        localObject3 = localSQLiteDatabase2;
      }
      catch (SQLiteException localSQLiteException)
      {
        if (this.mName == null)
          throw localSQLiteException;
        Log.e(TAG, "Couldn't open " + this.mName + " for writing (will try read-only):", localSQLiteException);
        localSQLiteDatabase1 = null;
        try
        {
          this.mIsInitializing = true;
          String str = this.mContext.getDatabasePath(this.mName).getPath();
          File localFile1 = new File(str);
          File localFile2 = new File(this.mContext.getDatabasePath(this.mName).getParent());
          boolean bool1 = localFile2.exists();
          localSQLiteDatabase1 = null;
          if (!bool1)
            localFile2.mkdirs();
          boolean bool2 = localFile1.exists();
          localSQLiteDatabase1 = null;
          if (!bool2)
          {
            this.mIsInitializing = false;
            localSQLiteDatabase1 = getWritableDatabase(paramString);
            this.mIsInitializing = true;
            localSQLiteDatabase1.close();
          }
          localSQLiteDatabase1 = SQLiteDatabase.openDatabase(str, paramString, this.mFactory, 1);
          if (localSQLiteDatabase1.getVersion() != this.mNewVersion)
            throw new SQLiteException("Can't upgrade read-only database from version " + localSQLiteDatabase1.getVersion() + " to " + this.mNewVersion + ": " + str);
        }
        finally
        {
          this.mIsInitializing = false;
          if ((localSQLiteDatabase1 != null) && (localSQLiteDatabase1 != this.mDatabase))
            localSQLiteDatabase1.close();
        }
        onOpen(localSQLiteDatabase1);
        Log.w(TAG, "Opened " + this.mName + " in read-only mode");
        this.mDatabase = localSQLiteDatabase1;
        localObject3 = this.mDatabase;
        this.mIsInitializing = false;
      }
      if ((localSQLiteDatabase1 != null) && (localSQLiteDatabase1 != this.mDatabase))
        localSQLiteDatabase1.close();
    }
  }

  // ERROR //
  public SQLiteDatabase getWritableDatabase(String paramString)
  {
    // Byte code:
    //   0: aload_0
    //   1: monitorenter
    //   2: aload_0
    //   3: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   6: ifnull +32 -> 38
    //   9: aload_0
    //   10: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   13: invokevirtual 75	net/sqlcipher/database/SQLiteDatabase:isOpen	()Z
    //   16: ifeq +22 -> 38
    //   19: aload_0
    //   20: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   23: invokevirtual 149	net/sqlcipher/database/SQLiteDatabase:isReadOnly	()Z
    //   26: ifne +12 -> 38
    //   29: aload_0
    //   30: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   33: astore_3
    //   34: aload_0
    //   35: monitorexit
    //   36: aload_3
    //   37: areturn
    //   38: aload_0
    //   39: getfield 35	net/sqlcipher/database/SQLiteOpenHelper:mIsInitializing	Z
    //   42: ifeq +18 -> 60
    //   45: new 66	java/lang/IllegalStateException
    //   48: dup
    //   49: ldc 151
    //   51: invokespecial 69	java/lang/IllegalStateException:<init>	(Ljava/lang/String;)V
    //   54: athrow
    //   55: astore_2
    //   56: aload_0
    //   57: monitorexit
    //   58: aload_2
    //   59: athrow
    //   60: aconst_null
    //   61: astore_3
    //   62: aload_0
    //   63: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   66: ifnull +10 -> 76
    //   69: aload_0
    //   70: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   73: invokevirtual 154	net/sqlcipher/database/SQLiteDatabase:lock	()V
    //   76: aload_0
    //   77: iconst_1
    //   78: putfield 35	net/sqlcipher/database/SQLiteOpenHelper:mIsInitializing	Z
    //   81: aload_0
    //   82: getfield 59	net/sqlcipher/database/SQLiteOpenHelper:mName	Ljava/lang/String;
    //   85: ifnonnull +101 -> 186
    //   88: aconst_null
    //   89: aload_1
    //   90: invokestatic 158	net/sqlcipher/database/SQLiteDatabase:create	(Lnet/sqlcipher/database/SQLiteDatabase$CursorFactory;Ljava/lang/String;)Lnet/sqlcipher/database/SQLiteDatabase;
    //   93: astore_3
    //   94: aload_3
    //   95: invokevirtual 125	net/sqlcipher/database/SQLiteDatabase:getVersion	()I
    //   98: istore 12
    //   100: iload 12
    //   102: aload_0
    //   103: getfield 63	net/sqlcipher/database/SQLiteOpenHelper:mNewVersion	I
    //   106: if_icmpeq +33 -> 139
    //   109: aload_3
    //   110: invokevirtual 161	net/sqlcipher/database/SQLiteDatabase:beginTransaction	()V
    //   113: iload 12
    //   115: ifne +139 -> 254
    //   118: aload_0
    //   119: aload_3
    //   120: invokevirtual 164	net/sqlcipher/database/SQLiteOpenHelper:onCreate	(Lnet/sqlcipher/database/SQLiteDatabase;)V
    //   123: aload_3
    //   124: aload_0
    //   125: getfield 63	net/sqlcipher/database/SQLiteOpenHelper:mNewVersion	I
    //   128: invokevirtual 168	net/sqlcipher/database/SQLiteDatabase:setVersion	(I)V
    //   131: aload_3
    //   132: invokevirtual 171	net/sqlcipher/database/SQLiteDatabase:setTransactionSuccessful	()V
    //   135: aload_3
    //   136: invokevirtual 174	net/sqlcipher/database/SQLiteDatabase:endTransaction	()V
    //   139: aload_0
    //   140: aload_3
    //   141: invokevirtual 136	net/sqlcipher/database/SQLiteOpenHelper:onOpen	(Lnet/sqlcipher/database/SQLiteDatabase;)V
    //   144: aload_0
    //   145: iconst_0
    //   146: putfield 35	net/sqlcipher/database/SQLiteOpenHelper:mIsInitializing	Z
    //   149: iconst_1
    //   150: ifeq +171 -> 321
    //   153: aload_0
    //   154: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   157: astore 13
    //   159: aload 13
    //   161: ifnull +17 -> 178
    //   164: aload_0
    //   165: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   168: invokevirtual 77	net/sqlcipher/database/SQLiteDatabase:close	()V
    //   171: aload_0
    //   172: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   175: invokevirtual 177	net/sqlcipher/database/SQLiteDatabase:unlock	()V
    //   178: aload_0
    //   179: aload_3
    //   180: putfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   183: goto -149 -> 34
    //   186: aload_0
    //   187: getfield 57	net/sqlcipher/database/SQLiteOpenHelper:mContext	Landroid/content/Context;
    //   190: aload_0
    //   191: getfield 59	net/sqlcipher/database/SQLiteOpenHelper:mName	Ljava/lang/String;
    //   194: invokevirtual 102	android/content/Context:getDatabasePath	(Ljava/lang/String;)Ljava/io/File;
    //   197: invokevirtual 107	java/io/File:getPath	()Ljava/lang/String;
    //   200: astore 7
    //   202: new 104	java/io/File
    //   205: dup
    //   206: aload 7
    //   208: invokespecial 108	java/io/File:<init>	(Ljava/lang/String;)V
    //   211: astore 8
    //   213: aload 8
    //   215: invokevirtual 114	java/io/File:exists	()Z
    //   218: istore 9
    //   220: aconst_null
    //   221: astore_3
    //   222: iload 9
    //   224: ifne +12 -> 236
    //   227: aload 8
    //   229: invokevirtual 181	java/io/File:getParentFile	()Ljava/io/File;
    //   232: invokevirtual 117	java/io/File:mkdirs	()Z
    //   235: pop
    //   236: aload 7
    //   238: aload_1
    //   239: aload_0
    //   240: getfield 61	net/sqlcipher/database/SQLiteOpenHelper:mFactory	Lnet/sqlcipher/database/SQLiteDatabase$CursorFactory;
    //   243: invokestatic 185	net/sqlcipher/database/SQLiteDatabase:openOrCreateDatabase	(Ljava/lang/String;Ljava/lang/String;Lnet/sqlcipher/database/SQLiteDatabase$CursorFactory;)Lnet/sqlcipher/database/SQLiteDatabase;
    //   246: astore 11
    //   248: aload 11
    //   250: astore_3
    //   251: goto -157 -> 94
    //   254: aload_0
    //   255: aload_3
    //   256: iload 12
    //   258: aload_0
    //   259: getfield 63	net/sqlcipher/database/SQLiteOpenHelper:mNewVersion	I
    //   262: invokevirtual 189	net/sqlcipher/database/SQLiteOpenHelper:onUpgrade	(Lnet/sqlcipher/database/SQLiteDatabase;II)V
    //   265: goto -142 -> 123
    //   268: astore 15
    //   270: aload_3
    //   271: invokevirtual 174	net/sqlcipher/database/SQLiteDatabase:endTransaction	()V
    //   274: aload 15
    //   276: athrow
    //   277: astore 4
    //   279: aload_0
    //   280: iconst_0
    //   281: putfield 35	net/sqlcipher/database/SQLiteOpenHelper:mIsInitializing	Z
    //   284: iconst_0
    //   285: ifeq +61 -> 346
    //   288: aload_0
    //   289: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   292: astore 5
    //   294: aload 5
    //   296: ifnull +17 -> 313
    //   299: aload_0
    //   300: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   303: invokevirtual 77	net/sqlcipher/database/SQLiteDatabase:close	()V
    //   306: aload_0
    //   307: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   310: invokevirtual 177	net/sqlcipher/database/SQLiteDatabase:unlock	()V
    //   313: aload_0
    //   314: aload_3
    //   315: putfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   318: aload 4
    //   320: athrow
    //   321: aload_0
    //   322: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   325: ifnull +10 -> 335
    //   328: aload_0
    //   329: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   332: invokevirtual 177	net/sqlcipher/database/SQLiteDatabase:unlock	()V
    //   335: aload_3
    //   336: ifnull -302 -> 34
    //   339: aload_3
    //   340: invokevirtual 77	net/sqlcipher/database/SQLiteDatabase:close	()V
    //   343: goto -309 -> 34
    //   346: aload_0
    //   347: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   350: ifnull +10 -> 360
    //   353: aload_0
    //   354: getfield 33	net/sqlcipher/database/SQLiteOpenHelper:mDatabase	Lnet/sqlcipher/database/SQLiteDatabase;
    //   357: invokevirtual 177	net/sqlcipher/database/SQLiteDatabase:unlock	()V
    //   360: aload_3
    //   361: ifnull -43 -> 318
    //   364: aload_3
    //   365: invokevirtual 77	net/sqlcipher/database/SQLiteDatabase:close	()V
    //   368: goto -50 -> 318
    //   371: astore 6
    //   373: goto -67 -> 306
    //   376: astore 14
    //   378: goto -207 -> 171
    //
    // Exception table:
    //   from	to	target	type
    //   2	34	55	finally
    //   38	55	55	finally
    //   62	76	55	finally
    //   144	149	55	finally
    //   153	159	55	finally
    //   164	171	55	finally
    //   171	178	55	finally
    //   178	183	55	finally
    //   279	284	55	finally
    //   288	294	55	finally
    //   299	306	55	finally
    //   306	313	55	finally
    //   313	318	55	finally
    //   318	321	55	finally
    //   321	335	55	finally
    //   339	343	55	finally
    //   346	360	55	finally
    //   364	368	55	finally
    //   118	123	268	finally
    //   123	135	268	finally
    //   254	265	268	finally
    //   76	94	277	finally
    //   94	113	277	finally
    //   135	139	277	finally
    //   139	144	277	finally
    //   186	220	277	finally
    //   227	236	277	finally
    //   236	248	277	finally
    //   270	277	277	finally
    //   299	306	371	java/lang/Exception
    //   164	171	376	java/lang/Exception
  }

  public abstract void onCreate(SQLiteDatabase paramSQLiteDatabase);

  public void onOpen(SQLiteDatabase paramSQLiteDatabase)
  {
  }

  public abstract void onUpgrade(SQLiteDatabase paramSQLiteDatabase, int paramInt1, int paramInt2);
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     net.sqlcipher.database.SQLiteOpenHelper
 * JD-Core Version:    0.6.2
 */