package org.jraf.android.backport.switchwidget;

import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.text.Layout;
import android.text.Layout.Alignment;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View.MeasureSpec;
import android.view.ViewConfiguration;
import android.view.ViewParent;
import android.widget.CompoundButton;

public class Switch extends CompoundButton
{
  private static final int[] CHECKED_STATE_SET = { 16842912 };
  private static final int MONOSPACE = 3;
  private static final int SANS = 1;
  private static final int SERIF = 2;
  private static final int TOUCH_MODE_DOWN = 1;
  private static final int TOUCH_MODE_DRAGGING = 2;
  private static final int TOUCH_MODE_IDLE;
  private final int mMinFlingVelocity;
  private Layout mOffLayout;
  private Layout mOnLayout;
  private int mSwitchBottom;
  private int mSwitchHeight;
  private int mSwitchLeft;
  private final int mSwitchMinWidth;
  private final int mSwitchPadding;
  private int mSwitchRight;
  private int mSwitchTop;
  private int mSwitchWidth;
  private final Rect mTempRect = new Rect();
  private ColorStateList mTextColors;
  private CharSequence mTextOff;
  private CharSequence mTextOn;
  private final TextPaint mTextPaint = new TextPaint(1);
  private final Drawable mThumbDrawable;
  private float mThumbPosition;
  private final int mThumbTextPadding;
  private int mThumbWidth;
  private int mTouchMode;
  private final int mTouchSlop;
  private float mTouchX;
  private float mTouchY;
  private final Drawable mTrackDrawable;
  private final VelocityTracker mVelocityTracker = VelocityTracker.obtain();

  public Switch(Context paramContext)
  {
    this(paramContext, null);
  }

  public Switch(Context paramContext, AttributeSet paramAttributeSet)
  {
    this(paramContext, paramAttributeSet, R.attr.switchStyle);
  }

  public Switch(Context paramContext, AttributeSet paramAttributeSet, int paramInt)
  {
    super(paramContext, paramAttributeSet, paramInt);
    Resources localResources = getResources();
    this.mTextPaint.density = localResources.getDisplayMetrics().density;
    TypedArray localTypedArray = paramContext.obtainStyledAttributes(paramAttributeSet, R.styleable.Switch, paramInt, R.style.Widget_Holo_Light_CompoundButton_Switch);
    this.mThumbDrawable = localTypedArray.getDrawable(0);
    this.mTrackDrawable = localTypedArray.getDrawable(1);
    this.mTextOn = localTypedArray.getText(2);
    this.mTextOff = localTypedArray.getText(3);
    this.mThumbTextPadding = localTypedArray.getDimensionPixelSize(4, 0);
    this.mSwitchMinWidth = localTypedArray.getDimensionPixelSize(6, 0);
    this.mSwitchPadding = localTypedArray.getDimensionPixelSize(7, 0);
    int i = localTypedArray.getResourceId(5, 0);
    if (i != 0)
      setSwitchTextAppearance(paramContext, i);
    localTypedArray.recycle();
    ViewConfiguration localViewConfiguration = ViewConfiguration.get(paramContext);
    this.mTouchSlop = localViewConfiguration.getScaledTouchSlop();
    this.mMinFlingVelocity = localViewConfiguration.getScaledMinimumFlingVelocity();
    refreshDrawableState();
    setChecked(isChecked());
  }

  private void animateThumbToCheckedState(boolean paramBoolean)
  {
    setChecked(paramBoolean);
  }

  private void cancelSuperTouch(MotionEvent paramMotionEvent)
  {
    MotionEvent localMotionEvent = MotionEvent.obtain(paramMotionEvent);
    localMotionEvent.setAction(3);
    super.onTouchEvent(localMotionEvent);
    localMotionEvent.recycle();
  }

  private boolean getTargetCheckedState()
  {
    return this.mThumbPosition >= getThumbScrollRange() / 2;
  }

  private int getThumbScrollRange()
  {
    if (this.mTrackDrawable == null)
      return 0;
    this.mTrackDrawable.getPadding(this.mTempRect);
    return this.mSwitchWidth - this.mThumbWidth - this.mTempRect.left - this.mTempRect.right;
  }

  private boolean hitThumb(float paramFloat1, float paramFloat2)
  {
    this.mThumbDrawable.getPadding(this.mTempRect);
    int i = this.mSwitchTop - this.mTouchSlop;
    int j = this.mSwitchLeft + (int)(0.5F + this.mThumbPosition) - this.mTouchSlop;
    int k = j + this.mThumbWidth + this.mTempRect.left + this.mTempRect.right + this.mTouchSlop;
    int m = this.mSwitchBottom + this.mTouchSlop;
    return (paramFloat1 > j) && (paramFloat1 < k) && (paramFloat2 > i) && (paramFloat2 < m);
  }

  private Layout makeLayout(CharSequence paramCharSequence)
  {
    return new StaticLayout(paramCharSequence, this.mTextPaint, (int)Math.ceil(Layout.getDesiredWidth(paramCharSequence, this.mTextPaint)), Layout.Alignment.ALIGN_NORMAL, 1.0F, 0.0F, true);
  }

  private void setSwitchTypefaceByIndex(int paramInt1, int paramInt2)
  {
    Typeface localTypeface = null;
    switch (paramInt1)
    {
    default:
    case 1:
    case 2:
    case 3:
    }
    while (true)
    {
      setSwitchTypeface(localTypeface, paramInt2);
      return;
      localTypeface = Typeface.SANS_SERIF;
      continue;
      localTypeface = Typeface.SERIF;
      continue;
      localTypeface = Typeface.MONOSPACE;
    }
  }

  private void stopDrag(MotionEvent paramMotionEvent)
  {
    this.mTouchMode = 0;
    int i;
    boolean bool;
    if ((paramMotionEvent.getAction() == 1) && (isEnabled()))
    {
      i = 1;
      cancelSuperTouch(paramMotionEvent);
      if (i == 0)
        break label98;
      this.mVelocityTracker.computeCurrentVelocity(1000);
      float f = this.mVelocityTracker.getXVelocity();
      if (Math.abs(f) <= this.mMinFlingVelocity)
        break label89;
      if (f <= 0.0F)
        break label83;
      bool = true;
    }
    while (true)
    {
      animateThumbToCheckedState(bool);
      return;
      i = 0;
      break;
      label83: bool = false;
      continue;
      label89: bool = getTargetCheckedState();
    }
    label98: animateThumbToCheckedState(isChecked());
  }

  protected void drawableStateChanged()
  {
    super.drawableStateChanged();
    int[] arrayOfInt = getDrawableState();
    if (this.mThumbDrawable != null)
      this.mThumbDrawable.setState(arrayOfInt);
    if (this.mTrackDrawable != null)
      this.mTrackDrawable.setState(arrayOfInt);
    invalidate();
  }

  public int getCompoundPaddingRight()
  {
    int i = super.getCompoundPaddingRight() + this.mSwitchWidth;
    if (!TextUtils.isEmpty(getText()))
      i += this.mSwitchPadding;
    return i;
  }

  public CharSequence getTextOff()
  {
    return this.mTextOff;
  }

  public CharSequence getTextOn()
  {
    return this.mTextOn;
  }

  protected int[] onCreateDrawableState(int paramInt)
  {
    int[] arrayOfInt = super.onCreateDrawableState(paramInt + 1);
    if (isChecked())
      mergeDrawableStates(arrayOfInt, CHECKED_STATE_SET);
    return arrayOfInt;
  }

  protected void onDraw(Canvas paramCanvas)
  {
    super.onDraw(paramCanvas);
    int i = this.mSwitchLeft;
    int j = this.mSwitchTop;
    int k = this.mSwitchRight;
    int m = this.mSwitchBottom;
    this.mTrackDrawable.setBounds(i, j, k, m);
    this.mTrackDrawable.draw(paramCanvas);
    paramCanvas.save();
    this.mTrackDrawable.getPadding(this.mTempRect);
    int n = i + this.mTempRect.left;
    int i1 = j + this.mTempRect.top;
    int i2 = k - this.mTempRect.right;
    int i3 = m - this.mTempRect.bottom;
    paramCanvas.clipRect(n, j, i2, m);
    this.mThumbDrawable.getPadding(this.mTempRect);
    int i4 = (int)(0.5F + this.mThumbPosition);
    int i5 = i4 + (n - this.mTempRect.left);
    int i6 = n + i4 + this.mThumbWidth + this.mTempRect.right;
    this.mThumbDrawable.setBounds(i5, j, i6, m);
    this.mThumbDrawable.draw(paramCanvas);
    if (this.mTextColors != null)
      this.mTextPaint.setColor(this.mTextColors.getColorForState(getDrawableState(), this.mTextColors.getDefaultColor()));
    this.mTextPaint.drawableState = getDrawableState();
    if (getTargetCheckedState());
    for (Layout localLayout = this.mOnLayout; ; localLayout = this.mOffLayout)
    {
      paramCanvas.translate((i5 + i6) / 2 - localLayout.getWidth() / 2, (i1 + i3) / 2 - localLayout.getHeight() / 2);
      localLayout.draw(paramCanvas);
      paramCanvas.restore();
      return;
    }
  }

  protected void onLayout(boolean paramBoolean, int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    super.onLayout(paramBoolean, paramInt1, paramInt2, paramInt3, paramInt4);
    int i;
    int j;
    int k;
    int n;
    int m;
    if (isChecked())
    {
      i = getThumbScrollRange();
      this.mThumbPosition = i;
      j = getWidth() - getPaddingRight();
      k = j - this.mSwitchWidth;
      switch (0x70 & getGravity())
      {
      default:
        n = getPaddingTop();
        m = n + this.mSwitchHeight;
      case 16:
      case 80:
      }
    }
    while (true)
    {
      this.mSwitchLeft = k;
      this.mSwitchTop = n;
      this.mSwitchBottom = m;
      this.mSwitchRight = j;
      return;
      i = 0;
      break;
      n = (getPaddingTop() + getHeight() - getPaddingBottom()) / 2 - this.mSwitchHeight / 2;
      m = n + this.mSwitchHeight;
      continue;
      m = getHeight() - getPaddingBottom();
      n = m - this.mSwitchHeight;
    }
  }

  public void onMeasure(int paramInt1, int paramInt2)
  {
    int i = View.MeasureSpec.getMode(paramInt1);
    int j = View.MeasureSpec.getMode(paramInt2);
    int k = View.MeasureSpec.getSize(paramInt1);
    int m = View.MeasureSpec.getSize(paramInt2);
    if (this.mOnLayout == null)
      this.mOnLayout = makeLayout(this.mTextOn);
    if (this.mOffLayout == null)
      this.mOffLayout = makeLayout(this.mTextOff);
    this.mTrackDrawable.getPadding(this.mTempRect);
    int n = Math.max(this.mOnLayout.getWidth(), this.mOffLayout.getWidth());
    int i1 = Math.max(this.mSwitchMinWidth, n * 2 + 4 * this.mThumbTextPadding + this.mTempRect.left + this.mTempRect.right);
    int i2 = this.mTrackDrawable.getIntrinsicHeight();
    this.mThumbWidth = (n + 2 * this.mThumbTextPadding);
    switch (i)
    {
    default:
      switch (j)
      {
      default:
      case -2147483648:
      case 0:
      }
      break;
    case -2147483648:
    case 0:
    }
    while (true)
    {
      this.mSwitchWidth = i1;
      this.mSwitchHeight = i2;
      super.onMeasure(paramInt1, paramInt2);
      if (getMeasuredHeight() < i2)
        setMeasuredDimension(getMeasuredWidth(), i2);
      return;
      Math.min(k, i1);
      break;
      break;
      Math.min(m, i2);
    }
  }

  public boolean onTouchEvent(MotionEvent paramMotionEvent)
  {
    int i = 1;
    this.mVelocityTracker.addMovement(paramMotionEvent);
    switch (paramMotionEvent.getAction())
    {
    default:
    case 0:
    case 2:
    case 1:
    case 3:
    }
    while (true)
    {
      i = super.onTouchEvent(paramMotionEvent);
      float f1;
      float f2;
      do
      {
        return i;
        float f5 = paramMotionEvent.getX();
        float f6 = paramMotionEvent.getY();
        if ((!isEnabled()) || (!hitThumb(f5, f6)))
          break;
        this.mTouchMode = i;
        this.mTouchX = f5;
        this.mTouchY = f6;
        break;
        switch (this.mTouchMode)
        {
        case 0:
        default:
          break;
        case 1:
          float f3 = paramMotionEvent.getX();
          float f4 = paramMotionEvent.getY();
          if ((Math.abs(f3 - this.mTouchX) <= this.mTouchSlop) && (Math.abs(f4 - this.mTouchY) <= this.mTouchSlop))
            break;
          this.mTouchMode = 2;
          getParent().requestDisallowInterceptTouchEvent(i);
          this.mTouchX = f3;
          this.mTouchY = f4;
          return i;
        case 2:
          f1 = paramMotionEvent.getX();
          f2 = Math.max(0.0F, Math.min(f1 - this.mTouchX + this.mThumbPosition, getThumbScrollRange()));
        }
      }
      while (f2 == this.mThumbPosition);
      this.mThumbPosition = f2;
      this.mTouchX = f1;
      invalidate();
      return i;
      if (this.mTouchMode == 2)
      {
        stopDrag(paramMotionEvent);
        return i;
      }
      this.mTouchMode = 0;
      this.mVelocityTracker.clear();
    }
  }

  public void setChecked(boolean paramBoolean)
  {
    super.setChecked(paramBoolean);
    if (paramBoolean);
    for (int i = getThumbScrollRange(); ; i = 0)
    {
      this.mThumbPosition = i;
      invalidate();
      return;
    }
  }

  public void setSwitchTextAppearance(Context paramContext, int paramInt)
  {
    TypedArray localTypedArray = paramContext.obtainStyledAttributes(paramInt, R.styleable.Android);
    ColorStateList localColorStateList = localTypedArray.getColorStateList(3);
    if (localColorStateList != null);
    for (this.mTextColors = localColorStateList; ; this.mTextColors = getTextColors())
    {
      int i = localTypedArray.getDimensionPixelSize(0, 0);
      if ((i != 0) && (i != this.mTextPaint.getTextSize()))
      {
        this.mTextPaint.setTextSize(i);
        requestLayout();
      }
      setSwitchTypefaceByIndex(localTypedArray.getInt(1, -1), localTypedArray.getInt(2, -1));
      localTypedArray.recycle();
      return;
    }
  }

  public void setSwitchTypeface(Typeface paramTypeface)
  {
    if (this.mTextPaint.getTypeface() != paramTypeface)
    {
      this.mTextPaint.setTypeface(paramTypeface);
      requestLayout();
      invalidate();
    }
  }

  public void setSwitchTypeface(Typeface paramTypeface, int paramInt)
  {
    if (paramInt > 0)
    {
      Typeface localTypeface;
      int i;
      label28: TextPaint localTextPaint2;
      if (paramTypeface == null)
      {
        localTypeface = Typeface.defaultFromStyle(paramInt);
        setSwitchTypeface(localTypeface);
        if (localTypeface == null)
          break label101;
        i = localTypeface.getStyle();
        int j = paramInt & (i ^ 0xFFFFFFFF);
        TextPaint localTextPaint1 = this.mTextPaint;
        int k = j & 0x1;
        boolean bool = false;
        if (k != 0)
          bool = true;
        localTextPaint1.setFakeBoldText(bool);
        localTextPaint2 = this.mTextPaint;
        if ((j & 0x2) == 0)
          break label107;
      }
      label101: label107: for (float f = -0.25F; ; f = 0.0F)
      {
        localTextPaint2.setTextSkewX(f);
        return;
        localTypeface = Typeface.create(paramTypeface, paramInt);
        break;
        i = 0;
        break label28;
      }
    }
    this.mTextPaint.setFakeBoldText(false);
    this.mTextPaint.setTextSkewX(0.0F);
    setSwitchTypeface(paramTypeface);
  }

  public void setTextOff(CharSequence paramCharSequence)
  {
    this.mTextOff = paramCharSequence;
    requestLayout();
  }

  public void setTextOn(CharSequence paramCharSequence)
  {
    this.mTextOn = paramCharSequence;
    requestLayout();
  }

  protected boolean verifyDrawable(Drawable paramDrawable)
  {
    return (super.verifyDrawable(paramDrawable)) || (paramDrawable == this.mThumbDrawable) || (paramDrawable == this.mTrackDrawable);
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     org.jraf.android.backport.switchwidget.Switch
 * JD-Core Version:    0.6.2
 */