package org.jraf.android.backport.switchwidget;

import android.content.Context;
import android.content.res.TypedArray;
import android.os.Parcel;
import android.os.Parcelable;
import android.os.Parcelable.Creator;
import android.preference.Preference;
import android.preference.Preference.BaseSavedState;
import android.util.AttributeSet;
import android.view.View;
import android.widget.TextView;

public abstract class TwoStatePreference extends Preference
{
  boolean mChecked;
  private boolean mDisableDependentsState;
  private CharSequence mSummaryOff;
  private CharSequence mSummaryOn;

  public TwoStatePreference(Context paramContext)
  {
    this(paramContext, null);
  }

  public TwoStatePreference(Context paramContext, AttributeSet paramAttributeSet)
  {
    this(paramContext, paramAttributeSet, 0);
  }

  public TwoStatePreference(Context paramContext, AttributeSet paramAttributeSet, int paramInt)
  {
    super(paramContext, paramAttributeSet, paramInt);
  }

  public boolean getDisableDependentsState()
  {
    return this.mDisableDependentsState;
  }

  public CharSequence getSummaryOff()
  {
    return this.mSummaryOff;
  }

  public CharSequence getSummaryOn()
  {
    return this.mSummaryOn;
  }

  public boolean isChecked()
  {
    return this.mChecked;
  }

  protected void onClick()
  {
    super.onClick();
    if (isChecked());
    for (boolean bool = false; !callChangeListener(Boolean.valueOf(bool)); bool = true)
      return;
    setChecked(bool);
  }

  protected Object onGetDefaultValue(TypedArray paramTypedArray, int paramInt)
  {
    return Boolean.valueOf(paramTypedArray.getBoolean(paramInt, false));
  }

  protected void onRestoreInstanceState(Parcelable paramParcelable)
  {
    if ((paramParcelable == null) || (!paramParcelable.getClass().equals(SavedState.class)))
    {
      super.onRestoreInstanceState(paramParcelable);
      return;
    }
    SavedState localSavedState = (SavedState)paramParcelable;
    super.onRestoreInstanceState(localSavedState.getSuperState());
    setChecked(localSavedState.checked);
  }

  protected Parcelable onSaveInstanceState()
  {
    Parcelable localParcelable = super.onSaveInstanceState();
    if (isPersistent())
      return localParcelable;
    SavedState localSavedState = new SavedState(localParcelable);
    localSavedState.checked = isChecked();
    return localSavedState;
  }

  protected void onSetInitialValue(boolean paramBoolean, Object paramObject)
  {
    if (paramBoolean);
    for (boolean bool = getPersistedBoolean(this.mChecked); ; bool = ((Boolean)paramObject).booleanValue())
    {
      setChecked(bool);
      return;
    }
  }

  public void setChecked(boolean paramBoolean)
  {
    if (this.mChecked != paramBoolean)
    {
      this.mChecked = paramBoolean;
      persistBoolean(paramBoolean);
      notifyDependencyChange(shouldDisableDependents());
      notifyChanged();
    }
  }

  public void setDisableDependentsState(boolean paramBoolean)
  {
    this.mDisableDependentsState = paramBoolean;
  }

  public void setSummaryOff(int paramInt)
  {
    setSummaryOff(getContext().getString(paramInt));
  }

  public void setSummaryOff(CharSequence paramCharSequence)
  {
    this.mSummaryOff = paramCharSequence;
    if (!isChecked())
      notifyChanged();
  }

  public void setSummaryOn(int paramInt)
  {
    setSummaryOn(getContext().getString(paramInt));
  }

  public void setSummaryOn(CharSequence paramCharSequence)
  {
    this.mSummaryOn = paramCharSequence;
    if (isChecked())
      notifyChanged();
  }

  public boolean shouldDisableDependents()
  {
    boolean bool;
    if (this.mDisableDependentsState)
      bool = this.mChecked;
    while ((!bool) && (!super.shouldDisableDependents()))
    {
      return false;
      if (this.mChecked)
        bool = false;
      else
        bool = true;
    }
    return true;
  }

  void syncSummaryView(View paramView)
  {
    TextView localTextView = (TextView)paramView.findViewById(16908304);
    if (localTextView != null)
    {
      i = 1;
      if ((!this.mChecked) || (this.mSummaryOn == null))
        break label90;
      localTextView.setText(this.mSummaryOn);
    }
    for (int i = 0; ; i = 0)
    {
      label90: 
      do
      {
        if (i != 0)
        {
          CharSequence localCharSequence = getSummary();
          if (localCharSequence != null)
          {
            localTextView.setText(localCharSequence);
            i = 0;
          }
        }
        int j = 8;
        if (i == 0)
          j = 0;
        if (j != localTextView.getVisibility())
          localTextView.setVisibility(j);
        return;
      }
      while ((this.mChecked) || (this.mSummaryOff == null));
      localTextView.setText(this.mSummaryOff);
    }
  }

  static class SavedState extends Preference.BaseSavedState
  {
    public static final Parcelable.Creator<SavedState> CREATOR = new Parcelable.Creator()
    {
      public TwoStatePreference.SavedState createFromParcel(Parcel paramAnonymousParcel)
      {
        return new TwoStatePreference.SavedState(paramAnonymousParcel);
      }

      public TwoStatePreference.SavedState[] newArray(int paramAnonymousInt)
      {
        return new TwoStatePreference.SavedState[paramAnonymousInt];
      }
    };
    boolean checked;

    public SavedState(Parcel paramParcel)
    {
      super();
      if (paramParcel.readInt() == i);
      while (true)
      {
        this.checked = i;
        return;
        i = 0;
      }
    }

    public SavedState(Parcelable paramParcelable)
    {
      super();
    }

    public void writeToParcel(Parcel paramParcel, int paramInt)
    {
      super.writeToParcel(paramParcel, paramInt);
      if (this.checked);
      for (int i = 1; ; i = 0)
      {
        paramParcel.writeInt(i);
        return;
      }
    }
  }
}

/* Location:           /tmp/apk/wickr/classes_dex2jar.jar
 * Qualified Name:     org.jraf.android.backport.switchwidget.TwoStatePreference
 * JD-Core Version:    0.6.2
 */